// Copyright 2018, Google Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#pragma warning disable 1591
namespace Google.Api.Ads.AdManager.v201802
{
	using System.ComponentModel;
	using System;
	using Google.Api.Ads.AdManager.Lib;
	using Google.Api.Ads.AdManager.Headers;

	/// <summary>Exception class for holding a list of service errors.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ApiException : ApplicationException {
		private ApiError[] errorsField;

		/// <summary>List of errors.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("errors", Order = 0)]
		public ApiError[] errors {
			get {
				return this.errorsField;
			}
			set {
				this.errorsField = value;
			}
		}
	}


	/// <summary>The API error base class that provides details about an error that occurred
	/// while processing a service request. <p>The OGNL field path is provided for
	/// parsers to identify the request data element that may have caused the error.</p>
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UniqueError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(StringLengthError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(StringFormatError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(StatementError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ServerError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RequiredError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RequiredCollectionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RangeError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(QuotaError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(PublisherQueryLanguageSyntaxError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(PublisherQueryLanguageContextError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(PermissionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ParseError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(NotNullError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(InternalApiError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(FeatureError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CommonError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CollectionSizeError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AuthenticationError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ApiVersionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivityError))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RequiredNumberError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ContentMetadataKeyHierarchyError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(TypeError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(InvalidUrlError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(TemplateInstantiatedCreativeError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SwiffyConversionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SetTopBoxCreativeError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RichMediaStudioCreativeError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RequiredSizeError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(NullError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(LineItemCreativeAssociationError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(LabelEntityAssociationError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(InvalidPhoneNumberError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ImageError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(HtmlBundleProcessorError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(FileError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(EntityLimitReachedError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CustomFieldValueError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CustomCreativeError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CreativeTemplateOperationError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CreativeTemplateError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CreativeSetError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CreativeError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CreativeAssetMacroError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AssetError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(LabelError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CreativeWrapperError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(EntityChildrenLimitReachedError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CustomTargetingError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CustomFieldError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ExchangeRateError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(VideoPositionTargetingError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UserDomainTargetingError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(TimeZoneError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(TechnologyTargetingError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(TeamError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SetTopBoxLineItemError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AudienceSegmentError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ReservationDetailsError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RegExError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProgrammaticError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(OrderError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(OrderActionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(LineItemOperationError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(LineItemFlightDateError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(LineItemError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(LineItemActivityAssociationError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(InventoryUnitError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(InventoryTargetingError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(GrpSettingsError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(GeoTargetingError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(GenericTargetingError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(FrequencyCapError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ForecastError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DayPartTargetingError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DateTimeRangeTargetingError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CrossSellError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ContentMetadataTargetingError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CompanyCreditStatusError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ClickTrackingLineItemError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AudienceExtensionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AdUnitCodeError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AdRuleSlotError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(InventoryUnitSizesError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(InventoryUnitRefreshRateError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(InvalidColorError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CompanyError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AdUnitHierarchyError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AdSenseAccountError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(LineItemCreativeAssociationOperationError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CreativePreviewError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SamSessionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(LiveStreamEventDateTimeError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(LiveStreamEventCdnSettingsError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(LiveStreamEventActionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(MobileApplicationError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(MobileApplicationActionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RequestError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(PrecisionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(NetworkError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(InvalidEmailError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(PlacementError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AdExclusionRuleError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(PremiumRateError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProgrammaticProductError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProgrammaticEntitiesError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProductError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProductActionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(PreferredDealError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(NonProgrammaticProductError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BaseRateError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProductTemplateError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProductTemplateActionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(WorkflowValidationError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(WorkflowActionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProposalLineItemProgrammaticError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProposalLineItemError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProposalError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProposalActionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(PackageError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(PackageActionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DealError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BillingError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AvailableBillingError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProposalLineItemActionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RateCardError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RateCardActionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ReconciliationError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ReconciliationImportError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(PoddingError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AdRuleTargetingError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AdRulePriorityError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AdRuleFrequencyCapError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AdRuleDateError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ReportError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CurrencyCodeError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(TokenError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(WorkflowRequestError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProductPackageRateCardAssociationError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProductPackageItemError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProductPackageActionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProductPackageItemActionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ContactError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(NativeStyleError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BaseRateActionError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CdnConfigurationError))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ContentFilterError))]
	public abstract partial class ApiError {
		private string fieldPathField;

		private FieldPathElement[] fieldPathElementsField;

		private string triggerField;

		private string errorStringField;

		/// <summary>The OGNL field path to identify cause of error.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string fieldPath {
			get {
				return this.fieldPathField;
			}
			set {
				this.fieldPathField = value;
			}
		}

		/// <summary>A parsed copy of the field path. For example, the field path
		/// "operations[1].operand" corresponds to this list: {FieldPathElement(field =
		/// "operations", index = 1), FieldPathElement(field = "operand", index = null)}.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("fieldPathElements", Order = 1)]
		public FieldPathElement[] fieldPathElements {
			get {
				return this.fieldPathElementsField;
			}
			set {
				this.fieldPathElementsField = value;
			}
		}

		/// <summary>The data that caused the error.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string trigger {
			get {
				return this.triggerField;
			}
			set {
				this.triggerField = value;
			}
		}

		/// <summary>A simple string representation of the error and reason.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string errorString {
			get {
				return this.errorStringField;
			}
			set {
				this.errorStringField = value;
			}
		}
	}


	/// <summary>A segment of a field path. Each dot in a field path defines a new segment.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class FieldPathElement {
		private string fieldField;

		private int indexField;

		private bool indexFieldSpecified;

		/// <summary>The name of a field in lower camelcase. (e.g. "biddingStrategy")
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string field {
			get {
				return this.fieldField;
			}
			set {
				this.fieldField = value;
			}
		}

		/// <summary>For list fields, this is a 0-indexed position in the list. Null for non-list
		/// fields.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int index {
			get {
				return this.indexField;
			}
			set {
				this.indexField = value;
				this.indexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="index" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool indexSpecified {
			get {
				return this.indexFieldSpecified;
			}
			set {
				this.indexFieldSpecified = value;
			}
		}
	}


	/// <summary>Base class for exceptions.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ApiException))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ApplicationException {
		private string messageField;

		/// <summary>Error message.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string message {
			get {
				return this.messageField;
			}
			set {
				this.messageField = value;
			}
		}
	}


	/// <summary>Activities are organized within activity groups, which are sets of activities
	/// that share the same configuration. You create and manage activities from within
	/// activity groups.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivityGroup {
		private int idField;

		private bool idFieldSpecified;

		private string nameField;

		private long[] companyIdsField;

		private int impressionsLookbackField;

		private bool impressionsLookbackFieldSpecified;

		private int clicksLookbackField;

		private bool clicksLookbackFieldSpecified;

		private ActivityGroupStatus statusField;

		private bool statusFieldSpecified;

		/// <summary>The unique ID of the <code>ActivityGroup</code>. This attribute is readonly and
		/// is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the <code>ActivityGroup</code>. This attribute is required to create
		/// an activity group and has a maximum length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The company ids whose ads will be included for conversion tracking on the
		/// activities in this group. Only clicks and impressions of ads from these
		/// companies will lead to conversions on the containing activities. This attribute
		/// is required when creating an activity group. The company types allowed are: <a
		/// href='Company.Type#ADVERTISER'>Company.Type#ADVERTISER</a>, and <a
		/// href='Company.Type#AD_NETWORK'>Company.Type#AD_NETWORK</a>, and <a
		/// href='Company.Type#HOUSE_ADVERTISER'>Company.Type#HOUSE_ADVERTISER</a>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("companyIds", Order = 2)]
		public long[] companyIds {
			get {
				return this.companyIdsField;
			}
			set {
				this.companyIdsField = value;
			}
		}

		/// <summary>Ad Manager records view-through conversions for users who have previously viewed
		/// an Ad Manager ad within the number of days that you set here (1 to 30 days),
		/// then visits a webpage containing activity tags from this activity group. To be
		/// counted, the ad needs to belong to one of the companies associated with the
		/// activity group. This attribute is required to create an activity group.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public int impressionsLookback {
			get {
				return this.impressionsLookbackField;
			}
			set {
				this.impressionsLookbackField = value;
				this.impressionsLookbackSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="impressionsLookback" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool impressionsLookbackSpecified {
			get {
				return this.impressionsLookbackFieldSpecified;
			}
			set {
				this.impressionsLookbackFieldSpecified = value;
			}
		}

		/// <summary>Ad Manager records click-through conversions for users who have previously
		/// clicked on an Ad Manager ad within the number of days that you set here (1 to 30
		/// days), then visits a webpage containing activity tags from this activity group.
		/// To be counted, the ad needs to belong to one of the companies associated with
		/// the activity group. This attribute is required to create an activity group.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public int clicksLookback {
			get {
				return this.clicksLookbackField;
			}
			set {
				this.clicksLookbackField = value;
				this.clicksLookbackSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="clicksLookback" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool clicksLookbackSpecified {
			get {
				return this.clicksLookbackFieldSpecified;
			}
			set {
				this.clicksLookbackFieldSpecified = value;
			}
		}

		/// <summary>The status of this activity group. This attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public ActivityGroupStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}
	}


	/// <summary>The activity group status.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ActivityGroup.Status", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ActivityGroupStatus {
		ACTIVE = 0,
		INACTIVE = 1,
	}


	/// <summary>An error for a field which must satisfy a uniqueness constraint
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UniqueError : ApiError {
	}


	/// <summary>Errors for Strings which do not meet given length constraints.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class StringLengthError : ApiError {
		private StringLengthErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public StringLengthErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "StringLengthError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum StringLengthErrorReason {
		TOO_LONG = 0,
		TOO_SHORT = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>A list of error code for reporting invalid content of input strings.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class StringFormatError : ApiError {
		private StringFormatErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public StringFormatErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "StringFormatError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum StringFormatErrorReason {
		UNKNOWN = 0,
		/// <summary>The input string value contains disallowed characters.
		/// </summary>
		ILLEGAL_CHARS = 1,
		/// <summary>The input string value is invalid for the associated field.
		/// </summary>
		INVALID_FORMAT = 2,
	}


	/// <summary>An error that occurs while parsing <a href='Statement'>Statement</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class StatementError : ApiError {
		private StatementErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public StatementErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "StatementError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum StatementErrorReason {
		/// <summary>A bind variable has not been bound to a value.
		/// </summary>
		VARIABLE_NOT_BOUND_TO_VALUE = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>Errors related to the server.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ServerError : ApiError {
		private ServerErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ServerErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes reasons for server errors
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ServerError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ServerErrorReason {
		/// <summary>Indicates that an unexpected error occured.
		/// </summary>
		SERVER_ERROR = 0,
		/// <summary>Indicates that the server is currently experiencing a high load. Please wait and
		/// try your request again.
		/// </summary>
		SERVER_BUSY = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Errors due to missing required field.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RequiredError : ApiError {
		private RequiredErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public RequiredErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "RequiredError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RequiredErrorReason {
		/// <summary>Missing required field.
		/// </summary>
		REQUIRED = 0,
	}


	/// <summary>A list of all errors to be used for validating sizes of collections.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RequiredCollectionError : ApiError {
		private RequiredCollectionErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public RequiredCollectionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "RequiredCollectionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RequiredCollectionErrorReason {
		/// <summary>A required collection is missing.
		/// </summary>
		REQUIRED = 0,
		/// <summary>Collection size is too large.
		/// </summary>
		TOO_LARGE = 1,
		/// <summary>Collection size is too small.
		/// </summary>
		TOO_SMALL = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>A list of all errors associated with the Range constraint.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RangeError : ApiError {
		private RangeErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public RangeErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "RangeError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RangeErrorReason {
		TOO_HIGH = 0,
		TOO_LOW = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Describes a client-side error on which a user is attempting to perform an action
	/// to which they have no quota remaining.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class QuotaError : ApiError {
		private QuotaErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public QuotaErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "QuotaError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum QuotaErrorReason {
		/// <summary>The number of requests made per second is too high and has exceeded the
		/// allowable limit. The recommended approach to handle this error is to wait about
		/// 5 seconds and then retry the request. Note that this does not guarantee the
		/// request will succeed. If it fails again, try increasing the wait time.
		/// <p>Another way to mitigate this error is to limit requests to 8 per second for
		/// Ad Manager 360 accounts, or 2 per second for Ad Manager accounts. Once again
		/// this does not guarantee that every request will succeed, but may help reduce the
		/// number of times you receive this error.</p>
		/// </summary>
		EXCEEDED_QUOTA = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
		/// <summary>This user has exceeded the allowed number of new report requests per hour (this
		/// includes both reports run via the UI and reports run via <a
		/// href='ReportService#runReportJob'>ReportService#runReportJob</a>). The
		/// recommended approach to handle this error is to wait about 10 minutes and then
		/// retry the request. Note that this does not guarantee the request will succeed.
		/// If it fails again, try increasing the wait time. <p>Another way to mitigate this
		/// error is to limit the number of new report requests to 250 per hour per user.
		/// Once again, this does not guarantee that every request will succeed, but may
		/// help reduce the number of times you receive this error.</p>
		/// </summary>
		REPORT_JOB_LIMIT = 2,
	}


	/// <summary>An error that occurs while parsing a PQL query contained in a <a
	/// href='Statement'>Statement</a> object.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PublisherQueryLanguageSyntaxError : ApiError {
		private PublisherQueryLanguageSyntaxErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public PublisherQueryLanguageSyntaxErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "PublisherQueryLanguageSyntaxError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum PublisherQueryLanguageSyntaxErrorReason {
		/// <summary>Indicates that there was a PQL syntax error.
		/// </summary>
		UNPARSABLE = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>An error that occurs while executing a PQL query contained in a <a
	/// href='Statement'>Statement</a> object.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PublisherQueryLanguageContextError : ApiError {
		private PublisherQueryLanguageContextErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public PublisherQueryLanguageContextErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "PublisherQueryLanguageContextError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum PublisherQueryLanguageContextErrorReason {
		/// <summary>Indicates that there was an error executing the PQL.
		/// </summary>
		UNEXECUTABLE = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>Errors related to incorrect permission.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PermissionError : ApiError {
		private PermissionErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public PermissionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes reasons for permission errors.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "PermissionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum PermissionErrorReason {
		/// <summary>User does not have the required permission for the request.
		/// </summary>
		PERMISSION_DENIED = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>Lists errors related to parsing.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ParseError : ApiError {
		private ParseErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ParseErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ParseError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ParseErrorReason {
		/// <summary>Indicates an error in parsing an attribute.
		/// </summary>
		UNPARSABLE = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>Caused by supplying a null value for an attribute that cannot be null.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class NotNullError : ApiError {
		private NotNullErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public NotNullErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "NotNullError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum NotNullErrorReason {
		/// <summary>Assuming that a method will not have more than 3 arguments, if it does, return
		/// NULL
		/// </summary>
		ARG1_NULL = 0,
		ARG2_NULL = 1,
		ARG3_NULL = 2,
		NULL = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>Indicates that a server-side error has occured. <code></code>s are generally not
	/// the result of an invalid request or message sent by the client.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class InternalApiError : ApiError {
		private InternalApiErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public InternalApiErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The single reason for the internal API error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "InternalApiError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum InternalApiErrorReason {
		/// <summary>API encountered an unexpected internal error.
		/// </summary>
		UNEXPECTED_INTERNAL_API_ERROR = 0,
		/// <summary>A temporary error occurred during the request. Please retry.
		/// </summary>
		TRANSIENT_ERROR = 1,
		/// <summary>The cause of the error is not known or only defined in newer versions.
		/// </summary>
		UNKNOWN = 2,
		/// <summary>The API is currently unavailable for a planned downtime.
		/// </summary>
		DOWNTIME = 3,
		/// <summary>Mutate succeeded but server was unable to build response. Client should not
		/// retry mutate.
		/// </summary>
		ERROR_GENERATING_RESPONSE = 4,
	}


	/// <summary>Errors related to feature management. If you attempt using a feature that is not
	/// available to the current network you'll receive a FeatureError with the missing
	/// feature as the trigger.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class FeatureError : ApiError {
		private FeatureErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public FeatureErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "FeatureError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum FeatureErrorReason {
		/// <summary>A feature is being used that is not enabled on the current network.
		/// </summary>
		MISSING_FEATURE = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>A place for common errors that can be used across services.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CommonError : ApiError {
		private CommonErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CommonErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes reasons for common errors
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CommonError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CommonErrorReason {
		/// <summary>Indicates that an attempt was made to retrieve an entity that does not exist.
		/// </summary>
		NOT_FOUND = 0,
		/// <summary>Indicates that an attempt was made to create an entity that already exists.
		/// </summary>
		ALREADY_EXISTS = 1,
		/// <summary>Indicates that a value is not applicable for given use case.
		/// </summary>
		NOT_APPLICABLE = 6,
		/// <summary>Indicates that two elements in the collection were identical.
		/// </summary>
		DUPLICATE_OBJECT = 2,
		/// <summary>Indicates that an attempt was made to change an immutable field.
		/// </summary>
		CANNOT_UPDATE = 3,
		/// <summary>Indicates that another request attempted to update the same data in the same
		/// network at about the same time. Please wait and try the request again.
		/// </summary>
		CONCURRENT_MODIFICATION = 4,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 5,
	}


	/// <summary>Error for the size of the collection being too large
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CollectionSizeError : ApiError {
		private CollectionSizeErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CollectionSizeErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CollectionSizeError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CollectionSizeErrorReason {
		TOO_LARGE = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>An error for an exception that occurred when authenticating.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AuthenticationError : ApiError {
		private AuthenticationErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AuthenticationErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AuthenticationError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AuthenticationErrorReason {
		/// <summary>The SOAP message contains a request header with an ambiguous definition of the
		/// authentication header fields. This means either the <code>authToken</code> and
		/// <code>oAuthToken</code> fields were both null or both were specified. Exactly
		/// one value should be specified with each request.
		/// </summary>
		AMBIGUOUS_SOAP_REQUEST_HEADER = 0,
		/// <summary>The login provided is invalid.
		/// </summary>
		INVALID_EMAIL = 1,
		/// <summary>Tried to authenticate with provided information, but failed.
		/// </summary>
		AUTHENTICATION_FAILED = 2,
		/// <summary>The OAuth provided is invalid.
		/// </summary>
		INVALID_OAUTH_SIGNATURE = 3,
		/// <summary>The specified service to use was not recognized.
		/// </summary>
		INVALID_SERVICE = 4,
		/// <summary>The SOAP message is missing a request header with an <code></code> and optional
		/// <code>networkCode</code>.
		/// </summary>
		MISSING_SOAP_REQUEST_HEADER = 5,
		/// <summary>The HTTP request is missing a request header with an <code></code>
		/// </summary>
		MISSING_AUTHENTICATION_HTTP_HEADER = 6,
		/// <summary>The request is missing an <code>authToken</code>
		/// </summary>
		MISSING_AUTHENTICATION = 7,
		/// <summary>The customer is not whitelisted for API access.
		/// </summary>
		NOT_WHITELISTED_FOR_API_ACCESS = 8,
		/// <summary>The user is not associated with any network.
		/// </summary>
		NO_NETWORKS_TO_ACCESS = 9,
		/// <summary>No network for the given <code>networkCode</code> was found.
		/// </summary>
		NETWORK_NOT_FOUND = 10,
		/// <summary>The user has access to more than one network, but did not provide a
		/// <code>networkCode</code>.
		/// </summary>
		NETWORK_CODE_REQUIRED = 11,
		/// <summary>An error happened on the server side during connection to authentication
		/// service.
		/// </summary>
		CONNECTION_ERROR = 12,
		/// <summary>The user tried to create a test network using an account that already is
		/// associated with a network.
		/// </summary>
		GOOGLE_ACCOUNT_ALREADY_ASSOCIATED_WITH_NETWORK = 13,
		/// <summary>The account is blocked and under investigation by the collections team. Please
		/// contact Google for more information.
		/// </summary>
		UNDER_INVESTIGATION = 15,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 14,
	}


	/// <summary>Errors related to the usage of API versions.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ApiVersionError : ApiError {
		private ApiVersionErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ApiVersionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ApiVersionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ApiVersionErrorReason {
		/// <summary>Indicates that the operation is not allowed in the version the request was made
		/// in.
		/// </summary>
		UPDATE_TO_NEWER_VERSION = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>Errors relating to Activity and Activity Group services.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivityError : ApiError {
		private ActivityErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ActivityErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ActivityError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ActivityErrorReason {
		/// <summary>The 'activities' feature is required but not enabled.
		/// </summary>
		ACTIVITIES_FEATURE_REQUIRED = 0,
		/// <summary>Activity group cannot be associated with the company types.
		/// </summary>
		UNSUPPORTED_COMPANY_TYPE = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>Captures the <code>WHERE</code>, <code>ORDER BY</code> and <code>LIMIT</code>
	/// clauses of a PQL query. Statements are typically used to retrieve objects of a
	/// predefined domain type, which makes SELECT clause unnecessary. <p>An example
	/// query text might be <code>"WHERE status = 'ACTIVE' ORDER BY id LIMIT
	/// 30"</code>.</p> <p>Statements support bind variables. These are substitutes for
	/// literals and can be thought of as input parameters to a PQL query.</p> <p>An
	/// example of such a query might be <code>"WHERE id = :idValue"</code>.</p>
	/// <p>Statements also support use of the LIKE keyword. This provides partial and
	/// wildcard string matching.</p> <p>An example of such a query might be
	/// <code>"WHERE name LIKE 'startswith%'"</code>.</p> The value for the variable
	/// idValue must then be set with an object of type <a href='Value'>Value</a>, e.g.,
	/// <a href='NumberValue'>NumberValue</a>, <a href='TextValue'>TextValue</a> or <a
	/// href='BooleanValue'>BooleanValue</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Statement {
		private string queryField;

		private String_ValueMapEntry[] valuesField;

		/// <summary>Holds the query in PQL syntax. The syntax is:<br /> <code>[WHERE
		/// &lt;condition&gt; {[AND | OR] &lt;condition&gt; ...}]</code><br /> <code>[ORDER
		/// BY &lt;property&gt; [ASC | DESC]]</code><br /> <code>[LIMIT {[&lt;offset&gt;,]
		/// &lt;count&gt;} | {&lt;count&gt; OFFSET &lt;offset&gt;}]</code><br />
		/// <p><code>&lt;condition&gt;</code><br /> #x160;#x160;#x160;#x160; <code>:=
		/// &lt;property&gt; {&lt; | &lt;= | &gt; | &gt;= | = | != } &lt;value&gt;</code><br
		/// /> <code>&lt;condition&gt;</code><br /> #x160;#x160;#x160;#x160; <code>:=
		/// &lt;property&gt; {&lt; | &lt;= | &gt; | &gt;= | = | != } &lt;bind
		/// variable&gt;</code><br /> <code>&lt;condition&gt; := &lt;property&gt; IN
		/// &lt;list&gt;</code><br /> <code>&lt;condition&gt; := &lt;property&gt; IS
		/// NULL</code><br /> <code>&lt;condition&gt; := &lt;property&gt; LIKE
		/// &lt;wildcard%match&gt;</code><br /> <code>&lt;bind variable&gt; :=
		/// :&lt;name&gt;</code><br /> </p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string query {
			get {
				return this.queryField;
			}
			set {
				this.queryField = value;
			}
		}

		/// <summary>Holds keys and values for bind variables and their values. The key is the name
		/// of the bind variable. The value is the literal value of the variable. <p>In the
		/// example <code>"WHERE status = :bindStatus ORDER BY id LIMIT 30"</code>, the bind
		/// variable, represented by <code>:bindStatus</code> is named
		/// <code>bindStatus</code>, which would also be the parameter map key. The bind
		/// variable's value would be represented by a parameter map value of type <a
		/// href='TextValue'>TextValue</a>. The final result, for example, would be an entry
		/// of <code>"bindStatus" =&gt; StringParam("ACTIVE")</code>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("values", Order = 1)]
		public String_ValueMapEntry[] values {
			get {
				return this.valuesField;
			}
			set {
				this.valuesField = value;
			}
		}
	}


	/// <summary>This represents an entry in a map with a key of type String and value of type
	/// Value.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class String_ValueMapEntry {
		private string keyField;

		private Value valueField;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string key {
			get {
				return this.keyField;
			}
			set {
				this.keyField = value;
			}
		}

		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public Value value {
			get {
				return this.valueField;
			}
			set {
				this.valueField = value;
			}
		}
	}


	/// <summary><code>Value</code> represents a value.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(TextValue))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SetValue))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(NumberValue))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DateValue))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DateTimeValue))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BooleanValue))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ObjectValue))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(TargetingValue))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ChangeHistoryValue))]
	public abstract partial class Value {
	}


	/// <summary>Contains a string value.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class TextValue : Value {
		private string valueField;

		/// <summary>The string value.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string value {
			get {
				return this.valueField;
			}
			set {
				this.valueField = value;
			}
		}
	}


	/// <summary>Contains a set of <a href='Value'>Values</a>. May not contain duplicates.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SetValue : Value {
		private Value[] valuesField;

		/// <summary>The values. They must all be the same type of <code>Value</code> and not contain
		/// duplicates.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("values", Order = 0)]
		public Value[] values {
			get {
				return this.valuesField;
			}
			set {
				this.valuesField = value;
			}
		}
	}


	/// <summary>Contains a numeric value.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class NumberValue : Value {
		private string valueField;

		/// <summary>The numeric value represented as a string.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string value {
			get {
				return this.valueField;
			}
			set {
				this.valueField = value;
			}
		}
	}


	/// <summary>Contains a date value.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DateValue : Value {
		private Date valueField;

		/// <summary>The <code>Date</code> value.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public Date value {
			get {
				return this.valueField;
			}
			set {
				this.valueField = value;
			}
		}
	}


	/// <summary>Represents a date.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Date {
		private int yearField;

		private bool yearFieldSpecified;

		private int monthField;

		private bool monthFieldSpecified;

		private int dayField;

		private bool dayFieldSpecified;

		/// <summary>Year (e.g., 2009)
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int year {
			get {
				return this.yearField;
			}
			set {
				this.yearField = value;
				this.yearSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="year" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool yearSpecified {
			get {
				return this.yearFieldSpecified;
			}
			set {
				this.yearFieldSpecified = value;
			}
		}

		/// <summary>Month (1..12)
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int month {
			get {
				return this.monthField;
			}
			set {
				this.monthField = value;
				this.monthSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="month" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool monthSpecified {
			get {
				return this.monthFieldSpecified;
			}
			set {
				this.monthFieldSpecified = value;
			}
		}

		/// <summary>Day (1..31)
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public int day {
			get {
				return this.dayField;
			}
			set {
				this.dayField = value;
				this.daySpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="day" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool daySpecified {
			get {
				return this.dayFieldSpecified;
			}
			set {
				this.dayFieldSpecified = value;
			}
		}
	}


	/// <summary>Contains a date-time value.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DateTimeValue : Value {
		private DateTime valueField;

		/// <summary>The <code>DateTime</code> value.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public DateTime value {
			get {
				return this.valueField;
			}
			set {
				this.valueField = value;
			}
		}
	}


	/// <summary>Represents a date combined with the time of day.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DateTime {
		private Date dateField;

		private int hourField;

		private bool hourFieldSpecified;

		private int minuteField;

		private bool minuteFieldSpecified;

		private int secondField;

		private bool secondFieldSpecified;

		private string timeZoneIDField;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public Date date {
			get {
				return this.dateField;
			}
			set {
				this.dateField = value;
			}
		}

		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int hour {
			get {
				return this.hourField;
			}
			set {
				this.hourField = value;
				this.hourSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="hour" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool hourSpecified {
			get {
				return this.hourFieldSpecified;
			}
			set {
				this.hourFieldSpecified = value;
			}
		}

		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public int minute {
			get {
				return this.minuteField;
			}
			set {
				this.minuteField = value;
				this.minuteSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="minute" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool minuteSpecified {
			get {
				return this.minuteFieldSpecified;
			}
			set {
				this.minuteFieldSpecified = value;
			}
		}

		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public int second {
			get {
				return this.secondField;
			}
			set {
				this.secondField = value;
				this.secondSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="second" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool secondSpecified {
			get {
				return this.secondFieldSpecified;
			}
			set {
				this.secondFieldSpecified = value;
			}
		}

		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string timeZoneID {
			get {
				return this.timeZoneIDField;
			}
			set {
				this.timeZoneIDField = value;
			}
		}
	}


	/// <summary>Contains a boolean value.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class BooleanValue : Value {
		private bool valueField;

		private bool valueFieldSpecified;

		/// <summary>The boolean value.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool value {
			get {
				return this.valueField;
			}
			set {
				this.valueField = value;
				this.valueSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="value" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool valueSpecified {
			get {
				return this.valueFieldSpecified;
			}
			set {
				this.valueFieldSpecified = value;
			}
		}
	}


	/// <summary>Contains an object value. <p><b>This object is experimental!
	/// <code>ObjectValue</code> is an experimental, innovative, and rapidly changing
	/// new feature for Ad Manager. Unfortunately, being on the bleeding edge means that
	/// we may make backwards-incompatible changes to <code>ObjectValue</code>. We will
	/// inform the community when this feature is no longer experimental.</b></p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(TargetingValue))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ChangeHistoryValue))]
	public abstract partial class ObjectValue : Value {
	}


	/// <summary>Captures a page of <a href='ActivityGroup'>ActivityGroup</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivityGroupPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private ActivityGroup[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of activity groups contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public ActivityGroup[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ActivityGroupServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ActivityGroupServiceInterface, System.ServiceModel.IClientChannel
	{
	}
	namespace Wrappers.ActivityGroupService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createActivityGroups", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createActivityGroupsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("activityGroups")]
			public Google.Api.Ads.AdManager.v201802.ActivityGroup[] activityGroups;

			/// <summary> Creates a new instance of the <see
			/// cref="createActivityGroupsRequest"/> class. </summary>
			public createActivityGroupsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createActivityGroupsRequest"/> class. </summary>
			public createActivityGroupsRequest(Google.Api.Ads.AdManager.v201802.ActivityGroup[] activityGroups) {
				this.activityGroups = activityGroups;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createActivityGroupsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createActivityGroupsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ActivityGroup[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createActivityGroupsResponse"/> class. </summary>
			public createActivityGroupsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createActivityGroupsResponse"/> class. </summary>
			public createActivityGroupsResponse(Google.Api.Ads.AdManager.v201802.ActivityGroup[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateActivityGroups", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateActivityGroupsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("activityGroups")]
			public Google.Api.Ads.AdManager.v201802.ActivityGroup[] activityGroups;

			/// <summary> Creates a new instance of the <see
			/// cref="updateActivityGroupsRequest"/> class. </summary>
			public updateActivityGroupsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateActivityGroupsRequest"/> class. </summary>
			public updateActivityGroupsRequest(Google.Api.Ads.AdManager.v201802.ActivityGroup[] activityGroups) {
				this.activityGroups = activityGroups;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateActivityGroupsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateActivityGroupsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ActivityGroup[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateActivityGroupsResponse"/> class. </summary>
			public updateActivityGroupsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateActivityGroupsResponse"/> class. </summary>
			public updateActivityGroupsResponse(Google.Api.Ads.AdManager.v201802.ActivityGroup[] rval) {
				this.rval = rval;
			}
		}
	}
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ActivityGroupServiceInterface")]
	public interface ActivityGroupServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ActivityGroupService.createActivityGroupsResponse createActivityGroups(Wrappers.ActivityGroupService.createActivityGroupsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ActivityGroupService.createActivityGroupsResponse> createActivityGroupsAsync(Wrappers.ActivityGroupService.createActivityGroupsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ActivityGroupPage getActivityGroupsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ActivityGroupPage> getActivityGroupsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ActivityGroupService.updateActivityGroupsResponse updateActivityGroups(Wrappers.ActivityGroupService.updateActivityGroupsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ActivityGroupService.updateActivityGroupsResponse> updateActivityGroupsAsync(Wrappers.ActivityGroupService.updateActivityGroupsRequest request);
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='ActivityGroup'>ActivityGroup</a> objects. <p>An activity group contains <a
	/// href='Activity'>Activity</a> objects. Activities have a many-to-one relationship
	/// with activity groups, meaning each activity can belong to only one activity
	/// group, but activity groups can have multiple activities. An activity group can
	/// be used to manage the activities it contains.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ActivityGroupService : AdManagerSoapClient<IActivityGroupService>, IActivityGroupService {
		/// <summary> Creates a new instance of the <see cref="ActivityGroupService"/>
		/// class. </summary>
		public ActivityGroupService() {
		}

		/// <summary> Creates a new instance of the <see cref="ActivityGroupService"/>
		/// class. </summary>
		public ActivityGroupService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="ActivityGroupService"/>
		/// class. </summary>
		public ActivityGroupService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ActivityGroupService"/>
		/// class. </summary>
		public ActivityGroupService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ActivityGroupService"/>
		/// class. </summary>
		public ActivityGroupService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ActivityGroupService.createActivityGroupsResponse Google.Api.Ads.AdManager.v201802.ActivityGroupServiceInterface.createActivityGroups(Wrappers.ActivityGroupService.createActivityGroupsRequest request) {
			return base.Channel.createActivityGroups(request);
		}

		/// <summary>Creates a new <a href='ActivityGroup'>ActivityGroup</a> objects.
		/// </summary><param name='activityGroups'>the activity groups to be created.</param>
		/// <returns>the created activity groups with their IDs filled in.</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ActivityGroup[] createActivityGroups(Google.Api.Ads.AdManager.v201802.ActivityGroup[] activityGroups) {
			Wrappers.ActivityGroupService.createActivityGroupsRequest inValue = new Wrappers.ActivityGroupService.createActivityGroupsRequest();
			inValue.activityGroups = activityGroups;
			Wrappers.ActivityGroupService.createActivityGroupsResponse retVal = ((Google.Api.Ads.AdManager.v201802.ActivityGroupServiceInterface)(this)).createActivityGroups(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ActivityGroupService.createActivityGroupsResponse> Google.Api.Ads.AdManager.v201802.ActivityGroupServiceInterface.createActivityGroupsAsync(Wrappers.ActivityGroupService.createActivityGroupsRequest request) {
			return base.Channel.createActivityGroupsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ActivityGroup[]> createActivityGroupsAsync(Google.Api.Ads.AdManager.v201802.ActivityGroup[] activityGroups) {
			Wrappers.ActivityGroupService.createActivityGroupsRequest inValue = new Wrappers.ActivityGroupService.createActivityGroupsRequest();
			inValue.activityGroups = activityGroups;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ActivityGroup[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ActivityGroupServiceInterface)(this)).createActivityGroupsAsync(inValue)).Result.rval);
		}

		/// <summary>Gets an <a href='ActivityGroupPage'>ActivityGroupPage</a> of <a
		/// href='ActivityGroup'>ActivityGroup</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='ActivityGroup#id'>ActivityGroup#id</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a
		/// href='ActivityGroup#name'>ActivityGroup#name</a></td> </tr> <tr>
		/// <td><code>impressionsLookback</code></td> <td><a
		/// href='ActivityGroup#impressionsLookback'>ActivityGroup#impressionsLookback</a></td>
		/// </tr> <tr> <td><code>clicksLookback</code></td> <td><a
		/// href='ActivityGroup#clicksLookback'>ActivityGroup#clicksLookback</a></td> </tr>
		/// <tr> <td><code>status</code></td> <td><a
		/// href='ActivityGroup#status'>ActivityGroup#status</a></td> </tr> </table>
		/// </summary><param name='filterStatement'>a statement used to filter a set of activity
		/// groups</param>
		/// <returns>the activity groups that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ActivityGroupPage getActivityGroupsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getActivityGroupsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ActivityGroupPage> getActivityGroupsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getActivityGroupsByStatementAsync(filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ActivityGroupService.updateActivityGroupsResponse Google.Api.Ads.AdManager.v201802.ActivityGroupServiceInterface.updateActivityGroups(Wrappers.ActivityGroupService.updateActivityGroupsRequest request) {
			return base.Channel.updateActivityGroups(request);
		}

		/// <summary>Updates the specified <a href='ActivityGroup'>ActivityGroup</a> objects.
		/// </summary><param name='activityGroups'>the activity groups to update.</param>
		/// <returns>the updated activity groups.</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ActivityGroup[] updateActivityGroups(Google.Api.Ads.AdManager.v201802.ActivityGroup[] activityGroups) {
			Wrappers.ActivityGroupService.updateActivityGroupsRequest inValue = new Wrappers.ActivityGroupService.updateActivityGroupsRequest();
			inValue.activityGroups = activityGroups;
			Wrappers.ActivityGroupService.updateActivityGroupsResponse retVal = ((Google.Api.Ads.AdManager.v201802.ActivityGroupServiceInterface)(this)).updateActivityGroups(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ActivityGroupService.updateActivityGroupsResponse> Google.Api.Ads.AdManager.v201802.ActivityGroupServiceInterface.updateActivityGroupsAsync(Wrappers.ActivityGroupService.updateActivityGroupsRequest request) {
			return base.Channel.updateActivityGroupsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ActivityGroup[]> updateActivityGroupsAsync(Google.Api.Ads.AdManager.v201802.ActivityGroup[] activityGroups) {
			Wrappers.ActivityGroupService.updateActivityGroupsRequest inValue = new Wrappers.ActivityGroupService.updateActivityGroupsRequest();
			inValue.activityGroups = activityGroups;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ActivityGroup[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ActivityGroupServiceInterface)(this)).updateActivityGroupsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.ContentMetadataKeyHierarchyService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createContentMetadataKeyHierarchies", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createContentMetadataKeyHierarchiesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("contentMetadataKeyHierarchies")]
			public Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] contentMetadataKeyHierarchies;

			/// <summary> Creates a new instance of the <see
			/// cref="createContentMetadataKeyHierarchiesRequest"/> class. </summary>
			public createContentMetadataKeyHierarchiesRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createContentMetadataKeyHierarchiesRequest"/> class. </summary>
			public createContentMetadataKeyHierarchiesRequest(Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] contentMetadataKeyHierarchies) {
				this.contentMetadataKeyHierarchies = contentMetadataKeyHierarchies;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createContentMetadataKeyHierarchiesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createContentMetadataKeyHierarchiesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createContentMetadataKeyHierarchiesResponse"/> class. </summary>
			public createContentMetadataKeyHierarchiesResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createContentMetadataKeyHierarchiesResponse"/> class. </summary>
			public createContentMetadataKeyHierarchiesResponse(Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateContentMetadataKeyHierarchies", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateContentMetadataKeyHierarchiesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("contentMetadataKeyHierarchies")]
			public Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] contentMetadataKeyHierarchies;

			/// <summary> Creates a new instance of the <see
			/// cref="updateContentMetadataKeyHierarchiesRequest"/> class. </summary>
			public updateContentMetadataKeyHierarchiesRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateContentMetadataKeyHierarchiesRequest"/> class. </summary>
			public updateContentMetadataKeyHierarchiesRequest(Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] contentMetadataKeyHierarchies) {
				this.contentMetadataKeyHierarchies = contentMetadataKeyHierarchies;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateContentMetadataKeyHierarchiesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateContentMetadataKeyHierarchiesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateContentMetadataKeyHierarchiesResponse"/> class. </summary>
			public updateContentMetadataKeyHierarchiesResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateContentMetadataKeyHierarchiesResponse"/> class. </summary>
			public updateContentMetadataKeyHierarchiesResponse(Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>A <code>ContentMetadataKeyHierarchyLevel</code> represents one level in a <a
	/// href=''>ContentMetadataKeyHierarchy</a>. The level consists of a <a
	/// href='CustomTargetingKey'>CustomTargetingKey</a> and an integer that represents
	/// the level's position in the hierarchy.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ContentMetadataKeyHierarchyLevel {
		private long customTargetingKeyIdField;

		private bool customTargetingKeyIdFieldSpecified;

		private int hierarchyLevelField;

		private bool hierarchyLevelFieldSpecified;

		/// <summary>The ID of the <a href='CustomTargetingKey'>CustomTargetingKey</a> associated
		/// with this level of the hierarchy. This attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long customTargetingKeyId {
			get {
				return this.customTargetingKeyIdField;
			}
			set {
				this.customTargetingKeyIdField = value;
				this.customTargetingKeyIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="customTargetingKeyId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool customTargetingKeyIdSpecified {
			get {
				return this.customTargetingKeyIdFieldSpecified;
			}
			set {
				this.customTargetingKeyIdFieldSpecified = value;
			}
		}

		/// <summary>This content metadata key's position in the hierarchy. This attribute is
		/// readonly and can range from 1 to N, where N is the number of the levels in the
		/// hierarchy.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int hierarchyLevel {
			get {
				return this.hierarchyLevelField;
			}
			set {
				this.hierarchyLevelField = value;
				this.hierarchyLevelSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="hierarchyLevel" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool hierarchyLevelSpecified {
			get {
				return this.hierarchyLevelFieldSpecified;
			}
			set {
				this.hierarchyLevelFieldSpecified = value;
			}
		}
	}


	/// <summary>A <code>ContentMetadataKeyHierarchy</code> defines a hierarchical relationship
	/// between content metadata keys.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ContentMetadataKeyHierarchy {
		private int idField;

		private bool idFieldSpecified;

		private string nameField;

		private ContentMetadataKeyHierarchyLevel[] hierarchyLevelsField;

		private ContentMetadataKeyHierarchyStatus statusField;

		private bool statusFieldSpecified;

		/// <summary>The unique ID of the <code>ContentMetadataKeyHierarchy</code>. This value is
		/// readonly and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The unique name of the <code>ContentMetadataKeyHierarchy</code>. This attribute
		/// is readonly and has a maximum length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The levels of the <code>ContentMetadataKeyHierarchy</code>. This attribute is
		/// readonly and the hierarchy levels must form a continuous set of 1, 2, ..., N
		/// where N is the number of levels in the hierarchy.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("hierarchyLevels", Order = 2)]
		public ContentMetadataKeyHierarchyLevel[] hierarchyLevels {
			get {
				return this.hierarchyLevelsField;
			}
			set {
				this.hierarchyLevelsField = value;
			}
		}

		/// <summary>The <a
		/// href='ContentMetadataKeyHierarchyStatus'>ContentMetadataKeyHierarchyStatus</a>
		/// of the hierarchy. This attribute is read-only and defaults to <a
		/// href='ContentMetadataKeyHierarchyStatus#ACTIVE'>ContentMetadataKeyHierarchyStatus#ACTIVE</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public ContentMetadataKeyHierarchyStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents the status of a <a
	/// href='ContentMetadataKeyHierarchy'>ContentMetadataKeyHierarchy</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ContentMetadataKeyHierarchyStatus {
		/// <summary>The hierarchy is active and user-visable.
		/// </summary>
		ACTIVE = 0,
		/// <summary>The hierarchy is deleted and not user-visable.
		/// </summary>
		DELETED = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>A list of all errors to be used in conjunction with required number validators.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RequiredNumberError : ApiError {
		private RequiredNumberErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public RequiredNumberErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes reasons for a number to be invalid.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "RequiredNumberError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RequiredNumberErrorReason {
		REQUIRED = 0,
		TOO_LARGE = 1,
		TOO_SMALL = 2,
		TOO_LARGE_WITH_DETAILS = 3,
		TOO_SMALL_WITH_DETAILS = 4,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 5,
	}


	/// <summary>Lists all errors associated with content hierarchies.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ContentMetadataKeyHierarchyError : ApiError {
		private ContentMetadataKeyHierarchyErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ContentMetadataKeyHierarchyErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the <a
	/// href='ContentMetadataKeyHierarchyError'>ContentMetadataKeyHierarchyError</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ContentMetadataKeyHierarchyError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ContentMetadataKeyHierarchyErrorReason {
		/// <summary>One or more levels of the hierarchy are missing. For example, if the levels are
		/// {1, 2, 2} or {1, 3, 4}, this error will be thrown.
		/// </summary>
		LEVEL_MISSING = 0,
		/// <summary>DSM networks can only have one hierarchy per network and that hierarchy can only
		/// have one level.
		/// </summary>
		INVALID_DSM_HIERARCHY = 1,
		/// <summary>Cannot load or save the network browse by key when the content metadata key
		/// hierarchy feature is enabled.
		/// </summary>
		CANNOT_USE_BROWSE_BY_KEY_WITH_HIERARCHY_FEATURE_ENABLED = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchyServiceInterface")]
	public interface ContentMetadataKeyHierarchyServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ContentMetadataKeyHierarchyService.createContentMetadataKeyHierarchiesResponse createContentMetadataKeyHierarchies(Wrappers.ContentMetadataKeyHierarchyService.createContentMetadataKeyHierarchiesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ContentMetadataKeyHierarchyService.createContentMetadataKeyHierarchiesResponse> createContentMetadataKeyHierarchiesAsync(Wrappers.ContentMetadataKeyHierarchyService.createContentMetadataKeyHierarchiesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchyPage getContentMetadataKeyHierarchiesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchyPage> getContentMetadataKeyHierarchiesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performContentMetadataKeyHierarchyAction(Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchyAction contentMetadataKeyHierarchyAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performContentMetadataKeyHierarchyActionAsync(Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchyAction contentMetadataKeyHierarchyAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ContentMetadataKeyHierarchyService.updateContentMetadataKeyHierarchiesResponse updateContentMetadataKeyHierarchies(Wrappers.ContentMetadataKeyHierarchyService.updateContentMetadataKeyHierarchiesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ContentMetadataKeyHierarchyService.updateContentMetadataKeyHierarchiesResponse> updateContentMetadataKeyHierarchiesAsync(Wrappers.ContentMetadataKeyHierarchyService.updateContentMetadataKeyHierarchiesRequest request);
	}


	/// <summary>Captures a page of <a
	/// href='ContentMetadataKeyHierarchy'>ContentMetadataKeyHierarchy</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ContentMetadataKeyHierarchyPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private ContentMetadataKeyHierarchy[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of content metadata key hierarchies contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public ContentMetadataKeyHierarchy[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a
	/// href='ContentMetadataKeyHierarchy'>ContentMetadataKeyHierarchy</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeleteContentMetadataKeyHierarchies))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class ContentMetadataKeyHierarchyAction {
	}


	/// <summary>The action used for deleting <a
	/// href='ContentMetadataKeyHierarchy'>ContentMetadataKeyHierarchy</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeleteContentMetadataKeyHierarchies : ContentMetadataKeyHierarchyAction {
	}


	/// <summary>Represents the result of performing an action on objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UpdateResult {
		private int numChangesField;

		private bool numChangesFieldSpecified;

		/// <summary>The number of objects that were changed as a result of performing the action.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int numChanges {
			get {
				return this.numChangesField;
			}
			set {
				this.numChangesField = value;
				this.numChangesSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="numChanges"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool numChangesSpecified {
			get {
				return this.numChangesFieldSpecified;
			}
			set {
				this.numChangesFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ContentMetadataKeyHierarchyServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchyServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating, updating, and retrieving <a
	/// href='ContentMetadataKeyHierarchy'>ContentMetadataKeyHierarchy</a> objects.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ContentMetadataKeyHierarchyService : AdManagerSoapClient<IContentMetadataKeyHierarchyService>, IContentMetadataKeyHierarchyService {
		/// <summary> Creates a new instance of the <see
		/// cref="ContentMetadataKeyHierarchyService"/> class. </summary>
		public ContentMetadataKeyHierarchyService() {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ContentMetadataKeyHierarchyService"/> class. </summary>
		public ContentMetadataKeyHierarchyService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ContentMetadataKeyHierarchyService"/> class. </summary>
		public ContentMetadataKeyHierarchyService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ContentMetadataKeyHierarchyService"/> class. </summary>
		public ContentMetadataKeyHierarchyService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ContentMetadataKeyHierarchyService"/> class. </summary>
		public ContentMetadataKeyHierarchyService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ContentMetadataKeyHierarchyService.createContentMetadataKeyHierarchiesResponse Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchyServiceInterface.createContentMetadataKeyHierarchies(Wrappers.ContentMetadataKeyHierarchyService.createContentMetadataKeyHierarchiesRequest request) {
			return base.Channel.createContentMetadataKeyHierarchies(request);
		}

		/// <summary>Creates new <a
		/// href='ContentMetadataKeyHierarchy'>ContentMetadataKeyHierarchy</a> objects.
		/// <p>The following fields are required:</p> <ul> <li><a
		/// href='ContentMetadataKeyHierarchy#id'>ContentMetadataKeyHierarchy#id</a></li>
		/// <li><a
		/// href='ContentMetadataKeyHierarchy#name'>ContentMetadataKeyHierarchy#name</a></li>
		/// <li><a
		/// href='ContentMetadataKeyHierarchy#hierarchyLevels'>ContentMetadataKeyHierarchy#hierarchyLevels</a></li>
		/// </ul>
		/// </summary><param name='contentMetadataKeyHierarchies'>the hierarchies to create</param>
		/// <returns>the created hierarchies with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] createContentMetadataKeyHierarchies(Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] contentMetadataKeyHierarchies) {
			Wrappers.ContentMetadataKeyHierarchyService.createContentMetadataKeyHierarchiesRequest inValue = new Wrappers.ContentMetadataKeyHierarchyService.createContentMetadataKeyHierarchiesRequest();
			inValue.contentMetadataKeyHierarchies = contentMetadataKeyHierarchies;
			Wrappers.ContentMetadataKeyHierarchyService.createContentMetadataKeyHierarchiesResponse retVal = ((Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchyServiceInterface)(this)).createContentMetadataKeyHierarchies(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ContentMetadataKeyHierarchyService.createContentMetadataKeyHierarchiesResponse> Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchyServiceInterface.createContentMetadataKeyHierarchiesAsync(Wrappers.ContentMetadataKeyHierarchyService.createContentMetadataKeyHierarchiesRequest request) {
			return base.Channel.createContentMetadataKeyHierarchiesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[]> createContentMetadataKeyHierarchiesAsync(Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] contentMetadataKeyHierarchies) {
			Wrappers.ContentMetadataKeyHierarchyService.createContentMetadataKeyHierarchiesRequest inValue = new Wrappers.ContentMetadataKeyHierarchyService.createContentMetadataKeyHierarchiesRequest();
			inValue.contentMetadataKeyHierarchies = contentMetadataKeyHierarchies;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchyServiceInterface)(this)).createContentMetadataKeyHierarchiesAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a
		/// href='ContentMetadataKeyHierarchyPage'>ContentMetadataKeyHierarchyPage</a> of <a
		/// href='ContentMetadataKeyHierarchy'>ContentMetadataKeyHierarchy</a> objects that
		/// satisfy the given <a href='Statement#query'>Statement#query</a>. The following
		/// fields are supported for filtering: <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>id</code></td> <td><a
		/// href='ContentMetadataKeyHierarchy#id'>ContentMetadataKeyHierarchy#id</a></td>
		/// </tr> <tr> <td><code>name</code></td> <td><a
		/// href='ContentMetadataKeyHierarchy#name'>ContentMetadataKeyHierarchy#name</a></td>
		/// </tr> <tr> <td><code>status</code></td> <td><a
		/// href='ContentMetadataKeyHierarchy#status'>ContentMetadataKeyHierarchy#status</a></td>
		/// </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of content metadata key hierarchies</param>
		/// <returns>the content metadata key hierarchies that match the given
		/// filter</returns>
		/// <exception cref='ApiException'>if the ID of the active network does not exist or
		/// there is a backend error</exception>
		public virtual Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchyPage getContentMetadataKeyHierarchiesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getContentMetadataKeyHierarchiesByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchyPage> getContentMetadataKeyHierarchiesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getContentMetadataKeyHierarchiesByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a
		/// href='ContentMetadataKeyHierarchy'>ContentMetadataKeyHierarchy</a> objects that
		/// match the given <a href=''>Statement#query</a>.
		/// </summary><param name='contentMetadataKeyHierarchyAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of hierarchies</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performContentMetadataKeyHierarchyAction(Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchyAction contentMetadataKeyHierarchyAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performContentMetadataKeyHierarchyAction(contentMetadataKeyHierarchyAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performContentMetadataKeyHierarchyActionAsync(Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchyAction contentMetadataKeyHierarchyAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performContentMetadataKeyHierarchyActionAsync(contentMetadataKeyHierarchyAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ContentMetadataKeyHierarchyService.updateContentMetadataKeyHierarchiesResponse Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchyServiceInterface.updateContentMetadataKeyHierarchies(Wrappers.ContentMetadataKeyHierarchyService.updateContentMetadataKeyHierarchiesRequest request) {
			return base.Channel.updateContentMetadataKeyHierarchies(request);
		}

		/// <summary>Updates the specified <a
		/// href='ContentMetadataKeyHierarchy'>ContentMetadataKeyHierarchy</a> objects.
		/// </summary><param name='contentMetadataKeyHierarchies'>the hierarchies to update</param>
		/// <returns>the updated hierarchies</returns>
		/// <exception cref='ApiException'>if there is an error updating the one of the
		/// hierarchies</exception>
		public virtual Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] updateContentMetadataKeyHierarchies(Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] contentMetadataKeyHierarchies) {
			Wrappers.ContentMetadataKeyHierarchyService.updateContentMetadataKeyHierarchiesRequest inValue = new Wrappers.ContentMetadataKeyHierarchyService.updateContentMetadataKeyHierarchiesRequest();
			inValue.contentMetadataKeyHierarchies = contentMetadataKeyHierarchies;
			Wrappers.ContentMetadataKeyHierarchyService.updateContentMetadataKeyHierarchiesResponse retVal = ((Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchyServiceInterface)(this)).updateContentMetadataKeyHierarchies(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ContentMetadataKeyHierarchyService.updateContentMetadataKeyHierarchiesResponse> Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchyServiceInterface.updateContentMetadataKeyHierarchiesAsync(Wrappers.ContentMetadataKeyHierarchyService.updateContentMetadataKeyHierarchiesRequest request) {
			return base.Channel.updateContentMetadataKeyHierarchiesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[]> updateContentMetadataKeyHierarchiesAsync(Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] contentMetadataKeyHierarchies) {
			Wrappers.ContentMetadataKeyHierarchyService.updateContentMetadataKeyHierarchiesRequest inValue = new Wrappers.ContentMetadataKeyHierarchyService.updateContentMetadataKeyHierarchiesRequest();
			inValue.contentMetadataKeyHierarchies = contentMetadataKeyHierarchies;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchyServiceInterface)(this)).updateContentMetadataKeyHierarchiesAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.ContentService
	{
	}
	/// <summary>Contains information about <a href='Content'>Content</a> from the CMS it was
	/// ingested from.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CmsContent {
		private long idField;

		private bool idFieldSpecified;

		private string displayNameField;

		private string cmsContentIdField;

		/// <summary>The ID of the Content Source associated with the CMS in Ad Manager. This
		/// attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The display name of the CMS this content is in. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string displayName {
			get {
				return this.displayNameField;
			}
			set {
				this.displayNameField = value;
			}
		}

		/// <summary>The ID of the <a href='Content'>Content</a> in the CMS. This ID will be a 3rd
		/// party ID, usually the ID of the content in a CMS (Content Management System).
		/// This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string cmsContentId {
			get {
				return this.cmsContentIdField;
			}
			set {
				this.cmsContentIdField = value;
			}
		}
	}


	/// <summary>Represents an error associated with a DAI content's status.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DaiIngestError {
		private DaiIngestErrorReason reasonField;

		private bool reasonFieldSpecified;

		private string triggerField;

		/// <summary>The error associated with the content.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public DaiIngestErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}

		/// <summary>The field, if any, that triggered the error.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string trigger {
			get {
				return this.triggerField;
			}
			set {
				this.triggerField = value;
			}
		}
	}


	/// <summary>Describes what caused the DAI content to fail during the ingestion proccess.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum DaiIngestErrorReason {
		/// <summary>The ingest URL provided in the publisher's content source feed is invalid. The
		/// trigger for this error is the ingest URL specified in the publisher's feed.
		/// </summary>
		INVALID_INGEST_URL = 0,
		/// <summary>The closed caption URL provided in the publisher's content source feed is
		/// invalid. The trigger for this error is the closed caption URL specified in the
		/// publisher's feed.
		/// </summary>
		INVALID_CLOSED_CAPTION_URL = 1,
		/// <summary>There is no closed caption URL for a content in the publisher's content source
		/// feed. There is no trigger for this error.
		/// </summary>
		MISSING_CLOSED_CAPTION_URL = 2,
		/// <summary>There was an error while trying to fetch the HLS from the specified ingest URL.
		/// The trigger for this error is the ingest URL specified in the publisher's feed.
		/// </summary>
		COULD_NOT_FETCH_HLS = 3,
		/// <summary>There was an error while trying to fetch the subtitles from the specified closed
		/// caption url. The trigger for this error is the closed caption URL specified in
		/// the publisher's feed.
		/// </summary>
		COULD_NOT_FETCH_SUBTITLES = 4,
		/// <summary>One of the subtitles from the closed caption URL is missing a language. The
		/// trigger for this error is the closed caption URL that does not have a language
		/// associated with it.
		/// </summary>
		MISSING_SUBTITLE_LANGUAGE = 5,
		/// <summary>Error fetching the media files from the URLs specified in the master HLS
		/// playlist. The trigger for this error is a media playlist URL within the
		/// publisher's HLS playlist that could not be fetched.
		/// </summary>
		COULD_NOT_FETCH_MEDIA = 6,
		/// <summary>The media from the publisher's CDN is malformed and cannot be conditioned. The
		/// trigger for this error is a media playlist URL within the publisher's HLS
		/// playlist that is malformed.
		/// </summary>
		MALFORMED_MEDIA_BYTES = 7,
		/// <summary>A chapter time for the content is outside of the range of the content's
		/// duration. The trigger for this error is the chapter time (a parsable long
		/// representing the time in ms) that is out of bounds.
		/// </summary>
		CHAPTER_TIME_OUT_OF_BOUNDS = 8,
		/// <summary>An internal error occurred while conditioning the content. There is no trigger
		/// for this error.
		/// </summary>
		INTERNAL_ERROR = 9,
		/// <summary>The content has chapter times but the content's source has no CDN settings for
		/// midrolls. There is no trigger for this error.
		/// </summary>
		CONTENT_HAS_CHAPTER_TIMES_BUT_NO_MIDROLL_SETTINGS = 10,
		/// <summary>There is bad/missing/malformed data in a media playlist. The trigger for this
		/// error is the URL that points to the malformed media playlist.
		/// </summary>
		MALFORMED_MEDIA_PLAYLIST = 11,
		/// <summary>There is bad/missing/malformed data in a subtitles file. The trigger for this
		/// error is the URL that points to the malformed subtitles.
		/// </summary>
		MALFORMED_SUBTITLES = 12,
		/// <summary>A playlist item has a URL that does not begin with the ingest common path
		/// provided in the DAI settings. The trigger for this error is the playlist item
		/// URL.
		/// </summary>
		PLAYLIST_ITEM_URL_DOES_NOT_MATCH_INGEST_COMMON_PATH = 13,
		/// <summary>Uploading split media segments failed due to an authentication error.
		/// </summary>
		COULD_NOT_UPLOAD_SPLIT_MEDIA_AUTHENTICATION_FAILED = 14,
		/// <summary>Uploading spit media segments failed due to a connection error.
		/// </summary>
		COULD_NOT_UPLOAD_SPLIT_MEDIA_CONNECTION_FAILED = 15,
		/// <summary>Uploading split media segments failed due to a write error.
		/// </summary>
		COULD_NOT_UPLOAD_SPLIT_MEDIA_WRITE_FAILED = 16,
		/// <summary>Variants in a playlist do not have the same number of discontinuities. The
		/// trigger for this error is the master playlist URI.
		/// </summary>
		PLAYLISTS_HAVE_DIFFERENT_NUMBER_OF_DISCONTINUITIES = 17,
		/// <summary>The playlist does not have a starting PTS value. The trigger for this error is
		/// the master playlist URI.
		/// </summary>
		PLAYIST_HAS_NO_STARTING_PTS_VALUE = 18,
		/// <summary>The PTS at a discontinuity varies too much between the different variants. The
		/// trigger for this error is the master playlist URI.
		/// </summary>
		PLAYLIST_DISCONTINUITY_PTS_VALUES_DIFFER_TOO_MUCH = 19,
		/// <summary>A media segment has no PTS. The trigger for this error is the segment data URI.
		/// </summary>
		SEGMENT_HAS_NO_PTS = 20,
		/// <summary>The language in the subtitles file does not match the language specified in the
		/// feed. The trigger for this error is the feed language and the parsed language
		/// separated by a semi-colon, e.g. "en;sp".
		/// </summary>
		SUBTITLE_LANGUAGE_DOES_NOT_MATCH_LANGUAGE_IN_FEED = 21,
		/// <summary>There are multiple subtitles files at the closed caption URI, and none of them
		/// match the language defined in the feed. The trigger for this error is language
		/// in the feed.
		/// </summary>
		CANNOT_DETERMINE_CORRECT_SUBTITLES_FOR_LANGUAGE = 22,
		/// <summary>No CDN configuration found for the content. The trigger for this error is the
		/// content's master playlist URI.
		/// </summary>
		NO_CDN_CONFIGURATION_FOUND = 23,
		/// <summary>The content has midrolls but there was no split content config on the CDN
		/// configuration for that content so the content was not conditioned. There is no
		/// trigger for this error.
		/// </summary>
		CONTENT_HAS_MIDROLLS_BUT_NO_SPLIT_CONTENT_CONFIG = 24,
		/// <summary>The content has midrolls but the source the content was ingested from has
		/// mid-rolls disabled, so the content was not conditioned. There is no trigger for
		/// this error.
		/// </summary>
		CONTENT_HAS_MIDROLLS_BUT_SOURCE_HAS_MIDROLLS_DISABLED = 25,
		/// <summary>Error parsing ADTS while splitting the content. The trigger for this error is
		/// the variant URL and the cue-point separated by a semi-colon, e.g.
		/// "www.variant2.com;5000".
		/// </summary>
		ADTS_PARSE_ERROR = 26,
		/// <summary>Error splitting an AAC segment. The trigger for this error is the variant URL
		/// and the cue-point separated by a semi-colon, e.g. "www.variant2.com;5000".
		/// </summary>
		AAC_SPLIT_ERROR = 27,
		/// <summary>Error parsing an AAC file while splitting the content. The trigger for this
		/// error is the variant URL and the cue-point separated by a semi-colon, e.g.
		/// "www.variant2.com;5000".
		/// </summary>
		AAC_PARSE_ERROR = 28,
		/// <summary>Error parsing a TS file while splitting the content. The trigger for this error
		/// is the variant URL and the cue-point separated by a semi-colon, e.g.
		/// "www.variant2.com;5000".
		/// </summary>
		TS_PARSE_ERROR = 29,
		/// <summary>Error splitting a TS file while splitting the content. The trigger for this
		/// error is the variant URL and the cue-point separated by a semi-colon, e.g.
		/// "www.variant2.com;5000".
		/// </summary>
		TS_SPLIT_ERROR = 30,
		/// <summary>Encountered an unsupported container format while splitting the content. The
		/// trigger for this error is the variant URL and the cue-point separated by a
		/// semi-colon, e.g. "www.variant2.com;5000".
		/// </summary>
		UNSUPPORTED_CONTAINER_FORMAT = 31,
		/// <summary>Encountered an unsupported TS media format while splitting the content. The
		/// trigger for this error is the variant URL and the cue-point separated by a
		/// semi-colon, e.g. "www.variant2.com;5000".
		/// </summary>
		UNSUPPORTED_TS_MEDIA_FORMAT = 32,
		/// <summary>Error splitting because there were no i-frames near the target split point. The
		/// trigger for this error is the variant URL and the cue-point separated by a
		/// semi-colon, e.g. "www.variant2.com;5000".
		/// </summary>
		NO_IFRAMES_NEAR_CUE_POINT = 33,
		/// <summary>Error splitting an AC-3 segment. The trigger for this error is the variant URL
		/// and the cue-point separated by a semi-colon, e.g. "www.variant2.com;5000".
		/// </summary>
		AC3_SPLIT_ERROR = 35,
		/// <summary>Error parsing an AC-3 file while splitting the content. The trigger for this
		/// error is the variant URL and the cue-point separated by a semi-colon, e.g.
		/// "www.variant2.com;5000".
		/// </summary>
		AC3_PARSE_ERROR = 36,
		/// <summary>Error splitting an E-AC-3 segment. The trigger for this error is the variant URL
		/// and the cue-point separated by a semi-colon, e.g. "www.variant2.com;5000".
		/// </summary>
		EAC3_SPLIT_ERROR = 37,
		/// <summary>Error caused by an invalid encryption key. The trigger for this error is a media
		/// playlist URL within the publisher's HLS playlist that has the invalid encryption
		/// key.
		/// </summary>
		INVALID_ENCRYPTION_KEY = 38,
		/// <summary>Error parsing an E-AC-3 file while splitting the content. The trigger for this
		/// error is the variant URL and the cue-point separated by a semi-colon, e.g.
		/// "www.variant2.com;5000".
		/// </summary>
		EAC3_PARSE_ERROR = 39,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 34,
	}


	/// <summary>A <code>Content</code> represents video metadata from a publisher's Content
	/// Management System (CMS) that has been synced to Ad Manager. <p>Video line items
	/// can be targeted to <code>Content</code> to indicate what ads should match when
	/// the <code>Content</code> is being played.</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Content {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private ContentStatus statusField;

		private bool statusFieldSpecified;

		private ContentStatusDefinedBy statusDefinedByField;

		private bool statusDefinedByFieldSpecified;

		private DaiIngestStatus hlsIngestStatusField;

		private bool hlsIngestStatusFieldSpecified;

		private DaiIngestError[] hlsIngestErrorsField;

		private DateTime lastHlsIngestDateTimeField;

		private DaiIngestStatus dashIngestStatusField;

		private bool dashIngestStatusFieldSpecified;

		private DaiIngestError[] dashIngestErrorsField;

		private DateTime lastDashIngestDateTimeField;

		private DateTime importDateTimeField;

		private DateTime lastModifiedDateTimeField;

		private long[] userDefinedCustomTargetingValueIdsField;

		private long[] mappingRuleDefinedCustomTargetingValueIdsField;

		private CmsContent[] cmsSourcesField;

		/// <summary>Uniquely identifies the <code>Content</code>. This attribute is read-only and is
		/// assigned by Google when the content is created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the <code>Content</code>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The status of this <code>Content</code>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public ContentStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>Whether the content status was defined by the user, or by the source CMS from
		/// which the content was ingested. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public ContentStatusDefinedBy statusDefinedBy {
			get {
				return this.statusDefinedByField;
			}
			set {
				this.statusDefinedByField = value;
				this.statusDefinedBySpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="statusDefinedBy" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusDefinedBySpecified {
			get {
				return this.statusDefinedByFieldSpecified;
			}
			set {
				this.statusDefinedByFieldSpecified = value;
			}
		}

		/// <summary>The current DAI ingest status of the HLS media for the <code></code>. This
		/// attribute is read-only and is null if the content is not eligible for dynamic ad
		/// insertion or if the content does not have HLS media.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public DaiIngestStatus hlsIngestStatus {
			get {
				return this.hlsIngestStatusField;
			}
			set {
				this.hlsIngestStatusField = value;
				this.hlsIngestStatusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="hlsIngestStatus" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool hlsIngestStatusSpecified {
			get {
				return this.hlsIngestStatusFieldSpecified;
			}
			set {
				this.hlsIngestStatusFieldSpecified = value;
			}
		}

		/// <summary>The list of any errors that occurred during the most recent DAI ingestion
		/// process of the HLS media. This attribute is read-only and will be null if the <a
		/// href='#hlsIngestStatus'>#hlsIngestStatus</a> is <a
		/// href=''>DaiIngestStatus#STATUS_SUCCESS</a> or if the content is not eligible for
		/// dynamic ad insertion or if the content does not have HLS media.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("hlsIngestErrors", Order = 5)]
		public DaiIngestError[] hlsIngestErrors {
			get {
				return this.hlsIngestErrorsField;
			}
			set {
				this.hlsIngestErrorsField = value;
			}
		}

		/// <summary>The date and time at which this content's HLS media was last ingested for DAI.
		/// This attribute is read-only and will be null if the content is not eligible for
		/// dynamic ad insertion or if the content does not have HLS media.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public DateTime lastHlsIngestDateTime {
			get {
				return this.lastHlsIngestDateTimeField;
			}
			set {
				this.lastHlsIngestDateTimeField = value;
			}
		}

		/// <summary>The current DAI ingest status of the DASH media for the <code></code>. This
		/// attribute is read-only and is null if the content is not eligible for dynamic ad
		/// insertion or if the content does not have DASH media.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public DaiIngestStatus dashIngestStatus {
			get {
				return this.dashIngestStatusField;
			}
			set {
				this.dashIngestStatusField = value;
				this.dashIngestStatusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="dashIngestStatus" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool dashIngestStatusSpecified {
			get {
				return this.dashIngestStatusFieldSpecified;
			}
			set {
				this.dashIngestStatusFieldSpecified = value;
			}
		}

		/// <summary>The list of any errors that occurred during the most recent DAI ingestion
		/// process of the DASH media. This attribute is read-only and will be null if the
		/// <a href='#hlsIngestStatus'>#hlsIngestStatus</a> is <a
		/// href=''>DaiIngestStatus#STATUS_SUCCESS</a> or if the content is not eligible for
		/// dynamic ad insertion or if the content does not have DASH media.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("dashIngestErrors", Order = 8)]
		public DaiIngestError[] dashIngestErrors {
			get {
				return this.dashIngestErrorsField;
			}
			set {
				this.dashIngestErrorsField = value;
			}
		}

		/// <summary>The date and time at which this content's DASH media was last ingested for DAI.
		/// This attribute is read-only and will be null if the content is not eligible for
		/// dynamic ad insertion or if the content does not have DASH media.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public DateTime lastDashIngestDateTime {
			get {
				return this.lastDashIngestDateTimeField;
			}
			set {
				this.lastDashIngestDateTimeField = value;
			}
		}

		/// <summary>The date and time at which this content was published. This attribute is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public DateTime importDateTime {
			get {
				return this.importDateTimeField;
			}
			set {
				this.importDateTimeField = value;
			}
		}

		/// <summary>The date and time at which this content was last modified. This attribute is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 11)]
		public DateTime lastModifiedDateTime {
			get {
				return this.lastModifiedDateTimeField;
			}
			set {
				this.lastModifiedDateTimeField = value;
			}
		}

		/// <summary>A collection of custom targeting value IDs manually assigned to this content by
		/// the user. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("userDefinedCustomTargetingValueIds", Order = 12)]
		public long[] userDefinedCustomTargetingValueIds {
			get {
				return this.userDefinedCustomTargetingValueIdsField;
			}
			set {
				this.userDefinedCustomTargetingValueIdsField = value;
			}
		}

		/// <summary>A collection of custom targeting value IDs automatically targeted to this
		/// content via metadata mapping rules. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("mappingRuleDefinedCustomTargetingValueIds", Order = 13)]
		public long[] mappingRuleDefinedCustomTargetingValueIds {
			get {
				return this.mappingRuleDefinedCustomTargetingValueIdsField;
			}
			set {
				this.mappingRuleDefinedCustomTargetingValueIdsField = value;
			}
		}

		/// <summary>Information about the content from the CMS it was ingested from. This attribute
		/// is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("cmsSources", Order = 14)]
		public CmsContent[] cmsSources {
			get {
				return this.cmsSourcesField;
			}
			set {
				this.cmsSourcesField = value;
			}
		}
	}


	/// <summary>Describes the status of a <a href='Content'>Content</a> object.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ContentStatus {
		/// <summary>Indicates the <a href='Content'>Content</a> has been created and is eligible to
		/// have ads served against it.
		/// </summary>
		ACTIVE = 0,
		/// <summary>Indicates the <a href='Content'>Content</a> has been deactivated and cannot have
		/// ads served against it.
		/// </summary>
		INACTIVE = 1,
		/// <summary>Indicates the <a href='Content'>Content</a> has been archived; user-visible.
		/// </summary>
		ARCHIVED = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Describes who defined the effective status of the <code>Content</code>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ContentStatusDefinedBy {
		/// <summary>Indicates that the status of the <code>Content</code> is defined by the CMS.
		/// </summary>
		CMS = 0,
		/// <summary>Indicates that the status of the <code>Content</code> is defined by the user.
		/// </summary>
		USER = 1,
	}


	/// <summary>The status of the DAI ingestion process. Only content with a status of <a
	/// href='#SUCCESS'>#SUCCESS</a> will be available for dynamic ad insertion.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum DaiIngestStatus {
		/// <summary>The content was successfully ingested for DAI.
		/// </summary>
		SUCCESS = 0,
		/// <summary>There was a non-fatal issue during the DAI ingestion proccess.
		/// </summary>
		WARNING = 1,
		/// <summary>There was a non-fatal issue during the DAI ingestion proccess and the content is
		/// not available for dynamic ad insertion.
		/// </summary>
		FAILURE = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Captures a page of <code>Content</code> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ContentPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private Content[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of content contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public Content[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>An error for a field which is an invalid type.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class TypeError : ApiError {
	}


	/// <summary>Lists all errors associated with URLs.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class InvalidUrlError : ApiError {
		private InvalidUrlErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public InvalidUrlErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "InvalidUrlError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum InvalidUrlErrorReason {
		/// <summary>The URL contains invalid characters.
		/// </summary>
		ILLEGAL_CHARACTERS = 0,
		/// <summary>The format of the URL is not allowed. This could occur for a number of reasons.
		/// For example, if an invalid scheme is specified (like "ftp://") or if a port is
		/// specified when not required, or if a query was specified when not required.
		/// </summary>
		INVALID_FORMAT = 1,
		/// <summary>URL contains insecure scheme.
		/// </summary>
		INSECURE_SCHEME = 2,
		/// <summary>The URL does not contain a scheme.
		/// </summary>
		NO_SCHEME = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ContentServiceInterface")]
	public interface ContentServiceInterface
	{
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ContentPage getContentByStatement(Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentPage> getContentByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ContentPage getContentByStatementAndCustomTargetingValue(Google.Api.Ads.AdManager.v201802.Statement filterStatement, long customTargetingValueId);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentPage> getContentByStatementAndCustomTargetingValueAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement, long customTargetingValueId);
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ContentServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ContentServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Service for retrieving <a href='Content'>Content</a>. <p><code>Content</code>
	/// entities can be targeted in video <a href='LineItem'>LineItem</a>s.</p> <p>You
	/// can query for content that belongs to a particular category or has assigned
	/// metadata. Categories and metadata for <code></code> are stored in DFP as <a
	/// href='CustomCriteria'>CustomCriteria</a>.</p> <p>For example, to find all
	/// <code>Content</code> that is "genre=comedy", you would:</p> <ul> <li>Retrieve
	/// the custom targeting key corresponding to "genre" using <a
	/// href=''>CustomTargetingService#getCustomTargetingKeysByStatement</a></li>
	/// <li>Using the <a
	/// href='CustomTargetingService#getCustomTargetingValuesByStatement'>CustomTargetingService#getCustomTargetingValuesByStatement</a>
	/// method and a filter like "WHERE customTargetingKeyId = :genreKeyId and name =
	/// 'comedy'", retrieve the ID for the "comedy" custom targeting value.</li>
	/// <li>Call <a
	/// href='#getContentByStatementAndCustomTargetingValue'>#getContentByStatementAndCustomTargetingValue</a>
	/// with a filter like "WHERE status = 'ACTIVE'" and the ID of the custom targeting
	/// value from step 2.</li> </ul>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ContentService : AdManagerSoapClient<IContentService>, IContentService {
		/// <summary> Creates a new instance of the <see cref="ContentService"/> class.
		/// </summary>
		public ContentService() {
		}

		/// <summary> Creates a new instance of the <see cref="ContentService"/> class.
		/// </summary>
		public ContentService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="ContentService"/> class.
		/// </summary>
		public ContentService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ContentService"/> class.
		/// </summary>
		public ContentService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ContentService"/> class.
		/// </summary>
		public ContentService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		/// <summary>Gets a <a href='ContentPage'>ContentPage</a> of <a href='Content'>Content</a>
		/// objects that satisfy the given <a href=''>Statement#query</a>. The following
		/// fields are supported for filtering: <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>id</code></td> <td><a href='Content#id'>Content#id</a></td> </tr> <tr>
		/// <td><code>status</code></td> <td><a
		/// href='Content#status'>Content#status</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a href='Content#name'>Content#name</a></td>
		/// </tr> <tr> <td><code>lastModifiedDateTime</code></td> <td><a
		/// href='Content#lastModifiedDateTime'>Content#lastModifiedDateTime</a></td> </tr>
		/// <tr> <td><code>lastDaiIngestDateTime</code></td> <td><a
		/// href='Content#lastDaiIngestDateTime'>Content#lastDaiIngestDateTime</a></td>
		/// </tr> <tr> <td><code>daiIngestStatus</code></td> <td><a
		/// href='Content#daiIngestStatus'>Content#daiIngestStatus</a></td> </tr> </table>
		/// </summary><param name='statement'>a Publisher Query Language statement used to filter a
		/// set of content</param>
		/// <returns>the content that matches the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ContentPage getContentByStatement(Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.getContentByStatement(statement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentPage> getContentByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.getContentByStatementAsync(statement);
		}

		/// <summary>Gets a <a href='ContentPage'>ContentPage</a> of <a href='Content'>Content</a>
		/// objects that satisfy the given <a href='Statement#query'>Statement#query</a>.
		/// Additionally, filters on the given value ID and key ID that the value belongs
		/// to. The following fields are supported for filtering: <table> <tr> <th
		/// scope="col">PQL Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>id</code></td> <td><a href='Content#id'>Content#id</a></td> </tr> <tr>
		/// <td><code>status</code></td> <td><a
		/// href='Content#status'>Content#status</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a href='Content#name'>Content#name</a></td>
		/// </tr> <tr> <td><code>lastModifiedDateTime</code></td> <td><a
		/// href='Content#lastModifiedDateTime&gt;'>Content#lastModifiedDateTime&gt;</a></td>
		/// </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of content</param>
		/// <param name='customTargetingValueId'>the id of the value to match</param>
		/// <returns>the content that matches the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ContentPage getContentByStatementAndCustomTargetingValue(Google.Api.Ads.AdManager.v201802.Statement filterStatement, long customTargetingValueId) {
			return base.Channel.getContentByStatementAndCustomTargetingValue(filterStatement, customTargetingValueId);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentPage> getContentByStatementAndCustomTargetingValueAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement, long customTargetingValueId) {
			return base.Channel.getContentByStatementAndCustomTargetingValueAsync(filterStatement, customTargetingValueId);
		}
	}
	namespace Wrappers.CreativeService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createCreatives", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createCreativesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("creatives")]
			public Google.Api.Ads.AdManager.v201802.Creative[] creatives;

			/// <summary> Creates a new instance of the <see cref="createCreativesRequest"/>
			/// class. </summary>
			public createCreativesRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createCreativesRequest"/>
			/// class. </summary>
			public createCreativesRequest(Google.Api.Ads.AdManager.v201802.Creative[] creatives) {
				this.creatives = creatives;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createCreativesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createCreativesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Creative[] rval;

			/// <summary> Creates a new instance of the <see cref="createCreativesResponse"/>
			/// class. </summary>
			public createCreativesResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createCreativesResponse"/>
			/// class. </summary>
			public createCreativesResponse(Google.Api.Ads.AdManager.v201802.Creative[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateCreatives", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateCreativesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("creatives")]
			public Google.Api.Ads.AdManager.v201802.Creative[] creatives;

			/// <summary> Creates a new instance of the <see cref="updateCreativesRequest"/>
			/// class. </summary>
			public updateCreativesRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updateCreativesRequest"/>
			/// class. </summary>
			public updateCreativesRequest(Google.Api.Ads.AdManager.v201802.Creative[] creatives) {
				this.creatives = creatives;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateCreativesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateCreativesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Creative[] rval;

			/// <summary> Creates a new instance of the <see cref="updateCreativesResponse"/>
			/// class. </summary>
			public updateCreativesResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updateCreativesResponse"/>
			/// class. </summary>
			public updateCreativesResponse(Google.Api.Ads.AdManager.v201802.Creative[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>A base class for storing values of the <a
	/// href='CreativeTemplateVariable'>CreativeTemplateVariable</a>.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UrlCreativeTemplateVariableValue))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(StringCreativeTemplateVariableValue))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(LongCreativeTemplateVariableValue))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AssetCreativeTemplateVariableValue))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class BaseCreativeTemplateVariableValue {
		private string uniqueNameField;

		/// <summary>A uniqueName of the <a
		/// href='CreativeTemplateVariable'>CreativeTemplateVariable</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string uniqueName {
			get {
				return this.uniqueNameField;
			}
			set {
				this.uniqueNameField = value;
			}
		}
	}


	/// <summary>Stores values of <a href='CreativeTemplateVariable'>CreativeTemplateVariable</a>
	/// of <a href='VariableType#URL'>VariableType#URL</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UrlCreativeTemplateVariableValue : BaseCreativeTemplateVariableValue {
		private string valueField;

		/// <summary>The url value of <a href='CreativeTemplateVariable'>CreativeTemplateVariable</a>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string value {
			get {
				return this.valueField;
			}
			set {
				this.valueField = value;
			}
		}
	}


	/// <summary>Stores values of <a href='CreativeTemplateVariable'>CreativeTemplateVariable</a>
	/// of <a href='VariableType#STRING'>VariableType#STRING</a> and <a
	/// href='VariableType#LIST'>VariableType#LIST</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class StringCreativeTemplateVariableValue : BaseCreativeTemplateVariableValue {
		private string valueField;

		/// <summary>The string value of <a
		/// href='CreativeTemplateVariable'>CreativeTemplateVariable</a>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string value {
			get {
				return this.valueField;
			}
			set {
				this.valueField = value;
			}
		}
	}


	/// <summary>Stores values of <a href='CreativeTemplateVariable'>CreativeTemplateVariable</a>
	/// of <a href='VariableType#LONG'>VariableType#LONG</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LongCreativeTemplateVariableValue : BaseCreativeTemplateVariableValue {
		private long valueField;

		private bool valueFieldSpecified;

		/// <summary>The long value of <a
		/// href='CreativeTemplateVariable'>CreativeTemplateVariable</a>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long value {
			get {
				return this.valueField;
			}
			set {
				this.valueField = value;
				this.valueSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="value" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool valueSpecified {
			get {
				return this.valueFieldSpecified;
			}
			set {
				this.valueFieldSpecified = value;
			}
		}
	}


	/// <summary>Stores values of <a href='CreativeTemplateVariable'>CreativeTemplateVariable</a>
	/// of <a href='VariableType#ASSET'>VariableType#ASSET</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AssetCreativeTemplateVariableValue : BaseCreativeTemplateVariableValue {
		private CreativeAsset assetField;

		/// <summary>The associated asset. This attribute is required when creating a new
		/// <code>TemplateCreative</code>. To view the asset, use <a
		/// href='CreativeAsset#assetUrl'>CreativeAsset#assetUrl</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CreativeAsset asset {
			get {
				return this.assetField;
			}
			set {
				this.assetField = value;
			}
		}
	}


	/// <summary>A <code>CreativeAsset</code> is an asset that can be used in creatives.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreativeAsset {
		private long assetIdField;

		private bool assetIdFieldSpecified;

		private byte[] assetByteArrayField;

		private string fileNameField;

		private long fileSizeField;

		private bool fileSizeFieldSpecified;

		private string assetUrlField;

		private Size sizeField;

		private ClickTag[] clickTagsField;

		private ImageDensity imageDensityField;

		private bool imageDensityFieldSpecified;

		/// <summary>The ID of the asset. This attribute is generated by Google upon creation.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long assetId {
			get {
				return this.assetIdField;
			}
			set {
				this.assetIdField = value;
				this.assetIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="assetId" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool assetIdSpecified {
			get {
				return this.assetIdFieldSpecified;
			}
			set {
				this.assetIdFieldSpecified = value;
			}
		}

		/// <summary>The content of the asset as a byte array. This attribute is required when
		/// creating the creative that contains this asset if an <code>assetId</code> is not
		/// provided. <br /> When updating the content, pass a new byte array, and set
		/// <code></code> to null. Otherwise, this field can be null. <br /> The
		/// <code>assetByteArray</code> will be <code>null</code> when the creative is
		/// retrieved.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(DataType = "base64Binary", Order = 1)]
		public byte[] assetByteArray {
			get {
				return this.assetByteArrayField;
			}
			set {
				this.assetByteArrayField = value;
			}
		}

		/// <summary>The file name of the asset. This attribute is required when creating a new asset
		/// (e.g. when <a href='#assetByteArray'>#assetByteArray</a> is not null).
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string fileName {
			get {
				return this.fileNameField;
			}
			set {
				this.fileNameField = value;
			}
		}

		/// <summary>The file size of the asset in bytes. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public long fileSize {
			get {
				return this.fileSizeField;
			}
			set {
				this.fileSizeField = value;
				this.fileSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="fileSize"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool fileSizeSpecified {
			get {
				return this.fileSizeFieldSpecified;
			}
			set {
				this.fileSizeFieldSpecified = value;
			}
		}

		/// <summary>A URL where the asset can be previewed at. This field is read-only and set by
		/// Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string assetUrl {
			get {
				return this.assetUrlField;
			}
			set {
				this.assetUrlField = value;
			}
		}

		/// <summary>The size of the asset. Note that this may not always reflect the actual physical
		/// size of the asset, but may reflect the expected size. This attribute is
		/// read-only and is populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public Size size {
			get {
				return this.sizeField;
			}
			set {
				this.sizeField = value;
			}
		}

		/// <summary>The click tags of the asset. This field is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("clickTags", Order = 6)]
		public ClickTag[] clickTags {
			get {
				return this.clickTagsField;
			}
			set {
				this.clickTagsField = value;
			}
		}

		/// <summary>The display density of the image. This is the ratio between a dimension in
		/// pixels of the image and the dimension in pixels that it should occupy in
		/// device-independent pixels when displayed. This attribute is optional and
		/// defaults to ONE_TO_ONE.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public ImageDensity imageDensity {
			get {
				return this.imageDensityField;
			}
			set {
				this.imageDensityField = value;
				this.imageDensitySpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="imageDensity" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool imageDensitySpecified {
			get {
				return this.imageDensityFieldSpecified;
			}
			set {
				this.imageDensityFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents the dimensions of an <a href='AdUnit'>AdUnit</a>, <a
	/// href='LineItem'>LineItem</a> or <a href='Creative'>Creative</a>. <p>For
	/// interstitial size (out-of-page), native, ignored and fluid size,
	/// <code>Size</code> must be 1x1.</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Size {
		private int widthField;

		private bool widthFieldSpecified;

		private int heightField;

		private bool heightFieldSpecified;

		private bool isAspectRatioField;

		private bool isAspectRatioFieldSpecified;

		/// <summary>The width of the <a href='AdUnit'>AdUnit</a>, <a href='LineItem'>LineItem</a> or
		/// <a href='Creative'>Creative</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int width {
			get {
				return this.widthField;
			}
			set {
				this.widthField = value;
				this.widthSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="width" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool widthSpecified {
			get {
				return this.widthFieldSpecified;
			}
			set {
				this.widthFieldSpecified = value;
			}
		}

		/// <summary>The height of the <a href='AdUnit'>AdUnit</a>, <a href='LineItem'>LineItem</a>
		/// or <a href='Creative'>Creative</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int height {
			get {
				return this.heightField;
			}
			set {
				this.heightField = value;
				this.heightSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="height" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool heightSpecified {
			get {
				return this.heightFieldSpecified;
			}
			set {
				this.heightFieldSpecified = value;
			}
		}

		/// <summary>True if this size represents an aspect ratio, false otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public bool isAspectRatio {
			get {
				return this.isAspectRatioField;
			}
			set {
				this.isAspectRatioField = value;
				this.isAspectRatioSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isAspectRatio" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isAspectRatioSpecified {
			get {
				return this.isAspectRatioFieldSpecified;
			}
			set {
				this.isAspectRatioFieldSpecified = value;
			}
		}
	}


	/// <summary>Click tags define click-through URLs for each exit on an HTML5 creative. An exit
	/// is any area that can be clicked that directs the browser to a landing page. Each
	/// click tag defines the click-through URL for a different exit. In Ad Manager,
	/// tracking pixels are attached to the click tags if URLs are valid.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ClickTag {
		private string nameField;

		private string urlField;

		/// <summary>Name of the click tag, follows the regex "clickTag\\d*"
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>URL of the click tag.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string url {
			get {
				return this.urlField;
			}
			set {
				this.urlField = value;
			}
		}
	}


	/// <summary>Image densities.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ImageDensity {
		/// <summary>Indicates that there is a 1:1 ratio between the dimensions of the raw image and
		/// the dimensions that it should be displayed at in device-independent pixels.
		/// </summary>
		ONE_TO_ONE = 0,
		/// <summary>Indicates that there is a 3:2 ratio between the dimensions of the raw image and
		/// the dimensions that it should be displayed at in device-independent pixels.
		/// </summary>
		THREE_TO_TWO = 1,
		/// <summary>Indicates that there is a 2:1 ratio between the dimensions of the raw image and
		/// the dimensions that it should be displayed at in device-independent pixels.
		/// </summary>
		TWO_TO_ONE = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>A <code>CustomCreativeAsset</code> is an association between a <a
	/// href='CustomCreative'>CustomCreative</a> and an asset. Any assets that are
	/// associated with a creative can be inserted into its HTML snippet.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomCreativeAsset {
		private string macroNameField;

		private CreativeAsset assetField;

		/// <summary>The name by which the associated asset will be referenced. For example, if the
		/// value is "foo", then the asset can be inserted into an HTML snippet using the
		/// macro: "%%FILE:foo%%".
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string macroName {
			get {
				return this.macroNameField;
			}
			set {
				this.macroNameField = value;
			}
		}

		/// <summary>The asset. This attribute is required. To view the asset, use <a
		/// href='CreativeAsset#assetUrl'>CreativeAsset#assetUrl</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public CreativeAsset asset {
			get {
				return this.assetField;
			}
			set {
				this.assetField = value;
			}
		}
	}


	/// <summary>Metadata for a video asset.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class VideoMetadata {
		private ScalableType scalableTypeField;

		private bool scalableTypeFieldSpecified;

		private int durationField;

		private bool durationFieldSpecified;

		private int bitRateField;

		private bool bitRateFieldSpecified;

		private int minimumBitRateField;

		private bool minimumBitRateFieldSpecified;

		private int maximumBitRateField;

		private bool maximumBitRateFieldSpecified;

		private Size sizeField;

		private MimeType mimeTypeField;

		private bool mimeTypeFieldSpecified;

		private VideoDeliveryType deliveryTypeField;

		private bool deliveryTypeFieldSpecified;

		private string[] codecsField;

		/// <summary>The scalable type of the asset. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ScalableType scalableType {
			get {
				return this.scalableTypeField;
			}
			set {
				this.scalableTypeField = value;
				this.scalableTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="scalableType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool scalableTypeSpecified {
			get {
				return this.scalableTypeFieldSpecified;
			}
			set {
				this.scalableTypeFieldSpecified = value;
			}
		}

		/// <summary>The duration of the asset in milliseconds. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int duration {
			get {
				return this.durationField;
			}
			set {
				this.durationField = value;
				this.durationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="duration"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool durationSpecified {
			get {
				return this.durationFieldSpecified;
			}
			set {
				this.durationFieldSpecified = value;
			}
		}

		/// <summary>The bit rate of the asset in kbps. If the asset can play at a range of bit rates
		/// (such as an Http Live Streaming video), then set the bit rate to zero and
		/// populate the minimum and maximum bit rate instead.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public int bitRate {
			get {
				return this.bitRateField;
			}
			set {
				this.bitRateField = value;
				this.bitRateSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="bitRate" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool bitRateSpecified {
			get {
				return this.bitRateFieldSpecified;
			}
			set {
				this.bitRateFieldSpecified = value;
			}
		}

		/// <summary>The minimum bitrate of the video in kbps. Only set this if the asset can play at
		/// a range of bit rates.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public int minimumBitRate {
			get {
				return this.minimumBitRateField;
			}
			set {
				this.minimumBitRateField = value;
				this.minimumBitRateSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="minimumBitRate" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool minimumBitRateSpecified {
			get {
				return this.minimumBitRateFieldSpecified;
			}
			set {
				this.minimumBitRateFieldSpecified = value;
			}
		}

		/// <summary>The maximum bitrate of the video in kbps. Only set this if the asset can play at
		/// a range of bit rates.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public int maximumBitRate {
			get {
				return this.maximumBitRateField;
			}
			set {
				this.maximumBitRateField = value;
				this.maximumBitRateSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="maximumBitRate" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool maximumBitRateSpecified {
			get {
				return this.maximumBitRateFieldSpecified;
			}
			set {
				this.maximumBitRateFieldSpecified = value;
			}
		}

		/// <summary>The size (width and height) of the asset. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public Size size {
			get {
				return this.sizeField;
			}
			set {
				this.sizeField = value;
			}
		}

		/// <summary>The mime type of the asset. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public MimeType mimeType {
			get {
				return this.mimeTypeField;
			}
			set {
				this.mimeTypeField = value;
				this.mimeTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="mimeType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool mimeTypeSpecified {
			get {
				return this.mimeTypeFieldSpecified;
			}
			set {
				this.mimeTypeFieldSpecified = value;
			}
		}

		/// <summary>The delivery type of the asset. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public VideoDeliveryType deliveryType {
			get {
				return this.deliveryTypeField;
			}
			set {
				this.deliveryTypeField = value;
				this.deliveryTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="deliveryType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool deliveryTypeSpecified {
			get {
				return this.deliveryTypeFieldSpecified;
			}
			set {
				this.deliveryTypeFieldSpecified = value;
			}
		}

		/// <summary>The codecs of the asset. This attribute is optional and defaults to an empty
		/// list.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("codecs", Order = 8)]
		public string[] codecs {
			get {
				return this.codecsField;
			}
			set {
				this.codecsField = value;
			}
		}
	}


	/// <summary>The different ways a video/flash can scale.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ScalableType {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		/// <summary>The creative should not be scaled.
		/// </summary>
		NOT_SCALABLE = 1,
		/// <summary>The creative can be scaled and its aspect-ratio must be maintained.
		/// </summary>
		RATIO_SCALABLE = 2,
		/// <summary>The creative can be scaled and its aspect-ratio can be distorted.
		/// </summary>
		STRETCH_SCALABLE = 3,
	}


	/// <summary>Enum of supported mime types
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum MimeType {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		/// <summary>application/x-asp
		/// </summary>
		ASP = 1,
		/// <summary>audio/aiff
		/// </summary>
		AUDIO_AIFF = 2,
		/// <summary>audio/basic
		/// </summary>
		AUDIO_BASIC = 3,
		/// <summary>audio/flac
		/// </summary>
		AUDIO_FLAC = 4,
		/// <summary>audio/mid
		/// </summary>
		AUDIO_MID = 5,
		/// <summary>audio/mpeg
		/// </summary>
		AUDIO_MP3 = 6,
		/// <summary>audio/mp4
		/// </summary>
		AUDIO_MP4 = 7,
		/// <summary>audio/x-mpegurl
		/// </summary>
		AUDIO_MPEG_URL = 8,
		/// <summary>audio/x-ms-wma
		/// </summary>
		AUDIO_MS_WMA = 9,
		/// <summary>audio/ogg
		/// </summary>
		AUDIO_OGG = 10,
		/// <summary>audio/x-pn-realaudio-plugin
		/// </summary>
		AUDIO_REAL_AUDIO_PLUGIN = 11,
		/// <summary>audio/x-wav
		/// </summary>
		AUDIO_WAV = 12,
		/// <summary>application/binary
		/// </summary>
		BINARY = 13,
		/// <summary>application/dash+xml
		/// </summary>
		DASH = 62,
		/// <summary>application/x-director
		/// </summary>
		DIRECTOR = 14,
		/// <summary>application/x-shockwave-flash
		/// </summary>
		FLASH = 15,
		/// <summary>application/graphicconverter
		/// </summary>
		GRAPHIC_CONVERTER = 16,
		/// <summary>application/x-javascript
		/// </summary>
		JAVASCRIPT = 17,
		/// <summary>application/json
		/// </summary>
		JSON = 18,
		/// <summary>image/x-win-bitmap
		/// </summary>
		IMAGE_BITMAP = 19,
		/// <summary>image/bmp
		/// </summary>
		IMAGE_BMP = 20,
		/// <summary>image/gif
		/// </summary>
		IMAGE_GIF = 21,
		/// <summary>image/jpeg
		/// </summary>
		IMAGE_JPEG = 22,
		/// <summary>image/photoshop
		/// </summary>
		IMAGE_PHOTOSHOP = 23,
		/// <summary>image/png
		/// </summary>
		IMAGE_PNG = 24,
		/// <summary>image/tiff
		/// </summary>
		IMAGE_TIFF = 25,
		/// <summary>image/vnd.wap.wbmp
		/// </summary>
		IMAGE_WBMP = 26,
		/// <summary>application/x-mpegURL
		/// </summary>
		M3U8 = 27,
		/// <summary>application/mac-binhex40
		/// </summary>
		MAC_BIN_HEX_40 = 28,
		/// <summary>application/vnd.ms-excel
		/// </summary>
		MS_EXCEL = 29,
		/// <summary>application/ms-powerpoint
		/// </summary>
		MS_POWERPOINT = 30,
		/// <summary>application/msword
		/// </summary>
		MS_WORD = 31,
		/// <summary>application/octet-stream
		/// </summary>
		OCTET_STREAM = 32,
		/// <summary>application/pdf
		/// </summary>
		PDF = 33,
		/// <summary>application/postscript
		/// </summary>
		POSTSCRIPT = 34,
		/// <summary>application/vnd.rn-realmedia
		/// </summary>
		RN_REAL_MEDIA = 35,
		/// <summary>message/rfc822
		/// </summary>
		RFC_822 = 36,
		/// <summary>application/rtf
		/// </summary>
		RTF = 37,
		/// <summary>text/calendar
		/// </summary>
		TEXT_CALENDAR = 38,
		/// <summary>text/css
		/// </summary>
		TEXT_CSS = 39,
		/// <summary>text/csv
		/// </summary>
		TEXT_CSV = 40,
		/// <summary>text/html
		/// </summary>
		TEXT_HTML = 41,
		/// <summary>text/java
		/// </summary>
		TEXT_JAVA = 42,
		/// <summary>text/plain
		/// </summary>
		TEXT_PLAIN = 43,
		/// <summary>video/3gpp
		/// </summary>
		VIDEO_3GPP = 44,
		/// <summary>video/3gpp2
		/// </summary>
		VIDEO_3GPP2 = 45,
		/// <summary>video/avi
		/// </summary>
		VIDEO_AVI = 46,
		/// <summary>video/x-flv
		/// </summary>
		VIDEO_FLV = 47,
		/// <summary>video/mp4
		/// </summary>
		VIDEO_MP4 = 48,
		/// <summary>video/mp4v-es
		/// </summary>
		VIDEO_MP4V_ES = 49,
		/// <summary>video/mpeg
		/// </summary>
		VIDEO_MPEG = 50,
		/// <summary>video/x-ms-asf
		/// </summary>
		VIDEO_MS_ASF = 51,
		/// <summary>video/x-ms-wm
		/// </summary>
		VIDEO_MS_WM = 52,
		/// <summary>video/x-ms-wmv
		/// </summary>
		VIDEO_MS_WMV = 53,
		/// <summary>video/x-ms-wvx
		/// </summary>
		VIDEO_MS_WVX = 54,
		/// <summary>video/ogg
		/// </summary>
		VIDEO_OGG = 55,
		/// <summary>video/x-quicktime
		/// </summary>
		VIDEO_QUICKTIME = 56,
		/// <summary>video/webm
		/// </summary>
		VIDEO_WEBM = 57,
		/// <summary>application/xaml+xml
		/// </summary>
		XAML = 58,
		/// <summary>application/xhtml+xml
		/// </summary>
		XHTML = 59,
		/// <summary>application/xml
		/// </summary>
		XML = 60,
		/// <summary>application/zip
		/// </summary>
		ZIP = 61,
	}


	/// <summary>The video delivery type.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum VideoDeliveryType {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		/// <summary>Video will be served through a progressive download.
		/// </summary>
		PROGRESSIVE = 1,
		/// <summary>Video will be served via a streaming protocol like RTMP.
		/// </summary>
		STREAMING = 2,
	}


	/// <summary>Base asset properties.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RedirectAsset))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(VideoRedirectAsset))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class Asset {
	}


	/// <summary>An externally hosted asset.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(VideoRedirectAsset))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class RedirectAsset : Asset {
		private string redirectUrlField;

		/// <summary>The URL where the asset is hosted.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string redirectUrl {
			get {
				return this.redirectUrlField;
			}
			set {
				this.redirectUrlField = value;
			}
		}
	}


	/// <summary>An externally-hosted video asset.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class VideoRedirectAsset : RedirectAsset {
		private VideoMetadata metadataField;

		/// <summary>Metadata related to the asset. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public VideoMetadata metadata {
			get {
				return this.metadataField;
			}
			set {
				this.metadataField = value;
			}
		}
	}


	/// <summary>This represents an entry in a map with a key of type ConversionEvent and value
	/// of type TrackingUrls.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ConversionEvent_TrackingUrlsMapEntry {
		private ConversionEvent keyField;

		private bool keyFieldSpecified;

		private string[] valueField;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ConversionEvent key {
			get {
				return this.keyField;
			}
			set {
				this.keyField = value;
				this.keySpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="key" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool keySpecified {
			get {
				return this.keyFieldSpecified;
			}
			set {
				this.keyFieldSpecified = value;
			}
		}

		[System.Xml.Serialization.XmlArrayAttribute(Order = 1)]
		[System.Xml.Serialization.XmlArrayItemAttribute("urls", IsNullable = false)]
		public string[] value {
			get {
				return this.valueField;
			}
			set {
				this.valueField = value;
			}
		}
	}


	/// <summary>All possible tracking event types. Not all events are supported by every kind of
	/// creative.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ConversionEvent {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		/// <summary>Corresponds to the <code>creativeView</code> tracking event.
		/// </summary>
		CREATIVE_VIEW = 1,
		/// <summary>Corresponds to the <code>start</code> tracking event.
		/// </summary>
		START = 2,
		/// <summary>An event that is fired when a video skip button is shown, usually after 5
		/// seconds of viewing the video. This event does not correspond to any VAST element
		/// and is implemented using an extension.
		/// </summary>
		SKIP_SHOWN = 3,
		/// <summary>Corresponds to the <code>firstQuartile</code> tracking event.
		/// </summary>
		FIRST_QUARTILE = 4,
		/// <summary>Corresponds to the <code>midpoint</code> tracking event.
		/// </summary>
		MIDPOINT = 5,
		/// <summary>Corresponds to the <code>thirdQuartile</code> tracking event.
		/// </summary>
		THIRD_QUARTILE = 6,
		/// <summary>An event that is fired after 30 seconds of viewing the video or when the video
		/// finished (if the video duration is less than 30 seconds). This event does not
		/// correspond to any VAST element and is implemented using an extension.
		/// </summary>
		ENGAGED_VIEW = 7,
		/// <summary>Corresponds to the <code>complete</code> tracking event.
		/// </summary>
		COMPLETE = 8,
		/// <summary>Corresponds to the <code>mute</code> tracking event.
		/// </summary>
		MUTE = 9,
		/// <summary>Corresponds to the <code>unmute</code> tracking event.
		/// </summary>
		UNMUTE = 10,
		/// <summary>Corresponds to the <code>pause</code> tracking event.
		/// </summary>
		PAUSE = 11,
		/// <summary>Corresponds to the <code>rewind</code> tracking event.
		/// </summary>
		REWIND = 12,
		/// <summary>Corresponds to the <code>resume</code> tracking event.
		/// </summary>
		RESUME = 13,
		/// <summary>An event that is fired when a video was skipped. This event does not correspond
		/// to any VAST element and is implemented using an extension.
		/// </summary>
		SKIPPED = 14,
		/// <summary>Corresponds to the <code>fullscreen</code> tracking event.
		/// </summary>
		FULLSCREEN = 15,
		/// <summary>Corresponds to the <code>expand</code> tracking event.
		/// </summary>
		EXPAND = 16,
		/// <summary>Corresponds to the <code>collapse</code> tracking event.
		/// </summary>
		COLLAPSE = 17,
		/// <summary>Corresponds to the <code>acceptInvitation</code> tracking event.
		/// </summary>
		ACCEPT_INVITATION = 18,
		/// <summary>Corresponds to the <code>close</code> tracking event.
		/// </summary>
		CLOSE = 19,
		/// <summary>Corresponds to the <code>Linear.VideoClicks.ClickTracking</code> node.
		/// </summary>
		CLICK_TRACKING = 20,
		/// <summary>Corresponds to the <code>InLine.Survey</code> node.
		/// </summary>
		SURVEY = 21,
		/// <summary>Corresponds to the <code>Linear.VideoClicks.CustomClick</code> node.
		/// </summary>
		CUSTOM_CLICK = 22,
		/// <summary>Corresponds to the <code>measurableImpression</code> tracking event.
		/// </summary>
		MEASURABLE_IMPRESSION = 23,
		/// <summary>Corresponds to the <code>viewableImpression</code> tracking event.
		/// </summary>
		VIEWABLE_IMPRESSION = 24,
		/// <summary>Corresponds to the <code>abandon</code> tracking event.
		/// </summary>
		VIDEO_ABANDON = 25,
		/// <summary>Corresponds to the <code></code> tracking event.
		/// </summary>
		FULLY_VIEWABLE_AUDIBLE_HALF_DURATION_IMPRESSION = 26,
	}


	/// <summary>A fallback swiffy asset used for flash creatives.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SwiffyFallbackAsset {
		private CreativeAsset assetField;

		private Html5Feature[] html5FeaturesField;

		private string[] localizedInfoMessagesField;

		/// <summary>The Swiffy asset.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CreativeAsset asset {
			get {
				return this.assetField;
			}
			set {
				this.assetField = value;
			}
		}

		/// <summary>A list of <a href='Html5Feature'>HTML5 features</a> required to play this Swiffy
		/// fallback asset correctly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("html5Features", Order = 1)]
		public Html5Feature[] html5Features {
			get {
				return this.html5FeaturesField;
			}
			set {
				this.html5FeaturesField = value;
			}
		}

		/// <summary>A list of localized messages that give detailed information about the Swiffy
		/// conversion. Does not contain error or warning messages.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("localizedInfoMessages", Order = 2)]
		public string[] localizedInfoMessages {
			get {
				return this.localizedInfoMessagesField;
			}
			set {
				this.localizedInfoMessagesField = value;
			}
		}
	}


	/// <summary>An HTML5 features required by HTML5 assets.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum Html5Feature {
		/// <summary>Requires a basic SVG animation.
		/// </summary>
		BASIC_SVG = 0,
		/// <summary>Requires support for SVG filter based animation.
		/// </summary>
		SVG_FILTERS = 1,
		/// <summary>The feature is not known or defined in newer versions.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Represents a child asset in <code>RichMediaStudioCreative</code>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RichMediaStudioChildAssetProperty {
		private string nameField;

		private RichMediaStudioChildAssetPropertyType typeField;

		private bool typeFieldSpecified;

		private long totalFileSizeField;

		private bool totalFileSizeFieldSpecified;

		private int widthField;

		private bool widthFieldSpecified;

		private int heightField;

		private bool heightFieldSpecified;

		private string urlField;

		/// <summary>The name of the asset as known by Rich Media Studio. This attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>Required file type of the asset. This attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public RichMediaStudioChildAssetPropertyType type {
			get {
				return this.typeField;
			}
			set {
				this.typeField = value;
				this.typeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="type" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool typeSpecified {
			get {
				return this.typeFieldSpecified;
			}
			set {
				this.typeFieldSpecified = value;
			}
		}

		/// <summary>The total size of the asset in bytes. This attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public long totalFileSize {
			get {
				return this.totalFileSizeField;
			}
			set {
				this.totalFileSizeField = value;
				this.totalFileSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalFileSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalFileSizeSpecified {
			get {
				return this.totalFileSizeFieldSpecified;
			}
			set {
				this.totalFileSizeFieldSpecified = value;
			}
		}

		/// <summary>Width of the widget in pixels. This attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public int width {
			get {
				return this.widthField;
			}
			set {
				this.widthField = value;
				this.widthSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="width" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool widthSpecified {
			get {
				return this.widthFieldSpecified;
			}
			set {
				this.widthFieldSpecified = value;
			}
		}

		/// <summary>Height of the widget in pixels. This attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public int height {
			get {
				return this.heightField;
			}
			set {
				this.heightField = value;
				this.heightSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="height" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool heightSpecified {
			get {
				return this.heightFieldSpecified;
			}
			set {
				this.heightFieldSpecified = value;
			}
		}

		/// <summary>The URL of the asset. This attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public string url {
			get {
				return this.urlField;
			}
			set {
				this.urlField = value;
			}
		}
	}


	/// <summary>Type of <code>RichMediaStudioChildAssetProperty</code>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "RichMediaStudioChildAssetProperty.Type", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RichMediaStudioChildAssetPropertyType {
		/// <summary>SWF files
		/// </summary>
		FLASH = 0,
		/// <summary>FLVS and any other video file types
		/// </summary>
		VIDEO = 1,
		/// <summary>Image files
		/// </summary>
		IMAGE = 2,
		/// <summary>The rest of the supported file types .txt, .xml, etc.
		/// </summary>
		DATA = 3,
	}


	/// <summary>The value of a <a href='CustomField'>CustomField</a> for a particular entity.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DropDownCustomFieldValue))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CustomFieldValue))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class BaseCustomFieldValue {
		private long customFieldIdField;

		private bool customFieldIdFieldSpecified;

		/// <summary>Id of the <code>CustomField</code> to which this value belongs. This attribute
		/// is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long customFieldId {
			get {
				return this.customFieldIdField;
			}
			set {
				this.customFieldIdField = value;
				this.customFieldIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="customFieldId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool customFieldIdSpecified {
			get {
				return this.customFieldIdFieldSpecified;
			}
			set {
				this.customFieldIdFieldSpecified = value;
			}
		}
	}


	/// <summary>A <a href='CustomFieldValue'>CustomFieldValue</a> for a <a
	/// href='CustomField'>CustomField</a> that has a <a
	/// href='CustomField#dataType'>CustomField#dataType</a> of <a
	/// href='CustomFieldDataType#DROP_DOWN'>CustomFieldDataType#DROP_DOWN</a>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DropDownCustomFieldValue : BaseCustomFieldValue {
		private long customFieldOptionIdField;

		private bool customFieldOptionIdFieldSpecified;

		/// <summary>The <a href='CustomFieldOption#id'>ID</a> of the <a
		/// href='CustomFieldOption'>CustomFieldOption</a> for this value.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long customFieldOptionId {
			get {
				return this.customFieldOptionIdField;
			}
			set {
				this.customFieldOptionIdField = value;
				this.customFieldOptionIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="customFieldOptionId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool customFieldOptionIdSpecified {
			get {
				return this.customFieldOptionIdFieldSpecified;
			}
			set {
				this.customFieldOptionIdFieldSpecified = value;
			}
		}
	}


	/// <summary>The value of a <a href='CustomField'>CustomField</a> that does not have a <a
	/// href='CustomField#dataType'>CustomField#dataType</a> of <a
	/// href='CustomFieldDataType#DROP_DOWN'>CustomFieldDataType#DROP_DOWN</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomFieldValue : BaseCustomFieldValue {
		private Value valueField;

		/// <summary>The value for this field. The appropriate type of <code>Value</code> is
		/// determined by the <a href='CustomField#dataType'>CustomField#dataType</a> of the
		/// <code></code> that this conforms to. <table> <tr> <th><a
		/// href='CustomFieldDataType'>CustomFieldDataType</a></th> <th><a
		/// href='Value'>Value</a> type</th> </tr> <tr> <td><a
		/// href='CustomFieldDataType#STRING'>STRING</a></td> <td><a
		/// href='TextValue'>TextValue</a></td> </tr> <tr> <td><a
		/// href='CustomFieldDataType#NUMBER'>NUMBER</a></td> <td><a
		/// href='NumberValue'>NumberValue</a></td> </tr> <tr> <td><a
		/// href='CustomFieldDataType#TOGGLE'>TOGGLE</a></td> <td><a
		/// href='BooleanValue'>BooleanValue</a></td> </tr> </table>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public Value value {
			get {
				return this.valueField;
			}
			set {
				this.valueField = value;
			}
		}
	}


	/// <summary>Represents a <a href='Label'>Label</a> that can be applied to an entity. To
	/// negate an inherited label, create an <code></code> with <code>labelId</code> as
	/// the inherited label's ID and <code>isNegated</code> set to true.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AppliedLabel {
		private long labelIdField;

		private bool labelIdFieldSpecified;

		private bool isNegatedField;

		private bool isNegatedFieldSpecified;

		/// <summary>The ID of a created <a href='Label'>Label</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long labelId {
			get {
				return this.labelIdField;
			}
			set {
				this.labelIdField = value;
				this.labelIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="labelId" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool labelIdSpecified {
			get {
				return this.labelIdFieldSpecified;
			}
			set {
				this.labelIdFieldSpecified = value;
			}
		}

		/// <summary><code>isNegated</code> should be set to <code>true</code> to negate the effects
		/// of <code>labelId</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public bool isNegated {
			get {
				return this.isNegatedField;
			}
			set {
				this.isNegatedField = value;
				this.isNegatedSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isNegated"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isNegatedSpecified {
			get {
				return this.isNegatedFieldSpecified;
			}
			set {
				this.isNegatedFieldSpecified = value;
			}
		}
	}


	/// <summary>A <code>Creative</code> represents the media for the ad being served. <p>Read
	/// more about creatives on the <a
	/// href="https://support.google.com/dfp_premium/answer/3185155">Ad Manager Help
	/// Center</a>.</p>
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(VastRedirectCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UnsupportedCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ThirdPartyCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(TemplateCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProgrammaticCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(LegacyDfpCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(InternalRedirectCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(Html5Creative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(HasDestinationUrlCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CustomCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BaseVideoCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(VideoRedirectCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(VideoCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SetTopBoxCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BaseImageRedirectCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ImageRedirectOverlayCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ImageRedirectCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BaseImageCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ImageOverlayCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ImageCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BaseFlashRedirectCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(FlashRedirectOverlayCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(FlashRedirectCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BaseFlashCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(FlashOverlayCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(FlashCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AspectRatioImageCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ClickTrackingCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BaseRichMediaStudioCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RichMediaStudioCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BaseDynamicAllocationCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(HasHtmlSnippetDynamicAllocationCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AdSenseCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AdExchangeCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AdMobBackfillCreative))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class Creative {
		private long advertiserIdField;

		private bool advertiserIdFieldSpecified;

		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private Size sizeField;

		private string previewUrlField;

		private CreativePolicyViolation[] policyViolationsField;

		private AppliedLabel[] appliedLabelsField;

		private DateTime lastModifiedDateTimeField;

		private BaseCustomFieldValue[] customFieldValuesField;

		/// <summary>The ID of the advertiser that owns the creative. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long advertiserId {
			get {
				return this.advertiserIdField;
			}
			set {
				this.advertiserIdField = value;
				this.advertiserIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="advertiserId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool advertiserIdSpecified {
			get {
				return this.advertiserIdFieldSpecified;
			}
			set {
				this.advertiserIdFieldSpecified = value;
			}
		}

		/// <summary>Uniquely identifies the <code>Creative</code>. This value is read-only and is
		/// assigned by Google when the creative is created. This attribute is required for
		/// updates.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the creative. This attribute is required and has a maximum length of
		/// 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The <a href='Size'>Size</a> of the creative. This attribute is required for
		/// creation and then is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public Size size {
			get {
				return this.sizeField;
			}
			set {
				this.sizeField = value;
			}
		}

		/// <summary>The URL of the creative for previewing the media. This attribute is read-only
		/// and is assigned by Google when a creative is created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string previewUrl {
			get {
				return this.previewUrlField;
			}
			set {
				this.previewUrlField = value;
			}
		}

		/// <summary>Set of policy violations detected for this creative. This attribute is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("policyViolations", Order = 5)]
		public CreativePolicyViolation[] policyViolations {
			get {
				return this.policyViolationsField;
			}
			set {
				this.policyViolationsField = value;
			}
		}

		/// <summary>The set of labels applied to this creative.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("appliedLabels", Order = 6)]
		public AppliedLabel[] appliedLabels {
			get {
				return this.appliedLabelsField;
			}
			set {
				this.appliedLabelsField = value;
			}
		}

		/// <summary>The date and time this creative was last modified.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public DateTime lastModifiedDateTime {
			get {
				return this.lastModifiedDateTimeField;
			}
			set {
				this.lastModifiedDateTimeField = value;
			}
		}

		/// <summary>The values of the custom fields associated with this creative.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("customFieldValues", Order = 8)]
		public BaseCustomFieldValue[] customFieldValues {
			get {
				return this.customFieldValuesField;
			}
			set {
				this.customFieldValuesField = value;
			}
		}
	}


	/// <summary>Represents the different types of policy violations that may be detected on a
	/// given creative. <p>For more information about the various types of policy
	/// violations, see <a
	/// href="https://support.google.com/adwordspolicy/answer/6008942?hl=en">here</a>.</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CreativePolicyViolation {
		/// <summary>Malware was found in the creative. <p>For more information see <a
		/// href="https://support.google.com/adwordspolicy/answer/1308246">here</a>.</p>
		/// </summary>
		MALWARE_IN_CREATIVE = 0,
		/// <summary>Malware was found in the landing page. <p>For more information see <a
		/// href="https://support.google.com/adwordspolicy/answer/1308246">here</a>.</p>
		/// </summary>
		MALWARE_IN_LANDING_PAGE = 1,
		/// <summary>The redirect url contains legally objectionable content.
		/// </summary>
		LEGALLY_BLOCKED_REDIRECT_URL = 2,
		/// <summary>The creative misrepresents the product or service being advertised. <p>For more
		/// information see <a
		/// href="https://support.google.com/adwordspolicy/answer/6020955?hl=en#355">
		/// here</a>.</p>
		/// </summary>
		MISREPRESENTATION_OF_PRODUCT = 3,
		/// <summary>The creative has been determined to be self clicking.
		/// </summary>
		SELF_CLICKING_CREATIVE = 4,
		/// <summary>The creative has been determined as attempting to game the Google network.
		/// <p>For more information see <a
		/// href="https://support.google.com/adwordspolicy/answer/6020954?hl=en#319">
		/// here</a>.</p>
		/// </summary>
		GAMING_GOOGLE_NETWORK = 5,
		/// <summary>The landing page for the creative uses a dynamic DNS. <p>For more information
		/// see <a
		/// href="https://support.google.com/adwordspolicy/answer/6020954?rd=1">here</a>.</p>
		/// </summary>
		DYNAMIC_DNS = 6,
		/// <summary>Phishing found in creative or landing page. <p>For more information see <a
		/// href="https://support.google.com/adwordspolicy/answer/6020955">here</a>.</p>
		/// </summary>
		PHISHING = 7,
		/// <summary>The creative prompts the user to download a file. <p>For more information see <a
		/// href="https://support.google.com/dfp_premium/answer/7513391">here</a></p>
		/// </summary>
		DOWNLOAD_PROMPT_IN_CREATIVE = 9,
		/// <summary>The creative sets an unauthorized cookie on a Google domain. <p>For more
		/// information see <a
		/// href="https://support.google.com/dfp_premium/answer/7513391">here</a></p>
		/// </summary>
		UNAUTHORIZED_COOKIE_DETECTED = 10,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 8,
	}


	/// <summary>A <code>Creative</code> that points to an externally hosted VAST ad and is
	/// served via VAST XML as a VAST Wrapper.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class VastRedirectCreative : Creative {
		private string vastXmlUrlField;

		private VastRedirectType vastRedirectTypeField;

		private bool vastRedirectTypeFieldSpecified;

		private int durationField;

		private bool durationFieldSpecified;

		private long[] companionCreativeIdsField;

		private ConversionEvent_TrackingUrlsMapEntry[] trackingUrlsField;

		private string vastPreviewUrlField;

		private SslScanResult sslScanResultField;

		private bool sslScanResultFieldSpecified;

		private SslManualOverride sslManualOverrideField;

		private bool sslManualOverrideFieldSpecified;

		/// <summary>The URL where the 3rd party VAST XML is hosted. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string vastXmlUrl {
			get {
				return this.vastXmlUrlField;
			}
			set {
				this.vastXmlUrlField = value;
			}
		}

		/// <summary>The type of VAST ad that this redirects to. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public VastRedirectType vastRedirectType {
			get {
				return this.vastRedirectTypeField;
			}
			set {
				this.vastRedirectTypeField = value;
				this.vastRedirectTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="vastRedirectType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool vastRedirectTypeSpecified {
			get {
				return this.vastRedirectTypeFieldSpecified;
			}
			set {
				this.vastRedirectTypeFieldSpecified = value;
			}
		}

		/// <summary>The duration of the VAST ad in milliseconds. This attribute is optional and
		/// defaults to 0.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public int duration {
			get {
				return this.durationField;
			}
			set {
				this.durationField = value;
				this.durationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="duration"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool durationSpecified {
			get {
				return this.durationFieldSpecified;
			}
			set {
				this.durationFieldSpecified = value;
			}
		}

		/// <summary>The IDs of the companion creatives that are associated with this creative. This
		/// attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("companionCreativeIds", Order = 3)]
		public long[] companionCreativeIds {
			get {
				return this.companionCreativeIdsField;
			}
			set {
				this.companionCreativeIdsField = value;
			}
		}

		/// <summary>A map from <code>ConversionEvent</code> to a list of URLs that will be pinged
		/// when the event happens. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("trackingUrls", Order = 4)]
		public ConversionEvent_TrackingUrlsMapEntry[] trackingUrls {
			get {
				return this.trackingUrlsField;
			}
			set {
				this.trackingUrlsField = value;
			}
		}

		/// <summary>An ad tag URL that will return a preview of the VAST XML response specific to
		/// this creative. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public string vastPreviewUrl {
			get {
				return this.vastPreviewUrlField;
			}
			set {
				this.vastPreviewUrlField = value;
			}
		}

		/// <summary>The SSL compatibility scan result for this creative. <p>This attribute is
		/// read-only and determined by Google.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public SslScanResult sslScanResult {
			get {
				return this.sslScanResultField;
			}
			set {
				this.sslScanResultField = value;
				this.sslScanResultSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslScanResult" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslScanResultSpecified {
			get {
				return this.sslScanResultFieldSpecified;
			}
			set {
				this.sslScanResultFieldSpecified = value;
			}
		}

		/// <summary>The manual override for the SSL compatibility of this creative. <p>This
		/// attribute is optional and defaults to <a
		/// href='SslManualOverride#NO_OVERRIDE'>SslManualOverride#NO_OVERRIDE</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public SslManualOverride sslManualOverride {
			get {
				return this.sslManualOverrideField;
			}
			set {
				this.sslManualOverrideField = value;
				this.sslManualOverrideSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslManualOverride" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslManualOverrideSpecified {
			get {
				return this.sslManualOverrideFieldSpecified;
			}
			set {
				this.sslManualOverrideFieldSpecified = value;
			}
		}
	}


	/// <summary>The types of VAST ads that a <a
	/// href='VastRedirectCreative'>VastRedirectCreative</a> can point to.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum VastRedirectType {
		/// <summary>The VAST XML contains only <code>linear</code> ads.
		/// </summary>
		LINEAR = 0,
		/// <summary>The VAST XML contains only <code>nonlinear</code> ads.
		/// </summary>
		NON_LINEAR = 1,
		/// <summary>The VAST XML contains both <code>linear</code> and <code>nonlinear</code> ads.
		/// </summary>
		LINEAR_AND_NON_LINEAR = 2,
	}


	/// <summary>Enum to store the creative SSL compatibility scan result.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum SslScanResult {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		UNSCANNED = 1,
		SCANNED_SSL = 2,
		SCANNED_NON_SSL = 3,
	}


	/// <summary>Enum to store the creative SSL compatibility manual override. Its three states
	/// are similar to that of <a href='SslScanResult'>SslScanResult</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum SslManualOverride {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		NO_OVERRIDE = 1,
		SSL_COMPATIBLE = 2,
		NOT_SSL_COMPATIBLE = 3,
	}


	/// <summary>A <code>Creative</code> that isn't supported by this version of the API. This
	/// object is readonly and when encountered should be reported on the Ad Manager API
	/// forum.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UnsupportedCreative : Creative {
		private string unsupportedCreativeTypeField;

		/// <summary>The creative type that is unsupported by this API version.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string unsupportedCreativeType {
			get {
				return this.unsupportedCreativeTypeField;
			}
			set {
				this.unsupportedCreativeTypeField = value;
			}
		}
	}


	/// <summary>A <code>Creative</code> that is served by a 3rd-party vendor.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ThirdPartyCreative : Creative {
		private string snippetField;

		private string expandedSnippetField;

		private SslScanResult sslScanResultField;

		private bool sslScanResultFieldSpecified;

		private SslManualOverride sslManualOverrideField;

		private bool sslManualOverrideFieldSpecified;

		private LockedOrientation lockedOrientationField;

		private bool lockedOrientationFieldSpecified;

		private bool isSafeFrameCompatibleField;

		private bool isSafeFrameCompatibleFieldSpecified;

		private string[] thirdPartyImpressionTrackingUrlsField;

		/// <summary>The HTML snippet that this creative delivers. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string snippet {
			get {
				return this.snippetField;
			}
			set {
				this.snippetField = value;
			}
		}

		/// <summary>The HTML snippet that this creative delivers with macros expanded. This
		/// attribute is read-only and is set by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string expandedSnippet {
			get {
				return this.expandedSnippetField;
			}
			set {
				this.expandedSnippetField = value;
			}
		}

		/// <summary>The SSL compatibility scan result for this creative. <p>This attribute is
		/// read-only and determined by Google.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public SslScanResult sslScanResult {
			get {
				return this.sslScanResultField;
			}
			set {
				this.sslScanResultField = value;
				this.sslScanResultSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslScanResult" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslScanResultSpecified {
			get {
				return this.sslScanResultFieldSpecified;
			}
			set {
				this.sslScanResultFieldSpecified = value;
			}
		}

		/// <summary>The manual override for the SSL compatibility of this creative. <p>This
		/// attribute is optional and defaults to <a
		/// href='SslManualOverride#NO_OVERRIDE'>SslManualOverride#NO_OVERRIDE</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public SslManualOverride sslManualOverride {
			get {
				return this.sslManualOverrideField;
			}
			set {
				this.sslManualOverrideField = value;
				this.sslManualOverrideSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslManualOverride" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslManualOverrideSpecified {
			get {
				return this.sslManualOverrideFieldSpecified;
			}
			set {
				this.sslManualOverrideFieldSpecified = value;
			}
		}

		/// <summary>A locked orientation for this creative to be displayed in.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public LockedOrientation lockedOrientation {
			get {
				return this.lockedOrientationField;
			}
			set {
				this.lockedOrientationField = value;
				this.lockedOrientationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lockedOrientation" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lockedOrientationSpecified {
			get {
				return this.lockedOrientationFieldSpecified;
			}
			set {
				this.lockedOrientationFieldSpecified = value;
			}
		}

		/// <summary>Whether the <a href='Creative'>Creative</a> is compatible for SafeFrame
		/// rendering. <p>This attribute is optional and defaults to <code>true</code>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public bool isSafeFrameCompatible {
			get {
				return this.isSafeFrameCompatibleField;
			}
			set {
				this.isSafeFrameCompatibleField = value;
				this.isSafeFrameCompatibleSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isSafeFrameCompatible" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isSafeFrameCompatibleSpecified {
			get {
				return this.isSafeFrameCompatibleFieldSpecified;
			}
			set {
				this.isSafeFrameCompatibleFieldSpecified = value;
			}
		}

		/// <summary>A list of impression tracking URLs to ping when this creative is displayed. This
		/// field is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("thirdPartyImpressionTrackingUrls", Order = 6)]
		public string[] thirdPartyImpressionTrackingUrls {
			get {
				return this.thirdPartyImpressionTrackingUrlsField;
			}
			set {
				this.thirdPartyImpressionTrackingUrlsField = value;
			}
		}
	}


	/// <summary>Describes the orientation that a creative should be served with.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LockedOrientation {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		FREE_ORIENTATION = 1,
		PORTRAIT_ONLY = 2,
		LANDSCAPE_ONLY = 3,
	}


	/// <summary>A <code>Creative</code> that is created by the specified creative template.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class TemplateCreative : Creative {
		private long creativeTemplateIdField;

		private bool creativeTemplateIdFieldSpecified;

		private bool isInterstitialField;

		private bool isInterstitialFieldSpecified;

		private bool isNativeEligibleField;

		private bool isNativeEligibleFieldSpecified;

		private bool isSafeFrameCompatibleField;

		private bool isSafeFrameCompatibleFieldSpecified;

		private string destinationUrlField;

		private BaseCreativeTemplateVariableValue[] creativeTemplateVariableValuesField;

		private SslScanResult sslScanResultField;

		private bool sslScanResultFieldSpecified;

		private SslManualOverride sslManualOverrideField;

		private bool sslManualOverrideFieldSpecified;

		private LockedOrientation lockedOrientationField;

		private bool lockedOrientationFieldSpecified;

		/// <summary>Creative template ID that this creative is created from.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long creativeTemplateId {
			get {
				return this.creativeTemplateIdField;
			}
			set {
				this.creativeTemplateIdField = value;
				this.creativeTemplateIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="creativeTemplateId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool creativeTemplateIdSpecified {
			get {
				return this.creativeTemplateIdFieldSpecified;
			}
			set {
				this.creativeTemplateIdFieldSpecified = value;
			}
		}

		/// <summary><code>true</code> if this template instantiated creative is interstitial. This
		/// attribute is read-only and is assigned by Google based on the creative template.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public bool isInterstitial {
			get {
				return this.isInterstitialField;
			}
			set {
				this.isInterstitialField = value;
				this.isInterstitialSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isInterstitial" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isInterstitialSpecified {
			get {
				return this.isInterstitialFieldSpecified;
			}
			set {
				this.isInterstitialFieldSpecified = value;
			}
		}

		/// <summary><code>true</code> if this template instantiated creative is eligible for native
		/// adserving. This attribute is read-only and is assigned by Google based on the
		/// creative template.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public bool isNativeEligible {
			get {
				return this.isNativeEligibleField;
			}
			set {
				this.isNativeEligibleField = value;
				this.isNativeEligibleSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isNativeEligible" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isNativeEligibleSpecified {
			get {
				return this.isNativeEligibleFieldSpecified;
			}
			set {
				this.isNativeEligibleFieldSpecified = value;
			}
		}

		/// <summary>Whether the <a href='Creative'>Creative</a> is compatible for SafeFrame
		/// rendering. <p>This attribute is read-only and is assigned by Google based on the
		/// <a href='CreativeTemplate'>CreativeTemplate</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public bool isSafeFrameCompatible {
			get {
				return this.isSafeFrameCompatibleField;
			}
			set {
				this.isSafeFrameCompatibleField = value;
				this.isSafeFrameCompatibleSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isSafeFrameCompatible" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isSafeFrameCompatibleSpecified {
			get {
				return this.isSafeFrameCompatibleFieldSpecified;
			}
			set {
				this.isSafeFrameCompatibleFieldSpecified = value;
			}
		}

		/// <summary>The URL the user is directed to if they click on the creative. This attribute is
		/// only required if the template snippet contains the <code>%u</code> or
		/// <code>%%DEST_URL%%</code> macro. It has a maximum length of 1024 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string destinationUrl {
			get {
				return this.destinationUrlField;
			}
			set {
				this.destinationUrlField = value;
			}
		}

		/// <summary>Stores values of <a href='CreativeTemplateVariable'>CreativeTemplateVariable</a>
		/// in the <a href='CreativeTemplate'>CreativeTemplate</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("creativeTemplateVariableValues", Order = 5)]
		public BaseCreativeTemplateVariableValue[] creativeTemplateVariableValues {
			get {
				return this.creativeTemplateVariableValuesField;
			}
			set {
				this.creativeTemplateVariableValuesField = value;
			}
		}

		/// <summary>The SSL compatibility scan result for this creative. <p>This attribute is
		/// read-only and determined by Google.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public SslScanResult sslScanResult {
			get {
				return this.sslScanResultField;
			}
			set {
				this.sslScanResultField = value;
				this.sslScanResultSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslScanResult" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslScanResultSpecified {
			get {
				return this.sslScanResultFieldSpecified;
			}
			set {
				this.sslScanResultFieldSpecified = value;
			}
		}

		/// <summary>The manual override for the SSL compatibility of this creative. <p>This
		/// attribute is optional and defaults to <a
		/// href='SslManualOverride#NO_OVERRIDE'>SslManualOverride#NO_OVERRIDE</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public SslManualOverride sslManualOverride {
			get {
				return this.sslManualOverrideField;
			}
			set {
				this.sslManualOverrideField = value;
				this.sslManualOverrideSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslManualOverride" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslManualOverrideSpecified {
			get {
				return this.sslManualOverrideFieldSpecified;
			}
			set {
				this.sslManualOverrideFieldSpecified = value;
			}
		}

		/// <summary>A locked orientation for this creative to be displayed in.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public LockedOrientation lockedOrientation {
			get {
				return this.lockedOrientationField;
			}
			set {
				this.lockedOrientationField = value;
				this.lockedOrientationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lockedOrientation" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lockedOrientationSpecified {
			get {
				return this.lockedOrientationFieldSpecified;
			}
			set {
				this.lockedOrientationFieldSpecified = value;
			}
		}
	}


	/// <summary>A <code>Creative</code> used for programmatic trafficking. This creative will be
	/// auto-created with the right approval from the buyer. This creative cannot be
	/// created through the API. This creative can be updated.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProgrammaticCreative : Creative {
		private bool isSafeFrameCompatibleField;

		private bool isSafeFrameCompatibleFieldSpecified;

		/// <summary><code>true</code> if this <a href='Creative'>Creative</a> is served in a
		/// SafeFrame.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool isSafeFrameCompatible {
			get {
				return this.isSafeFrameCompatibleField;
			}
			set {
				this.isSafeFrameCompatibleField = value;
				this.isSafeFrameCompatibleSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isSafeFrameCompatible" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isSafeFrameCompatibleSpecified {
			get {
				return this.isSafeFrameCompatibleFieldSpecified;
			}
			set {
				this.isSafeFrameCompatibleFieldSpecified = value;
			}
		}
	}


	/// <summary>A <code>Creative</code> that isn't supported by Google DFP, but was migrated
	/// from DART. Creatives of this type cannot be created or modified.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LegacyDfpCreative : Creative {
	}


	/// <summary>A <code>Creative</code> hosted by Campaign Manager. <p>Similar to third-party
	/// creatives, a Campaign Manager tag is used to retrieve a creative asset. However,
	/// Campaign Manager tags are not sent to the user's browser. Instead, they are
	/// processed internally within the Google Marketing Platform system..</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class InternalRedirectCreative : Creative {
		private LockedOrientation lockedOrientationField;

		private bool lockedOrientationFieldSpecified;

		private Size assetSizeField;

		private string internalRedirectUrlField;

		private bool overrideSizeField;

		private bool overrideSizeFieldSpecified;

		private bool isInterstitialField;

		private bool isInterstitialFieldSpecified;

		private SslScanResult sslScanResultField;

		private bool sslScanResultFieldSpecified;

		private SslManualOverride sslManualOverrideField;

		private bool sslManualOverrideFieldSpecified;

		private string[] thirdPartyImpressionTrackingUrlsField;

		/// <summary>A locked orientation for this creative to be displayed in.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public LockedOrientation lockedOrientation {
			get {
				return this.lockedOrientationField;
			}
			set {
				this.lockedOrientationField = value;
				this.lockedOrientationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lockedOrientation" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lockedOrientationSpecified {
			get {
				return this.lockedOrientationFieldSpecified;
			}
			set {
				this.lockedOrientationFieldSpecified = value;
			}
		}

		/// <summary>The asset size of an internal redirect creative. Note that this may differ from
		/// <code>size</code> if users set <code>overrideSize</code> to true. This attribute
		/// is read-only and is populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public Size assetSize {
			get {
				return this.assetSizeField;
			}
			set {
				this.assetSizeField = value;
			}
		}

		/// <summary>The internal redirect URL of the DFA or DART for Publishers hosted creative.
		/// This attribute is required and has a maximum length of 1024 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string internalRedirectUrl {
			get {
				return this.internalRedirectUrlField;
			}
			set {
				this.internalRedirectUrlField = value;
			}
		}

		/// <summary>Allows the creative size to differ from the actual size specified in the
		/// internal redirect's url. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public bool overrideSize {
			get {
				return this.overrideSizeField;
			}
			set {
				this.overrideSizeField = value;
				this.overrideSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="overrideSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool overrideSizeSpecified {
			get {
				return this.overrideSizeFieldSpecified;
			}
			set {
				this.overrideSizeFieldSpecified = value;
			}
		}

		/// <summary><code>true</code> if this internal redirect creative is interstitial.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public bool isInterstitial {
			get {
				return this.isInterstitialField;
			}
			set {
				this.isInterstitialField = value;
				this.isInterstitialSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isInterstitial" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isInterstitialSpecified {
			get {
				return this.isInterstitialFieldSpecified;
			}
			set {
				this.isInterstitialFieldSpecified = value;
			}
		}

		/// <summary>The SSL compatibility scan result for this creative. <p>This attribute is
		/// read-only and determined by Google.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public SslScanResult sslScanResult {
			get {
				return this.sslScanResultField;
			}
			set {
				this.sslScanResultField = value;
				this.sslScanResultSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslScanResult" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslScanResultSpecified {
			get {
				return this.sslScanResultFieldSpecified;
			}
			set {
				this.sslScanResultFieldSpecified = value;
			}
		}

		/// <summary>The manual override for the SSL compatibility of this creative. <p>This
		/// attribute is optional and defaults to <a
		/// href='SslManualOverride#NO_OVERRIDE'>SslManualOverride#NO_OVERRIDE</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public SslManualOverride sslManualOverride {
			get {
				return this.sslManualOverrideField;
			}
			set {
				this.sslManualOverrideField = value;
				this.sslManualOverrideSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslManualOverride" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslManualOverrideSpecified {
			get {
				return this.sslManualOverrideFieldSpecified;
			}
			set {
				this.sslManualOverrideFieldSpecified = value;
			}
		}

		/// <summary>A list of impression tracking URLs to ping when this creative is displayed. This
		/// field is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("thirdPartyImpressionTrackingUrls", Order = 7)]
		public string[] thirdPartyImpressionTrackingUrls {
			get {
				return this.thirdPartyImpressionTrackingUrlsField;
			}
			set {
				this.thirdPartyImpressionTrackingUrlsField = value;
			}
		}
	}


	/// <summary>A <code>Creative</code> that contains a zipped HTML5 bundle asset, a list of
	/// third party impression trackers, and a third party click tracker.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Html5Creative : Creative {
		private bool overrideSizeField;

		private bool overrideSizeFieldSpecified;

		private string[] thirdPartyImpressionTrackingUrlsField;

		private string thirdPartyClickTrackingUrlField;

		private LockedOrientation lockedOrientationField;

		private bool lockedOrientationFieldSpecified;

		private SslScanResult sslScanResultField;

		private bool sslScanResultFieldSpecified;

		private SslManualOverride sslManualOverrideField;

		private bool sslManualOverrideFieldSpecified;

		private bool isSafeFrameCompatibleField;

		private bool isSafeFrameCompatibleFieldSpecified;

		private CreativeAsset html5AssetField;

		/// <summary>Allows the creative size to differ from the actual HTML5 asset size. This
		/// attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool overrideSize {
			get {
				return this.overrideSizeField;
			}
			set {
				this.overrideSizeField = value;
				this.overrideSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="overrideSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool overrideSizeSpecified {
			get {
				return this.overrideSizeFieldSpecified;
			}
			set {
				this.overrideSizeFieldSpecified = value;
			}
		}

		/// <summary>Impression tracking URLs to ping when this creative is displayed. This field is
		/// optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("thirdPartyImpressionTrackingUrls", Order = 1)]
		public string[] thirdPartyImpressionTrackingUrls {
			get {
				return this.thirdPartyImpressionTrackingUrlsField;
			}
			set {
				this.thirdPartyImpressionTrackingUrlsField = value;
			}
		}

		/// <summary>A click tracking URL to ping when this creative is clicked. This field is
		/// optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string thirdPartyClickTrackingUrl {
			get {
				return this.thirdPartyClickTrackingUrlField;
			}
			set {
				this.thirdPartyClickTrackingUrlField = value;
			}
		}

		/// <summary>A locked orientation for this creative to be displayed in.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public LockedOrientation lockedOrientation {
			get {
				return this.lockedOrientationField;
			}
			set {
				this.lockedOrientationField = value;
				this.lockedOrientationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lockedOrientation" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lockedOrientationSpecified {
			get {
				return this.lockedOrientationFieldSpecified;
			}
			set {
				this.lockedOrientationFieldSpecified = value;
			}
		}

		/// <summary>The SSL compatibility scan result of this creative. <p>This attribute is
		/// read-only and determined by Google.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public SslScanResult sslScanResult {
			get {
				return this.sslScanResultField;
			}
			set {
				this.sslScanResultField = value;
				this.sslScanResultSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslScanResult" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslScanResultSpecified {
			get {
				return this.sslScanResultFieldSpecified;
			}
			set {
				this.sslScanResultFieldSpecified = value;
			}
		}

		/// <summary>The manual override for the SSL compatibility of this creative. <p>This
		/// attribute is optional and defaults to <a
		/// href='SslManualOverride#NO_OVERRIDE'>SslManualOverride#NO_OVERRIDE</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public SslManualOverride sslManualOverride {
			get {
				return this.sslManualOverrideField;
			}
			set {
				this.sslManualOverrideField = value;
				this.sslManualOverrideSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslManualOverride" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslManualOverrideSpecified {
			get {
				return this.sslManualOverrideFieldSpecified;
			}
			set {
				this.sslManualOverrideFieldSpecified = value;
			}
		}

		/// <summary>Whether the <a href='Creative'>Creative</a> is compatible for SafeFrame
		/// rendering. <p>This attribute is optional and defaults to <code>true</code>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public bool isSafeFrameCompatible {
			get {
				return this.isSafeFrameCompatibleField;
			}
			set {
				this.isSafeFrameCompatibleField = value;
				this.isSafeFrameCompatibleSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isSafeFrameCompatible" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isSafeFrameCompatibleSpecified {
			get {
				return this.isSafeFrameCompatibleFieldSpecified;
			}
			set {
				this.isSafeFrameCompatibleFieldSpecified = value;
			}
		}

		/// <summary>The HTML5 asset. To preview the HTML5 asset, use the <a
		/// href='CreativeAsset#assetUrl'>CreativeAsset#assetUrl</a>. In this field, the <a
		/// href='CreativeAsset#assetByteArray'>CreativeAsset#assetByteArray</a> must be a
		/// zip bundle and the <a href='CreativeAsset#fileName'>CreativeAsset#fileName</a>
		/// must have a zip extension. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public CreativeAsset html5Asset {
			get {
				return this.html5AssetField;
			}
			set {
				this.html5AssetField = value;
			}
		}
	}


	/// <summary>A <code>Creative</code> that has a destination url
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CustomCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BaseVideoCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(VideoRedirectCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(VideoCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SetTopBoxCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BaseImageRedirectCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ImageRedirectOverlayCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ImageRedirectCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BaseImageCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ImageOverlayCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ImageCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BaseFlashRedirectCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(FlashRedirectOverlayCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(FlashRedirectCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BaseFlashCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(FlashOverlayCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(FlashCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AspectRatioImageCreative))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class HasDestinationUrlCreative : Creative {
		private string destinationUrlField;

		private DestinationUrlType destinationUrlTypeField;

		private bool destinationUrlTypeFieldSpecified;

		/// <summary>The URL that the user is directed to if they click on the creative. This
		/// attribute is required unless the <a
		/// href='destinationUrlType'>destinationUrlType</a> is <a
		/// href='DestinationUrlType#NONE'>DestinationUrlType#NONE</a>, and has a maximum
		/// length of 1024 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string destinationUrl {
			get {
				return this.destinationUrlField;
			}
			set {
				this.destinationUrlField = value;
			}
		}

		/// <summary>The action that should be performed if the user clicks on the creative. This
		/// attribute is optional and defaults to <a
		/// href='DestinationUrlType#CLICK_TO_WEB'>DestinationUrlType#CLICK_TO_WEB</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public DestinationUrlType destinationUrlType {
			get {
				return this.destinationUrlTypeField;
			}
			set {
				this.destinationUrlTypeField = value;
				this.destinationUrlTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="destinationUrlType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool destinationUrlTypeSpecified {
			get {
				return this.destinationUrlTypeFieldSpecified;
			}
			set {
				this.destinationUrlTypeFieldSpecified = value;
			}
		}
	}


	/// <summary>The valid actions that a destination URL may perform if the user clicks on the
	/// ad.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum DestinationUrlType {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		/// <summary>Navigate to a web page. (a.k.a. "Click-through URL").
		/// </summary>
		CLICK_TO_WEB = 1,
		/// <summary>Start an application.
		/// </summary>
		CLICK_TO_APP = 2,
		/// <summary>Make a phone call.
		/// </summary>
		CLICK_TO_CALL = 3,
		/// <summary>Destination URL not present. Useful for video creatives where a landing page or
		/// a product isn't necessarily applicable.
		/// </summary>
		NONE = 4,
	}


	/// <summary>A <code>Creative</code> that contains an arbitrary HTML snippet and file assets.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomCreative : HasDestinationUrlCreative {
		private string htmlSnippetField;

		private CustomCreativeAsset[] customCreativeAssetsField;

		private bool isInterstitialField;

		private bool isInterstitialFieldSpecified;

		private LockedOrientation lockedOrientationField;

		private bool lockedOrientationFieldSpecified;

		private SslScanResult sslScanResultField;

		private bool sslScanResultFieldSpecified;

		private SslManualOverride sslManualOverrideField;

		private bool sslManualOverrideFieldSpecified;

		private bool isSafeFrameCompatibleField;

		private bool isSafeFrameCompatibleFieldSpecified;

		private string[] thirdPartyImpressionTrackingUrlsField;

		/// <summary>The HTML snippet that this creative delivers. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string htmlSnippet {
			get {
				return this.htmlSnippetField;
			}
			set {
				this.htmlSnippetField = value;
			}
		}

		/// <summary>A list of file assets that are associated with this creative, and can be
		/// referenced in the snippet.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("customCreativeAssets", Order = 1)]
		public CustomCreativeAsset[] customCreativeAssets {
			get {
				return this.customCreativeAssetsField;
			}
			set {
				this.customCreativeAssetsField = value;
			}
		}

		/// <summary><code>true</code> if this custom creative is interstitial. An interstitial
		/// creative will not consider an impression served until it is fully rendered in
		/// the browser.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public bool isInterstitial {
			get {
				return this.isInterstitialField;
			}
			set {
				this.isInterstitialField = value;
				this.isInterstitialSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isInterstitial" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isInterstitialSpecified {
			get {
				return this.isInterstitialFieldSpecified;
			}
			set {
				this.isInterstitialFieldSpecified = value;
			}
		}

		/// <summary>A locked orientation for this creative to be displayed in.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public LockedOrientation lockedOrientation {
			get {
				return this.lockedOrientationField;
			}
			set {
				this.lockedOrientationField = value;
				this.lockedOrientationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lockedOrientation" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lockedOrientationSpecified {
			get {
				return this.lockedOrientationFieldSpecified;
			}
			set {
				this.lockedOrientationFieldSpecified = value;
			}
		}

		/// <summary>The SSL compatibility scan result of this creative. <p>This attribute is
		/// read-only and determined by Google.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public SslScanResult sslScanResult {
			get {
				return this.sslScanResultField;
			}
			set {
				this.sslScanResultField = value;
				this.sslScanResultSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslScanResult" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslScanResultSpecified {
			get {
				return this.sslScanResultFieldSpecified;
			}
			set {
				this.sslScanResultFieldSpecified = value;
			}
		}

		/// <summary>The manual override for the SSL compatibility of this creative. <p>This
		/// attribute is optional and defaults to <a
		/// href='SslManualOverride#NO_OVERRIDE'>SslManualOverride#NO_OVERRIDE</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public SslManualOverride sslManualOverride {
			get {
				return this.sslManualOverrideField;
			}
			set {
				this.sslManualOverrideField = value;
				this.sslManualOverrideSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslManualOverride" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslManualOverrideSpecified {
			get {
				return this.sslManualOverrideFieldSpecified;
			}
			set {
				this.sslManualOverrideFieldSpecified = value;
			}
		}

		/// <summary>Whether the <a href='Creative'>Creative</a> is compatible for SafeFrame
		/// rendering. <p>This attribute is optional and defaults to <code>true</code>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public bool isSafeFrameCompatible {
			get {
				return this.isSafeFrameCompatibleField;
			}
			set {
				this.isSafeFrameCompatibleField = value;
				this.isSafeFrameCompatibleSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isSafeFrameCompatible" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isSafeFrameCompatibleSpecified {
			get {
				return this.isSafeFrameCompatibleFieldSpecified;
			}
			set {
				this.isSafeFrameCompatibleFieldSpecified = value;
			}
		}

		/// <summary>A list of impression tracking URLs to ping when this creative is displayed. This
		/// field is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("thirdPartyImpressionTrackingUrls", Order = 7)]
		public string[] thirdPartyImpressionTrackingUrls {
			get {
				return this.thirdPartyImpressionTrackingUrlsField;
			}
			set {
				this.thirdPartyImpressionTrackingUrlsField = value;
			}
		}
	}


	/// <summary>A base type for video creatives.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(VideoRedirectCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(VideoCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SetTopBoxCreative))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class BaseVideoCreative : HasDestinationUrlCreative {
		private int durationField;

		private bool durationFieldSpecified;

		private bool allowDurationOverrideField;

		private bool allowDurationOverrideFieldSpecified;

		private ConversionEvent_TrackingUrlsMapEntry[] trackingUrlsField;

		private long[] companionCreativeIdsField;

		private string customParametersField;

		private SkippableAdType skippableAdTypeField;

		private bool skippableAdTypeFieldSpecified;

		private string vastPreviewUrlField;

		private SslScanResult sslScanResultField;

		private bool sslScanResultFieldSpecified;

		private SslManualOverride sslManualOverrideField;

		private bool sslManualOverrideFieldSpecified;

		/// <summary>The expected duration of this creative in milliseconds.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int duration {
			get {
				return this.durationField;
			}
			set {
				this.durationField = value;
				this.durationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="duration"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool durationSpecified {
			get {
				return this.durationFieldSpecified;
			}
			set {
				this.durationFieldSpecified = value;
			}
		}

		/// <summary>Allows the creative duration to differ from the actual asset durations. This
		/// attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public bool allowDurationOverride {
			get {
				return this.allowDurationOverrideField;
			}
			set {
				this.allowDurationOverrideField = value;
				this.allowDurationOverrideSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowDurationOverride" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowDurationOverrideSpecified {
			get {
				return this.allowDurationOverrideFieldSpecified;
			}
			set {
				this.allowDurationOverrideFieldSpecified = value;
			}
		}

		/// <summary>A map from <code>ConversionEvent</code> to a list of URLs that will be pinged
		/// when the event happens. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("trackingUrls", Order = 2)]
		public ConversionEvent_TrackingUrlsMapEntry[] trackingUrls {
			get {
				return this.trackingUrlsField;
			}
			set {
				this.trackingUrlsField = value;
			}
		}

		/// <summary>The IDs of the companion creatives that are associated with this creative. This
		/// attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("companionCreativeIds", Order = 3)]
		public long[] companionCreativeIds {
			get {
				return this.companionCreativeIdsField;
			}
			set {
				this.companionCreativeIdsField = value;
			}
		}

		/// <summary>A comma separated key=value list of parameters that will be supplied to the
		/// creative, written into the VAST <code></code> node. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string customParameters {
			get {
				return this.customParametersField;
			}
			set {
				this.customParametersField = value;
			}
		}

		/// <summary>The type of skippable ad.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public SkippableAdType skippableAdType {
			get {
				return this.skippableAdTypeField;
			}
			set {
				this.skippableAdTypeField = value;
				this.skippableAdTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="skippableAdType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool skippableAdTypeSpecified {
			get {
				return this.skippableAdTypeFieldSpecified;
			}
			set {
				this.skippableAdTypeFieldSpecified = value;
			}
		}

		/// <summary>An ad tag URL that will return a preview of the VAST XML response specific to
		/// this creative. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public string vastPreviewUrl {
			get {
				return this.vastPreviewUrlField;
			}
			set {
				this.vastPreviewUrlField = value;
			}
		}

		/// <summary>The SSL compatibility scan result of this creative. <p>This attribute is
		/// read-only and determined by Google.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public SslScanResult sslScanResult {
			get {
				return this.sslScanResultField;
			}
			set {
				this.sslScanResultField = value;
				this.sslScanResultSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslScanResult" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslScanResultSpecified {
			get {
				return this.sslScanResultFieldSpecified;
			}
			set {
				this.sslScanResultFieldSpecified = value;
			}
		}

		/// <summary>The manual override for the SSL compatibility of this creative. <p>This
		/// attribute is optional and defaults to <a
		/// href='SslManualOverride#NO_OVERRIDE'>SslManualOverride#NO_OVERRIDE</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public SslManualOverride sslManualOverride {
			get {
				return this.sslManualOverrideField;
			}
			set {
				this.sslManualOverrideField = value;
				this.sslManualOverrideSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslManualOverride" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslManualOverrideSpecified {
			get {
				return this.sslManualOverrideFieldSpecified;
			}
			set {
				this.sslManualOverrideFieldSpecified = value;
			}
		}
	}


	/// <summary>The different types of skippable ads.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum SkippableAdType {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		/// <summary>Skippable ad type is disabled.
		/// </summary>
		DISABLED = 1,
		/// <summary>Skippable ad type is enabled.
		/// </summary>
		ENABLED = 2,
		/// <summary>Skippable in-stream ad type.
		/// </summary>
		INSTREAM_SELECT = 3,
	}


	/// <summary>A <code>Creative</code> that contains externally hosted video ads and is served
	/// via VAST XML.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class VideoRedirectCreative : BaseVideoCreative {
		private VideoRedirectAsset[] videoAssetsField;

		private VideoRedirectAsset mezzanineFileField;

		/// <summary>The video creative assets.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("videoAssets", Order = 0)]
		public VideoRedirectAsset[] videoAssets {
			get {
				return this.videoAssetsField;
			}
			set {
				this.videoAssetsField = value;
			}
		}

		/// <summary>The high quality mezzanine video asset.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public VideoRedirectAsset mezzanineFile {
			get {
				return this.mezzanineFileField;
			}
			set {
				this.mezzanineFileField = value;
			}
		}
	}


	/// <summary>A <code>Creative</code> that contains Ad Manager hosted video ads and is served
	/// via VAST XML. This creative is read-only.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class VideoCreative : BaseVideoCreative {
	}


	/// <summary>A <code>Creative</code> that will be served into cable set-top boxes. There are
	/// no assets for this creative type, as they are hosted by external cable systems.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SetTopBoxCreative : BaseVideoCreative {
		private string externalAssetIdField;

		private string providerIdField;

		private string[] availabilityRegionIdsField;

		private DateTime licenseWindowStartDateTimeField;

		private DateTime licenseWindowEndDateTimeField;

		/// <summary>An external asset identifier that is used in the cable system. This attribute is
		/// read-only after creation.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string externalAssetId {
			get {
				return this.externalAssetIdField;
			}
			set {
				this.externalAssetIdField = value;
			}
		}

		/// <summary>An identifier for the provider in the cable system. This attribute is read-only
		/// after creation.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string providerId {
			get {
				return this.providerIdField;
			}
			set {
				this.providerIdField = value;
			}
		}

		/// <summary>IDs of regions where the creative is available to serve from a local cable
		/// video-on-demand server. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("availabilityRegionIds", Order = 2)]
		public string[] availabilityRegionIds {
			get {
				return this.availabilityRegionIdsField;
			}
			set {
				this.availabilityRegionIdsField = value;
			}
		}

		/// <summary>The date and time that this creative can begin serving from a local cable
		/// video-on-demand server. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public DateTime licenseWindowStartDateTime {
			get {
				return this.licenseWindowStartDateTimeField;
			}
			set {
				this.licenseWindowStartDateTimeField = value;
			}
		}

		/// <summary>The date and time that this creative can no longer be served from a local cable
		/// video-on-demand server. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public DateTime licenseWindowEndDateTime {
			get {
				return this.licenseWindowEndDateTimeField;
			}
			set {
				this.licenseWindowEndDateTimeField = value;
			}
		}
	}


	/// <summary>The base type for creatives that load an image asset from a specified URL.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ImageRedirectOverlayCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ImageRedirectCreative))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class BaseImageRedirectCreative : HasDestinationUrlCreative {
		private string imageUrlField;

		/// <summary>The URL where the actual asset resides. This attribute is required and has a
		/// maximum length of 1024 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string imageUrl {
			get {
				return this.imageUrlField;
			}
			set {
				this.imageUrlField = value;
			}
		}
	}


	/// <summary>An overlay <code>Creative</code> that loads an image asset from a specified URL
	/// and is served via VAST XML. Overlays cover part of the video content they are
	/// displayed on top of. This creative is read only.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ImageRedirectOverlayCreative : BaseImageRedirectCreative {
		private Size assetSizeField;

		private int durationField;

		private bool durationFieldSpecified;

		private long[] companionCreativeIdsField;

		private ConversionEvent_TrackingUrlsMapEntry[] trackingUrlsField;

		private string customParametersField;

		private string vastPreviewUrlField;

		/// <summary>The size of the image asset. Note that this may differ from <a
		/// href='#size'>#size</a> if the asset is not expected to fill the entire video
		/// player. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public Size assetSize {
			get {
				return this.assetSizeField;
			}
			set {
				this.assetSizeField = value;
			}
		}

		/// <summary>Minimum suggested duration in milliseconds. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int duration {
			get {
				return this.durationField;
			}
			set {
				this.durationField = value;
				this.durationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="duration"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool durationSpecified {
			get {
				return this.durationFieldSpecified;
			}
			set {
				this.durationFieldSpecified = value;
			}
		}

		/// <summary>The IDs of the companion creatives that are associated with this creative. This
		/// attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("companionCreativeIds", Order = 2)]
		public long[] companionCreativeIds {
			get {
				return this.companionCreativeIdsField;
			}
			set {
				this.companionCreativeIdsField = value;
			}
		}

		/// <summary>A map from <code>ConversionEvent</code> to a list of URLs that will be pinged
		/// when the event happens. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("trackingUrls", Order = 3)]
		public ConversionEvent_TrackingUrlsMapEntry[] trackingUrls {
			get {
				return this.trackingUrlsField;
			}
			set {
				this.trackingUrlsField = value;
			}
		}

		/// <summary>A comma separated key=value list of parameters that will be supplied to the
		/// creative, written into the VAST <code></code> node. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string customParameters {
			get {
				return this.customParametersField;
			}
			set {
				this.customParametersField = value;
			}
		}

		/// <summary>An ad tag URL that will return a preview of the VAST XML response specific to
		/// this creative. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public string vastPreviewUrl {
			get {
				return this.vastPreviewUrlField;
			}
			set {
				this.vastPreviewUrlField = value;
			}
		}
	}


	/// <summary>A <code>Creative</code> that loads an image asset from a specified URL.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ImageRedirectCreative : BaseImageRedirectCreative {
		private string altTextField;

		private string thirdPartyImpressionUrlField;

		/// <summary>Alternative text to be rendered along with the creative used mainly for
		/// accessibility. This field is optional and has a maximum length of 500
		/// characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string altText {
			get {
				return this.altTextField;
			}
			set {
				this.altTextField = value;
			}
		}

		/// <summary>An impression tracking URL to ping when this creative is displayed. This field
		/// is optional has a maximum length of 1024 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string thirdPartyImpressionUrl {
			get {
				return this.thirdPartyImpressionUrlField;
			}
			set {
				this.thirdPartyImpressionUrlField = value;
			}
		}
	}


	/// <summary>The base type for creatives that display an image.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ImageOverlayCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ImageCreative))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class BaseImageCreative : HasDestinationUrlCreative {
		private bool overrideSizeField;

		private bool overrideSizeFieldSpecified;

		private CreativeAsset primaryImageAssetField;

		/// <summary>Allows the creative size to differ from the actual image asset size. This
		/// attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool overrideSize {
			get {
				return this.overrideSizeField;
			}
			set {
				this.overrideSizeField = value;
				this.overrideSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="overrideSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool overrideSizeSpecified {
			get {
				return this.overrideSizeFieldSpecified;
			}
			set {
				this.overrideSizeFieldSpecified = value;
			}
		}

		/// <summary>The primary image asset associated with this creative. This attribute is
		/// required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public CreativeAsset primaryImageAsset {
			get {
				return this.primaryImageAssetField;
			}
			set {
				this.primaryImageAssetField = value;
			}
		}
	}


	/// <summary>An overlay <code>Creative</code> that displays an image and is served via VAST
	/// 2.0 XML. Overlays cover part of the video content they are displayed on top of.
	/// This creative is read only prior to v201705.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ImageOverlayCreative : BaseImageCreative {
		private long[] companionCreativeIdsField;

		private ConversionEvent_TrackingUrlsMapEntry[] trackingUrlsField;

		private LockedOrientation lockedOrientationField;

		private bool lockedOrientationFieldSpecified;

		private string customParametersField;

		private int durationField;

		private bool durationFieldSpecified;

		private string vastPreviewUrlField;

		/// <summary>The IDs of the companion creatives that are associated with this creative. This
		/// attribute is optional. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("companionCreativeIds", Order = 0)]
		public long[] companionCreativeIds {
			get {
				return this.companionCreativeIdsField;
			}
			set {
				this.companionCreativeIdsField = value;
			}
		}

		/// <summary>A map from <code>ConversionEvent</code> to a list of URLs that will be pinged
		/// when the event happens. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("trackingUrls", Order = 1)]
		public ConversionEvent_TrackingUrlsMapEntry[] trackingUrls {
			get {
				return this.trackingUrlsField;
			}
			set {
				this.trackingUrlsField = value;
			}
		}

		/// <summary>A locked orientation for this creative to be displayed in.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public LockedOrientation lockedOrientation {
			get {
				return this.lockedOrientationField;
			}
			set {
				this.lockedOrientationField = value;
				this.lockedOrientationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lockedOrientation" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lockedOrientationSpecified {
			get {
				return this.lockedOrientationFieldSpecified;
			}
			set {
				this.lockedOrientationFieldSpecified = value;
			}
		}

		/// <summary>A comma separated key=value list of parameters that will be supplied to the
		/// creative, written into the VAST <code></code> node. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string customParameters {
			get {
				return this.customParametersField;
			}
			set {
				this.customParametersField = value;
			}
		}

		/// <summary>Minimum suggested duration in milliseconds. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public int duration {
			get {
				return this.durationField;
			}
			set {
				this.durationField = value;
				this.durationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="duration"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool durationSpecified {
			get {
				return this.durationFieldSpecified;
			}
			set {
				this.durationFieldSpecified = value;
			}
		}

		/// <summary>An ad tag URL that will return a preview of the VAST XML response specific to
		/// this creative. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public string vastPreviewUrl {
			get {
				return this.vastPreviewUrlField;
			}
			set {
				this.vastPreviewUrlField = value;
			}
		}
	}


	/// <summary>A <code>Creative</code> that displays an image.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ImageCreative : BaseImageCreative {
		private string altTextField;

		private string thirdPartyImpressionUrlField;

		private CreativeAsset[] secondaryImageAssetsField;

		private LockedOrientation lockedOrientationField;

		private bool lockedOrientationFieldSpecified;

		/// <summary>Alternative text to be rendered along with the creative used mainly for
		/// accessibility. This field is optional and has a maximum length of 500
		/// characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string altText {
			get {
				return this.altTextField;
			}
			set {
				this.altTextField = value;
			}
		}

		/// <summary>An impression tracking URL to ping when this creative is displayed. This field
		/// is optional has a maximum length of 1024 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string thirdPartyImpressionUrl {
			get {
				return this.thirdPartyImpressionUrlField;
			}
			set {
				this.thirdPartyImpressionUrlField = value;
			}
		}

		/// <summary>The list of secondary image assets associated with this creative. This attribute
		/// is optional. <p>Secondary image assets can be used to store different resolution
		/// versions of the primary asset for use on non-standard density screens.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("secondaryImageAssets", Order = 2)]
		public CreativeAsset[] secondaryImageAssets {
			get {
				return this.secondaryImageAssetsField;
			}
			set {
				this.secondaryImageAssetsField = value;
			}
		}

		/// <summary>A locked orientation for this creative to be displayed in.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public LockedOrientation lockedOrientation {
			get {
				return this.lockedOrientationField;
			}
			set {
				this.lockedOrientationField = value;
				this.lockedOrientationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lockedOrientation" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lockedOrientationSpecified {
			get {
				return this.lockedOrientationFieldSpecified;
			}
			set {
				this.lockedOrientationFieldSpecified = value;
			}
		}
	}


	/// <summary>The base type for creatives that load a Flash asset from a specified URL. If the
	/// remote flash asset cannot be served, a fallback image is used at an alternate
	/// URL.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(FlashRedirectOverlayCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(FlashRedirectCreative))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class BaseFlashRedirectCreative : HasDestinationUrlCreative {
		private string flashUrlField;

		private string fallbackUrlField;

		private string fallbackPreviewUrlField;

		private SslScanResult sslScanResultField;

		private bool sslScanResultFieldSpecified;

		private SslManualOverride sslManualOverrideField;

		private bool sslManualOverrideFieldSpecified;

		/// <summary>The URL where the Flash asset resides. This attribute is required and has a
		/// maximum length of 1024 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string flashUrl {
			get {
				return this.flashUrlField;
			}
			set {
				this.flashUrlField = value;
			}
		}

		/// <summary>The fallback URL to use if the Flash URL cannot be used. This attribute is
		/// required and has a maximum length of 1024 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string fallbackUrl {
			get {
				return this.fallbackUrlField;
			}
			set {
				this.fallbackUrlField = value;
			}
		}

		/// <summary>The URL of the fallback image for preview. This attribute is read-only and is
		/// populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string fallbackPreviewUrl {
			get {
				return this.fallbackPreviewUrlField;
			}
			set {
				this.fallbackPreviewUrlField = value;
			}
		}

		/// <summary>The SSL compatibility scan result of this creative. <p>This attribute is
		/// read-only and determined by Google.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public SslScanResult sslScanResult {
			get {
				return this.sslScanResultField;
			}
			set {
				this.sslScanResultField = value;
				this.sslScanResultSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslScanResult" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslScanResultSpecified {
			get {
				return this.sslScanResultFieldSpecified;
			}
			set {
				this.sslScanResultFieldSpecified = value;
			}
		}

		/// <summary>The manual override for the SSL compatibility of this creative. <p>This
		/// attribute is optional and defaults to <a
		/// href='SslManualOverride#NO_OVERRIDE'>SslManualOverride#NO_OVERRIDE</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public SslManualOverride sslManualOverride {
			get {
				return this.sslManualOverrideField;
			}
			set {
				this.sslManualOverrideField = value;
				this.sslManualOverrideSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslManualOverride" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslManualOverrideSpecified {
			get {
				return this.sslManualOverrideFieldSpecified;
			}
			set {
				this.sslManualOverrideFieldSpecified = value;
			}
		}
	}


	/// <summary>An overlay <code>Creative</code> that loads a Flash asset from a specified URL
	/// and is served via VAST XML. Overlays cover part of the video content they are
	/// displayed on top of.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class FlashRedirectOverlayCreative : BaseFlashRedirectCreative {
		private long[] companionCreativeIdsField;

		private ConversionEvent_TrackingUrlsMapEntry[] trackingUrlsField;

		private string customParametersField;

		private ApiFramework apiFrameworkField;

		private bool apiFrameworkFieldSpecified;

		private int durationField;

		private bool durationFieldSpecified;

		private Size flashAssetSizeField;

		private string vastPreviewUrlField;

		/// <summary>The IDs of the companion creatives that are associated with this creative. This
		/// attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("companionCreativeIds", Order = 0)]
		public long[] companionCreativeIds {
			get {
				return this.companionCreativeIdsField;
			}
			set {
				this.companionCreativeIdsField = value;
			}
		}

		/// <summary>A map from <code>ConversionEvent</code> to a list of URLs that will be pinged
		/// when the event happens. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("trackingUrls", Order = 1)]
		public ConversionEvent_TrackingUrlsMapEntry[] trackingUrls {
			get {
				return this.trackingUrlsField;
			}
			set {
				this.trackingUrlsField = value;
			}
		}

		/// <summary>A comma separated key=value list of parameters that will be supplied to the
		/// creative, written into the VAST <code></code> node. If the <a
		/// href='#apiFramework'>#apiFramework</a> is <a
		/// href='ApiFramework#VPAID'>ApiFramework#VPAID</a>, the value does not need to be
		/// a comma separated key-value list (and can instead be any arbitrary string). This
		/// attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string customParameters {
			get {
				return this.customParametersField;
			}
			set {
				this.customParametersField = value;
			}
		}

		/// <summary>The API framework of the asset. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public ApiFramework apiFramework {
			get {
				return this.apiFrameworkField;
			}
			set {
				this.apiFrameworkField = value;
				this.apiFrameworkSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="apiFramework" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool apiFrameworkSpecified {
			get {
				return this.apiFrameworkFieldSpecified;
			}
			set {
				this.apiFrameworkFieldSpecified = value;
			}
		}

		/// <summary>Minimum suggested duration in milliseconds. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public int duration {
			get {
				return this.durationField;
			}
			set {
				this.durationField = value;
				this.durationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="duration"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool durationSpecified {
			get {
				return this.durationFieldSpecified;
			}
			set {
				this.durationFieldSpecified = value;
			}
		}

		/// <summary>The size of the flash asset. Note that this may differ from <a
		/// href='#size'>#size</a> if the asset is not expected to fill the entire video
		/// player. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public Size flashAssetSize {
			get {
				return this.flashAssetSizeField;
			}
			set {
				this.flashAssetSizeField = value;
			}
		}

		/// <summary>An ad tag URL that will return a preview of the VAST XML response specific to
		/// this creative. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public string vastPreviewUrl {
			get {
				return this.vastPreviewUrlField;
			}
			set {
				this.vastPreviewUrlField = value;
			}
		}
	}


	/// <summary>The various ApiFramework types.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ApiFramework {
		NONE = 0,
		CLICKTAG = 1,
		VPAID = 2,
	}


	/// <summary>A <code>Creative</code> that loads a Flash asset from a specified URL. If the
	/// remote flash asset cannot be served, a fallback image is used at an alternate
	/// URL.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class FlashRedirectCreative : BaseFlashRedirectCreative {
	}


	/// <summary>A base type for creatives that display a Flash-based ad. If the Flash ad cannot
	/// load, a fallback image is displayed instead.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(FlashOverlayCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(FlashCreative))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class BaseFlashCreative : HasDestinationUrlCreative {
		private bool overrideSizeField;

		private bool overrideSizeFieldSpecified;

		private bool clickTagRequiredField;

		private bool clickTagRequiredFieldSpecified;

		private SslScanResult sslScanResultField;

		private bool sslScanResultFieldSpecified;

		private SslManualOverride sslManualOverrideField;

		private bool sslManualOverrideFieldSpecified;

		private CreativeAsset flashAssetField;

		private CreativeAsset fallbackImageAssetField;

		/// <summary>Allows the creative size to differ from the actual Flash asset size. This
		/// attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool overrideSize {
			get {
				return this.overrideSizeField;
			}
			set {
				this.overrideSizeField = value;
				this.overrideSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="overrideSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool overrideSizeSpecified {
			get {
				return this.overrideSizeFieldSpecified;
			}
			set {
				this.overrideSizeFieldSpecified = value;
			}
		}

		/// <summary>Specifies whether the Flash asset is required to have a click tag embedded in it
		/// or not. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public bool clickTagRequired {
			get {
				return this.clickTagRequiredField;
			}
			set {
				this.clickTagRequiredField = value;
				this.clickTagRequiredSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="clickTagRequired" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool clickTagRequiredSpecified {
			get {
				return this.clickTagRequiredFieldSpecified;
			}
			set {
				this.clickTagRequiredFieldSpecified = value;
			}
		}

		/// <summary>The SSL compatibility scan result of this creative. <p>This attribute is
		/// read-only and determined by Google.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public SslScanResult sslScanResult {
			get {
				return this.sslScanResultField;
			}
			set {
				this.sslScanResultField = value;
				this.sslScanResultSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslScanResult" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslScanResultSpecified {
			get {
				return this.sslScanResultFieldSpecified;
			}
			set {
				this.sslScanResultFieldSpecified = value;
			}
		}

		/// <summary>The manual override for the SSL compatibility of this creative. <p>This
		/// attribute is optional and defaults to <a
		/// href='SslManualOverride#NO_OVERRIDE'>SslManualOverride#NO_OVERRIDE</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public SslManualOverride sslManualOverride {
			get {
				return this.sslManualOverrideField;
			}
			set {
				this.sslManualOverrideField = value;
				this.sslManualOverrideSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslManualOverride" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslManualOverrideSpecified {
			get {
				return this.sslManualOverrideFieldSpecified;
			}
			set {
				this.sslManualOverrideFieldSpecified = value;
			}
		}

		/// <summary>The flash asset. This attribute is required. To view the Flash image, use the <a
		/// href='CreativeAsset#assetUrl'>CreativeAsset#assetUrl</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public CreativeAsset flashAsset {
			get {
				return this.flashAssetField;
			}
			set {
				this.flashAssetField = value;
			}
		}

		/// <summary>The image asset to fall back on if the flash creative cannot be loaded. To view
		/// the fallback image, use the <a
		/// href='CreativeAsset#assetUrl'>CreativeAsset#assetUrl</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public CreativeAsset fallbackImageAsset {
			get {
				return this.fallbackImageAssetField;
			}
			set {
				this.fallbackImageAssetField = value;
			}
		}
	}


	/// <summary>An overlay <code>Creative</code> that displays a Flash-based ad and is served
	/// via VAST XML. Overlays cover part of the video content they are displayed on top
	/// of. This creative is read-only.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class FlashOverlayCreative : BaseFlashCreative {
		private long[] companionCreativeIdsField;

		private ConversionEvent_TrackingUrlsMapEntry[] trackingUrlsField;

		private string customParametersField;

		private ApiFramework apiFrameworkField;

		private bool apiFrameworkFieldSpecified;

		private int durationField;

		private bool durationFieldSpecified;

		private string vastPreviewUrlField;

		private LockedOrientation lockedOrientationField;

		private bool lockedOrientationFieldSpecified;

		/// <summary>The IDs of the companion creatives that are associated with this creative. This
		/// attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("companionCreativeIds", Order = 0)]
		public long[] companionCreativeIds {
			get {
				return this.companionCreativeIdsField;
			}
			set {
				this.companionCreativeIdsField = value;
			}
		}

		/// <summary>A map from <code>ConversionEvent</code> to a list of URLs that will be pinged
		/// when the event happens. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("trackingUrls", Order = 1)]
		public ConversionEvent_TrackingUrlsMapEntry[] trackingUrls {
			get {
				return this.trackingUrlsField;
			}
			set {
				this.trackingUrlsField = value;
			}
		}

		/// <summary>A comma separated key=value list of parameters that will be supplied to the
		/// creative, written into the VAST <code></code> node. If the <a
		/// href='#apiFramework'>#apiFramework</a> is <a
		/// href='ApiFramework#VPAID'>ApiFramework#VPAID</a>, the value does not need to be
		/// a comma separated key-value list (and can instead be any arbitrary string). This
		/// attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string customParameters {
			get {
				return this.customParametersField;
			}
			set {
				this.customParametersField = value;
			}
		}

		/// <summary>The API framework of the asset. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public ApiFramework apiFramework {
			get {
				return this.apiFrameworkField;
			}
			set {
				this.apiFrameworkField = value;
				this.apiFrameworkSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="apiFramework" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool apiFrameworkSpecified {
			get {
				return this.apiFrameworkFieldSpecified;
			}
			set {
				this.apiFrameworkFieldSpecified = value;
			}
		}

		/// <summary>Minimum suggested duration in milliseconds. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public int duration {
			get {
				return this.durationField;
			}
			set {
				this.durationField = value;
				this.durationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="duration"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool durationSpecified {
			get {
				return this.durationFieldSpecified;
			}
			set {
				this.durationFieldSpecified = value;
			}
		}

		/// <summary>An ad tag URL that will return a preview of the VAST XML response specific to
		/// this creative. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public string vastPreviewUrl {
			get {
				return this.vastPreviewUrlField;
			}
			set {
				this.vastPreviewUrlField = value;
			}
		}

		/// <summary>A locked orientation for this creative to be displayed in.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public LockedOrientation lockedOrientation {
			get {
				return this.lockedOrientationField;
			}
			set {
				this.lockedOrientationField = value;
				this.lockedOrientationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lockedOrientation" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lockedOrientationSpecified {
			get {
				return this.lockedOrientationFieldSpecified;
			}
			set {
				this.lockedOrientationFieldSpecified = value;
			}
		}
	}


	/// <summary>A <code>Creative</code> that displays a Flash-based ad. If the Flash ad cannot
	/// load, a fallback image is displayed instead.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class FlashCreative : BaseFlashCreative {
		private SwiffyFallbackAsset swiffyAssetField;

		private bool createSwiffyAssetField;

		private bool createSwiffyAssetFieldSpecified;

		private LockedOrientation lockedOrientationField;

		private bool lockedOrientationFieldSpecified;

		private bool clickTagOverlayEnabledField;

		private bool clickTagOverlayEnabledFieldSpecified;

		/// <summary>A Swiffy asset that can be used as a fallback for this flash creative. This
		/// attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public SwiffyFallbackAsset swiffyAsset {
			get {
				return this.swiffyAssetField;
			}
			set {
				this.swiffyAssetField = value;
			}
		}

		/// <summary>Enables Swiffy fallback asset creation and serving. <p>If <code>true</code>
		/// during creation or update, the flash asset will be converted to a <a
		/// href='#swiffyAsset'>Swiffy asset</a>. If successful, the Swiffy asset will be
		/// used for ad serving, which may lead to additional latency.</p> <p>To remove the
		/// swiffy asset, set this attribute to <code>false</code> and update the <a
		/// href='#flashByteArray'>flash asset</a>.</p> <p>This attribute is optional and
		/// defaults to false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public bool createSwiffyAsset {
			get {
				return this.createSwiffyAssetField;
			}
			set {
				this.createSwiffyAssetField = value;
				this.createSwiffyAssetSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="createSwiffyAsset" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool createSwiffyAssetSpecified {
			get {
				return this.createSwiffyAssetFieldSpecified;
			}
			set {
				this.createSwiffyAssetFieldSpecified = value;
			}
		}

		/// <summary>A locked orientation for this creative to be displayed in.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public LockedOrientation lockedOrientation {
			get {
				return this.lockedOrientationField;
			}
			set {
				this.lockedOrientationField = value;
				this.lockedOrientationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lockedOrientation" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lockedOrientationSpecified {
			get {
				return this.lockedOrientationFieldSpecified;
			}
			set {
				this.lockedOrientationFieldSpecified = value;
			}
		}

		/// <summary>Enables the creative to be served with click tag overlay. <p>This attribute is
		/// optional and defaults to false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public bool clickTagOverlayEnabled {
			get {
				return this.clickTagOverlayEnabledField;
			}
			set {
				this.clickTagOverlayEnabledField = value;
				this.clickTagOverlayEnabledSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="clickTagOverlayEnabled" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool clickTagOverlayEnabledSpecified {
			get {
				return this.clickTagOverlayEnabledFieldSpecified;
			}
			set {
				this.clickTagOverlayEnabledFieldSpecified = value;
			}
		}
	}


	/// <summary>A <code>Creative</code> intended for mobile platforms that displays an image,
	/// whose <a href='LineItem#creativePlaceholders'>size</a> is defined as an <a
	/// href='CreativeSizeType#ASPECT_RATIO'>aspect ratio</a>, i.e. <a
	/// href='Size#isAspectRatio'>Size#isAspectRatio</a>. It can have multiple images
	/// whose dimensions conform to that aspect ratio.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AspectRatioImageCreative : HasDestinationUrlCreative {
		private CreativeAsset[] imageAssetsField;

		private string altTextField;

		private string thirdPartyImpressionUrlField;

		private bool overrideSizeField;

		private bool overrideSizeFieldSpecified;

		/// <summary>The images associated with this creative. The ad server will choose one based on
		/// the capabilities of the device. Each asset should have a size which is of the
		/// same aspect ratio as the <a href='Creative#size'>Creative#size</a>. This
		/// attribute is required and must have at least one asset.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("imageAssets", Order = 0)]
		public CreativeAsset[] imageAssets {
			get {
				return this.imageAssetsField;
			}
			set {
				this.imageAssetsField = value;
			}
		}

		/// <summary>The text that is served along with the image creative, primarily for
		/// accessibility. If no suitable image size is available for the device, this text
		/// replaces the image completely. This field is optional and has a maximum length
		/// of 500 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string altText {
			get {
				return this.altTextField;
			}
			set {
				this.altTextField = value;
			}
		}

		/// <summary>An impression tracking URL to ping when this creative is displayed. This field
		/// is optional has a maximum length of 1024 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string thirdPartyImpressionUrl {
			get {
				return this.thirdPartyImpressionUrlField;
			}
			set {
				this.thirdPartyImpressionUrlField = value;
			}
		}

		/// <summary>Allows the actual image asset sizes to differ from the creative size. This
		/// attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public bool overrideSize {
			get {
				return this.overrideSizeField;
			}
			set {
				this.overrideSizeField = value;
				this.overrideSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="overrideSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool overrideSizeSpecified {
			get {
				return this.overrideSizeFieldSpecified;
			}
			set {
				this.overrideSizeFieldSpecified = value;
			}
		}
	}


	/// <summary>A creative that is used for tracking clicks on ads that are served directly from
	/// the customers' web servers or media servers. NOTE: The size attribute is not
	/// used for click tracking creative and it will not be persisted upon save.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ClickTrackingCreative : Creative {
		private string clickTrackingUrlField;

		/// <summary>The click tracking URL. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string clickTrackingUrl {
			get {
				return this.clickTrackingUrlField;
			}
			set {
				this.clickTrackingUrlField = value;
			}
		}
	}


	/// <summary>A <code>Creative</code> that is created by a Rich Media Studio.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RichMediaStudioCreative))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class BaseRichMediaStudioCreative : Creative {
		private long studioCreativeIdField;

		private bool studioCreativeIdFieldSpecified;

		private RichMediaStudioCreativeFormat creativeFormatField;

		private bool creativeFormatFieldSpecified;

		private RichMediaStudioCreativeArtworkType artworkTypeField;

		private bool artworkTypeFieldSpecified;

		private long totalFileSizeField;

		private bool totalFileSizeFieldSpecified;

		private string[] adTagKeysField;

		private string[] customKeyValuesField;

		private string surveyUrlField;

		private string allImpressionsUrlField;

		private string richMediaImpressionsUrlField;

		private string backupImageImpressionsUrlField;

		private string overrideCssField;

		private string requiredFlashPluginVersionField;

		private int durationField;

		private bool durationFieldSpecified;

		private RichMediaStudioCreativeBillingAttribute billingAttributeField;

		private bool billingAttributeFieldSpecified;

		private RichMediaStudioChildAssetProperty[] richMediaStudioChildAssetPropertiesField;

		private SslScanResult sslScanResultField;

		private bool sslScanResultFieldSpecified;

		private SslManualOverride sslManualOverrideField;

		private bool sslManualOverrideFieldSpecified;

		/// <summary>The creative ID as known by Rich Media Studio creative. This attribute is
		/// readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long studioCreativeId {
			get {
				return this.studioCreativeIdField;
			}
			set {
				this.studioCreativeIdField = value;
				this.studioCreativeIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="studioCreativeId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool studioCreativeIdSpecified {
			get {
				return this.studioCreativeIdFieldSpecified;
			}
			set {
				this.studioCreativeIdFieldSpecified = value;
			}
		}

		/// <summary>The creative format of the Rich Media Studio creative. This attribute is
		/// readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public RichMediaStudioCreativeFormat creativeFormat {
			get {
				return this.creativeFormatField;
			}
			set {
				this.creativeFormatField = value;
				this.creativeFormatSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="creativeFormat" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool creativeFormatSpecified {
			get {
				return this.creativeFormatFieldSpecified;
			}
			set {
				this.creativeFormatFieldSpecified = value;
			}
		}

		/// <summary>The type of artwork used in this creative. This attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public RichMediaStudioCreativeArtworkType artworkType {
			get {
				return this.artworkTypeField;
			}
			set {
				this.artworkTypeField = value;
				this.artworkTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="artworkType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool artworkTypeSpecified {
			get {
				return this.artworkTypeFieldSpecified;
			}
			set {
				this.artworkTypeFieldSpecified = value;
			}
		}

		/// <summary>The total size of all assets in bytes. This attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public long totalFileSize {
			get {
				return this.totalFileSizeField;
			}
			set {
				this.totalFileSizeField = value;
				this.totalFileSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalFileSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalFileSizeSpecified {
			get {
				return this.totalFileSizeFieldSpecified;
			}
			set {
				this.totalFileSizeFieldSpecified = value;
			}
		}

		/// <summary>Ad tag keys. This attribute is optional and updatable.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("adTagKeys", Order = 4)]
		public string[] adTagKeys {
			get {
				return this.adTagKeysField;
			}
			set {
				this.adTagKeysField = value;
			}
		}

		/// <summary>Custom key values. This attribute is optional and updatable.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("customKeyValues", Order = 5)]
		public string[] customKeyValues {
			get {
				return this.customKeyValuesField;
			}
			set {
				this.customKeyValuesField = value;
			}
		}

		/// <summary>The survey URL for this creative. This attribute is optional and updatable.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public string surveyUrl {
			get {
				return this.surveyUrlField;
			}
			set {
				this.surveyUrlField = value;
			}
		}

		/// <summary>The tracking URL to be triggered when an ad starts to play, whether Rich Media
		/// or backup content is displayed. Behaves like the <code></code> URL that DART
		/// used to track impressions. This URL can't exceed 1024 characters and must start
		/// with http:// or https://. This attribute is optional and updatable.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public string allImpressionsUrl {
			get {
				return this.allImpressionsUrlField;
			}
			set {
				this.allImpressionsUrlField = value;
			}
		}

		/// <summary>The tracking URL to be triggered when any rich media artwork is displayed in an
		/// ad. Behaves like the <code>/imp</code> URL that DART used to track impressions.
		/// This URL can't exceed 1024 characters and must start with http:// or https://.
		/// This attribute is optional and updatable.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public string richMediaImpressionsUrl {
			get {
				return this.richMediaImpressionsUrlField;
			}
			set {
				this.richMediaImpressionsUrlField = value;
			}
		}

		/// <summary>The tracking URL to be triggered when the Rich Media backup image is served.
		/// This attribute is optional and updatable.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public string backupImageImpressionsUrl {
			get {
				return this.backupImageImpressionsUrlField;
			}
			set {
				this.backupImageImpressionsUrlField = value;
			}
		}

		/// <summary>The override CSS. You can put custom CSS code here to repair creative styling;
		/// e.g. <code>tr td { background-color:#FBB; </code>}. This attribute is optional
		/// and updatable.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public string overrideCss {
			get {
				return this.overrideCssField;
			}
			set {
				this.overrideCssField = value;
			}
		}

		/// <summary>The Flash plugin version required to view this creative; e.g. <code>Flash
		/// 10.2/AS 3</code>. This attribute is read only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 11)]
		public string requiredFlashPluginVersion {
			get {
				return this.requiredFlashPluginVersionField;
			}
			set {
				this.requiredFlashPluginVersionField = value;
			}
		}

		/// <summary>The duration of the creative in milliseconds. This attribute is optional and
		/// updatable.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 12)]
		public int duration {
			get {
				return this.durationField;
			}
			set {
				this.durationField = value;
				this.durationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="duration"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool durationSpecified {
			get {
				return this.durationFieldSpecified;
			}
			set {
				this.durationFieldSpecified = value;
			}
		}

		/// <summary>The billing attribute associated with this creative. This attribute is read
		/// only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 13)]
		public RichMediaStudioCreativeBillingAttribute billingAttribute {
			get {
				return this.billingAttributeField;
			}
			set {
				this.billingAttributeField = value;
				this.billingAttributeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="billingAttribute" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool billingAttributeSpecified {
			get {
				return this.billingAttributeFieldSpecified;
			}
			set {
				this.billingAttributeFieldSpecified = value;
			}
		}

		/// <summary>The list of child assets associated with this creative. This attribute is read
		/// only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("richMediaStudioChildAssetProperties", Order = 14)]
		public RichMediaStudioChildAssetProperty[] richMediaStudioChildAssetProperties {
			get {
				return this.richMediaStudioChildAssetPropertiesField;
			}
			set {
				this.richMediaStudioChildAssetPropertiesField = value;
			}
		}

		/// <summary>The SSL compatibility scan result of this creative. <p>This attribute is
		/// read-only and determined by Google.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 15)]
		public SslScanResult sslScanResult {
			get {
				return this.sslScanResultField;
			}
			set {
				this.sslScanResultField = value;
				this.sslScanResultSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslScanResult" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslScanResultSpecified {
			get {
				return this.sslScanResultFieldSpecified;
			}
			set {
				this.sslScanResultFieldSpecified = value;
			}
		}

		/// <summary>The manual override for the SSL compatibility of this creative. <p>This
		/// attribute is optional and defaults to <a
		/// href='SslManualOverride#NO_OVERRIDE'>SslManualOverride#NO_OVERRIDE</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 16)]
		public SslManualOverride sslManualOverride {
			get {
				return this.sslManualOverrideField;
			}
			set {
				this.sslManualOverrideField = value;
				this.sslManualOverrideSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sslManualOverride" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sslManualOverrideSpecified {
			get {
				return this.sslManualOverrideFieldSpecified;
			}
			set {
				this.sslManualOverrideFieldSpecified = value;
			}
		}
	}


	/// <summary>Different creative format supported by Rich Media Studio creative.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RichMediaStudioCreativeFormat {
		/// <summary>In-page creatives are served into an ad slot on publishers page. In-page implies
		/// that they maintain a static size, e.g, 468x60 and do not break out of these
		/// dimensions.
		/// </summary>
		IN_PAGE = 0,
		/// <summary>Expanding creatives expand/collapse on user interaction such as mouse over. It
		/// consists of an initial, or collapsed and an expanded creative area.
		/// </summary>
		EXPANDING = 1,
		/// <summary>Creatives that are served in an instant messenger application such as AOL
		/// Instant Messanger or Yahoo! Messenger. This can also be used in desktop
		/// applications such as weatherbug.
		/// </summary>
		IM_EXPANDING = 2,
		/// <summary>Floating creatives float on top of publishers page and can be closed with a
		/// close button.
		/// </summary>
		FLOATING = 3,
		/// <summary>Peel-down creatives show a glimpse of your ad in the corner of a web page. When
		/// the user interacts, the rest of the ad peels down to reveal the full message.
		/// </summary>
		PEEL_DOWN = 4,
		/// <summary>An In-Page with Floating creative is a dual-asset creative consisting of an
		/// in-page asset and a floating asset. This creative type lets you deliver a static
		/// primary ad to a webpage, while inviting a user to find out more through a
		/// floating asset delivered when the user interacts with the creative.
		/// </summary>
		IN_PAGE_WITH_FLOATING = 5,
		/// <summary>A Flash ad that renders in a Flash environment. The adserver will serve this
		/// using VAST, but it is not a proper VAST XML ad. It's an amalgamation of the
		/// proprietary InStream protocol, rendered inside VAST so that we can capture some
		/// standard behavior such as companions.
		/// </summary>
		FLASH_IN_FLASH = 6,
		/// <summary>An expanding flash ad that renders in a Flash environment. The adserver will
		/// serve this using VAST, but it is not a proper VAST XML ad. It's an amalgamation
		/// of the proprietary InStream protocol, rendered inside VAST so that we can
		/// capture some standard behavior such as companions.
		/// </summary>
		FLASH_IN_FLASH_EXPANDING = 7,
		/// <summary>In-app creatives are served into an ad slot within a publisher's app. In-app
		/// implies that they maintain a static size, e.g, 468x60 and do not break out of
		/// these dimensions.
		/// </summary>
		IN_APP = 8,
		/// <summary>The creative format is unknown or not supported in the API version in use.
		/// </summary>
		UNKNOWN = 9,
	}


	/// <summary>Rich Media Studio creative artwork types.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RichMediaStudioCreativeArtworkType {
		/// <summary>The creative is a Flash creative.
		/// </summary>
		FLASH = 0,
		/// <summary>The creative is HTML5.
		/// </summary>
		HTML5 = 1,
		/// <summary>The creative is Flash if available, and HTML5 otherwise.
		/// </summary>
		MIXED = 2,
	}


	/// <summary>Rich Media Studio creative supported billing attributes. <p>This is determined
	/// by Rich Media Studio based on the content of the creative and is not
	/// updateable.</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RichMediaStudioCreativeBillingAttribute {
		/// <summary>Applies to any <a
		/// href='RichMediaStudioCreativeFormat#IN_PAGE'>RichMediaStudioCreativeFormat#IN_PAGE</a>,
		/// without Video.
		/// </summary>
		IN_PAGE = 0,
		/// <summary>Applies to any of these following <a
		/// href='RichMediaStudioCreativeFormat'>RichMediaStudioCreativeFormat</a>, without
		/// Video: <a
		/// href='RichMediaStudioCreativeFormat#EXPANDING'>RichMediaStudioCreativeFormat#EXPANDING</a>,
		/// <a
		/// href='RichMediaStudioCreativeFormat#IM_EXPANDING'>RichMediaStudioCreativeFormat#IM_EXPANDING</a>,
		/// <a
		/// href='RichMediaStudioCreativeFormat#FLOATING'>RichMediaStudioCreativeFormat#FLOATING</a>,
		/// <a
		/// href='RichMediaStudioCreativeFormat#PEEL_DOWN'>RichMediaStudioCreativeFormat#PEEL_DOWN</a>,
		/// <a
		/// href='RichMediaStudioCreativeFormat#IN_PAGE_WITH_FLOATING'>RichMediaStudioCreativeFormat#IN_PAGE_WITH_FLOATING</a>
		/// </summary>
		FLOATING_EXPANDING = 1,
		/// <summary>Applies to any creatives that includes a video.
		/// </summary>
		VIDEO = 2,
		/// <summary>Applies to any <a
		/// href='RichMediaStudioCreativeFormat#FLASH_IN_FLASH'>RichMediaStudioCreativeFormat#FLASH_IN_FLASH</a>,
		/// without Video.
		/// </summary>
		FLASH_IN_FLASH = 3,
	}


	/// <summary>A <code>Creative</code> that is created by a Rich Media Studio. You cannot
	/// create this creative, but you can update some fields of this creative.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RichMediaStudioCreative : BaseRichMediaStudioCreative {
		private LockedOrientation lockedOrientationField;

		private bool lockedOrientationFieldSpecified;

		private bool isInterstitialField;

		private bool isInterstitialFieldSpecified;

		/// <summary>A locked orientation for this creative to be displayed in.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public LockedOrientation lockedOrientation {
			get {
				return this.lockedOrientationField;
			}
			set {
				this.lockedOrientationField = value;
				this.lockedOrientationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lockedOrientation" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lockedOrientationSpecified {
			get {
				return this.lockedOrientationFieldSpecified;
			}
			set {
				this.lockedOrientationFieldSpecified = value;
			}
		}

		/// <summary><code>true</code> if this is interstitial. An interstitial creative will not
		/// consider an impression served until it is fully rendered in the browser. This
		/// attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public bool isInterstitial {
			get {
				return this.isInterstitialField;
			}
			set {
				this.isInterstitialField = value;
				this.isInterstitialSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isInterstitial" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isInterstitialSpecified {
			get {
				return this.isInterstitialFieldSpecified;
			}
			set {
				this.isInterstitialFieldSpecified = value;
			}
		}
	}


	/// <summary>A base class for dynamic allocation creatives.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(HasHtmlSnippetDynamicAllocationCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AdSenseCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AdExchangeCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AdMobBackfillCreative))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class BaseDynamicAllocationCreative : Creative {
	}


	/// <summary>Dynamic allocation creative with a backfill code snippet.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AdSenseCreative))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AdExchangeCreative))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class HasHtmlSnippetDynamicAllocationCreative : BaseDynamicAllocationCreative {
		private string codeSnippetField;

		/// <summary>The code snippet (ad tag) from Ad Exchange or AdSense to traffic the dynamic
		/// allocation creative. Only valid Ad Exchange or AdSense parameters will be
		/// considered. Any extraneous HTML or JavaScript will be ignored.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string codeSnippet {
			get {
				return this.codeSnippetField;
			}
			set {
				this.codeSnippetField = value;
			}
		}
	}


	/// <summary>An AdSense dynamic allocation creative.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdSenseCreative : HasHtmlSnippetDynamicAllocationCreative {
	}


	/// <summary>An Ad Exchange dynamic allocation creative.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdExchangeCreative : HasHtmlSnippetDynamicAllocationCreative {
		private bool isNativeEligibleField;

		private bool isNativeEligibleFieldSpecified;

		private bool isInterstitialField;

		private bool isInterstitialFieldSpecified;

		/// <summary>Whether this creative is eligible for native ad-serving. This value is optional
		/// and defaults to <code>false</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool isNativeEligible {
			get {
				return this.isNativeEligibleField;
			}
			set {
				this.isNativeEligibleField = value;
				this.isNativeEligibleSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isNativeEligible" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isNativeEligibleSpecified {
			get {
				return this.isNativeEligibleFieldSpecified;
			}
			set {
				this.isNativeEligibleFieldSpecified = value;
			}
		}

		/// <summary><code>true</code> if this creative is interstitial. An interstitial creative
		/// will not consider an impression served until it is fully rendered in the
		/// browser.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public bool isInterstitial {
			get {
				return this.isInterstitialField;
			}
			set {
				this.isInterstitialField = value;
				this.isInterstitialSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isInterstitial" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isInterstitialSpecified {
			get {
				return this.isInterstitialFieldSpecified;
			}
			set {
				this.isInterstitialFieldSpecified = value;
			}
		}
	}


	/// <summary>An AdMob backfill creative.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdMobBackfillCreative : BaseDynamicAllocationCreative {
		private string additionalParametersField;

		private string publisherIdField;

		private LockedOrientation lockedOrientationField;

		private bool lockedOrientationFieldSpecified;

		/// <summary>Optional parameters that you can append to the request to AdMob, for example,
		/// test=true&amp;bgcolor=000000.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string additionalParameters {
			get {
				return this.additionalParametersField;
			}
			set {
				this.additionalParametersField = value;
			}
		}

		/// <summary>The AdMob publisher ID. See the <a
		/// href="https://support.google.com/dfp_premium/answer/1209767#admob">Ad Manager
		/// Help Center</a> for more information. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string publisherId {
			get {
				return this.publisherIdField;
			}
			set {
				this.publisherIdField = value;
			}
		}

		/// <summary>A locked orientation for this creative to be displayed in.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public LockedOrientation lockedOrientation {
			get {
				return this.lockedOrientationField;
			}
			set {
				this.lockedOrientationField = value;
				this.lockedOrientationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lockedOrientation" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lockedOrientationSpecified {
			get {
				return this.lockedOrientationFieldSpecified;
			}
			set {
				this.lockedOrientationFieldSpecified = value;
			}
		}
	}


	/// <summary>Lists all errors associated with template instantiated creatives.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class TemplateInstantiatedCreativeError : ApiError {
		private TemplateInstantiatedCreativeErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public TemplateInstantiatedCreativeErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reason for the error
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "TemplateInstantiatedCreativeError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum TemplateInstantiatedCreativeErrorReason {
		/// <summary>A new creative cannot be created from an inactive creative template.
		/// </summary>
		INACTIVE_CREATIVE_TEMPLATE = 0,
		/// <summary>An uploaded file type is not allowed
		/// </summary>
		FILE_TYPE_NOT_ALLOWED = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Error for converting flash to swiffy asset.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SwiffyConversionError : ApiError {
		private SwiffyConversionErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public SwiffyConversionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Error reason for <a href='SwiffyConversionError'>SwiffyConversionError</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "SwiffyConversionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum SwiffyConversionErrorReason {
		/// <summary>Indicates the Swiffy service has an internal error that prevents the flash asset
		/// being converted.
		/// </summary>
		SERVER_ERROR = 0,
		/// <summary>Indicates the uploaded flash asset is not a valid flash file.
		/// </summary>
		INVALID_FLASH_FILE = 1,
		/// <summary>Indicates the Swiffy service currently does not support converting this flash
		/// asset.
		/// </summary>
		UNSUPPORTED_FLASH = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Errors associated with <a href='SetTopBoxCreative'>set-top box creatives</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SetTopBoxCreativeError : ApiError {
		private SetTopBoxCreativeErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public SetTopBoxCreativeErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Error reasons for set-top box creatives.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "SetTopBoxCreativeError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum SetTopBoxCreativeErrorReason {
		/// <summary>Set-top box creative external asset IDs are immutable after creation.
		/// </summary>
		EXTERNAL_ASSET_ID_IMMUTABLE = 1,
		/// <summary>Set-top box creatives require an external asset ID.
		/// </summary>
		EXTERNAL_ASSET_ID_REQUIRED = 2,
		/// <summary>Set-top box creative provider IDs are immutable after creation.
		/// </summary>
		PROVIDER_ID_IMMUTABLE = 3,
		/// <summary>An invalid tracking URL event type was set on the set-top box creative.
		/// </summary>
		INVALID_THIRD_PARTY_TRACKING_URL_EVENT_TYPE = 5,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>Lists all errors associated with Studio creatives.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RichMediaStudioCreativeError : ApiError {
		private RichMediaStudioCreativeErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public RichMediaStudioCreativeErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "RichMediaStudioCreativeError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RichMediaStudioCreativeErrorReason {
		/// <summary>Only Studio can create a <code>RichMediaStudioCreative</code>.
		/// </summary>
		CREATION_NOT_ALLOWED = 0,
		/// <summary>Unknown error
		/// </summary>
		UKNOWN_ERROR = 1,
		/// <summary>Invalid request indicating missing/invalid request parameters.
		/// </summary>
		INVALID_CODE_GENERATION_REQUEST = 2,
		/// <summary>Invalid creative object.
		/// </summary>
		INVALID_CREATIVE_OBJECT = 3,
		/// <summary>Unable to connect to Rich Media Studio to save the creative. Please try again
		/// later.
		/// </summary>
		STUDIO_CONNECTION_ERROR = 4,
		/// <summary>The push down duration is not allowed
		/// </summary>
		PUSHDOWN_DURATION_NOT_ALLOWED = 5,
		/// <summary>The position is invalid
		/// </summary>
		INVALID_POSITION = 6,
		/// <summary>The Z-index is invalid
		/// </summary>
		INVALID_Z_INDEX = 7,
		/// <summary>The push-down duration is invalid
		/// </summary>
		INVALID_PUSHDOWN_DURATION = 8,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 9,
	}


	/// <summary>A list of all errors to be used for validating <a href='Size'>Size</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RequiredSizeError : ApiError {
		private RequiredSizeErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public RequiredSizeErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "RequiredSizeError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RequiredSizeErrorReason {
		/// <summary><a href='Creative#size'>Creative#size</a> or <a
		/// href='LineItem#creativeSizes'>LineItem#creativeSizes</a> is missing.
		/// </summary>
		REQUIRED = 0,
		/// <summary><a
		/// href='LineItemCreativeAssociation#sizes'>LineItemCreativeAssociation#sizes</a>
		/// must be a subset of <a href='LineItem#creativeSizes'>LineItem#creativeSizes</a>.
		/// </summary>
		NOT_ALLOWED = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Errors associated with violation of a NOT NULL check.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class NullError : ApiError {
		private NullErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public NullErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the validation error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "NullError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum NullErrorReason {
		/// <summary>Specified list/container must not contain any null elements
		/// </summary>
		NULL_CONTENT = 0,
	}


	/// <summary>Lists all errors associated with line item-to-creative association dates.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LineItemCreativeAssociationError : ApiError {
		private LineItemCreativeAssociationErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public LineItemCreativeAssociationErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "LineItemCreativeAssociationError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LineItemCreativeAssociationErrorReason {
		/// <summary>Cannot associate a creative to the wrong advertiser
		/// </summary>
		CREATIVE_IN_WRONG_ADVERTISERS_LIBRARY = 0,
		/// <summary>The creative type being associated is a invalid for the line item type.
		/// </summary>
		INVALID_LINEITEM_CREATIVE_PAIRING = 1,
		/// <summary>Association start date cannot be before line item start date
		/// </summary>
		STARTDATE_BEFORE_LINEITEM_STARTDATE = 2,
		/// <summary>Association start date cannot be same as or after line item end date
		/// </summary>
		STARTDATE_NOT_BEFORE_LINEITEM_ENDDATE = 3,
		/// <summary>Association end date cannot be after line item end date
		/// </summary>
		ENDDATE_AFTER_LINEITEM_ENDDATE = 4,
		/// <summary>Association end date cannot be same as or before line item start date
		/// </summary>
		ENDDATE_NOT_AFTER_LINEITEM_STARTDATE = 5,
		/// <summary>Association end date cannot be same as or before its start date
		/// </summary>
		ENDDATE_NOT_AFTER_STARTDATE = 6,
		/// <summary>Association end date cannot be in the past.
		/// </summary>
		ENDDATE_IN_THE_PAST = 7,
		/// <summary>Cannot copy an association to the same line item without creating new creative
		/// </summary>
		CANNOT_COPY_WITHIN_SAME_LINE_ITEM = 8,
		/// <summary>Programmatic creatives can only be assigned to one line item.
		/// </summary>
		PROGRAMMATIC_CREATIVES_CAN_ONLY_BE_ASSIGNED_TO_ONE_LINE_ITEM = 9,
		/// <summary>Cannot create programmatic creatives.
		/// </summary>
		CANNOT_CREATE_PROGRAMMATIC_CREATIVES = 10,
		/// <summary>Cannot update programmatic creatives.
		/// </summary>
		CANNOT_UPDATE_PROGRAMMATIC_CREATIVES = 11,
		/// <summary>Cannot associate a creative with a line item if only one of them is set-top box
		/// enabled.
		/// </summary>
		CREATIVE_AND_LINE_ITEM_MUST_BOTH_BE_SET_TOP_BOX_ENABLED = 12,
		/// <summary>Cannot delete associations between set-top box enabled line items and set-top
		/// box enabled creatives.
		/// </summary>
		CANNOT_DELETE_SET_TOP_BOX_ENABLED_ASSOCIATIONS = 13,
		/// <summary>Creative rotation weights must be integers.
		/// </summary>
		SET_TOP_BOX_CREATIVE_ROTATION_WEIGHT_MUST_BE_INTEGER = 14,
		/// <summary>Creative rotation weights are only valid when creative rotation type is set to
		/// <a href='CreativeRotationType#MANUAL'>CreativeRotationType#MANUAL</a>.
		/// </summary>
		INVALID_CREATIVE_ROTATION_TYPE_FOR_MANUAL_WEIGHT = 15,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 16,
	}


	/// <summary>Errors specific to creating label entity associations.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LabelEntityAssociationError : ApiError {
		private LabelEntityAssociationErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public LabelEntityAssociationErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "LabelEntityAssociationError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LabelEntityAssociationErrorReason {
		/// <summary>The label has already been attached to the entity.
		/// </summary>
		DUPLICATE_ASSOCIATION = 1,
		/// <summary>A label is being applied to an entity that does not support that entity type.
		/// </summary>
		INVALID_ASSOCIATION = 2,
		/// <summary>The same label is being applied and negated to the same entity.
		/// </summary>
		DUPLICATE_ASSOCIATION_WITH_NEGATION = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>Lists all errors associated with phone numbers.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class InvalidPhoneNumberError : ApiError {
		private InvalidPhoneNumberErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public InvalidPhoneNumberErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "InvalidPhoneNumberError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum InvalidPhoneNumberErrorReason {
		/// <summary>The phone number is invalid.
		/// </summary>
		INVALID_FORMAT = 0,
		/// <summary>The phone number is too short.
		/// </summary>
		TOO_SHORT = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Lists all errors associated with images.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ImageError : ApiError {
		private ImageErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ImageErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ImageError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ImageErrorReason {
		/// <summary>The file's format is invalid.
		/// </summary>
		INVALID_IMAGE = 0,
		/// <summary><a href='Size#width'>Size#width</a> and <a href='Size#height'>Size#height</a>
		/// cannot be negative.
		/// </summary>
		INVALID_SIZE = 1,
		/// <summary>The actual image size does not match the expected image size.
		/// </summary>
		UNEXPECTED_SIZE = 2,
		/// <summary>The size of the asset is larger than that of the overlay creative.
		/// </summary>
		OVERLAY_SIZE_TOO_LARGE = 3,
		/// <summary>Animated images are not allowed.
		/// </summary>
		ANIMATED_NOT_ALLOWED = 4,
		/// <summary>Animation length exceeded the allowed policy limit.
		/// </summary>
		ANIMATION_TOO_LONG = 5,
		/// <summary>Images in CMYK color formats are not allowed.
		/// </summary>
		CMYK_JPEG_NOT_ALLOWED = 6,
		/// <summary>Flash files are not allowed.
		/// </summary>
		FLASH_NOT_ALLOWED = 7,
		/// <summary>If <a href='FlashCreative#clickTagRequired'>FlashCreative#clickTagRequired</a>
		/// is <code>true</code>, then the flash file is required to have a click tag
		/// embedded in it.
		/// </summary>
		FLASH_WITHOUT_CLICKTAG = 8,
		/// <summary>Animated visual effect is not allowed.
		/// </summary>
		ANIMATED_VISUAL_EFFECT = 9,
		/// <summary>An error was encountered in the flash file.
		/// </summary>
		FLASH_ERROR = 10,
		/// <summary>Incorrect image layout.
		/// </summary>
		LAYOUT_PROBLEM = 11,
		/// <summary>Flash files with network objects are not allowed.
		/// </summary>
		FLASH_HAS_NETWORK_OBJECTS = 12,
		/// <summary>Flash files with network methods are not allowed.
		/// </summary>
		FLASH_HAS_NETWORK_METHODS = 13,
		/// <summary>Flash files with hard-coded click thru URLs are not allowed.
		/// </summary>
		FLASH_HAS_URL = 14,
		/// <summary>Flash files with mouse tracking are not allowed.
		/// </summary>
		FLASH_HAS_MOUSE_TRACKING = 15,
		/// <summary>Flash files that generate or use random numbers are not allowed.
		/// </summary>
		FLASH_HAS_RANDOM_NUM = 16,
		/// <summary>Flash files with self targets are not allowed.
		/// </summary>
		FLASH_SELF_TARGETS = 17,
		/// <summary>Flash file contains a bad geturl target.
		/// </summary>
		FLASH_BAD_GETURL_TARGET = 18,
		/// <summary>Flash or ActionScript version in the submitted file is not supported.
		/// </summary>
		FLASH_VERSION_NOT_SUPPORTED = 19,
		/// <summary>The uploaded file is too large.
		/// </summary>
		FILE_TOO_LARGE = 20,
		/// <summary>A system error occurred, please try again.
		/// </summary>
		SYSTEM_ERROR = 21,
		/// <summary>The image density for a primary asset was not one of the expected image
		/// densities.
		/// </summary>
		UNEXPECTED_PRIMARY_ASSET_DENSITY = 22,
		/// <summary>Two or more assets have the same image density.
		/// </summary>
		DUPLICATE_ASSET_DENSITY = 23,
		/// <summary>The creative does not contain a primary asset. (For high-density creatives, the
		/// primary asset must be a standard image file with 1x density.)
		/// </summary>
		MISSING_DEFAULT_ASSET = 24,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 25,
	}


	/// <summary>Lists all errors associated with html5 file processing.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class HtmlBundleProcessorError : ApiError {
		private HtmlBundleProcessorErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public HtmlBundleProcessorErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Error reasons that may arise during HTML5 bundle processing.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "HtmlBundleProcessorError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum HtmlBundleProcessorErrorReason {
		/// <summary>Cannot extract files from HTML5 bundle.
		/// </summary>
		CANNOT_EXTRACT_FILES_FROM_BUNDLE = 0,
		/// <summary>Bundle cannot have hard-coded click tag url(s).
		/// </summary>
		CLICK_TAG_HARD_CODED = 1,
		/// <summary>Bundles created using GWD (Google Web Designer) cannot have click tags.
		/// GWD-published bundles should use exit events instead of defining var
		/// <code>clickTAG</code>.
		/// </summary>
		CLICK_TAG_IN_GWD_UNUPPORTED = 2,
		/// <summary>Click tag detected outside of primary HTML file.
		/// </summary>
		CLICK_TAG_NOT_IN_PRIMARY_HTML = 3,
		/// <summary>Click tag or exit function has invalid name or url.
		/// </summary>
		CLICK_TAG_INVALID = 4,
		/// <summary>HTML5 bundle or total size of extracted files cannot be more than 1000 KB.
		/// </summary>
		FILE_SIZE_TOO_LARGE = 5,
		/// <summary>HTML5 bundle cannot have more than 50 files.
		/// </summary>
		FILES_TOO_MANY = 6,
		/// <summary>Flash files in HTML5 bundles are not supported. Any file with a .swf or .flv
		/// extension causes this error.
		/// </summary>
		FLASH_UNSUPPORTED = 7,
		/// <summary>The HTML5 bundle contains unsupported GWD component(s).
		/// </summary>
		GWD_COMPONENTS_UNSUPPORTED = 8,
		/// <summary>The HTML5 bundle contains Unsupported GWD Enabler method(s).
		/// </summary>
		GWD_ENABLER_METHODS_UNSUPPORTED = 9,
		/// <summary>GWD properties are invalid.
		/// </summary>
		GWD_PROPERTIES_INVALID = 10,
		/// <summary>The HTML5 bundle contains broken relative file reference(s).
		/// </summary>
		LINKED_FILES_NOT_FOUND = 11,
		/// <summary>No primary HTML file detected.
		/// </summary>
		PRIMARY_HTML_MISSING = 12,
		/// <summary>Multiple HTML files are detected. One of them should be named as
		/// <code>index.html</code>
		/// </summary>
		PRIMARY_HTML_UNDETERMINED = 13,
		/// <summary>An SVG block could not be parsed.
		/// </summary>
		SVG_BLOCK_INVALID = 14,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 15,
	}


	/// <summary>A list of all errors to be used for problems related to files.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class FileError : ApiError {
		private FileErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public FileErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "FileError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum FileErrorReason {
		/// <summary>The provided byte array is empty.
		/// </summary>
		MISSING_CONTENTS = 0,
		/// <summary>The provided file is larger than the maximum size defined for the network.
		/// </summary>
		SIZE_TOO_LARGE = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>An error that occurs when creating an entity if the limit on the number of
	/// allowed entities for a network has already been reached.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class EntityLimitReachedError : ApiError {
		private EntityLimitReachedErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public EntityLimitReachedErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the entity limit reached error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "EntityLimitReachedError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum EntityLimitReachedErrorReason {
		/// <summary>The number of custom targeting values exceeds the max number allowed in the
		/// network.
		/// </summary>
		CUSTOM_TARGETING_VALUES_LIMIT_REACHED = 0,
		/// <summary>The number of ad exclusion rules exceeds the max number allowed in the network.
		/// </summary>
		AD_EXCLUSION_RULES_LIMIT_REACHED = 1,
		/// <summary>The number of first party audience segments exceeds the max number allowed in
		/// the network.
		/// </summary>
		FIRST_PARTY_AUDIENCE_SEGMENTS_LIMIT_REACHED = 2,
		/// <summary>The number of active placements exceeds the max number allowed in the network.
		/// </summary>
		PLACEMENTS_LIMIT_REACHED = 3,
		/// <summary>The number of line items excceeds the max number allowed in the network.
		/// </summary>
		LINE_ITEMS_LIMIT_REACHED = 4,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 5,
	}


	/// <summary>Errors specific to editing custom field values
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomFieldValueError : ApiError {
		private CustomFieldValueErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CustomFieldValueErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CustomFieldValueError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CustomFieldValueErrorReason {
		/// <summary>An attempt was made to modify or create a <a
		/// href='CustomFieldValue'>CustomFieldValue</a> for a <a
		/// href='CustomField'>CustomField</a> that does not exist.
		/// </summary>
		CUSTOM_FIELD_NOT_FOUND = 0,
		/// <summary>An attempt was made to create a new value for a custom field that is inactive.
		/// </summary>
		CUSTOM_FIELD_INACTIVE = 1,
		/// <summary>An attempt was made to modify or create a <a
		/// href='CustomFieldValue'>CustomFieldValue</a> corresponding to a <a
		/// href='CustomFieldOption'>CustomFieldOption</a> that could not be found.
		/// </summary>
		CUSTOM_FIELD_OPTION_NOT_FOUND = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Lists all errors associated with custom creatives.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomCreativeError : ApiError {
		private CustomCreativeErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CustomCreativeErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CustomCreativeError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CustomCreativeErrorReason {
		/// <summary>Macros associated with a single custom creative must have unique names.
		/// </summary>
		DUPLICATE_MACRO_NAME_FOR_CREATIVE = 0,
		/// <summary>The file macro referenced in the snippet does not exist.
		/// </summary>
		SNIPPET_REFERENCES_MISSING_MACRO = 1,
		/// <summary>The macro referenced in the snippet is not valid.
		/// </summary>
		UNRECOGNIZED_MACRO = 2,
		/// <summary>Custom creatives are not allowed in this context.
		/// </summary>
		CUSTOM_CREATIVE_NOT_ALLOWED = 3,
		/// <summary>The custom creative is an interstitial, but the snippet is missing an
		/// interstitial macro.
		/// </summary>
		MISSING_INTERSTITIAL_MACRO = 4,
		/// <summary>Macros associated with the same custom creative cannot share the same asset.
		/// </summary>
		DUPLICATE_ASSET_IN_MACROS = 5,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 6,
	}


	/// <summary>An error that can occur while performing an operation on a creative template.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreativeTemplateOperationError : ApiError {
		private CreativeTemplateOperationErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CreativeTemplateOperationErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CreativeTemplateOperationError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CreativeTemplateOperationErrorReason {
		/// <summary>The current user is not allowed to modify this creative template.
		/// </summary>
		NOT_ALLOWED = 0,
		/// <summary>The operation is not applicable to the current state. (e.g. Trying to activate
		/// an active creative template)
		/// </summary>
		NOT_APPLICABLE = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>A catch-all error that lists all generic errors associated with
	/// CreativeTemplate.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreativeTemplateError : ApiError {
		private CreativeTemplateErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CreativeTemplateErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CreativeTemplateError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CreativeTemplateErrorReason {
		/// <summary>The XML of the creative template definition is malformed and cannot be parsed.
		/// </summary>
		CANNOT_PARSE_CREATIVE_TEMPLATE = 0,
		/// <summary>A creative template has multiple variables with the same uniqueName.
		/// </summary>
		VARIABLE_DUPLICATE_UNIQUE_NAME = 1,
		/// <summary>The creative template contains a variable with invalid characters. Valid
		/// characters are letters, numbers, spaces, forward slashes, dashes, and
		/// underscores.
		/// </summary>
		VARIABLE_INVALID_UNIQUE_NAME = 2,
		/// <summary>Multiple choices for a CreativeTemplateListStringVariable have the same value.
		/// </summary>
		LIST_CHOICE_DUPLICATE_VALUE = 3,
		/// <summary>The choices for a CreativeTemplateListStringVariable do not contain the default
		/// value.
		/// </summary>
		LIST_CHOICE_NEEDS_DEFAULT = 4,
		/// <summary>There are no choices specified for the list variable.
		/// </summary>
		LIST_CHOICES_EMPTY = 5,
		/// <summary>No target platform is assigned to a creative template.
		/// </summary>
		NO_TARGET_PLATFORMS = 6,
		/// <summary>More than one target platform is assigned to a single creative template.
		/// </summary>
		MULTIPLE_TARGET_PLATFORMS = 7,
		/// <summary>The formatter contains a placeholder which is not defined as a variable.
		/// </summary>
		UNRECOGNIZED_PLACEHOLDER = 8,
		/// <summary>There are variables defined which are not being used in the formatter.
		/// </summary>
		PLACEHOLDERS_NOT_IN_FORMATTER = 9,
		/// <summary>The creative template is interstitial, but the formatter doesn't contain an
		/// interstitial macro.
		/// </summary>
		MISSING_INTERSTITIAL_MACRO = 10,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 11,
	}


	/// <summary>Errors relating to creative sets &amp; subclasses.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreativeSetError : ApiError {
		private CreativeSetErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CreativeSetErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CreativeSetError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CreativeSetErrorReason {
		/// <summary>The 'video' feature is required but not enabled.
		/// </summary>
		VIDEO_FEATURE_REQUIRED = 0,
		/// <summary>Video creatives (including overlays, VAST redirects, etc..) cannot be created or
		/// updated through the API.
		/// </summary>
		CANNOT_CREATE_OR_UPDATE_VIDEO_CREATIVES = 1,
		/// <summary>The 'roadblock' feature is required but not enabled.
		/// </summary>
		ROADBLOCK_FEATURE_REQUIRED = 2,
		/// <summary>A master creative cannot be a companion creative in the same creative set.
		/// </summary>
		MASTER_CREATIVE_CANNOT_BE_COMPANION = 3,
		/// <summary>Creatives in a creative set must be for the same advertiser.
		/// </summary>
		INVALID_ADVERTISER = 4,
		/// <summary>Updating a master creative in a creative set is not allowed.
		/// </summary>
		UPDATE_MASTER_CREATIVE_NOT_ALLOWED = 5,
		/// <summary>A master creative must belong to only one video creative set.
		/// </summary>
		MASTER_CREATIVE_CANNOT_BELONG_TO_MULTIPLE_VIDEO_CREATIVE_SETS = 7,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 6,
	}


	/// <summary>Lists all errors associated with creatives.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreativeError : ApiError {
		private CreativeErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CreativeErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CreativeError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CreativeErrorReason {
		/// <summary><a href='FlashRedirectCreative#flashUrl'>FlashRedirectCreative#flashUrl</a> and
		/// <a
		/// href='FlashRedirectCreative#fallbackUrl'>FlashRedirectCreative#fallbackUrl</a>
		/// are the same. The fallback URL is used when the flash URL does not work and must
		/// be different from it.
		/// </summary>
		FLASH_AND_FALLBACK_URL_ARE_SAME = 0,
		/// <summary>The internal redirect URL was invalid. The URL must have the following syntax
		/// http://ad.doubleclick.net/ad/sitename/;sz=size.
		/// </summary>
		INVALID_INTERNAL_REDIRECT_URL = 1,
		/// <summary><a
		/// href='HasDestinationUrlCreative#destinationUrl'>HasDestinationUrlCreative#destinationUrl</a>
		/// is required.
		/// </summary>
		DESTINATION_URL_REQUIRED = 2,
		/// <summary><a
		/// href='HasDestinationUrlCreative#destinationUrl'>HasDestinationUrlCreative#destinationUrl</a>
		/// must be empty when its type is <a
		/// href='DestinationUrlType#NONE'>DestinationUrlType#NONE</a>.
		/// </summary>
		DESTINATION_URL_NOT_EMPTY = 14,
		/// <summary>The provided <a href='DestinationUrlType'>DestinationUrlType</a> is not
		/// supported for the creative type it is being used on.
		/// </summary>
		DESTINATION_URL_TYPE_NOT_SUPPORTED = 15,
		/// <summary>Cannot create or update legacy DART For Publishers creative.
		/// </summary>
		CANNOT_CREATE_OR_UPDATE_LEGACY_DFP_CREATIVE = 3,
		/// <summary>Cannot create or update legacy mobile creative.
		/// </summary>
		CANNOT_CREATE_OR_UPDATE_LEGACY_DFP_MOBILE_CREATIVE = 4,
		/// <summary>The user is missing a necessary feature.
		/// </summary>
		MISSING_FEATURE = 5,
		/// <summary>Company type should be one of Advertisers, House Advertisers and Ad Networks.
		/// </summary>
		INVALID_COMPANY_TYPE = 6,
		/// <summary>Invalid size for AdSense dynamic allocation creative. Only valid AFC sizes are
		/// allowed.
		/// </summary>
		INVALID_ADSENSE_CREATIVE_SIZE = 7,
		/// <summary>Invalid size for Ad Exchange dynamic allocation creative. Only valid Ad Exchange
		/// sizes are allowed.
		/// </summary>
		INVALID_AD_EXCHANGE_CREATIVE_SIZE = 8,
		/// <summary>Assets associated with the same creative must be unique.
		/// </summary>
		DUPLICATE_ASSET_IN_CREATIVE = 9,
		/// <summary>A creative asset cannot contain an asset ID and a byte array.
		/// </summary>
		CREATIVE_ASSET_CANNOT_HAVE_ID_AND_BYTE_ARRAY = 10,
		/// <summary>Cannot create or update unsupported creative.
		/// </summary>
		CANNOT_CREATE_OR_UPDATE_UNSUPPORTED_CREATIVE = 11,
		/// <summary>Cannot create programmatic creatives.
		/// </summary>
		CANNOT_CREATE_PROGRAMMATIC_CREATIVES = 12,
		/// <summary>A creative must have valid size to use the third-party impression tracker.
		/// </summary>
		INVALID_SIZE_FOR_THIRD_PARTY_IMPRESSION_TRACKER = 16,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 13,
	}


	/// <summary>Lists all errors associated with creative asset macros.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreativeAssetMacroError : ApiError {
		private CreativeAssetMacroErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CreativeAssetMacroErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CreativeAssetMacroError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CreativeAssetMacroErrorReason {
		/// <summary>Invalid macro name specified. Macro names must start with an alpha character and
		/// consist only of alpha-numeric characters and underscores and be between 1 and 64
		/// characters.
		/// </summary>
		INVALID_MACRO_NAME = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>Lists all errors associated with assets.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AssetError : ApiError {
		private AssetErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AssetErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AssetError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AssetErrorReason {
		/// <summary>An asset name must be unique across advertiser.
		/// </summary>
		NON_UNIQUE_NAME = 0,
		/// <summary>The file name is too long.
		/// </summary>
		FILE_NAME_TOO_LONG = 1,
		/// <summary>The file size is too large.
		/// </summary>
		FILE_SIZE_TOO_LARGE = 2,
		/// <summary>Required client code is not present in the code snippet.
		/// </summary>
		MISSING_REQUIRED_DYNAMIC_ALLOCATION_CLIENT = 3,
		/// <summary>Required height is not present in the code snippet.
		/// </summary>
		MISSING_REQUIRED_DYNAMIC_ALLOCATION_HEIGHT = 4,
		/// <summary>Required width is not present in the code snippet.
		/// </summary>
		MISSING_REQUIRED_DYNAMIC_ALLOCATION_WIDTH = 5,
		/// <summary>Required format is not present in the mobile code snippet.
		/// </summary>
		MISSING_REQUIRED_DYNAMIC_ALLOCATION_FORMAT = 6,
		/// <summary>The parameter value in the code snippet is invalid.
		/// </summary>
		INVALID_CODE_SNIPPET_PARAMETER_VALUE = 7,
		/// <summary>Invalid asset Id.
		/// </summary>
		INVALID_ASSET_ID = 8,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 9,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.CreativeServiceInterface")]
	public interface CreativeServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(Asset))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.CreativeService.createCreativesResponse createCreatives(Wrappers.CreativeService.createCreativesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.CreativeService.createCreativesResponse> createCreativesAsync(Wrappers.CreativeService.createCreativesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(Asset))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.CreativePage getCreativesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativePage> getCreativesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(Asset))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.CreativeService.updateCreativesResponse updateCreatives(Wrappers.CreativeService.updateCreativesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.CreativeService.updateCreativesResponse> updateCreativesAsync(Wrappers.CreativeService.updateCreativesRequest request);
	}


	/// <summary>Captures a page of <a href='Creative'>Creative</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreativePage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private Creative[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of creatives contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public Creative[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface CreativeServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.CreativeServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for adding, updating and retrieving <a
	/// href='Creative'>Creative</a> objects. <p>For a creative to run, it must be
	/// associated with a <a href='LineItem'>LineItem</a> managed by the <a
	/// href='LineItemCreativeAssociationService'>LineItemCreativeAssociationService</a>.</p>
	/// <p>Read more about creatives on the <a
	/// href="https://support.google.com/dfp_premium/answer/3185155">DFP Help
	/// Center</a>.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class CreativeService : AdManagerSoapClient<ICreativeService>, ICreativeService {
		/// <summary> Creates a new instance of the <see cref="CreativeService"/> class.
		/// </summary>
		public CreativeService() {
		}

		/// <summary> Creates a new instance of the <see cref="CreativeService"/> class.
		/// </summary>
		public CreativeService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="CreativeService"/> class.
		/// </summary>
		public CreativeService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="CreativeService"/> class.
		/// </summary>
		public CreativeService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="CreativeService"/> class.
		/// </summary>
		public CreativeService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.CreativeService.createCreativesResponse Google.Api.Ads.AdManager.v201802.CreativeServiceInterface.createCreatives(Wrappers.CreativeService.createCreativesRequest request) {
			return base.Channel.createCreatives(request);
		}

		/// <summary>Creates new <a href='Creative'>Creative</a> objects.
		/// </summary><param name='creatives'>the creatives to create</param>
		/// <returns>the created creatives with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Creative[] createCreatives(Google.Api.Ads.AdManager.v201802.Creative[] creatives) {
			Wrappers.CreativeService.createCreativesRequest inValue = new Wrappers.CreativeService.createCreativesRequest();
			inValue.creatives = creatives;
			Wrappers.CreativeService.createCreativesResponse retVal = ((Google.Api.Ads.AdManager.v201802.CreativeServiceInterface)(this)).createCreatives(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.CreativeService.createCreativesResponse> Google.Api.Ads.AdManager.v201802.CreativeServiceInterface.createCreativesAsync(Wrappers.CreativeService.createCreativesRequest request) {
			return base.Channel.createCreativesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Creative[]> createCreativesAsync(Google.Api.Ads.AdManager.v201802.Creative[] creatives) {
			Wrappers.CreativeService.createCreativesRequest inValue = new Wrappers.CreativeService.createCreativesRequest();
			inValue.creatives = creatives;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Creative[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.CreativeServiceInterface)(this)).createCreativesAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='CreativePage'>CreativePage</a> of <a
		/// href='Creative'>Creative</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='Creative#id'>Creative#id</a></td> </tr> <tr> <td><code>name</code></td>
		/// <td><a href='Creative#name'>Creative#name</a></td> </tr> <tr>
		/// <td><code>advertiserId</code></td> <td><a
		/// href='Creative#advertiserId'>Creative#advertiserId</a></td> </tr> <tr>
		/// <td><code>width</code></td> <td><a href='Creative#size'>Creative#size</a></td>
		/// </tr> <tr> <td><code>height</code></td> <td><a
		/// href='Creative#size'>Creative#size</a></td> </tr> <tr>
		/// <td><code>lastModifiedDateTime</code></td> <td><a
		/// href='Creative#lastModifiedDateTime'>Creative#lastModifiedDateTime</a></td>
		/// </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of creatives</param>
		/// <returns>the creatives that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CreativePage getCreativesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getCreativesByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativePage> getCreativesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getCreativesByStatementAsync(filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.CreativeService.updateCreativesResponse Google.Api.Ads.AdManager.v201802.CreativeServiceInterface.updateCreatives(Wrappers.CreativeService.updateCreativesRequest request) {
			return base.Channel.updateCreatives(request);
		}

		/// <summary>Updates the specified <a href='Creative'>Creative</a> objects.
		/// </summary><param name='creatives'>the creatives to update</param>
		/// <returns>the updated creatives</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Creative[] updateCreatives(Google.Api.Ads.AdManager.v201802.Creative[] creatives) {
			Wrappers.CreativeService.updateCreativesRequest inValue = new Wrappers.CreativeService.updateCreativesRequest();
			inValue.creatives = creatives;
			Wrappers.CreativeService.updateCreativesResponse retVal = ((Google.Api.Ads.AdManager.v201802.CreativeServiceInterface)(this)).updateCreatives(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.CreativeService.updateCreativesResponse> Google.Api.Ads.AdManager.v201802.CreativeServiceInterface.updateCreativesAsync(Wrappers.CreativeService.updateCreativesRequest request) {
			return base.Channel.updateCreativesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Creative[]> updateCreativesAsync(Google.Api.Ads.AdManager.v201802.Creative[] creatives) {
			Wrappers.CreativeService.updateCreativesRequest inValue = new Wrappers.CreativeService.updateCreativesRequest();
			inValue.creatives = creatives;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Creative[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.CreativeServiceInterface)(this)).updateCreativesAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.CreativeSetService
	{
	}
	/// <summary>A creative set is comprised of a master creative and its companion creatives.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreativeSet {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private long masterCreativeIdField;

		private bool masterCreativeIdFieldSpecified;

		private long[] companionCreativeIdsField;

		private DateTime lastModifiedDateTimeField;

		/// <summary>Uniquely identifies the <code>CreativeSet</code>. This attribute is read-only
		/// and is assigned by Google when a creative set is created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the creative set. This attribute is required and has a maximum
		/// length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The ID of the master creative associated with this creative set. This attribute
		/// is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public long masterCreativeId {
			get {
				return this.masterCreativeIdField;
			}
			set {
				this.masterCreativeIdField = value;
				this.masterCreativeIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="masterCreativeId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool masterCreativeIdSpecified {
			get {
				return this.masterCreativeIdFieldSpecified;
			}
			set {
				this.masterCreativeIdFieldSpecified = value;
			}
		}

		/// <summary>The IDs of the companion creatives associated with this creative set. This
		/// attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("companionCreativeIds", Order = 3)]
		public long[] companionCreativeIds {
			get {
				return this.companionCreativeIdsField;
			}
			set {
				this.companionCreativeIdsField = value;
			}
		}

		/// <summary>The date and time this creative set was last modified.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public DateTime lastModifiedDateTime {
			get {
				return this.lastModifiedDateTimeField;
			}
			set {
				this.lastModifiedDateTimeField = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.CreativeSetServiceInterface")]
	public interface CreativeSetServiceInterface
	{
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.CreativeSet createCreativeSet(Google.Api.Ads.AdManager.v201802.CreativeSet creativeSet);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeSet> createCreativeSetAsync(Google.Api.Ads.AdManager.v201802.CreativeSet creativeSet);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.CreativeSetPage getCreativeSetsByStatement(Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeSetPage> getCreativeSetsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.CreativeSet updateCreativeSet(Google.Api.Ads.AdManager.v201802.CreativeSet creativeSet);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeSet> updateCreativeSetAsync(Google.Api.Ads.AdManager.v201802.CreativeSet creativeSet);
	}


	/// <summary>Captures a page of <a href='CreativeSet'>CreativeSet</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreativeSetPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private CreativeSet[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of creative sets contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public CreativeSet[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface CreativeSetServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.CreativeSetServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for adding, updating and retrieving <a
	/// href='CreativeSet'>CreativeSet</a> objects.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class CreativeSetService : AdManagerSoapClient<ICreativeSetService>, ICreativeSetService {
		/// <summary> Creates a new instance of the <see cref="CreativeSetService"/> class.
		/// </summary>
		public CreativeSetService() {
		}

		/// <summary> Creates a new instance of the <see cref="CreativeSetService"/> class.
		/// </summary>
		public CreativeSetService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="CreativeSetService"/> class.
		/// </summary>
		public CreativeSetService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="CreativeSetService"/> class.
		/// </summary>
		public CreativeSetService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="CreativeSetService"/> class.
		/// </summary>
		public CreativeSetService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		/// <summary>Creates a new <a href='CreativeSet'>CreativeSet</a>.
		/// </summary><param name='creativeSet'>the creative set to create</param>
		/// <returns>the creative set with its ID filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CreativeSet createCreativeSet(Google.Api.Ads.AdManager.v201802.CreativeSet creativeSet) {
			return base.Channel.createCreativeSet(creativeSet);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeSet> createCreativeSetAsync(Google.Api.Ads.AdManager.v201802.CreativeSet creativeSet) {
			return base.Channel.createCreativeSetAsync(creativeSet);
		}

		/// <summary>Gets a <a href='CreativeSetPage'>CreativeSetPage</a> of <a
		/// href='CreativeSet'>CreativeSet</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='CreativeSet#id'>CreativeSet#id</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a
		/// href='CreativeSet#name'>CreativeSet#name</a></td> </tr> <tr>
		/// <td><code>masterCreativeId</code></td> <td><a
		/// href='CreativeSet#masterCreativeId'>CreativeSet#masterCreativeId</a></td> </tr>
		/// <tr> <td><code>lastModifiedDateTime</code></td> <td><a
		/// href='CreativeSet#lastModifiedDateTime'>CreativeSet#lastModifiedDateTime</a></td>
		/// </tr> </table>
		/// </summary><param name='statement'>a Publisher Query Language statement used to filter a
		/// set of creative sets</param>
		/// <returns>the creative sets that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CreativeSetPage getCreativeSetsByStatement(Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.getCreativeSetsByStatement(statement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeSetPage> getCreativeSetsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.getCreativeSetsByStatementAsync(statement);
		}

		/// <summary>Updates the specified <a href='CreativeSet'>CreativeSet</a>.
		/// </summary><param name='creativeSet'>the creative set to update</param>
		/// <returns>the updated creative set</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CreativeSet updateCreativeSet(Google.Api.Ads.AdManager.v201802.CreativeSet creativeSet) {
			return base.Channel.updateCreativeSet(creativeSet);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeSet> updateCreativeSetAsync(Google.Api.Ads.AdManager.v201802.CreativeSet creativeSet) {
			return base.Channel.updateCreativeSetAsync(creativeSet);
		}
	}
	namespace Wrappers.CreativeTemplateService
	{
	}
	/// <summary>Stores variable choices that users can select from
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ListStringCreativeTemplateVariable.VariableChoice", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ListStringCreativeTemplateVariableVariableChoice {
		private string labelField;

		private string valueField;

		/// <summary>Label that users can select from. This is displayed to users when creating a <a
		/// href='TemplateCreative'>TemplateCreative</a>. This attribute is intended to be
		/// more descriptive than <a href='#value'>#value</a>. This attribute is required
		/// and has a maximum length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string label {
			get {
				return this.labelField;
			}
			set {
				this.labelField = value;
			}
		}

		/// <summary>Value that users can select from. When creating a <a
		/// href='TemplateCreative'>TemplateCreative</a>, the value in <a
		/// href='StringCreativeTemplateVariableValue'>StringCreativeTemplateVariableValue</a>
		/// should match this value, if you intend to select this value. This attribute is
		/// required and has a maximum length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string value {
			get {
				return this.valueField;
			}
			set {
				this.valueField = value;
			}
		}
	}


	/// <summary>Represents a variable defined in a creative template.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UrlCreativeTemplateVariable))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(StringCreativeTemplateVariable))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ListStringCreativeTemplateVariable))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(LongCreativeTemplateVariable))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AssetCreativeTemplateVariable))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class CreativeTemplateVariable {
		private string labelField;

		private string uniqueNameField;

		private string descriptionField;

		private bool isRequiredField;

		private bool isRequiredFieldSpecified;

		/// <summary>Label that is displayed to users when creating <a
		/// href='TemplateCreative'>TemplateCreative</a> from the <a
		/// href='CreativeTemplate'>CreativeTemplate</a>. This attribute is required and has
		/// a maximum length of 127 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string label {
			get {
				return this.labelField;
			}
			set {
				this.labelField = value;
			}
		}

		/// <summary>Unique name used to identify the variable. This attribute is read-only and is
		/// assigned by Google, by deriving from label, when a creative template variable is
		/// created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string uniqueName {
			get {
				return this.uniqueNameField;
			}
			set {
				this.uniqueNameField = value;
			}
		}

		/// <summary>A descriptive help text that is displayed to users along with the label. This
		/// attribute is required and has a maximum length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string description {
			get {
				return this.descriptionField;
			}
			set {
				this.descriptionField = value;
			}
		}

		/// <summary><code>true</code> if this variable is required to be filled in by users when
		/// creating <a href='TemplateCreative'>TemplateCreative</a> from the <a
		/// href='CreativeTemplate'>CreativeTemplate</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public bool isRequired {
			get {
				return this.isRequiredField;
			}
			set {
				this.isRequiredField = value;
				this.isRequiredSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isRequired"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isRequiredSpecified {
			get {
				return this.isRequiredFieldSpecified;
			}
			set {
				this.isRequiredFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents a url variable defined in a creative template. <p>Use <a
	/// href='UrlCreativeTemplateVariableValue'>UrlCreativeTemplateVariableValue</a> to
	/// specify the value for this variable when creating <a
	/// href='TemplateCreative'>TemplateCreative</a> from the <a
	/// href='TemplateCreative'>TemplateCreative</a></p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UrlCreativeTemplateVariable : CreativeTemplateVariable {
		private string defaultValueField;

		private bool isTrackingUrlField;

		private bool isTrackingUrlFieldSpecified;

		/// <summary>Default value to be filled in when creating creatives from the creative
		/// template.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string defaultValue {
			get {
				return this.defaultValueField;
			}
			set {
				this.defaultValueField = value;
			}
		}

		/// <summary>When true, if the URL is identified as from a known vendor, cache-busting macros
		/// will automatically be inserted upon save.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public bool isTrackingUrl {
			get {
				return this.isTrackingUrlField;
			}
			set {
				this.isTrackingUrlField = value;
				this.isTrackingUrlSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isTrackingUrl" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isTrackingUrlSpecified {
			get {
				return this.isTrackingUrlFieldSpecified;
			}
			set {
				this.isTrackingUrlFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents a string variable defined in a creative template. <p>Use <a
	/// href='StringCreativeTemplateVariableValue'>StringCreativeTemplateVariableValue</a>
	/// to specify the value for this variable when creating <a
	/// href='TemplateCreative'>TemplateCreative</a> from the <a
	/// href='TemplateCreative'>TemplateCreative</a>.</p>
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ListStringCreativeTemplateVariable))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class StringCreativeTemplateVariable : CreativeTemplateVariable {
		private string defaultValueField;

		/// <summary>Default value to be filled in when creating creatives from the creative
		/// template.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string defaultValue {
			get {
				return this.defaultValueField;
			}
			set {
				this.defaultValueField = value;
			}
		}
	}


	/// <summary>Represents a list variable defined in a creative template. This is similar to <a
	/// href='StringCreativeTemplateVariable'>StringCreativeTemplateVariable</a>, except
	/// that there are possible choices to choose from. <p>Use <a
	/// href='StringCreativeTemplateVariableValue'>StringCreativeTemplateVariableValue</a>
	/// to specify the value for this variable when creating a <a
	/// href='TemplateCreative'>TemplateCreative</a> from a <a
	/// href='CreativeTemplate'>CreativeTemplate</a>.</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ListStringCreativeTemplateVariable : StringCreativeTemplateVariable {
		private ListStringCreativeTemplateVariableVariableChoice[] choicesField;

		private bool allowOtherChoiceField;

		private bool allowOtherChoiceFieldSpecified;

		/// <summary>The values within the list users need to select from.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("choices", Order = 0)]
		public ListStringCreativeTemplateVariableVariableChoice[] choices {
			get {
				return this.choicesField;
			}
			set {
				this.choicesField = value;
			}
		}

		/// <summary><code>true</code> if a user can specifiy an 'other' value. For example, if a
		/// variable called backgroundColor is defined as a list with values: red, green,
		/// blue, this boolean can be set to allow a user to enter a value not on the list
		/// such as purple.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public bool allowOtherChoice {
			get {
				return this.allowOtherChoiceField;
			}
			set {
				this.allowOtherChoiceField = value;
				this.allowOtherChoiceSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowOtherChoice" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowOtherChoiceSpecified {
			get {
				return this.allowOtherChoiceFieldSpecified;
			}
			set {
				this.allowOtherChoiceFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents a long variable defined in a creative template.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LongCreativeTemplateVariable : CreativeTemplateVariable {
		private long defaultValueField;

		private bool defaultValueFieldSpecified;

		/// <summary>Default value to be filled in when creating creatives from the creative
		/// template.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long defaultValue {
			get {
				return this.defaultValueField;
			}
			set {
				this.defaultValueField = value;
				this.defaultValueSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="defaultValue" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool defaultValueSpecified {
			get {
				return this.defaultValueFieldSpecified;
			}
			set {
				this.defaultValueFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents a file asset variable defined in a creative template. <p>Use <a
	/// href='AssetCreativeTemplateVariableValue'>AssetCreativeTemplateVariableValue</a>
	/// to specify the value for this variable when creating <a
	/// href='TemplateCreative'>TemplateCreative</a> from the <a
	/// href='TemplateCreative'>TemplateCreative</a>.</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AssetCreativeTemplateVariable : CreativeTemplateVariable {
		private AssetCreativeTemplateVariableMimeType[] mimeTypesField;

		/// <summary>A set of supported mime types. This set can be empty or null if there's no
		/// constraint, meaning files of any mime types are allowed.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("mimeTypes", Order = 0)]
		public AssetCreativeTemplateVariableMimeType[] mimeTypes {
			get {
				return this.mimeTypesField;
			}
			set {
				this.mimeTypesField = value;
			}
		}
	}


	/// <summary>Different mime type that the asset variable supports.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AssetCreativeTemplateVariable.MimeType", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AssetCreativeTemplateVariableMimeType {
		JPG = 0,
		PNG = 1,
		GIF = 2,
		SWF = 3,
	}


	/// <summary>A template upon which a creative can be created.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreativeTemplate {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private string descriptionField;

		private CreativeTemplateVariable[] variablesField;

		private string snippetField;

		private CreativeTemplateStatus statusField;

		private bool statusFieldSpecified;

		private CreativeTemplateType typeField;

		private bool typeFieldSpecified;

		private bool isInterstitialField;

		private bool isInterstitialFieldSpecified;

		private bool isNativeEligibleField;

		private bool isNativeEligibleFieldSpecified;

		private bool isSafeFrameCompatibleField;

		private bool isSafeFrameCompatibleFieldSpecified;

		/// <summary>Uniquely identifies the <code>CreativeTemplate</code>. This attribute is
		/// read-only and is assigned by Google when a creative template is created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the creative template. This attribute is required and has a maximum
		/// length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The description of the creative template. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string description {
			get {
				return this.descriptionField;
			}
			set {
				this.descriptionField = value;
			}
		}

		/// <summary>The list of creative template variables. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("variables", Order = 3)]
		public CreativeTemplateVariable[] variables {
			get {
				return this.variablesField;
			}
			set {
				this.variablesField = value;
			}
		}

		/// <summary>The snippet of the creative template, with placeholders for the associated
		/// variables. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string snippet {
			get {
				return this.snippetField;
			}
			set {
				this.snippetField = value;
			}
		}

		/// <summary>The status of the <code>CreativeTemplate</code>. This attribute is read-only and
		/// is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public CreativeTemplateStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>The type of the <code>CreativeTemplate</code>. Publisher can only create
		/// user-defined template
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public CreativeTemplateType type {
			get {
				return this.typeField;
			}
			set {
				this.typeField = value;
				this.typeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="type" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool typeSpecified {
			get {
				return this.typeFieldSpecified;
			}
			set {
				this.typeFieldSpecified = value;
			}
		}

		/// <summary><code>true</code> if this creative template produces interstitial creatives.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public bool isInterstitial {
			get {
				return this.isInterstitialField;
			}
			set {
				this.isInterstitialField = value;
				this.isInterstitialSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isInterstitial" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isInterstitialSpecified {
			get {
				return this.isInterstitialFieldSpecified;
			}
			set {
				this.isInterstitialFieldSpecified = value;
			}
		}

		/// <summary><code>true</code> if this creative template produces native-eligible creatives.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public bool isNativeEligible {
			get {
				return this.isNativeEligibleField;
			}
			set {
				this.isNativeEligibleField = value;
				this.isNativeEligibleSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isNativeEligible" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isNativeEligibleSpecified {
			get {
				return this.isNativeEligibleFieldSpecified;
			}
			set {
				this.isNativeEligibleFieldSpecified = value;
			}
		}

		/// <summary>Whether the <a href='Creative'>Creative</a> produced is compatible for SafeFrame
		/// rendering. <p>This attribute is optional and defaults to <code>true</code>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public bool isSafeFrameCompatible {
			get {
				return this.isSafeFrameCompatibleField;
			}
			set {
				this.isSafeFrameCompatibleField = value;
				this.isSafeFrameCompatibleSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isSafeFrameCompatible" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isSafeFrameCompatibleSpecified {
			get {
				return this.isSafeFrameCompatibleFieldSpecified;
			}
			set {
				this.isSafeFrameCompatibleFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes status of the creative template
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CreativeTemplateStatus {
		/// <summary>The <a href='CreativeTemplate'>CreativeTemplate</a> is active
		/// </summary>
		ACTIVE = 0,
		/// <summary>The <a href='CreativeTemplate'>CreativeTemplate</a> is inactive. Users cannot
		/// create new creatives from this template, but existing ones can be edited and
		/// continue to serve
		/// </summary>
		INACTIVE = 1,
		/// <summary>The <a href='CreativeTemplate'>CreativeTemplate</a> is deleted. Creatives
		/// created from this <a href='CreativeTemplate'>CreativeTemplate</a> can no longer
		/// serve.
		/// </summary>
		DELETED = 2,
	}


	/// <summary>Describes type of the creative template.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CreativeTemplateType {
		/// <summary>Creative templates that Google defines for users to use.
		/// </summary>
		SYSTEM_DEFINED = 0,
		/// <summary>Arbitrary creative templates that users can define as they see fit. Such
		/// templates are bound to a specific network and can only be used with creatives
		/// being created under the network.
		/// </summary>
		USER_DEFINED = 1,
	}


	/// <summary>Captures a page of <a href='CreativeTemplate'>CreativeTemplate</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreativeTemplatePage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private CreativeTemplate[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of creative templates contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public CreativeTemplate[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.CreativeTemplateServiceInterface")]
	public interface CreativeTemplateServiceInterface
	{
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.CreativeTemplatePage getCreativeTemplatesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeTemplatePage> getCreativeTemplatesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface CreativeTemplateServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.CreativeTemplateServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for retrieving <a href='CreativeTemplate'>CreativeTemplate</a>
	/// objects.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class CreativeTemplateService : AdManagerSoapClient<ICreativeTemplateService>, ICreativeTemplateService {
		/// <summary> Creates a new instance of the <see cref="CreativeTemplateService"/>
		/// class. </summary>
		public CreativeTemplateService() {
		}

		/// <summary> Creates a new instance of the <see cref="CreativeTemplateService"/>
		/// class. </summary>
		public CreativeTemplateService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="CreativeTemplateService"/>
		/// class. </summary>
		public CreativeTemplateService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="CreativeTemplateService"/>
		/// class. </summary>
		public CreativeTemplateService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="CreativeTemplateService"/>
		/// class. </summary>
		public CreativeTemplateService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		/// <summary>Gets a <a href='CreativeTemplatePage'>CreativeTemplatePage</a> of <a
		/// href='CreativeTemplate'>CreativeTemplate</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='CreativeTemplate#id'>CreativeTemplate#id</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a
		/// href='CreativeTemplate#name'>CreativeTemplate#name</a></td> </tr> <tr>
		/// <td><code>type</code></td> <td><a
		/// href='CreativeTemplate#type'>CreativeTemplate#type</a></td> </tr> <tr>
		/// <td><code>status</code></td> <td><a
		/// href='CreativeTemplate#status'>CreativeTemplate#status</a></td> </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of creative templates.</param>
		/// <returns>the creative templates that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CreativeTemplatePage getCreativeTemplatesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getCreativeTemplatesByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeTemplatePage> getCreativeTemplatesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getCreativeTemplatesByStatementAsync(filterStatement);
		}
	}
	namespace Wrappers.CreativeWrapperService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createCreativeWrappers", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createCreativeWrappersRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("creativeWrappers")]
			public Google.Api.Ads.AdManager.v201802.CreativeWrapper[] creativeWrappers;

			/// <summary> Creates a new instance of the <see
			/// cref="createCreativeWrappersRequest"/> class. </summary>
			public createCreativeWrappersRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createCreativeWrappersRequest"/> class. </summary>
			public createCreativeWrappersRequest(Google.Api.Ads.AdManager.v201802.CreativeWrapper[] creativeWrappers) {
				this.creativeWrappers = creativeWrappers;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createCreativeWrappersResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createCreativeWrappersResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.CreativeWrapper[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createCreativeWrappersResponse"/> class. </summary>
			public createCreativeWrappersResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createCreativeWrappersResponse"/> class. </summary>
			public createCreativeWrappersResponse(Google.Api.Ads.AdManager.v201802.CreativeWrapper[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateCreativeWrappers", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateCreativeWrappersRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("creativeWrappers")]
			public Google.Api.Ads.AdManager.v201802.CreativeWrapper[] creativeWrappers;

			/// <summary> Creates a new instance of the <see
			/// cref="updateCreativeWrappersRequest"/> class. </summary>
			public updateCreativeWrappersRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateCreativeWrappersRequest"/> class. </summary>
			public updateCreativeWrappersRequest(Google.Api.Ads.AdManager.v201802.CreativeWrapper[] creativeWrappers) {
				this.creativeWrappers = creativeWrappers;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateCreativeWrappersResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateCreativeWrappersResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.CreativeWrapper[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateCreativeWrappersResponse"/> class. </summary>
			public updateCreativeWrappersResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateCreativeWrappersResponse"/> class. </summary>
			public updateCreativeWrappersResponse(Google.Api.Ads.AdManager.v201802.CreativeWrapper[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>A <code>CreativeWrapper</code> allows the wrapping of HTML snippets to be served
	/// along with <code>Creative</code> objects. <p>Creative wrappers must be
	/// associated with a <a
	/// href='LabelType#CREATIVE_WRAPPER'>LabelType#CREATIVE_WRAPPER</a> label and
	/// applied to ad units by <a
	/// href='AdUnit#appliedLabels'>AdUnit#appliedLabels</a>.</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreativeWrapper {
		private long idField;

		private bool idFieldSpecified;

		private long labelIdField;

		private bool labelIdFieldSpecified;

		private string htmlHeaderField;

		private string htmlFooterField;

		private string ampHeadField;

		private string ampBodyField;

		private CreativeWrapperOrdering orderingField;

		private bool orderingFieldSpecified;

		private CreativeWrapperStatus statusField;

		private bool statusFieldSpecified;

		/// <summary>The unique ID of the <code>CreativeWrapper</code>. This value is readonly and is
		/// assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The ID of the <a href='Label'>Label</a> which will be used to label ad units.
		/// The <code>labelId</code> on a creative wrapper cannot be changed once it is
		/// created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long labelId {
			get {
				return this.labelIdField;
			}
			set {
				this.labelIdField = value;
				this.labelIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="labelId" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool labelIdSpecified {
			get {
				return this.labelIdFieldSpecified;
			}
			set {
				this.labelIdFieldSpecified = value;
			}
		}

		/// <summary>The header HTML snippet that this creative wrapper delivers.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string htmlHeader {
			get {
				return this.htmlHeaderField;
			}
			set {
				this.htmlHeaderField = value;
			}
		}

		/// <summary>The footer HTML snippet that this creative wrapper delivers.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string htmlFooter {
			get {
				return this.htmlFooterField;
			}
			set {
				this.htmlFooterField = value;
			}
		}

		/// <summary>The header AMP snippet that this creative wrapper delivers.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string ampHead {
			get {
				return this.ampHeadField;
			}
			set {
				this.ampHeadField = value;
			}
		}

		/// <summary>The footer AMP snippet that this creative wrapper delivers.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public string ampBody {
			get {
				return this.ampBodyField;
			}
			set {
				this.ampBodyField = value;
			}
		}

		/// <summary>If there are multiple wrappers for a creative, then <code></code> defines the
		/// order in which the HTML snippets are rendered.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public CreativeWrapperOrdering ordering {
			get {
				return this.orderingField;
			}
			set {
				this.orderingField = value;
				this.orderingSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="ordering"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool orderingSpecified {
			get {
				return this.orderingFieldSpecified;
			}
			set {
				this.orderingFieldSpecified = value;
			}
		}

		/// <summary>The status of the <code>CreativeWrapper</code>. This attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public CreativeWrapperStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}
	}


	/// <summary>Defines the order in which the header and footer HTML snippets will be wrapped
	/// around the served creative. <code>INNER</code> snippets will be wrapped first,
	/// followed by <code>NO_PREFERENCE</code> and finally <code>OUTER</code>. If the
	/// creative needs to be wrapped with more than one snippet with the same <a
	/// href='CreativeWrapperOrdering'>CreativeWrapperOrdering</a>, then the order is
	/// unspecified.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CreativeWrapperOrdering {
		/// <summary>Wrapping occurs after <a href='#INNER'>#INNER</a> but before <a
		/// href='#OUTER'>#OUTER</a>
		/// </summary>
		NO_PREFERENCE = 0,
		/// <summary>Wrapping occurs as early as possible.
		/// </summary>
		INNER = 1,
		/// <summary>Wrapping occurs after both <a href='#NO_PREFERENCE'>#NO_PREFERENCE</a> and <a
		/// href='#INNER'>#INNER</a>
		/// </summary>
		OUTER = 2,
	}


	/// <summary>Indicates whether the <code>CreativeWrapper</code> is active. HTML snippets are
	/// served to creatives only when the creative wrapper is active.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CreativeWrapperStatus {
		ACTIVE = 0,
		INACTIVE = 1,
	}


	/// <summary>Errors specific to labels.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LabelError : ApiError {
		private LabelErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public LabelErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "LabelError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LabelErrorReason {
		/// <summary>A user created label cannot begin with the Google internal system label prefix.
		/// </summary>
		INVALID_PREFIX = 0,
		/// <summary><a href='Label#name'>Label#name</a> contains unsupported or reserved characters.
		/// </summary>
		NAME_INVALID_CHARS = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Errors specific to creative wrappers.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreativeWrapperError : ApiError {
		private CreativeWrapperErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CreativeWrapperErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the creative wrapper error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CreativeWrapperError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CreativeWrapperErrorReason {
		/// <summary>The label is already associated with a <a
		/// href='CreativeWrapper'>CreativeWrapper</a>.
		/// </summary>
		LABEL_ALREADY_ASSOCIATED_WITH_CREATIVE_WRAPPER = 0,
		/// <summary>The label type of a creative wrapper must be <a
		/// href='LabelType#CREATIVE_WRAPPER'>LabelType#CREATIVE_WRAPPER</a>.
		/// </summary>
		INVALID_LABEL_TYPE = 1,
		/// <summary>A macro used inside the snippet is not recognized.
		/// </summary>
		UNRECOGNIZED_MACRO = 2,
		/// <summary>When creating a new creative wrapper, either header or footer should exist.
		/// </summary>
		NEITHER_HEADER_NOR_FOOTER_SPECIFIED = 3,
		/// <summary>The network has not been enabled for creating labels of type <a
		/// href='LabelType#CREATIVE_WRAPPER'>LabelType#CREATIVE_WRAPPER</a>.
		/// </summary>
		CANNOT_USE_CREATIVE_WRAPPER_TYPE = 4,
		/// <summary>Cannot update <a href='CreativeWrapper#labelId'>CreativeWrapper#labelId</a>.
		/// </summary>
		CANNOT_UPDATE_LABEL_ID = 5,
		/// <summary>Cannot apply <a href='LabelType#CREATIVE_WRAPPER'>LabelType#CREATIVE_WRAPPER</a>
		/// labels to an ad unit if it has no descendants with <a
		/// href='AdUnit#adUnitSizes'>AdUnit#adUnitSizes</a> of <code></code> as <a
		/// href='EnvironmentType#BROWSER'>EnvironmentType#BROWSER</a>.
		/// </summary>
		CANNOT_APPLY_TO_AD_UNIT_WITH_VIDEO_SIZES = 6,
		/// <summary>Cannot apply <a href='LabelType#CREATIVE_WRAPPER'>LabelType#CREATIVE_WRAPPER</a>
		/// labels to an ad unit if <a
		/// href='AdUnit#targetPlatform'>AdUnit#targetPlatform</a> is of type <code></code>
		/// </summary>
		CANNOT_APPLY_TO_MOBILE_AD_UNIT = 7,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 8,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.CreativeWrapperServiceInterface")]
	public interface CreativeWrapperServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.CreativeWrapperService.createCreativeWrappersResponse createCreativeWrappers(Wrappers.CreativeWrapperService.createCreativeWrappersRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.CreativeWrapperService.createCreativeWrappersResponse> createCreativeWrappersAsync(Wrappers.CreativeWrapperService.createCreativeWrappersRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.CreativeWrapperPage getCreativeWrappersByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeWrapperPage> getCreativeWrappersByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performCreativeWrapperAction(Google.Api.Ads.AdManager.v201802.CreativeWrapperAction creativeWrapperAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performCreativeWrapperActionAsync(Google.Api.Ads.AdManager.v201802.CreativeWrapperAction creativeWrapperAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.CreativeWrapperService.updateCreativeWrappersResponse updateCreativeWrappers(Wrappers.CreativeWrapperService.updateCreativeWrappersRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.CreativeWrapperService.updateCreativeWrappersResponse> updateCreativeWrappersAsync(Wrappers.CreativeWrapperService.updateCreativeWrappersRequest request);
	}


	/// <summary>Captures a page of <a href='CreativeWrapper'>CreativeWrapper</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreativeWrapperPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private CreativeWrapper[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of creative wrappers contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public CreativeWrapper[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a
	/// href='CreativeWrapper'>CreativeWrapper</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeactivateCreativeWrappers))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateCreativeWrappers))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class CreativeWrapperAction {
	}


	/// <summary>The action used for deactivating <a href='CreativeWrapper'>CreativeWrapper</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeactivateCreativeWrappers : CreativeWrapperAction {
	}


	/// <summary>The action used for activating <a href='CreativeWrapper'>CreativeWrapper</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateCreativeWrappers : CreativeWrapperAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface CreativeWrapperServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.CreativeWrapperServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for the creation and management of creative wrappers. <a
	/// href='CreativeWrapper'>CreativeWrappers</a> allow HTML snippets to be served
	/// along with creatives. <p>Creative wrappers must be associated with a <a
	/// href='LabelType#CREATIVE_WRAPPER'>LabelType#CREATIVE_WRAPPER</a> label and
	/// applied to ad units by <a
	/// href='AdUnit#appliedLabels'>AdUnit#appliedLabels</a>.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class CreativeWrapperService : AdManagerSoapClient<ICreativeWrapperService>, ICreativeWrapperService {
		/// <summary> Creates a new instance of the <see cref="CreativeWrapperService"/>
		/// class. </summary>
		public CreativeWrapperService() {
		}

		/// <summary> Creates a new instance of the <see cref="CreativeWrapperService"/>
		/// class. </summary>
		public CreativeWrapperService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="CreativeWrapperService"/>
		/// class. </summary>
		public CreativeWrapperService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="CreativeWrapperService"/>
		/// class. </summary>
		public CreativeWrapperService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="CreativeWrapperService"/>
		/// class. </summary>
		public CreativeWrapperService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.CreativeWrapperService.createCreativeWrappersResponse Google.Api.Ads.AdManager.v201802.CreativeWrapperServiceInterface.createCreativeWrappers(Wrappers.CreativeWrapperService.createCreativeWrappersRequest request) {
			return base.Channel.createCreativeWrappers(request);
		}

		/// <summary>Creates a new <code>CreativeWrapper</code> objects. The following fields are
		/// required: <ul> <li><a
		/// href='CreativeWrapper#labelId'>CreativeWrapper#labelId</a></li> <li><a
		/// href='CreativeWrapper#ordering'>CreativeWrapper#ordering</a></li> <li><a
		/// href='CreativeWrapper#header'>CreativeWrapper#header</a> or <a
		/// href='CreativeWrapper#footer'>CreativeWrapper#footer</a></li> </ul>
		/// </summary><param name='creativeWrappers'>the creative wrappers to create</param>
		/// <returns>the creative wrappers with their IDs filled in</returns>
		/// ApiException
		public virtual Google.Api.Ads.AdManager.v201802.CreativeWrapper[] createCreativeWrappers(Google.Api.Ads.AdManager.v201802.CreativeWrapper[] creativeWrappers) {
			Wrappers.CreativeWrapperService.createCreativeWrappersRequest inValue = new Wrappers.CreativeWrapperService.createCreativeWrappersRequest();
			inValue.creativeWrappers = creativeWrappers;
			Wrappers.CreativeWrapperService.createCreativeWrappersResponse retVal = ((Google.Api.Ads.AdManager.v201802.CreativeWrapperServiceInterface)(this)).createCreativeWrappers(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.CreativeWrapperService.createCreativeWrappersResponse> Google.Api.Ads.AdManager.v201802.CreativeWrapperServiceInterface.createCreativeWrappersAsync(Wrappers.CreativeWrapperService.createCreativeWrappersRequest request) {
			return base.Channel.createCreativeWrappersAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeWrapper[]> createCreativeWrappersAsync(Google.Api.Ads.AdManager.v201802.CreativeWrapper[] creativeWrappers) {
			Wrappers.CreativeWrapperService.createCreativeWrappersRequest inValue = new Wrappers.CreativeWrapperService.createCreativeWrappersRequest();
			inValue.creativeWrappers = creativeWrappers;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeWrapper[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.CreativeWrapperServiceInterface)(this)).createCreativeWrappersAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='CreativeWrapperPage'>CreativeWrapperPage</a> of <a
		/// href='CreativeWrapper'>CreativeWrapper</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='CreativeWrapper#id'>CreativeWrapper#id</a></td> </tr> <tr>
		/// <td><code>labelId</code></td> <td><a
		/// href='CreativeWrapper#labelId'>CreativeWrapper#labelId</a></td> </tr> <tr>
		/// <td><code>status</code></td> <td><a
		/// href='CreativeWrapper#status'>CreativeWrapper#status</a></td> </tr> <tr>
		/// <td><code>ordering</code></td> <td><a
		/// href='CreativeWrapper#ordering'>CreativeWrapper#ordering</a></td> </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of creative wrappers.</param>
		/// <returns>the creative wrappers that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CreativeWrapperPage getCreativeWrappersByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getCreativeWrappersByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeWrapperPage> getCreativeWrappersByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getCreativeWrappersByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='CreativeWrapper'>CreativeWrapper</a> objects that
		/// match the given <a href='Statement#query'>Statement#query</a>.
		/// </summary><param name='creativeWrapperAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of labels</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performCreativeWrapperAction(Google.Api.Ads.AdManager.v201802.CreativeWrapperAction creativeWrapperAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performCreativeWrapperAction(creativeWrapperAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performCreativeWrapperActionAsync(Google.Api.Ads.AdManager.v201802.CreativeWrapperAction creativeWrapperAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performCreativeWrapperActionAsync(creativeWrapperAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.CreativeWrapperService.updateCreativeWrappersResponse Google.Api.Ads.AdManager.v201802.CreativeWrapperServiceInterface.updateCreativeWrappers(Wrappers.CreativeWrapperService.updateCreativeWrappersRequest request) {
			return base.Channel.updateCreativeWrappers(request);
		}

		/// <summary>Updates the specified <code>CreativeWrapper</code> objects.
		/// </summary><param name='creativeWrappers'>the creative wrappers to update</param>
		/// <returns>the updated creative wrapper objects</returns>
		/// ApiException
		public virtual Google.Api.Ads.AdManager.v201802.CreativeWrapper[] updateCreativeWrappers(Google.Api.Ads.AdManager.v201802.CreativeWrapper[] creativeWrappers) {
			Wrappers.CreativeWrapperService.updateCreativeWrappersRequest inValue = new Wrappers.CreativeWrapperService.updateCreativeWrappersRequest();
			inValue.creativeWrappers = creativeWrappers;
			Wrappers.CreativeWrapperService.updateCreativeWrappersResponse retVal = ((Google.Api.Ads.AdManager.v201802.CreativeWrapperServiceInterface)(this)).updateCreativeWrappers(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.CreativeWrapperService.updateCreativeWrappersResponse> Google.Api.Ads.AdManager.v201802.CreativeWrapperServiceInterface.updateCreativeWrappersAsync(Wrappers.CreativeWrapperService.updateCreativeWrappersRequest request) {
			return base.Channel.updateCreativeWrappersAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeWrapper[]> updateCreativeWrappersAsync(Google.Api.Ads.AdManager.v201802.CreativeWrapper[] creativeWrappers) {
			Wrappers.CreativeWrapperService.updateCreativeWrappersRequest inValue = new Wrappers.CreativeWrapperService.updateCreativeWrappersRequest();
			inValue.creativeWrappers = creativeWrappers;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeWrapper[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.CreativeWrapperServiceInterface)(this)).updateCreativeWrappersAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.CustomTargetingService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createCustomTargetingKeys", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createCustomTargetingKeysRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("keys")]
			public Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] keys;

			/// <summary> Creates a new instance of the <see
			/// cref="createCustomTargetingKeysRequest"/> class. </summary>
			public createCustomTargetingKeysRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createCustomTargetingKeysRequest"/> class. </summary>
			public createCustomTargetingKeysRequest(Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] keys) {
				this.keys = keys;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createCustomTargetingKeysResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createCustomTargetingKeysResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createCustomTargetingKeysResponse"/> class. </summary>
			public createCustomTargetingKeysResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createCustomTargetingKeysResponse"/> class. </summary>
			public createCustomTargetingKeysResponse(Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createCustomTargetingValues", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createCustomTargetingValuesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("values")]
			public Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] values;

			/// <summary> Creates a new instance of the <see
			/// cref="createCustomTargetingValuesRequest"/> class. </summary>
			public createCustomTargetingValuesRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createCustomTargetingValuesRequest"/> class. </summary>
			public createCustomTargetingValuesRequest(Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] values) {
				this.values = values;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createCustomTargetingValuesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createCustomTargetingValuesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createCustomTargetingValuesResponse"/> class. </summary>
			public createCustomTargetingValuesResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createCustomTargetingValuesResponse"/> class. </summary>
			public createCustomTargetingValuesResponse(Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateCustomTargetingKeys", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateCustomTargetingKeysRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("keys")]
			public Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] keys;

			/// <summary> Creates a new instance of the <see
			/// cref="updateCustomTargetingKeysRequest"/> class. </summary>
			public updateCustomTargetingKeysRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateCustomTargetingKeysRequest"/> class. </summary>
			public updateCustomTargetingKeysRequest(Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] keys) {
				this.keys = keys;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateCustomTargetingKeysResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateCustomTargetingKeysResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateCustomTargetingKeysResponse"/> class. </summary>
			public updateCustomTargetingKeysResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateCustomTargetingKeysResponse"/> class. </summary>
			public updateCustomTargetingKeysResponse(Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateCustomTargetingValues", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateCustomTargetingValuesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("values")]
			public Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] values;

			/// <summary> Creates a new instance of the <see
			/// cref="updateCustomTargetingValuesRequest"/> class. </summary>
			public updateCustomTargetingValuesRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateCustomTargetingValuesRequest"/> class. </summary>
			public updateCustomTargetingValuesRequest(Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] values) {
				this.values = values;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateCustomTargetingValuesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateCustomTargetingValuesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateCustomTargetingValuesResponse"/> class. </summary>
			public updateCustomTargetingValuesResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateCustomTargetingValuesResponse"/> class. </summary>
			public updateCustomTargetingValuesResponse(Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary><code>CustomTargetingKey</code> represents a key used for custom targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomTargetingKey {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private string displayNameField;

		private CustomTargetingKeyType typeField;

		private bool typeFieldSpecified;

		private CustomTargetingKeyStatus statusField;

		private bool statusFieldSpecified;

		/// <summary>The ID of the <code>CustomTargetingKey</code>. This value is readonly and is
		/// populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>Name of the key. This can be used for encoding . If you don't want users to be
		/// able to see potentially sensitive targeting information in the ad tags of your
		/// site, you can encode your key/values. For example, you can create key/value
		/// g1=abc to represent gender=female. Keys can contain up to 10 characters each.
		/// You can use alphanumeric characters and symbols other than the following: ", ',
		/// =, !, +, #, *, ~, ;, ^, (, ), &lt;, &gt;, [, ], the white space character.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>Descriptive name for the key.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string displayName {
			get {
				return this.displayNameField;
			}
			set {
				this.displayNameField = value;
			}
		}

		/// <summary>Indicates whether users will select from predefined values or create new
		/// targeting values, while specifying targeting criteria for a line item.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public CustomTargetingKeyType type {
			get {
				return this.typeField;
			}
			set {
				this.typeField = value;
				this.typeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="type" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool typeSpecified {
			get {
				return this.typeFieldSpecified;
			}
			set {
				this.typeFieldSpecified = value;
			}
		}

		/// <summary>Status of the <code>CustomTargetingKey</code>. This field is read-only. A key
		/// can be activated and deactivated by calling <a
		/// href='CustomTargetingService#performCustomTargetingKeyAction'>CustomTargetingService#performCustomTargetingKeyAction</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public CustomTargetingKeyStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}
	}


	/// <summary>Specifies the types for <code>CustomTargetingKey</code> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CustomTargetingKey.Type", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CustomTargetingKeyType {
		/// <summary>Target audiences by criteria values that are defined in advance.
		/// </summary>
		PREDEFINED = 0,
		/// <summary>Target audiences by adding criteria values when creating line items.
		/// </summary>
		FREEFORM = 1,
	}


	/// <summary>Describes the statuses for <code>CustomTargetingKey</code> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CustomTargetingKey.Status", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CustomTargetingKeyStatus {
		/// <summary>The object is active.
		/// </summary>
		ACTIVE = 0,
		/// <summary>The object is no longer active.
		/// </summary>
		INACTIVE = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Lists errors relating to having too many children on an entity.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class EntityChildrenLimitReachedError : ApiError {
		private EntityChildrenLimitReachedErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public EntityChildrenLimitReachedErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the entity children limit reached error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "EntityChildrenLimitReachedError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum EntityChildrenLimitReachedErrorReason {
		/// <summary>The number of line items on the order exceeds the max number of line items
		/// allowed per order in the network.
		/// </summary>
		LINE_ITEM_LIMIT_FOR_ORDER_REACHED = 0,
		/// <summary>The number of creatives associated with the line item exceeds the max number of
		/// creatives allowed to be associated with a line item in the network.
		/// </summary>
		CREATIVE_ASSOCIATION_LIMIT_FOR_LINE_ITEM_REACHED = 1,
		/// <summary>The number of ad units on the placement exceeds the max number of ad units
		/// allowed per placement in the network.
		/// </summary>
		AD_UNIT_LIMIT_FOR_PLACEMENT_REACHED = 2,
		/// <summary>The number of targeting expressions on the line item exceeds the max number of
		/// targeting expressions allowed per line item in the network.
		/// </summary>
		TARGETING_EXPRESSION_LIMIT_FOR_LINE_ITEM_REACHED = 3,
		/// <summary>The number of custom targeting values for the free-form or predefined custom
		/// targeting key exceeds the max number allowed.
		/// </summary>
		CUSTOM_TARGETING_VALUES_FOR_KEY_LIMIT_REACHED = 13,
		/// <summary>The total number of targeting expressions on the creatives for the line item
		/// exceeds the max number allowed per line item in the network.
		/// </summary>
		TARGETING_EXPRESSION_LIMIT_FOR_CREATIVES_ON_LINE_ITEM_REACHED = 14,
		/// <summary>The number of attachments added to the proposal exceeds the max number allowed
		/// per proposal in the network.
		/// </summary>
		ATTACHMENT_LIMIT_FOR_PROPOSAL_REACHED = 5,
		/// <summary>The number of proposal line items on the proposal exceeds the max number allowed
		/// per proposal in the network.
		/// </summary>
		PROPOSAL_LINE_ITEM_LIMIT_FOR_PROPOSAL_REACHED = 6,
		/// <summary>The number of product package items on the product package exceeds the max
		/// number allowed per product package in the network.
		/// </summary>
		PRODUCT_LIMIT_FOR_PRODUCT_PACKAGE_REACHED = 7,
		/// <summary>The number of product template and product base rates on the rate card
		/// (including excluded product base rates) exceeds the max number allowed per rate
		/// card in the network.
		/// </summary>
		PRODUCT_TEMPLATE_AND_PRODUCT_BASE_RATE_LIMIT_FOR_RATE_CARD_REACHED = 8,
		/// <summary>The number of product package item base rates on the rate card exceeds the max
		/// number allowed per rate card in the network.
		/// </summary>
		PRODUCT_PACKAGE_ITEM_BASE_RATE_LIMIT_FOR_RATE_CARD_REACHED = 9,
		/// <summary>The number of premiums of the rate card exceeds the max number allowed per rate
		/// card in the network.
		/// </summary>
		PREMIUM_LIMIT_FOR_RATE_CARD_REACHED = 10,
		/// <summary>The number of ad units on <a
		/// href='AdExclusionRule#inventoryTargeting'>AdExclusionRule#inventoryTargeting</a>
		/// exceeds the max number of ad units allowed per ad exclusion rule inventory
		/// targeting in the network.
		/// </summary>
		AD_UNIT_LIMIT_FOR_AD_EXCLUSION_RULE_TARGETING_REACHED = 11,
		/// <summary>The number of native styles under the native creative template exceeds the max
		/// number of native styles allowed per native creative template in the network.
		/// </summary>
		NATIVE_STYLE_LIMIT_FOR_NATIVE_AD_FORMAT_REACHED = 15,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 12,
	}


	/// <summary>Lists all errors related to <a href='CustomTargetingKey'>CustomTargetingKey</a>
	/// and <a href='CustomTargetingValue'>CustomTargetingValue</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomTargetingError : ApiError {
		private CustomTargetingErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CustomTargetingErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CustomTargetingError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CustomTargetingErrorReason {
		/// <summary>Requested <a href='CustomTargetingKey'>CustomTargetingKey</a> is not found.
		/// </summary>
		KEY_NOT_FOUND = 0,
		/// <summary>Number of <a href='CustomTargetingKey'>CustomTargetingKey</a> objects created
		/// exceeds the limit allowed for the network.
		/// </summary>
		KEY_COUNT_TOO_LARGE = 1,
		/// <summary><a href='CustomTargetingKey'>CustomTargetingKey</a> with the same <a
		/// href='CustomTargetingKey#name'>CustomTargetingKey#name</a> already exists.
		/// </summary>
		KEY_NAME_DUPLICATE = 2,
		/// <summary><a href='CustomTargetingKey#name'>CustomTargetingKey#name</a> is empty.
		/// </summary>
		KEY_NAME_EMPTY = 3,
		/// <summary><a href='CustomTargetingKey#name'>CustomTargetingKey#name</a> is too long.
		/// </summary>
		KEY_NAME_INVALID_LENGTH = 4,
		/// <summary><a href='CustomTargetingKey#name'>CustomTargetingKey#name</a> contains
		/// unsupported or reserved characters.
		/// </summary>
		KEY_NAME_INVALID_CHARS = 5,
		/// <summary><a href='CustomTargetingKey#name'>CustomTargetingKey#name</a> matches one of the
		/// reserved custom targeting key names.
		/// </summary>
		KEY_NAME_RESERVED = 6,
		/// <summary><a href='CustomTargetingKey#displayName'>CustomTargetingKey#displayName</a> is
		/// too long.
		/// </summary>
		KEY_DISPLAY_NAME_INVALID_LENGTH = 7,
		/// <summary>Requested <a href='CustomTargetingValue'>CustomTargetingValue</a> is not found.
		/// </summary>
		VALUE_NOT_FOUND = 8,
		/// <summary>The <code>WHERE</code> clause in the <a
		/// href='Statement#query'>Statement#query</a> must always contain <a
		/// href='CustomTargetingValue#customTargetingKeyId'>CustomTargetingValue#customTargetingKeyId</a>
		/// as one of its columns in a way that it is AND'ed with the rest of the query.
		/// </summary>
		GET_VALUES_BY_STATEMENT_MUST_CONTAIN_KEY_ID = 9,
		/// <summary>The number of <a href='CustomTargetingValue'>CustomTargetingValue</a> objects
		/// associated with a <a href='CustomTargetingKey'>CustomTargetingKey</a> exceeds
		/// the network limit. This is only applicable for keys of type <code></code>.
		/// </summary>
		VALUE_COUNT_FOR_KEY_TOO_LARGE = 10,
		/// <summary><a href='CustomTargetingValue'>CustomTargetingValue</a> with the same <a
		/// href='CustomTargetingValue#name'>CustomTargetingValue#name</a> already exists.
		/// </summary>
		VALUE_NAME_DUPLICATE = 11,
		/// <summary><a href='CustomTargetingValue#name'>CustomTargetingValue#name</a> is empty.
		/// </summary>
		VALUE_NAME_EMPTY = 12,
		/// <summary><a href='CustomTargetingValue#name'>CustomTargetingValue#name</a> is too long.
		/// </summary>
		VALUE_NAME_INVALID_LENGTH = 13,
		/// <summary><a href='CustomTargetingValue#name'>CustomTargetingValue#name</a> contains
		/// unsupported or reserved characters.
		/// </summary>
		VALUE_NAME_INVALID_CHARS = 14,
		/// <summary><a href='CustomTargetingValue#displayName'>CustomTargetingValue#displayName</a>
		/// is too long.
		/// </summary>
		VALUE_DISPLAY_NAME_INVALID_LENGTH = 15,
		/// <summary>Only Ad Manager 360 networks can have <a
		/// href='CustomTargetingValue#matchType'>CustomTargetingValue#matchType</a> other
		/// than <a
		/// href='CustomTargetingValue.MatchType#EXACT'>CustomTargetingValue.MatchType#EXACT</a>.
		/// </summary>
		VALUE_MATCH_TYPE_NOT_ALLOWED = 16,
		/// <summary>You can only create <a href='CustomTargetingValue'>CustomTargetingValue</a>
		/// objects with match type <a
		/// href='CustomTargetingValue.MatchType#EXACT'>CustomTargetingValue.MatchType#EXACT</a>
		/// when associating with <a href='CustomTargetingKey'>CustomTargetingKey</a>
		/// objects of type <a
		/// href='CustomTargetingKey.Type#PREDEFINED'>CustomTargetingKey.Type#PREDEFINED</a>
		/// </summary>
		VALUE_MATCH_TYPE_NOT_EXACT_FOR_PREDEFINED_KEY = 17,
		/// <summary><a href='CustomTargetingValue'>CustomTargetingValue</a> object cannot have match
		/// type of <a
		/// href='CustomTargetingValue.MatchType#SUFFIX'>CustomTargetingValue.MatchType#SUFFIX</a>
		/// when adding a <a href='CustomTargetingValue'>CustomTargetingValue</a> to a line
		/// item.
		/// </summary>
		SUFFIX_MATCH_TYPE_NOT_ALLOWED = 18,
		/// <summary><a href='CustomTargetingValue'>CustomTargetingValue</a> object cannot have match
		/// type of <a
		/// href='CustomTargetingValue.MatchType#CONTAINS'>CustomTargetingValue.MatchType#CONTAINS</a>
		/// when adding a <a href='CustomTargetingValue'>CustomTargetingValue</a> to
		/// targeting expression of a line item.
		/// </summary>
		CONTAINS_MATCH_TYPE_NOT_ALLOWED = 19,
		/// <summary>The <a href='CustomTargetingKey'>CustomTargetingKey</a> does not have any <a
		/// href='CustomTargetingValue'>CustomTargetingValue</a> associated with it.
		/// </summary>
		KEY_WITH_MISSING_VALUES = 20,
		/// <summary><a
		/// href='CustomCriteriaSet.LogicalOperator#OR'>CustomCriteriaSet.LogicalOperator#OR</a>
		/// operation cannot be applied to values with different keys.
		/// </summary>
		CANNOT_OR_DIFFERENT_KEYS = 21,
		/// <summary>Targeting expression is invalid. This can happen if the sequence of operators is
		/// wrong, or a node contains invalid number of children.
		/// </summary>
		INVALID_TARGETING_EXPRESSION = 22,
		/// <summary>The key has been deleted. <a href='CustomCriteria'>CustomCriteria</a> cannot
		/// have deleted keys.
		/// </summary>
		DELETED_KEY_CANNOT_BE_USED_FOR_TARGETING = 23,
		/// <summary>The value has been deleted. <a href='CustomCriteria'>CustomCriteria</a> cannot
		/// have deleted values.
		/// </summary>
		DELETED_VALUE_CANNOT_BE_USED_FOR_TARGETING = 24,
		/// <summary>The key is set as the video browse-by key, which cannot be used for custom
		/// targeting.
		/// </summary>
		VIDEO_BROWSE_BY_KEY_CANNOT_BE_USED_FOR_CUSTOM_TARGETING = 25,
		/// <summary>Only active custom-criteria keys are supported in content metadata mapping.
		/// </summary>
		CANNOT_DELETE_CUSTOM_KEY_USED_IN_CONTENT_METADATA_MAPPING = 31,
		/// <summary>Only active custom-criteria values are supported in content metadata mapping.
		/// </summary>
		CANNOT_DELETE_CUSTOM_VALUE_USED_IN_CONTENT_METADATA_MAPPING = 32,
		/// <summary>Cannot delete a custom criteria key that is targeted by an active partner
		/// assignment.
		/// </summary>
		CANNOT_DELETE_CUSTOM_KEY_USED_IN_PARTNER_ASSIGNMENT_TARGETING = 33,
		/// <summary>Cannot delete a custom criteria value that is targeted by an active partner
		/// assignment.
		/// </summary>
		CANNOT_DELETE_CUSTOM_VALUE_USED_IN_PARTNER_ASSIGNMENT_TARGETING = 34,
		/// <summary><a href='AudienceSegment'>AudienceSegment</a> object cannot be targeted.
		/// </summary>
		CANNOT_TARGET_AUDIENCE_SEGMENT = 26,
		/// <summary>Inactive <a href='AudienceSegment'>AudienceSegment</a> object cannot be
		/// targeted.
		/// </summary>
		CANNOT_TARGET_INACTIVE_AUDIENCE_SEGMENT = 27,
		/// <summary>Targeted <a href='AudienceSegment'>AudienceSegment</a> object is not valid.
		/// </summary>
		INVALID_AUDIENCE_SEGMENTS = 28,
		/// <summary>Targeted <a href='AudienceSegment'>AudienceSegment</a> objects have not been
		/// approved.
		/// </summary>
		ONLY_APPROVED_AUDIENCE_SEGMENTS_CAN_BE_TARGETED = 29,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 30,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.CustomTargetingServiceInterface")]
	public interface CustomTargetingServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.CustomTargetingService.createCustomTargetingKeysResponse createCustomTargetingKeys(Wrappers.CustomTargetingService.createCustomTargetingKeysRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.CustomTargetingService.createCustomTargetingKeysResponse> createCustomTargetingKeysAsync(Wrappers.CustomTargetingService.createCustomTargetingKeysRequest request);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.CustomTargetingService.createCustomTargetingValuesResponse createCustomTargetingValues(Wrappers.CustomTargetingService.createCustomTargetingValuesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.CustomTargetingService.createCustomTargetingValuesResponse> createCustomTargetingValuesAsync(Wrappers.CustomTargetingService.createCustomTargetingValuesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.CustomTargetingKeyPage getCustomTargetingKeysByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomTargetingKeyPage> getCustomTargetingKeysByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.CustomTargetingValuePage getCustomTargetingValuesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomTargetingValuePage> getCustomTargetingValuesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performCustomTargetingKeyAction(Google.Api.Ads.AdManager.v201802.CustomTargetingKeyAction customTargetingKeyAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performCustomTargetingKeyActionAsync(Google.Api.Ads.AdManager.v201802.CustomTargetingKeyAction customTargetingKeyAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performCustomTargetingValueAction(Google.Api.Ads.AdManager.v201802.CustomTargetingValueAction customTargetingValueAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performCustomTargetingValueActionAsync(Google.Api.Ads.AdManager.v201802.CustomTargetingValueAction customTargetingValueAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.CustomTargetingService.updateCustomTargetingKeysResponse updateCustomTargetingKeys(Wrappers.CustomTargetingService.updateCustomTargetingKeysRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.CustomTargetingService.updateCustomTargetingKeysResponse> updateCustomTargetingKeysAsync(Wrappers.CustomTargetingService.updateCustomTargetingKeysRequest request);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.CustomTargetingService.updateCustomTargetingValuesResponse updateCustomTargetingValues(Wrappers.CustomTargetingService.updateCustomTargetingValuesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.CustomTargetingService.updateCustomTargetingValuesResponse> updateCustomTargetingValuesAsync(Wrappers.CustomTargetingService.updateCustomTargetingValuesRequest request);
	}


	/// <summary><code>CustomTargetingValue</code> represents a value used for custom targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomTargetingValue {
		private long customTargetingKeyIdField;

		private bool customTargetingKeyIdFieldSpecified;

		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private string displayNameField;

		private CustomTargetingValueMatchType matchTypeField;

		private bool matchTypeFieldSpecified;

		private CustomTargetingValueStatus statusField;

		private bool statusFieldSpecified;

		/// <summary>The ID of the <code>CustomTargetingKey</code> for which this is the value.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long customTargetingKeyId {
			get {
				return this.customTargetingKeyIdField;
			}
			set {
				this.customTargetingKeyIdField = value;
				this.customTargetingKeyIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="customTargetingKeyId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool customTargetingKeyIdSpecified {
			get {
				return this.customTargetingKeyIdFieldSpecified;
			}
			set {
				this.customTargetingKeyIdFieldSpecified = value;
			}
		}

		/// <summary>The ID of the <code>CustomTargetingValue</code>. This value is readonly and is
		/// populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>Name of the value. This can be used for encoding . If you don't want users to be
		/// able to see potentially sensitive targeting information in the ad tags of your
		/// site, you can encode your key/values. For example, you can create key/value
		/// g1=abc to represent gender=female. Values can contain up to 40 characters each.
		/// You can use alphanumeric characters and symbols other than the following: ", ',
		/// =, !, +, #, *, ~, ;, ^, (, ), &lt;, &gt;, [, ]. Values are not data-specific;
		/// all values are treated as string. For example, instead of using "age&gt;=18 AND
		/// &lt;=34", try "18-34"
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>Descriptive name for the value.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string displayName {
			get {
				return this.displayNameField;
			}
			set {
				this.displayNameField = value;
			}
		}

		/// <summary>The way in which the <a
		/// href='CustomTargetingValue#name'>CustomTargetingValue#name</a> strings will be
		/// matched.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public CustomTargetingValueMatchType matchType {
			get {
				return this.matchTypeField;
			}
			set {
				this.matchTypeField = value;
				this.matchTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="matchType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool matchTypeSpecified {
			get {
				return this.matchTypeFieldSpecified;
			}
			set {
				this.matchTypeFieldSpecified = value;
			}
		}

		/// <summary>Status of the <code>CustomTargetingValue</code>. This field is read-only. A
		/// value can be activated and deactivated by calling <a
		/// href='CustomTargetingService#performCustomTargetingValueAction'>CustomTargetingService#performCustomTargetingValueAction</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public CustomTargetingValueStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents the ways in which <a
	/// href='CustomTargetingValue#name'>CustomTargetingValue#name</a> strings will be
	/// matched with ad requests.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CustomTargetingValue.MatchType", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CustomTargetingValueMatchType {
		/// <summary>Used for exact matching. For example, the targeting value <code></code> will
		/// only match to the ad request <code>car=honda</code>.
		/// </summary>
		EXACT = 0,
		/// <summary>Used for lenient matching when at least one of the words in the ad request
		/// matches the targeted value. The targeting value <code></code> will match to ad
		/// requests containing the word <code></code>. So ad requests
		/// <code>car=honda</code> or <code>car=honda civic</code> or <code>car=buy
		/// honda</code> or <code>car=how much does a honda cost</code> will all have the
		/// line item delivered. <p>This match type can not be used within an audience
		/// segment rule.</p>
		/// </summary>
		BROAD = 1,
		/// <summary>Used for 'starts with' matching when the first few characters in the ad request
		/// match all of the characters in the targeted value. The targeting value
		/// <code>car=honda</code> will match to ad requests <code>car=honda</code> or
		/// <code>car=hondas for sale</code> but not to <code>want a honda</code>.
		/// </summary>
		PREFIX = 2,
		/// <summary>This is a combination of <code>MatchType#BROAD</code> and <code></code>
		/// matching. The targeting value <code>car=honda</code> will match to ad requests
		/// that contain words that start with the characters in the targeted value, for
		/// example with <code>car=civic hondas</code>. <p>This match type can not be used
		/// within an audience segment rule.</p>
		/// </summary>
		BROAD_PREFIX = 3,
		/// <summary>Used for 'ends with' matching when the last characters in the ad request match
		/// all of the characters in the targeted value. The targeting value
		/// <code>car=honda</code> will match with ad requests <code>car=honda</code> or
		/// <code>car=I want a honda</code> but not to <code>for sale</code>. <p>This match
		/// type can not be used within line item targeting.</p>
		/// </summary>
		SUFFIX = 4,
		/// <summary>Used for 'within' matching when the string in the ad request contains the string
		/// in the targeted value. The targeting value <code>car=honda</code> will match
		/// with ad requests <code>car=honda</code>, <code>car=I want a honda</code>, and
		/// also with <code>car=hondas for sale</code>, but not with <code>car=misspelled
		/// hond a</code>. <p>This match type can not be used within line item
		/// targeting.</p>
		/// </summary>
		CONTAINS = 5,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 6,
	}


	/// <summary>Describes the statuses for <code>CustomTargetingValue</code> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CustomTargetingValue.Status", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CustomTargetingValueStatus {
		/// <summary>The object is active.
		/// </summary>
		ACTIVE = 0,
		/// <summary>The object is no longer active.
		/// </summary>
		INACTIVE = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Captures a page of <a href='CustomTargetingKey'>CustomTargetingKey</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomTargetingKeyPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private CustomTargetingKey[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of custom targeting keys contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public CustomTargetingKey[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Captures a page of <a href='CustomTargetingValue'>CustomTargetingValue</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomTargetingValuePage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private CustomTargetingValue[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of custom targeting keys contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public CustomTargetingValue[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a
	/// href='CustomTargetingKey'>CustomTargetingKey</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeleteCustomTargetingKeys))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateCustomTargetingKeys))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class CustomTargetingKeyAction {
	}


	/// <summary>Represents the delete action that can be performed on <a
	/// href='CustomTargetingKey'>CustomTargetingKey</a> objects. Deleting a key will
	/// not delete the <a href='CustomTargetingValue'>CustomTargetingValue</a> objects
	/// associated with it. Also, if a custom targeting key that has been deleted is
	/// recreated, any previous custom targeting values associated with it that were not
	/// deleted will continue to exist.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeleteCustomTargetingKeys : CustomTargetingKeyAction {
	}


	/// <summary>The action used for activating inactive (i.e. deleted) <a
	/// href='CustomTargetingKey'>CustomTargetingKey</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateCustomTargetingKeys : CustomTargetingKeyAction {
	}


	/// <summary>Represents the actions that can be performed on <a
	/// href='CustomTargetingValue'>CustomTargetingValue</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeleteCustomTargetingValues))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateCustomTargetingValues))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class CustomTargetingValueAction {
	}


	/// <summary>Represents the delete action that can be performed on <a
	/// href='CustomTargetingValue'>CustomTargetingValue</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeleteCustomTargetingValues : CustomTargetingValueAction {
	}


	/// <summary>The action used for activating inactive (i.e. deleted) <a
	/// href='CustomTargetingValue'>CustomTargetingValue</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateCustomTargetingValues : CustomTargetingValueAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface CustomTargetingServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.CustomTargetingServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides operations for creating, updating and retrieving <a
	/// href='CustomTargetingKey'>CustomTargetingKey</a> and <a
	/// href=''>CustomTargetingValue</a> objects.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class CustomTargetingService : AdManagerSoapClient<ICustomTargetingService>, ICustomTargetingService {
		/// <summary> Creates a new instance of the <see cref="CustomTargetingService"/>
		/// class. </summary>
		public CustomTargetingService() {
		}

		/// <summary> Creates a new instance of the <see cref="CustomTargetingService"/>
		/// class. </summary>
		public CustomTargetingService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="CustomTargetingService"/>
		/// class. </summary>
		public CustomTargetingService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="CustomTargetingService"/>
		/// class. </summary>
		public CustomTargetingService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="CustomTargetingService"/>
		/// class. </summary>
		public CustomTargetingService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.CustomTargetingService.createCustomTargetingKeysResponse Google.Api.Ads.AdManager.v201802.CustomTargetingServiceInterface.createCustomTargetingKeys(Wrappers.CustomTargetingService.createCustomTargetingKeysRequest request) {
			return base.Channel.createCustomTargetingKeys(request);
		}

		/// <summary>Creates new <a href='CustomTargetingKey'>CustomTargetingKey</a> objects. The
		/// following fields are required: <ul> <li><a
		/// href='CustomTargetingKey#name'>CustomTargetingKey#name</a></li> <li><a
		/// href='CustomTargetingKey#type'>CustomTargetingKey#type</a></li> </ul>
		/// </summary><param name='keys'>the custom targeting keys to update</param>
		/// <returns>the updated custom targeting keys</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] createCustomTargetingKeys(Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] keys) {
			Wrappers.CustomTargetingService.createCustomTargetingKeysRequest inValue = new Wrappers.CustomTargetingService.createCustomTargetingKeysRequest();
			inValue.keys = keys;
			Wrappers.CustomTargetingService.createCustomTargetingKeysResponse retVal = ((Google.Api.Ads.AdManager.v201802.CustomTargetingServiceInterface)(this)).createCustomTargetingKeys(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.CustomTargetingService.createCustomTargetingKeysResponse> Google.Api.Ads.AdManager.v201802.CustomTargetingServiceInterface.createCustomTargetingKeysAsync(Wrappers.CustomTargetingService.createCustomTargetingKeysRequest request) {
			return base.Channel.createCustomTargetingKeysAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomTargetingKey[]> createCustomTargetingKeysAsync(Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] keys) {
			Wrappers.CustomTargetingService.createCustomTargetingKeysRequest inValue = new Wrappers.CustomTargetingService.createCustomTargetingKeysRequest();
			inValue.keys = keys;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomTargetingKey[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.CustomTargetingServiceInterface)(this)).createCustomTargetingKeysAsync(inValue)).Result.rval);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.CustomTargetingService.createCustomTargetingValuesResponse Google.Api.Ads.AdManager.v201802.CustomTargetingServiceInterface.createCustomTargetingValues(Wrappers.CustomTargetingService.createCustomTargetingValuesRequest request) {
			return base.Channel.createCustomTargetingValues(request);
		}

		/// <summary>Creates new <a href='CustomTargetingValue'>CustomTargetingValue</a> objects. The
		/// following fields are required: <ul> <li><a
		/// href='CustomTargetingValue#customTargetingKeyId'>CustomTargetingValue#customTargetingKeyId</a></li>
		/// <li><a href='CustomTargetingValue#name'>CustomTargetingValue#name</a></li> </ul>
		/// </summary><param name='values'>the custom targeting values to update</param>
		/// <returns>the updated custom targeting keys</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] createCustomTargetingValues(Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] values) {
			Wrappers.CustomTargetingService.createCustomTargetingValuesRequest inValue = new Wrappers.CustomTargetingService.createCustomTargetingValuesRequest();
			inValue.values = values;
			Wrappers.CustomTargetingService.createCustomTargetingValuesResponse retVal = ((Google.Api.Ads.AdManager.v201802.CustomTargetingServiceInterface)(this)).createCustomTargetingValues(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.CustomTargetingService.createCustomTargetingValuesResponse> Google.Api.Ads.AdManager.v201802.CustomTargetingServiceInterface.createCustomTargetingValuesAsync(Wrappers.CustomTargetingService.createCustomTargetingValuesRequest request) {
			return base.Channel.createCustomTargetingValuesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomTargetingValue[]> createCustomTargetingValuesAsync(Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] values) {
			Wrappers.CustomTargetingService.createCustomTargetingValuesRequest inValue = new Wrappers.CustomTargetingService.createCustomTargetingValuesRequest();
			inValue.values = values;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomTargetingValue[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.CustomTargetingServiceInterface)(this)).createCustomTargetingValuesAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='CustomTargetingKeyPage'>CustomTargetingKeyPage</a> of <a
		/// href='CustomTargetingKey'>CustomTargetingKey</a> objects that satisfy the given
		/// <a href='Statement#query'>Statement#query</a>. The following fields are
		/// supported for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td></td> </tr> <tr>
		/// <td><code>id</code></td> <td><a
		/// href='CustomTargetingKey#id'>CustomTargetingKey#id</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a
		/// href='CustomTargetingKey#name'>CustomTargetingKey#name</a></td> </tr> <tr>
		/// <td><code>displayName</code></td> <td><a
		/// href='CustomTargetingKey#displayName'>CustomTargetingKey#displayName</a></td>
		/// </tr> <tr> <td><code>type</code></td> <td><a
		/// href='CustomTargetingKey#type'>CustomTargetingKey#type</a></td> </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of custom targeting keys</param>
		/// <returns>the custom targeting keys that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CustomTargetingKeyPage getCustomTargetingKeysByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getCustomTargetingKeysByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomTargetingKeyPage> getCustomTargetingKeysByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getCustomTargetingKeysByStatementAsync(filterStatement);
		}

		/// <summary>Gets a <a href='CustomTargetingValuePage'>CustomTargetingValuePage</a> of <a
		/// href='CustomTargetingValue'>CustomTargetingValue</a> objects that satisfy the
		/// given <a href='Statement#query'>Statement#query</a>. <p>The <code>WHERE</code>
		/// clause in the <a href='Statement#query'>Statement#query</a> must always contain
		/// <a
		/// href='CustomTargetingValue#customTargetingKeyId'>CustomTargetingValue#customTargetingKeyId</a>
		/// as one of its columns in a way that it is AND'ed with the rest of the query. So,
		/// if you want to retrieve values for a known set of key ids, valid <a
		/// href='Statement#query'>Statement#query</a> would look like:</p> <ol> <li>"WHERE
		/// customTargetingKeyId IN ('17','18','19')" retrieves all values that are
		/// associated with keys having ids 17, 18, 19.</li> <li>"WHERE customTargetingKeyId
		/// = '17' AND name = 'red'" retrieves values that are associated with keys having
		/// id 17 and value name is 'red'.</li> </ol> <br /> <br /> <p>The following fields
		/// are supported for filtering:</p> <table> <tr> <th scope="col">PQL Property</th>
		/// <th scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='CustomTargetingValue#id'>CustomTargetingValue#id</a></td> </tr> <tr>
		/// <td><code>customTargetingKeyId</code></td> <td><a
		/// href='CustomTargetingValue#customTargetingKeyId'>CustomTargetingValue#customTargetingKeyId</a></td>
		/// </tr> <tr> <td><code>name</code></td> <td><a
		/// href='CustomTargetingValue#name'>CustomTargetingValue#name</a></td> </tr> <tr>
		/// <td><code>displayName</code></td> <td><a
		/// href='CustomTargetingValue#displayName'>CustomTargetingValue#displayName</a></td>
		/// </tr> <tr> <td><code>matchType</code></td> <td><a
		/// href='CustomTargetingValue#matchType'>CustomTargetingValue#matchType</a></td>
		/// </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of custom targeting values</param>
		/// <returns>the custom targeting values that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CustomTargetingValuePage getCustomTargetingValuesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getCustomTargetingValuesByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomTargetingValuePage> getCustomTargetingValuesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getCustomTargetingValuesByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='CustomTargetingKey'>CustomTargetingKey</a> objects
		/// that match the given <a href='Statement#query'>Statement#query</a>.
		/// </summary><param name='customTargetingKeyAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of custom targeting keys</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performCustomTargetingKeyAction(Google.Api.Ads.AdManager.v201802.CustomTargetingKeyAction customTargetingKeyAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performCustomTargetingKeyAction(customTargetingKeyAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performCustomTargetingKeyActionAsync(Google.Api.Ads.AdManager.v201802.CustomTargetingKeyAction customTargetingKeyAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performCustomTargetingKeyActionAsync(customTargetingKeyAction, filterStatement);
		}

		/// <summary>Performs actions on <a href='CustomTargetingValue'>CustomTargetingValue</a>
		/// objects that match the given <a href='Statement#query'>Statement#query</a>.
		/// </summary><param name='customTargetingValueAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of ad units</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performCustomTargetingValueAction(Google.Api.Ads.AdManager.v201802.CustomTargetingValueAction customTargetingValueAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performCustomTargetingValueAction(customTargetingValueAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performCustomTargetingValueActionAsync(Google.Api.Ads.AdManager.v201802.CustomTargetingValueAction customTargetingValueAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performCustomTargetingValueActionAsync(customTargetingValueAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.CustomTargetingService.updateCustomTargetingKeysResponse Google.Api.Ads.AdManager.v201802.CustomTargetingServiceInterface.updateCustomTargetingKeys(Wrappers.CustomTargetingService.updateCustomTargetingKeysRequest request) {
			return base.Channel.updateCustomTargetingKeys(request);
		}

		/// <summary>Updates the specified <a href='CustomTargetingKey'>CustomTargetingKey</a>
		/// objects.
		/// </summary><param name='keys'>the custom targeting keys to update</param>
		/// <returns>the updated custom targeting keys</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] updateCustomTargetingKeys(Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] keys) {
			Wrappers.CustomTargetingService.updateCustomTargetingKeysRequest inValue = new Wrappers.CustomTargetingService.updateCustomTargetingKeysRequest();
			inValue.keys = keys;
			Wrappers.CustomTargetingService.updateCustomTargetingKeysResponse retVal = ((Google.Api.Ads.AdManager.v201802.CustomTargetingServiceInterface)(this)).updateCustomTargetingKeys(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.CustomTargetingService.updateCustomTargetingKeysResponse> Google.Api.Ads.AdManager.v201802.CustomTargetingServiceInterface.updateCustomTargetingKeysAsync(Wrappers.CustomTargetingService.updateCustomTargetingKeysRequest request) {
			return base.Channel.updateCustomTargetingKeysAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomTargetingKey[]> updateCustomTargetingKeysAsync(Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] keys) {
			Wrappers.CustomTargetingService.updateCustomTargetingKeysRequest inValue = new Wrappers.CustomTargetingService.updateCustomTargetingKeysRequest();
			inValue.keys = keys;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomTargetingKey[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.CustomTargetingServiceInterface)(this)).updateCustomTargetingKeysAsync(inValue)).Result.rval);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.CustomTargetingService.updateCustomTargetingValuesResponse Google.Api.Ads.AdManager.v201802.CustomTargetingServiceInterface.updateCustomTargetingValues(Wrappers.CustomTargetingService.updateCustomTargetingValuesRequest request) {
			return base.Channel.updateCustomTargetingValues(request);
		}

		/// <summary>Updates the specified <a href='CustomTargetingValue'>CustomTargetingValue</a>
		/// objects.
		/// </summary><param name='values'>the custom targeting values to update</param>
		/// <returns>the updated custom targeting values</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] updateCustomTargetingValues(Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] values) {
			Wrappers.CustomTargetingService.updateCustomTargetingValuesRequest inValue = new Wrappers.CustomTargetingService.updateCustomTargetingValuesRequest();
			inValue.values = values;
			Wrappers.CustomTargetingService.updateCustomTargetingValuesResponse retVal = ((Google.Api.Ads.AdManager.v201802.CustomTargetingServiceInterface)(this)).updateCustomTargetingValues(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.CustomTargetingService.updateCustomTargetingValuesResponse> Google.Api.Ads.AdManager.v201802.CustomTargetingServiceInterface.updateCustomTargetingValuesAsync(Wrappers.CustomTargetingService.updateCustomTargetingValuesRequest request) {
			return base.Channel.updateCustomTargetingValuesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomTargetingValue[]> updateCustomTargetingValuesAsync(Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] values) {
			Wrappers.CustomTargetingService.updateCustomTargetingValuesRequest inValue = new Wrappers.CustomTargetingService.updateCustomTargetingValuesRequest();
			inValue.values = values;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomTargetingValue[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.CustomTargetingServiceInterface)(this)).updateCustomTargetingValuesAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.CustomFieldService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createCustomFieldOptions", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createCustomFieldOptionsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("customFieldOptions")]
			public Google.Api.Ads.AdManager.v201802.CustomFieldOption[] customFieldOptions;

			/// <summary> Creates a new instance of the <see
			/// cref="createCustomFieldOptionsRequest"/> class. </summary>
			public createCustomFieldOptionsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createCustomFieldOptionsRequest"/> class. </summary>
			public createCustomFieldOptionsRequest(Google.Api.Ads.AdManager.v201802.CustomFieldOption[] customFieldOptions) {
				this.customFieldOptions = customFieldOptions;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createCustomFieldOptionsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createCustomFieldOptionsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.CustomFieldOption[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createCustomFieldOptionsResponse"/> class. </summary>
			public createCustomFieldOptionsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createCustomFieldOptionsResponse"/> class. </summary>
			public createCustomFieldOptionsResponse(Google.Api.Ads.AdManager.v201802.CustomFieldOption[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createCustomFields", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createCustomFieldsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("customFields")]
			public Google.Api.Ads.AdManager.v201802.CustomField[] customFields;

			/// <summary> Creates a new instance of the <see cref="createCustomFieldsRequest"/>
			/// class. </summary>
			public createCustomFieldsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createCustomFieldsRequest"/>
			/// class. </summary>
			public createCustomFieldsRequest(Google.Api.Ads.AdManager.v201802.CustomField[] customFields) {
				this.customFields = customFields;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createCustomFieldsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createCustomFieldsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.CustomField[] rval;

			/// <summary> Creates a new instance of the <see cref="createCustomFieldsResponse"/>
			/// class. </summary>
			public createCustomFieldsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createCustomFieldsResponse"/>
			/// class. </summary>
			public createCustomFieldsResponse(Google.Api.Ads.AdManager.v201802.CustomField[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateCustomFieldOptions", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateCustomFieldOptionsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("customFieldOptions")]
			public Google.Api.Ads.AdManager.v201802.CustomFieldOption[] customFieldOptions;

			/// <summary> Creates a new instance of the <see
			/// cref="updateCustomFieldOptionsRequest"/> class. </summary>
			public updateCustomFieldOptionsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateCustomFieldOptionsRequest"/> class. </summary>
			public updateCustomFieldOptionsRequest(Google.Api.Ads.AdManager.v201802.CustomFieldOption[] customFieldOptions) {
				this.customFieldOptions = customFieldOptions;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateCustomFieldOptionsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateCustomFieldOptionsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.CustomFieldOption[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateCustomFieldOptionsResponse"/> class. </summary>
			public updateCustomFieldOptionsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateCustomFieldOptionsResponse"/> class. </summary>
			public updateCustomFieldOptionsResponse(Google.Api.Ads.AdManager.v201802.CustomFieldOption[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateCustomFields", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateCustomFieldsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("customFields")]
			public Google.Api.Ads.AdManager.v201802.CustomField[] customFields;

			/// <summary> Creates a new instance of the <see cref="updateCustomFieldsRequest"/>
			/// class. </summary>
			public updateCustomFieldsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updateCustomFieldsRequest"/>
			/// class. </summary>
			public updateCustomFieldsRequest(Google.Api.Ads.AdManager.v201802.CustomField[] customFields) {
				this.customFields = customFields;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateCustomFieldsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateCustomFieldsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.CustomField[] rval;

			/// <summary> Creates a new instance of the <see cref="updateCustomFieldsResponse"/>
			/// class. </summary>
			public updateCustomFieldsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updateCustomFieldsResponse"/>
			/// class. </summary>
			public updateCustomFieldsResponse(Google.Api.Ads.AdManager.v201802.CustomField[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>An option represents a permitted value for a custom field that has a <a
	/// href='CustomField#dataType'>CustomField#dataType</a> of <a
	/// href='CustomFieldDataType#DROP_DOWN'>CustomFieldDataType#DROP_DOWN</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomFieldOption {
		private long idField;

		private bool idFieldSpecified;

		private long customFieldIdField;

		private bool customFieldIdFieldSpecified;

		private string displayNameField;

		/// <summary>Unique ID of this option. This value is readonly and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The id of the custom field this option belongs to.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long customFieldId {
			get {
				return this.customFieldIdField;
			}
			set {
				this.customFieldIdField = value;
				this.customFieldIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="customFieldId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool customFieldIdSpecified {
			get {
				return this.customFieldIdFieldSpecified;
			}
			set {
				this.customFieldIdFieldSpecified = value;
			}
		}

		/// <summary>The display name of this option.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string displayName {
			get {
				return this.displayNameField;
			}
			set {
				this.displayNameField = value;
			}
		}
	}


	/// <summary>Errors specific to editing custom fields
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomFieldError : ApiError {
		private CustomFieldErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CustomFieldErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CustomFieldError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CustomFieldErrorReason {
		/// <summary>An attempt was made to create a <a
		/// href='CustomFieldOption'>CustomFieldOption</a> for a <a
		/// href='CustomField'>CustomField</a> that does not have <a
		/// href='CustomFieldDataType#DROPDOWN'>CustomFieldDataType#DROPDOWN</a>.
		/// </summary>
		INVALID_CUSTOM_FIELD_FOR_OPTION = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.CustomFieldServiceInterface")]
	public interface CustomFieldServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.CustomFieldService.createCustomFieldOptionsResponse createCustomFieldOptions(Wrappers.CustomFieldService.createCustomFieldOptionsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.CustomFieldService.createCustomFieldOptionsResponse> createCustomFieldOptionsAsync(Wrappers.CustomFieldService.createCustomFieldOptionsRequest request);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.CustomFieldService.createCustomFieldsResponse createCustomFields(Wrappers.CustomFieldService.createCustomFieldsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.CustomFieldService.createCustomFieldsResponse> createCustomFieldsAsync(Wrappers.CustomFieldService.createCustomFieldsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.CustomFieldOption getCustomFieldOption(long customFieldOptionId);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomFieldOption> getCustomFieldOptionAsync(long customFieldOptionId);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.CustomFieldPage getCustomFieldsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomFieldPage> getCustomFieldsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performCustomFieldAction(Google.Api.Ads.AdManager.v201802.CustomFieldAction customFieldAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performCustomFieldActionAsync(Google.Api.Ads.AdManager.v201802.CustomFieldAction customFieldAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.CustomFieldService.updateCustomFieldOptionsResponse updateCustomFieldOptions(Wrappers.CustomFieldService.updateCustomFieldOptionsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.CustomFieldService.updateCustomFieldOptionsResponse> updateCustomFieldOptionsAsync(Wrappers.CustomFieldService.updateCustomFieldOptionsRequest request);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.CustomFieldService.updateCustomFieldsResponse updateCustomFields(Wrappers.CustomFieldService.updateCustomFieldsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.CustomFieldService.updateCustomFieldsResponse> updateCustomFieldsAsync(Wrappers.CustomFieldService.updateCustomFieldsRequest request);
	}


	/// <summary>An additional, user-created field on an entity.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DropDownCustomField))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomField {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private string descriptionField;

		private bool isActiveField;

		private bool isActiveFieldSpecified;

		private CustomFieldEntityType entityTypeField;

		private bool entityTypeFieldSpecified;

		private CustomFieldDataType dataTypeField;

		private bool dataTypeFieldSpecified;

		private CustomFieldVisibility visibilityField;

		private bool visibilityFieldSpecified;

		/// <summary>Unique ID of the <code>CustomField</code>. This value is readonly and is
		/// assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>Name of the <code>CustomField</code>. This is value is required to create a
		/// custom field. The max length is 127 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>A description of the custom field. This value is optional. The maximum length is
		/// 511 characters
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string description {
			get {
				return this.descriptionField;
			}
			set {
				this.descriptionField = value;
			}
		}

		/// <summary>Specifies whether or not the custom fields is active. This attribute is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public bool isActive {
			get {
				return this.isActiveField;
			}
			set {
				this.isActiveField = value;
				this.isActiveSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isActive"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isActiveSpecified {
			get {
				return this.isActiveFieldSpecified;
			}
			set {
				this.isActiveFieldSpecified = value;
			}
		}

		/// <summary>The type of entity that this custom field is associated with. This attribute is
		/// read-only if there exists a <a href='CustomFieldValue'>CustomFieldValue</a> for
		/// this field.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public CustomFieldEntityType entityType {
			get {
				return this.entityTypeField;
			}
			set {
				this.entityTypeField = value;
				this.entityTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="entityType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool entityTypeSpecified {
			get {
				return this.entityTypeFieldSpecified;
			}
			set {
				this.entityTypeFieldSpecified = value;
			}
		}

		/// <summary>The type of data this custom field contains. This attribute is read-only if
		/// there exists a <a href='CustomFieldValue'>CustomFieldValue</a> for this field.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public CustomFieldDataType dataType {
			get {
				return this.dataTypeField;
			}
			set {
				this.dataTypeField = value;
				this.dataTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="dataType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool dataTypeSpecified {
			get {
				return this.dataTypeFieldSpecified;
			}
			set {
				this.dataTypeFieldSpecified = value;
			}
		}

		/// <summary>How visible/accessible this field is in the UI.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public CustomFieldVisibility visibility {
			get {
				return this.visibilityField;
			}
			set {
				this.visibilityField = value;
				this.visibilitySpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="visibility"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool visibilitySpecified {
			get {
				return this.visibilityFieldSpecified;
			}
			set {
				this.visibilityFieldSpecified = value;
			}
		}
	}


	/// <summary>Entity types recognized by custom fields
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CustomFieldEntityType {
		/// <summary>Represents the <a href='LineItem'>LineItem</a> type.
		/// </summary>
		LINE_ITEM = 0,
		/// <summary>Represents the <a href='Order'>Order</a> type.
		/// </summary>
		ORDER = 1,
		/// <summary>Represents the <a href='Creative'>Creative</a> type.
		/// </summary>
		CREATIVE = 2,
		/// <summary>Represents the <a href='ProductTemplate'>ProductTemplate</a> type.
		/// </summary>
		PRODUCT_TEMPLATE = 3,
		/// <summary>Represents the <a href='Product'>Product</a> type.
		/// </summary>
		PRODUCT = 4,
		/// <summary>Represents the <a href='Proposal'>Proposal</a> type.
		/// </summary>
		PROPOSAL = 5,
		/// <summary>Represents the <a href='ProposalLineItem'>ProposalLineItem</a> type.
		/// </summary>
		PROPOSAL_LINE_ITEM = 6,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 8,
	}


	/// <summary>The data types allowed for <a href='CustomField'>CustomField</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CustomFieldDataType {
		/// <summary>A string field. The max length is 255 characters.
		/// </summary>
		STRING = 0,
		/// <summary>A number field.
		/// </summary>
		NUMBER = 1,
		/// <summary>A boolean field. Values may be "true", "false", or empty.
		/// </summary>
		TOGGLE = 2,
		/// <summary>A drop-down field. Values may only be the ids of <a
		/// href='CustomFieldOption'>CustomFieldOption</a> objects.
		/// </summary>
		DROP_DOWN = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>The visibility levels of a custom field.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CustomFieldVisibility {
		/// <summary>Only visible through the API.
		/// </summary>
		API_ONLY = 0,
		/// <summary>Visible in the UI, but only editable through the API
		/// </summary>
		READ_ONLY = 1,
		/// <summary>Visible and editable both in the API and the UI.
		/// </summary>
		FULL = 2,
	}


	/// <summary>A custom field that has the drop-down data type.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DropDownCustomField : CustomField {
		private CustomFieldOption[] optionsField;

		/// <summary>The options allowed for this custom field. This is read only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("options", Order = 0)]
		public CustomFieldOption[] options {
			get {
				return this.optionsField;
			}
			set {
				this.optionsField = value;
			}
		}
	}


	/// <summary>Captures a page of <a href='CustomField'>CustomField</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomFieldPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private CustomField[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of custom fields contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public CustomField[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a
	/// href='CustomField'>CustomField</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeactivateCustomFields))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateCustomFields))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomFieldAction {
	}


	/// <summary>The action used for deactivating <a href='CustomField'>CustomField</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeactivateCustomFields : CustomFieldAction {
	}


	/// <summary>The action used for activating <a href='CustomField'>CustomField</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateCustomFields : CustomFieldAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface CustomFieldServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.CustomFieldServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for the creation and management of <a
	/// href='CustomField'>CustomField</a> objects.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class CustomFieldService : AdManagerSoapClient<ICustomFieldService>, ICustomFieldService {
		/// <summary> Creates a new instance of the <see cref="CustomFieldService"/> class.
		/// </summary>
		public CustomFieldService() {
		}

		/// <summary> Creates a new instance of the <see cref="CustomFieldService"/> class.
		/// </summary>
		public CustomFieldService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="CustomFieldService"/> class.
		/// </summary>
		public CustomFieldService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="CustomFieldService"/> class.
		/// </summary>
		public CustomFieldService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="CustomFieldService"/> class.
		/// </summary>
		public CustomFieldService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.CustomFieldService.createCustomFieldOptionsResponse Google.Api.Ads.AdManager.v201802.CustomFieldServiceInterface.createCustomFieldOptions(Wrappers.CustomFieldService.createCustomFieldOptionsRequest request) {
			return base.Channel.createCustomFieldOptions(request);
		}

		/// <summary>Creates new <a href='CustomFieldOption'>CustomFieldOption</a> objects. The
		/// following fields are required: <ul> <li><a
		/// href='CustomFieldOption#displayName'>CustomFieldOption#displayName</a></li>
		/// <li><a
		/// href='CustomFieldOption#customFieldId'>CustomFieldOption#customFieldId</a></li>
		/// </ul>
		/// </summary><param name='customFieldOptions'>the custom fields to create</param>
		/// <returns>the created custom field options with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CustomFieldOption[] createCustomFieldOptions(Google.Api.Ads.AdManager.v201802.CustomFieldOption[] customFieldOptions) {
			Wrappers.CustomFieldService.createCustomFieldOptionsRequest inValue = new Wrappers.CustomFieldService.createCustomFieldOptionsRequest();
			inValue.customFieldOptions = customFieldOptions;
			Wrappers.CustomFieldService.createCustomFieldOptionsResponse retVal = ((Google.Api.Ads.AdManager.v201802.CustomFieldServiceInterface)(this)).createCustomFieldOptions(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.CustomFieldService.createCustomFieldOptionsResponse> Google.Api.Ads.AdManager.v201802.CustomFieldServiceInterface.createCustomFieldOptionsAsync(Wrappers.CustomFieldService.createCustomFieldOptionsRequest request) {
			return base.Channel.createCustomFieldOptionsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomFieldOption[]> createCustomFieldOptionsAsync(Google.Api.Ads.AdManager.v201802.CustomFieldOption[] customFieldOptions) {
			Wrappers.CustomFieldService.createCustomFieldOptionsRequest inValue = new Wrappers.CustomFieldService.createCustomFieldOptionsRequest();
			inValue.customFieldOptions = customFieldOptions;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomFieldOption[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.CustomFieldServiceInterface)(this)).createCustomFieldOptionsAsync(inValue)).Result.rval);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.CustomFieldService.createCustomFieldsResponse Google.Api.Ads.AdManager.v201802.CustomFieldServiceInterface.createCustomFields(Wrappers.CustomFieldService.createCustomFieldsRequest request) {
			return base.Channel.createCustomFields(request);
		}

		/// <summary>Creates new <a href='CustomField'>CustomField</a> objects. The following fields
		/// are required: <ul> <li><a href='CustomField#name'>CustomField#name</a></li>
		/// <li><a href='CustomField#entityType'>CustomField#entityType</a></li> <li><a
		/// href='CustomField#dataType'>CustomField#dataType</a></li> <li><a
		/// href='CustomField#visibility'>CustomField#visibility</a></li> </ul>
		/// </summary><param name='customFields'>the custom fields to create</param>
		/// <returns>the created custom fields with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CustomField[] createCustomFields(Google.Api.Ads.AdManager.v201802.CustomField[] customFields) {
			Wrappers.CustomFieldService.createCustomFieldsRequest inValue = new Wrappers.CustomFieldService.createCustomFieldsRequest();
			inValue.customFields = customFields;
			Wrappers.CustomFieldService.createCustomFieldsResponse retVal = ((Google.Api.Ads.AdManager.v201802.CustomFieldServiceInterface)(this)).createCustomFields(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.CustomFieldService.createCustomFieldsResponse> Google.Api.Ads.AdManager.v201802.CustomFieldServiceInterface.createCustomFieldsAsync(Wrappers.CustomFieldService.createCustomFieldsRequest request) {
			return base.Channel.createCustomFieldsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomField[]> createCustomFieldsAsync(Google.Api.Ads.AdManager.v201802.CustomField[] customFields) {
			Wrappers.CustomFieldService.createCustomFieldsRequest inValue = new Wrappers.CustomFieldService.createCustomFieldsRequest();
			inValue.customFields = customFields;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomField[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.CustomFieldServiceInterface)(this)).createCustomFieldsAsync(inValue)).Result.rval);
		}

		/// <summary>Returns the <a href='CustomFieldOption'>CustomFieldOption</a> uniquely
		/// identified by the given ID.
		/// </summary><param name='customFieldOptionId'>the ID of the custom field option, which must
		/// already exist</param>
		/// <returns>the <code>CustomFieldOption</code> uniquely identified by the given
		/// ID</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CustomFieldOption getCustomFieldOption(long customFieldOptionId) {
			return base.Channel.getCustomFieldOption(customFieldOptionId);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomFieldOption> getCustomFieldOptionAsync(long customFieldOptionId) {
			return base.Channel.getCustomFieldOptionAsync(customFieldOptionId);
		}

		/// <summary>Gets a <a href='CustomFieldPage'>CustomFieldPage</a> of <a
		/// href='CustomField'>CustomField</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='CustomField#id'>CustomField#id</a></td> </tr> <tr>
		/// <td><code>entityType</code></td> <td><a
		/// href='CustomField#entityType'>CustomField#entityType</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a
		/// href='CustomField#name'>CustomField#name</a></td> </tr> <tr>
		/// <td><code>isActive</code></td> <td><a
		/// href='CustomField#isActive'>CustomField#isActive</a></td> </tr> <tr>
		/// <td><code>visibility</code></td> <td><a
		/// href='CustomField#visibility'>CustomField#visibility</a></td> </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of custom fields.</param>
		/// <returns>the custom fields that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CustomFieldPage getCustomFieldsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getCustomFieldsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomFieldPage> getCustomFieldsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getCustomFieldsByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='CustomField'>CustomField</a> objects that match the
		/// given <a href='Statement#query'>Statement#query</a>.
		/// </summary><param name='customFieldAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of custom fields</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performCustomFieldAction(Google.Api.Ads.AdManager.v201802.CustomFieldAction customFieldAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performCustomFieldAction(customFieldAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performCustomFieldActionAsync(Google.Api.Ads.AdManager.v201802.CustomFieldAction customFieldAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performCustomFieldActionAsync(customFieldAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.CustomFieldService.updateCustomFieldOptionsResponse Google.Api.Ads.AdManager.v201802.CustomFieldServiceInterface.updateCustomFieldOptions(Wrappers.CustomFieldService.updateCustomFieldOptionsRequest request) {
			return base.Channel.updateCustomFieldOptions(request);
		}

		/// <summary>Updates the specified <a href='CustomFieldOption'>CustomFieldOption</a> objects.
		/// </summary><param name='customFieldOptions'>the custom field options to update</param>
		/// <returns>the updated custom field options</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CustomFieldOption[] updateCustomFieldOptions(Google.Api.Ads.AdManager.v201802.CustomFieldOption[] customFieldOptions) {
			Wrappers.CustomFieldService.updateCustomFieldOptionsRequest inValue = new Wrappers.CustomFieldService.updateCustomFieldOptionsRequest();
			inValue.customFieldOptions = customFieldOptions;
			Wrappers.CustomFieldService.updateCustomFieldOptionsResponse retVal = ((Google.Api.Ads.AdManager.v201802.CustomFieldServiceInterface)(this)).updateCustomFieldOptions(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.CustomFieldService.updateCustomFieldOptionsResponse> Google.Api.Ads.AdManager.v201802.CustomFieldServiceInterface.updateCustomFieldOptionsAsync(Wrappers.CustomFieldService.updateCustomFieldOptionsRequest request) {
			return base.Channel.updateCustomFieldOptionsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomFieldOption[]> updateCustomFieldOptionsAsync(Google.Api.Ads.AdManager.v201802.CustomFieldOption[] customFieldOptions) {
			Wrappers.CustomFieldService.updateCustomFieldOptionsRequest inValue = new Wrappers.CustomFieldService.updateCustomFieldOptionsRequest();
			inValue.customFieldOptions = customFieldOptions;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomFieldOption[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.CustomFieldServiceInterface)(this)).updateCustomFieldOptionsAsync(inValue)).Result.rval);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.CustomFieldService.updateCustomFieldsResponse Google.Api.Ads.AdManager.v201802.CustomFieldServiceInterface.updateCustomFields(Wrappers.CustomFieldService.updateCustomFieldsRequest request) {
			return base.Channel.updateCustomFields(request);
		}

		/// <summary>Updates the specified <a href='CustomField'>CustomField</a> objects.
		/// </summary><param name='customFields'>the custom fields to update</param>
		/// <returns>the updated custom fields</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CustomField[] updateCustomFields(Google.Api.Ads.AdManager.v201802.CustomField[] customFields) {
			Wrappers.CustomFieldService.updateCustomFieldsRequest inValue = new Wrappers.CustomFieldService.updateCustomFieldsRequest();
			inValue.customFields = customFields;
			Wrappers.CustomFieldService.updateCustomFieldsResponse retVal = ((Google.Api.Ads.AdManager.v201802.CustomFieldServiceInterface)(this)).updateCustomFields(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.CustomFieldService.updateCustomFieldsResponse> Google.Api.Ads.AdManager.v201802.CustomFieldServiceInterface.updateCustomFieldsAsync(Wrappers.CustomFieldService.updateCustomFieldsRequest request) {
			return base.Channel.updateCustomFieldsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomField[]> updateCustomFieldsAsync(Google.Api.Ads.AdManager.v201802.CustomField[] customFields) {
			Wrappers.CustomFieldService.updateCustomFieldsRequest inValue = new Wrappers.CustomFieldService.updateCustomFieldsRequest();
			inValue.customFields = customFields;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomField[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.CustomFieldServiceInterface)(this)).updateCustomFieldsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.ExchangeRateService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createExchangeRates", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createExchangeRatesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("exchangeRates")]
			public Google.Api.Ads.AdManager.v201802.ExchangeRate[] exchangeRates;

			/// <summary> Creates a new instance of the <see cref="createExchangeRatesRequest"/>
			/// class. </summary>
			public createExchangeRatesRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createExchangeRatesRequest"/>
			/// class. </summary>
			public createExchangeRatesRequest(Google.Api.Ads.AdManager.v201802.ExchangeRate[] exchangeRates) {
				this.exchangeRates = exchangeRates;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createExchangeRatesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createExchangeRatesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ExchangeRate[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createExchangeRatesResponse"/> class. </summary>
			public createExchangeRatesResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createExchangeRatesResponse"/> class. </summary>
			public createExchangeRatesResponse(Google.Api.Ads.AdManager.v201802.ExchangeRate[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateExchangeRates", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateExchangeRatesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("exchangeRates")]
			public Google.Api.Ads.AdManager.v201802.ExchangeRate[] exchangeRates;

			/// <summary> Creates a new instance of the <see cref="updateExchangeRatesRequest"/>
			/// class. </summary>
			public updateExchangeRatesRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updateExchangeRatesRequest"/>
			/// class. </summary>
			public updateExchangeRatesRequest(Google.Api.Ads.AdManager.v201802.ExchangeRate[] exchangeRates) {
				this.exchangeRates = exchangeRates;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateExchangeRatesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateExchangeRatesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ExchangeRate[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateExchangeRatesResponse"/> class. </summary>
			public updateExchangeRatesResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateExchangeRatesResponse"/> class. </summary>
			public updateExchangeRatesResponse(Google.Api.Ads.AdManager.v201802.ExchangeRate[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>An <code>ExchangeRate</code> represents a currency which is one of the <a
	/// href='Network#secondaryCurrencyCodes'>Network#secondaryCurrencyCodes</a>, and
	/// the latest exchange rate between this currency and <a
	/// href='Network#currencyCode'>Network#currencyCode</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ExchangeRate {
		private long idField;

		private bool idFieldSpecified;

		private string currencyCodeField;

		private ExchangeRateRefreshRate refreshRateField;

		private bool refreshRateFieldSpecified;

		private ExchangeRateDirection directionField;

		private bool directionFieldSpecified;

		private long exchangeRateField;

		private bool exchangeRateFieldSpecified;

		/// <summary>The ID of the <code>ExchangeRate</code>. This attribute is readonly and is
		/// assigned by Google when an exchange rate is created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The currency code that the <a href='#exchangeRate'>#exchangeRate</a> is related
		/// to. The <a href='#exchangeRate'>#exchangeRate</a> is between <a
		/// href='#currencyCode'>#currencyCode</a> and <a
		/// href='Network#currencyCode'>Network#currencyCode</a>. This attribute is required
		/// for creation and then is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string currencyCode {
			get {
				return this.currencyCodeField;
			}
			set {
				this.currencyCodeField = value;
			}
		}

		/// <summary>The refresh rate at which the exchange rate is updated. This attribute is
		/// required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public ExchangeRateRefreshRate refreshRate {
			get {
				return this.refreshRateField;
			}
			set {
				this.refreshRateField = value;
				this.refreshRateSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="refreshRate"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool refreshRateSpecified {
			get {
				return this.refreshRateFieldSpecified;
			}
			set {
				this.refreshRateFieldSpecified = value;
			}
		}

		/// <summary>The direction that the <a href='#exchangeRate'>#exchangeRate</a> is in. It
		/// determines whether the <a href='#exchangeRate'>#exchangeRate</a> is from <a
		/// href='#currencyCode'>#currencyCode</a> to <a
		/// href='Network#currencyCode'>Network#currencyCode</a>, or from <a
		/// href='Network#currencyCode'>Network#currencyCode</a> to <a
		/// href='#currencyCode'>#currencyCode</a>. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public ExchangeRateDirection direction {
			get {
				return this.directionField;
			}
			set {
				this.directionField = value;
				this.directionSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="direction"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool directionSpecified {
			get {
				return this.directionFieldSpecified;
			}
			set {
				this.directionFieldSpecified = value;
			}
		}

		/// <summary>The latest exchange rate at the <a href='#refreshRate'>#refreshRate</a> and in
		/// the <a href='#direction'>#direction</a>. The value is stored as the exchange
		/// rate times 10,000,000,000 truncated to a long. When the <a
		/// href='#refreshRate'>#refreshRate</a> is <a
		/// href='ExchangeRateRefreshRate#FIXED'>ExchangeRateRefreshRate#FIXED</a>, this
		/// attribute is required. When it is not, this attribute is readonly and is
		/// assigned by Google with the exchange rate for the latest time period.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public long exchangeRate {
			get {
				return this.exchangeRateField;
			}
			set {
				this.exchangeRateField = value;
				this.exchangeRateSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="exchangeRate" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool exchangeRateSpecified {
			get {
				return this.exchangeRateFieldSpecified;
			}
			set {
				this.exchangeRateFieldSpecified = value;
			}
		}
	}


	/// <summary>Determines at which rate the exchange rate is refreshed.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ExchangeRateRefreshRate {
		/// <summary>The exchange rate is input manually and not refreshed.
		/// </summary>
		FIXED = 0,
		/// <summary>The exchange rate will be updated automatically by Google every day using the
		/// latest day's rate.
		/// </summary>
		DAILY = 1,
		/// <summary>The exchange rate will be updated automatically by Google every month using the
		/// latest month's rate.
		/// </summary>
		MONTHLY = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Determines which direction (from which currency to which currency) the exchange
	/// rate is in.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ExchangeRateDirection {
		/// <summary>The exchange rate is from <a
		/// href='ExchangeRate#currencyCode'>ExchangeRate#currencyCode</a> to <a
		/// href='Network#currencyCode'>Network#currencyCode</a>.
		/// </summary>
		TO_NETWORK = 0,
		/// <summary>The exchange rate is from <a
		/// href='Network#currencyCode'>Network#currencyCode</a> to <a
		/// href='ExchangeRate#currencyCode'>ExchangeRate#currencyCode</a>.
		/// </summary>
		FROM_NETWORK = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Lists all errors associated with <a href='ExchangeRate'>ExchangeRate</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ExchangeRateError : ApiError {
		private ExchangeRateErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ExchangeRateErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ExchangeRateError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ExchangeRateErrorReason {
		/// <summary>The currency code is invalid and does not follow ISO 4217.
		/// </summary>
		INVALID_CURRENCY_CODE = 0,
		/// <summary>The currency code is not supported.
		/// </summary>
		UNSUPPORTED_CURRENCY_CODE = 1,
		/// <summary>The currency code already exists. When creating an exchange rate, its currency
		/// should not be associated with any existing exchange rate. When creating a list
		/// of exchange rates, there should not be two exchange rates associated with same
		/// currency.
		/// </summary>
		CURRENCY_CODE_ALREADY_EXISTS = 2,
		/// <summary>The exchange rate value is invalid. When the <a
		/// href='ExchangeRate#refreshRate'>ExchangeRate#refreshRate</a> is <a
		/// href='ExchangeRateRefreshRate#FIXED'>ExchangeRateRefreshRate#FIXED</a>, the <a
		/// href='ExchangeRate#exchangeRate'>ExchangeRate#exchangeRate</a> should be larger
		/// than 0. Otherwise it is invalid.
		/// </summary>
		INVALID_EXCHANGE_RATE = 3,
		/// <summary>The exchange rate value is not found. When the <a
		/// href='ExchangeRate#refreshRate'>ExchangeRate#refreshRate</a> is <a
		/// href='ExchangeRateRefreshRate#DAILY'>ExchangeRateRefreshRate#DAILY</a> or <a
		/// href='ExchangeRateRefreshRate#MONTHLY'>ExchangeRateRefreshRate#MONTHLY</a>, the
		/// <a href='ExchangeRate#exchangeRate'>ExchangeRate#exchangeRate</a> should be
		/// assigned by Google. It is not found if Google cannot find such an exchange rate.
		/// </summary>
		EXCHANGE_RATE_NOT_FOUND = 4,
		/// <summary>The exchange rate cannot be deleted as it is still being used by active rate
		/// cards.
		/// </summary>
		CANNOT_DELETE_EXCHANGE_RATE_WITH_ACTIVE_RATE_CARDS = 6,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 5,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ExchangeRateServiceInterface")]
	public interface ExchangeRateServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ExchangeRateService.createExchangeRatesResponse createExchangeRates(Wrappers.ExchangeRateService.createExchangeRatesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ExchangeRateService.createExchangeRatesResponse> createExchangeRatesAsync(Wrappers.ExchangeRateService.createExchangeRatesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ExchangeRatePage getExchangeRatesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ExchangeRatePage> getExchangeRatesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performExchangeRateAction(Google.Api.Ads.AdManager.v201802.ExchangeRateAction exchangeRateAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performExchangeRateActionAsync(Google.Api.Ads.AdManager.v201802.ExchangeRateAction exchangeRateAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ExchangeRateService.updateExchangeRatesResponse updateExchangeRates(Wrappers.ExchangeRateService.updateExchangeRatesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ExchangeRateService.updateExchangeRatesResponse> updateExchangeRatesAsync(Wrappers.ExchangeRateService.updateExchangeRatesRequest request);
	}


	/// <summary>Captures a page of <a href='ExchangeRate'>ExchangeRate</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ExchangeRatePage {
		private ExchangeRate[] resultsField;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		/// <summary>The collection of exchange rates contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 0)]
		public ExchangeRate[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a
	/// href='ExchangeRate'>ExchangeRate</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeleteExchangeRates))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class ExchangeRateAction {
	}


	/// <summary>The action used to delete <a href='ExchangeRate'>ExchangeRate</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeleteExchangeRates : ExchangeRateAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ExchangeRateServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ExchangeRateServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for adding, updating and retrieving <a
	/// href='ExchangeRate'>ExchangeRate</a> objects.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ExchangeRateService : AdManagerSoapClient<IExchangeRateService>, IExchangeRateService {
		/// <summary> Creates a new instance of the <see cref="ExchangeRateService"/> class.
		/// </summary>
		public ExchangeRateService() {
		}

		/// <summary> Creates a new instance of the <see cref="ExchangeRateService"/> class.
		/// </summary>
		public ExchangeRateService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="ExchangeRateService"/> class.
		/// </summary>
		public ExchangeRateService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ExchangeRateService"/> class.
		/// </summary>
		public ExchangeRateService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ExchangeRateService"/> class.
		/// </summary>
		public ExchangeRateService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ExchangeRateService.createExchangeRatesResponse Google.Api.Ads.AdManager.v201802.ExchangeRateServiceInterface.createExchangeRates(Wrappers.ExchangeRateService.createExchangeRatesRequest request) {
			return base.Channel.createExchangeRates(request);
		}

		/// <summary>Creates new <a href='ExchangeRate'>ExchangeRate</a> objects. For each exchange
		/// rate, the following fields are required: <ul> <li><a
		/// href='ExchangeRate#currencyCode'>ExchangeRate#currencyCode</a></li> <li><a
		/// href='ExchangeRate#exchangeRate'>ExchangeRate#exchangeRate</a> when <a
		/// href='ExchangeRate#refreshRate'>ExchangeRate#refreshRate</a> is <a
		/// href='ExchangeRateRefreshRate#FIXED'>ExchangeRateRefreshRate#FIXED</a></li>
		/// </ul>
		/// </summary><param name='exchangeRates'>the exchange rates to create</param>
		/// <returns>the created exchange rates with their exchange rate values filled
		/// in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ExchangeRate[] createExchangeRates(Google.Api.Ads.AdManager.v201802.ExchangeRate[] exchangeRates) {
			Wrappers.ExchangeRateService.createExchangeRatesRequest inValue = new Wrappers.ExchangeRateService.createExchangeRatesRequest();
			inValue.exchangeRates = exchangeRates;
			Wrappers.ExchangeRateService.createExchangeRatesResponse retVal = ((Google.Api.Ads.AdManager.v201802.ExchangeRateServiceInterface)(this)).createExchangeRates(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ExchangeRateService.createExchangeRatesResponse> Google.Api.Ads.AdManager.v201802.ExchangeRateServiceInterface.createExchangeRatesAsync(Wrappers.ExchangeRateService.createExchangeRatesRequest request) {
			return base.Channel.createExchangeRatesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ExchangeRate[]> createExchangeRatesAsync(Google.Api.Ads.AdManager.v201802.ExchangeRate[] exchangeRates) {
			Wrappers.ExchangeRateService.createExchangeRatesRequest inValue = new Wrappers.ExchangeRateService.createExchangeRatesRequest();
			inValue.exchangeRates = exchangeRates;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ExchangeRate[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ExchangeRateServiceInterface)(this)).createExchangeRatesAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='ExchangeRatePage'>ExchangeRatePage</a> of <a
		/// href='ExchangeRate'>ExchangeRate</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='ExchangeRate#id'>ExchangeRate#id</a></td> </tr> <tr>
		/// <td><code>currencyCode</code></td> <td><a
		/// href='ExchangeRate#currencyCode'>ExchangeRate#currencyCode</a></td> </tr> <tr>
		/// <td><code>refreshRate</code></td> <td><a
		/// href='ExchangeRate#refreshRate'>ExchangeRate#refreshRate</a></td> </tr> <tr>
		/// <td><code>direction</code></td> <td><a
		/// href='ExchangeRate#direction'>ExchangeRate#direction</a></td> </tr> <tr>
		/// <td><code>exchangeRate</code></td> <td><a
		/// href='ExchangeRate#exchangeRate'>ExchangeRate#exchangeRate</a></td> </tr>
		/// </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of exchange rates</param>
		/// <returns>the exchange rates that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ExchangeRatePage getExchangeRatesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getExchangeRatesByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ExchangeRatePage> getExchangeRatesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getExchangeRatesByStatementAsync(filterStatement);
		}

		/// <summary>Performs an action on <a href='ExchangeRate'>ExchangeRate</a> objects that
		/// satisfy the given <a href='Statement#query'>Statement#query</a>. The following
		/// fields are supported for filtering: <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>id</code></td> <td><a href='ExchangeRate#id'>ExchangeRate#id</a></td>
		/// </tr> <tr> <td><code>currencyCode</code></td> <td><a
		/// href='ExchangeRate#currencyCode'>ExchangeRate#currencyCode</a></td> </tr> <tr>
		/// <td><code>refreshRate</code></td> <td><a
		/// href='ExchangeRate#refreshRate'>ExchangeRate#refreshRate</a></td> </tr> <tr>
		/// <td><code>direction</code></td> <td><a
		/// href='ExchangeRate#direction'>ExchangeRate#direction</a></td> </tr> <tr>
		/// <td><code>exchangeRate</code></td> <td><a
		/// href='ExchangeRate#exchangeRate'>ExchangeRate#exchangeRate</a></td> </tr>
		/// </table>
		/// </summary><param name='exchangeRateAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of exchange rates</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performExchangeRateAction(Google.Api.Ads.AdManager.v201802.ExchangeRateAction exchangeRateAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performExchangeRateAction(exchangeRateAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performExchangeRateActionAsync(Google.Api.Ads.AdManager.v201802.ExchangeRateAction exchangeRateAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performExchangeRateActionAsync(exchangeRateAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ExchangeRateService.updateExchangeRatesResponse Google.Api.Ads.AdManager.v201802.ExchangeRateServiceInterface.updateExchangeRates(Wrappers.ExchangeRateService.updateExchangeRatesRequest request) {
			return base.Channel.updateExchangeRates(request);
		}

		/// <summary>Updates the specified <a href='ExchangeRate'>ExchangeRate</a> objects.
		/// </summary><param name='exchangeRates'>the exchange rates to update</param>
		/// <returns>the updated exchange rates</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ExchangeRate[] updateExchangeRates(Google.Api.Ads.AdManager.v201802.ExchangeRate[] exchangeRates) {
			Wrappers.ExchangeRateService.updateExchangeRatesRequest inValue = new Wrappers.ExchangeRateService.updateExchangeRatesRequest();
			inValue.exchangeRates = exchangeRates;
			Wrappers.ExchangeRateService.updateExchangeRatesResponse retVal = ((Google.Api.Ads.AdManager.v201802.ExchangeRateServiceInterface)(this)).updateExchangeRates(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ExchangeRateService.updateExchangeRatesResponse> Google.Api.Ads.AdManager.v201802.ExchangeRateServiceInterface.updateExchangeRatesAsync(Wrappers.ExchangeRateService.updateExchangeRatesRequest request) {
			return base.Channel.updateExchangeRatesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ExchangeRate[]> updateExchangeRatesAsync(Google.Api.Ads.AdManager.v201802.ExchangeRate[] exchangeRates) {
			Wrappers.ExchangeRateService.updateExchangeRatesRequest inValue = new Wrappers.ExchangeRateService.updateExchangeRatesRequest();
			inValue.exchangeRates = exchangeRates;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ExchangeRate[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ExchangeRateServiceInterface)(this)).updateExchangeRatesAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.ForecastService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "getDeliveryForecast", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class getDeliveryForecastRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("lineItems")]
			public Google.Api.Ads.AdManager.v201802.ProspectiveLineItem[] lineItems;

			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 1)]
			public Google.Api.Ads.AdManager.v201802.DeliveryForecastOptions forecastOptions;

			/// <summary> Creates a new instance of the <see cref="getDeliveryForecastRequest"/>
			/// class. </summary>
			public getDeliveryForecastRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="getDeliveryForecastRequest"/>
			/// class. </summary>
			public getDeliveryForecastRequest(Google.Api.Ads.AdManager.v201802.ProspectiveLineItem[] lineItems, Google.Api.Ads.AdManager.v201802.DeliveryForecastOptions forecastOptions) {
				this.lineItems = lineItems;
				this.forecastOptions = forecastOptions;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "getDeliveryForecastResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class getDeliveryForecastResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			public Google.Api.Ads.AdManager.v201802.DeliveryForecast rval;

			/// <summary> Creates a new instance of the <see
			/// cref="getDeliveryForecastResponse"/> class. </summary>
			public getDeliveryForecastResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="getDeliveryForecastResponse"/> class. </summary>
			public getDeliveryForecastResponse(Google.Api.Ads.AdManager.v201802.DeliveryForecast rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "getDeliveryForecastByIds", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class getDeliveryForecastByIdsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("lineItemIds")]
			public long[] lineItemIds;

			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 1)]
			public Google.Api.Ads.AdManager.v201802.DeliveryForecastOptions forecastOptions;

			/// <summary> Creates a new instance of the <see
			/// cref="getDeliveryForecastByIdsRequest"/> class. </summary>
			public getDeliveryForecastByIdsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="getDeliveryForecastByIdsRequest"/> class. </summary>
			public getDeliveryForecastByIdsRequest(long[] lineItemIds, Google.Api.Ads.AdManager.v201802.DeliveryForecastOptions forecastOptions) {
				this.lineItemIds = lineItemIds;
				this.forecastOptions = forecastOptions;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "getDeliveryForecastByIdsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class getDeliveryForecastByIdsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			public Google.Api.Ads.AdManager.v201802.DeliveryForecast rval;

			/// <summary> Creates a new instance of the <see
			/// cref="getDeliveryForecastByIdsResponse"/> class. </summary>
			public getDeliveryForecastByIdsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="getDeliveryForecastByIdsResponse"/> class. </summary>
			public getDeliveryForecastByIdsResponse(Google.Api.Ads.AdManager.v201802.DeliveryForecast rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>GRP forecast breakdown counts associated with a gender and age demographic.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class GrpDemographicBreakdown {
		private long availableUnitsField;

		private bool availableUnitsFieldSpecified;

		private long matchedUnitsField;

		private bool matchedUnitsFieldSpecified;

		private GrpUnitType unitTypeField;

		private bool unitTypeFieldSpecified;

		private GrpGender genderField;

		private bool genderFieldSpecified;

		private GrpAge ageField;

		private bool ageFieldSpecified;

		/// <summary>The number of units matching the demographic breakdown that can be booked
		/// without affecting the delivery of any reserved line items.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long availableUnits {
			get {
				return this.availableUnitsField;
			}
			set {
				this.availableUnitsField = value;
				this.availableUnitsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="availableUnits" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool availableUnitsSpecified {
			get {
				return this.availableUnitsFieldSpecified;
			}
			set {
				this.availableUnitsFieldSpecified = value;
			}
		}

		/// <summary>The number of units matching the demographic and matching specified targeting
		/// and delivery settings.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long matchedUnits {
			get {
				return this.matchedUnitsField;
			}
			set {
				this.matchedUnitsField = value;
				this.matchedUnitsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="matchedUnits" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool matchedUnitsSpecified {
			get {
				return this.matchedUnitsFieldSpecified;
			}
			set {
				this.matchedUnitsFieldSpecified = value;
			}
		}

		/// <summary>The <a href='GrpUnitType'>GrpUnitType</a> associated with this demographic
		/// breakdown.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public GrpUnitType unitType {
			get {
				return this.unitTypeField;
			}
			set {
				this.unitTypeField = value;
				this.unitTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="unitType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool unitTypeSpecified {
			get {
				return this.unitTypeFieldSpecified;
			}
			set {
				this.unitTypeFieldSpecified = value;
			}
		}

		/// <summary>The <a href='GrpGender'>GrpGender</a> associated with this demographic
		/// breakdown.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public GrpGender gender {
			get {
				return this.genderField;
			}
			set {
				this.genderField = value;
				this.genderSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="gender" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool genderSpecified {
			get {
				return this.genderFieldSpecified;
			}
			set {
				this.genderFieldSpecified = value;
			}
		}

		/// <summary>The <a href='GrpAge'>GrpAge</a> associated with this demographic breakdown.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public GrpAge age {
			get {
				return this.ageField;
			}
			set {
				this.ageField = value;
				this.ageSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="age" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool ageSpecified {
			get {
				return this.ageFieldSpecified;
			}
			set {
				this.ageFieldSpecified = value;
			}
		}
	}


	/// <summary>Type of unit represented in a GRP demographic breakdown.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum GrpUnitType {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		IMPRESSIONS = 1,
	}


	/// <summary>The demographic gender associated with a GRP demographic forecast.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum GrpGender {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		/// <summary>When gender is not available due to low impression levels, GRP privacy
		/// thresholds are activated and prevent us from specifying gender.
		/// </summary>
		GENDER_UNKNOWN = 1,
		GENDER_FEMALE = 2,
		GENDER_MALE = 3,
	}


	/// <summary>The age range associated with a GRP demographic forecast.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum GrpAge {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		/// <summary>When the age range is not available due to low impression levels, GRP privacy
		/// thresholds are activated and prevent us from specifying age.
		/// </summary>
		AGE_UNKNOWN = 1,
		AGE_0_TO_17 = 2,
		AGE_18_TO_24 = 3,
		AGE_25_TO_34 = 4,
		AGE_35_TO_44 = 5,
		AGE_45_TO_54 = 6,
		AGE_55_TO_64 = 7,
		AGE_65_PLUS = 8,
		AGE_18_TO_49 = 9,
		AGE_21_TO_34 = 10,
		AGE_21_TO_49 = 11,
		AGE_21_PLUS = 12,
		AGE_25_TO_49 = 13,
		AGE_21_TO_44 = 14,
		AGE_21_TO_54 = 15,
		AGE_21_TO_64 = 16,
		AGE_35_TO_49 = 17,
	}


	/// <summary>A view of the forecast in terms of an alternative unit type. <p>For example, a
	/// forecast for an impressions goal may include this to express the matched,
	/// available, and possible viewable impressions.</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AlternativeUnitTypeForecast {
		private UnitType unitTypeField;

		private bool unitTypeFieldSpecified;

		private long matchedUnitsField;

		private bool matchedUnitsFieldSpecified;

		private long availableUnitsField;

		private bool availableUnitsFieldSpecified;

		private long possibleUnitsField;

		private bool possibleUnitsFieldSpecified;

		/// <summary>The alternative unit type being presented.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public UnitType unitType {
			get {
				return this.unitTypeField;
			}
			set {
				this.unitTypeField = value;
				this.unitTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="unitType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool unitTypeSpecified {
			get {
				return this.unitTypeFieldSpecified;
			}
			set {
				this.unitTypeFieldSpecified = value;
			}
		}

		/// <summary>The number of units, defined by <a href='#unitType'>#unitType</a>, that match
		/// the specified targeting and delivery settings.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long matchedUnits {
			get {
				return this.matchedUnitsField;
			}
			set {
				this.matchedUnitsField = value;
				this.matchedUnitsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="matchedUnits" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool matchedUnitsSpecified {
			get {
				return this.matchedUnitsFieldSpecified;
			}
			set {
				this.matchedUnitsFieldSpecified = value;
			}
		}

		/// <summary>The number of units, defined by <a href='#unitType'>#unitType</a>, that can be
		/// booked without affecting the delivery of any reserved line items. Exceeding this
		/// value will not cause an overbook, but lower-priority line items may not run.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public long availableUnits {
			get {
				return this.availableUnitsField;
			}
			set {
				this.availableUnitsField = value;
				this.availableUnitsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="availableUnits" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool availableUnitsSpecified {
			get {
				return this.availableUnitsFieldSpecified;
			}
			set {
				this.availableUnitsFieldSpecified = value;
			}
		}

		/// <summary>The maximum number of units, defined by <a href='#unitType'>#unitType</a>, that
		/// could be booked by taking inventory away from lower-priority line items.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public long possibleUnits {
			get {
				return this.possibleUnitsField;
			}
			set {
				this.possibleUnitsField = value;
				this.possibleUnitsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="possibleUnits" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool possibleUnitsSpecified {
			get {
				return this.possibleUnitsFieldSpecified;
			}
			set {
				this.possibleUnitsFieldSpecified = value;
			}
		}
	}


	/// <summary>Indicates the type of unit used for defining a reservation. The <a
	/// href='CostType'>CostType</a> can differ from the <a href='UnitType'>UnitType</a>
	/// - an ad can have an impression goal, but be billed by its click. Usually <a
	/// href='CostType'>CostType</a> and <a href='UnitType'>UnitType</a> will refer to
	/// the same unit.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum UnitType {
		/// <summary>The number of impressions served by creatives associated with the line item.
		/// Line items of all <a href='LineItemType'>LineItemType</a> support this
		/// <code>UnitType</code>.
		/// </summary>
		IMPRESSIONS = 0,
		/// <summary>The number of clicks reported by creatives associated with the line item. The <a
		/// href='LineItem#lineItemType'>LineItem#lineItemType</a> must be <a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a>, <a
		/// href='LineItemType#BULK'>LineItemType#BULK</a> or <a
		/// href='LineItemType#PRICE_PRIORITY'>LineItemType#PRICE_PRIORITY</a>.
		/// </summary>
		CLICKS = 1,
		/// <summary>The number of click-through Cost-Per-Action (CPA) conversions from creatives
		/// associated with the line item. This is only supported as secondary goal and the
		/// <a href='LineItem#costType'>LineItem#costType</a> must be <a
		/// href='CostType#CPA'>CostType#CPA</a>.
		/// </summary>
		CLICK_THROUGH_CPA_CONVERSIONS = 2,
		/// <summary>The number of view-through Cost-Per-Action (CPA) conversions from creatives
		/// associated with the line item. This is only supported as secondary goal and the
		/// <a href='LineItem#costType'>LineItem#costType</a> must be <a
		/// href='CostType#CPA'>CostType#CPA</a>.
		/// </summary>
		VIEW_THROUGH_CPA_CONVERSIONS = 3,
		/// <summary>The number of total Cost-Per-Action (CPA) conversions from creatives associated
		/// with the line item. This is only supported as secondary goal and the <a
		/// href='LineItem#costType'>LineItem#costType</a> must be <a
		/// href='CostType#CPA'>CostType#CPA</a>.
		/// </summary>
		TOTAL_CPA_CONVERSIONS = 4,
		/// <summary>The number of viewable impressions reported by creatives associated with the
		/// line item. The <a href='LineItem#lineItemType'>LineItem#lineItemType</a> must be
		/// <a href='LineItemType#STANDARD'>LineItemType#STANDARD</a>.
		/// </summary>
		VIEWABLE_IMPRESSIONS = 6,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 5,
	}


	/// <summary>Describes contending line items for a <a href='Forecast'>Forecast</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ContendingLineItem {
		private long lineItemIdField;

		private bool lineItemIdFieldSpecified;

		private long contendingImpressionsField;

		private bool contendingImpressionsFieldSpecified;

		/// <summary>The <a href='LineItem#id'>Id</a> of the contending line item.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long lineItemId {
			get {
				return this.lineItemIdField;
			}
			set {
				this.lineItemIdField = value;
				this.lineItemIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="lineItemId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lineItemIdSpecified {
			get {
				return this.lineItemIdFieldSpecified;
			}
			set {
				this.lineItemIdFieldSpecified = value;
			}
		}

		/// <summary>Number of impressions contended for by both the forecasted line item and this
		/// line item, but served to this line item in the forecast simulation.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long contendingImpressions {
			get {
				return this.contendingImpressionsField;
			}
			set {
				this.contendingImpressionsField = value;
				this.contendingImpressionsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="contendingImpressions" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool contendingImpressionsSpecified {
			get {
				return this.contendingImpressionsFieldSpecified;
			}
			set {
				this.contendingImpressionsFieldSpecified = value;
			}
		}
	}


	/// <summary>A single targeting criteria breakdown result.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class TargetingCriteriaBreakdown {
		private TargetingDimension targetingDimensionField;

		private bool targetingDimensionFieldSpecified;

		private long targetingCriteriaIdField;

		private bool targetingCriteriaIdFieldSpecified;

		private string targetingCriteriaNameField;

		private bool excludedField;

		private bool excludedFieldSpecified;

		private long availableUnitsField;

		private bool availableUnitsFieldSpecified;

		private long matchedUnitsField;

		private bool matchedUnitsFieldSpecified;

		/// <summary>The dimension of this breakdown
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public TargetingDimension targetingDimension {
			get {
				return this.targetingDimensionField;
			}
			set {
				this.targetingDimensionField = value;
				this.targetingDimensionSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="targetingDimension" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool targetingDimensionSpecified {
			get {
				return this.targetingDimensionFieldSpecified;
			}
			set {
				this.targetingDimensionFieldSpecified = value;
			}
		}

		/// <summary>The unique ID of the targeting criteria.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long targetingCriteriaId {
			get {
				return this.targetingCriteriaIdField;
			}
			set {
				this.targetingCriteriaIdField = value;
				this.targetingCriteriaIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="targetingCriteriaId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool targetingCriteriaIdSpecified {
			get {
				return this.targetingCriteriaIdFieldSpecified;
			}
			set {
				this.targetingCriteriaIdFieldSpecified = value;
			}
		}

		/// <summary>The name of the targeting criteria.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string targetingCriteriaName {
			get {
				return this.targetingCriteriaNameField;
			}
			set {
				this.targetingCriteriaNameField = value;
			}
		}

		/// <summary>When true, the breakdown is negative.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public bool excluded {
			get {
				return this.excludedField;
			}
			set {
				this.excludedField = value;
				this.excludedSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="excluded"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool excludedSpecified {
			get {
				return this.excludedFieldSpecified;
			}
			set {
				this.excludedFieldSpecified = value;
			}
		}

		/// <summary>The available units for this breakdown.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public long availableUnits {
			get {
				return this.availableUnitsField;
			}
			set {
				this.availableUnitsField = value;
				this.availableUnitsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="availableUnits" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool availableUnitsSpecified {
			get {
				return this.availableUnitsFieldSpecified;
			}
			set {
				this.availableUnitsFieldSpecified = value;
			}
		}

		/// <summary>The matched units for this breakdown.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public long matchedUnits {
			get {
				return this.matchedUnitsField;
			}
			set {
				this.matchedUnitsField = value;
				this.matchedUnitsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="matchedUnits" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool matchedUnitsSpecified {
			get {
				return this.matchedUnitsFieldSpecified;
			}
			set {
				this.matchedUnitsFieldSpecified = value;
			}
		}
	}


	/// <summary>Targeting dimension of targeting breakdowns.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum TargetingDimension {
		CUSTOM_CRITERIA = 0,
		GEOGRAPHY = 1,
		BROWSER = 2,
		BROWSER_LANGUAGE = 3,
		BANDWIDTH_GROUP = 4,
		OPERATING_SYSTEM = 5,
		USER_DOMAIN = 6,
		CONTENT = 7,
		VIDEO_POSITION = 8,
		AD_SIZE = 9,
		AD_UNIT = 10,
		PLACEMENT = 11,
		MOBILE_CARRIER = 12,
		DEVICE_CAPABILITY = 13,
		DEVICE_CATEGORY = 14,
		DEVICE_MANUFACTURER = 15,
		MOBILE_APPLICATION = 17,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 16,
	}


	/// <summary>Describes predicted inventory availability for a <a
	/// href='ProspectiveLineItem'>ProspectiveLineItem</a>. <p>Inventory has three
	/// threshold values along a line of possible inventory. From least to most, these
	/// are:</p> <ul class="noindent"> <li>Available units -- How many units can be
	/// booked without affecting any other line items. Booking more than this number can
	/// cause lower and same priority line items to underdeliver.</li> <li>Possible
	/// units -- How many units can be booked without affecting any higher priority line
	/// items. Booking more than this number can cause the line item to
	/// underdeliver.</li> <li>Matched (forecast) units -- How many units satisfy all
	/// specified criteria. </li> </ul> <p>Underdelivery is caused by overbooking.
	/// However, if more impressions are served than are predicted, the extra available
	/// inventory might enable all inventory guarantees to be met without
	/// overbooking.</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AvailabilityForecast {
		private long lineItemIdField;

		private bool lineItemIdFieldSpecified;

		private long orderIdField;

		private bool orderIdFieldSpecified;

		private UnitType unitTypeField;

		private bool unitTypeFieldSpecified;

		private long availableUnitsField;

		private bool availableUnitsFieldSpecified;

		private long deliveredUnitsField;

		private bool deliveredUnitsFieldSpecified;

		private long matchedUnitsField;

		private bool matchedUnitsFieldSpecified;

		private long possibleUnitsField;

		private bool possibleUnitsFieldSpecified;

		private long reservedUnitsField;

		private bool reservedUnitsFieldSpecified;

		private TargetingCriteriaBreakdown[] targetingCriteriaBreakdownsField;

		private ContendingLineItem[] contendingLineItemsField;

		private AlternativeUnitTypeForecast[] alternativeUnitTypeForecastsField;

		private GrpDemographicBreakdown[] demographicBreakdownsField;

		/// <summary>Uniquely identifies this availability forecast. This value is read-only and is
		/// assigned by Google when the forecast is created. The attribute will be either
		/// the ID of the <a href='LineItem'>LineItem</a> object it represents, or
		/// <code>null</code> if the forecast represents a prospective line item.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long lineItemId {
			get {
				return this.lineItemIdField;
			}
			set {
				this.lineItemIdField = value;
				this.lineItemIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="lineItemId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lineItemIdSpecified {
			get {
				return this.lineItemIdFieldSpecified;
			}
			set {
				this.lineItemIdFieldSpecified = value;
			}
		}

		/// <summary>The unique ID for the <a href='Order'>Order</a> object that this line item
		/// belongs to, or <code>null</code> if the forecast represents a prospective line
		/// item without an <a href='LineItem#orderId'>LineItem#orderId</a> set.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long orderId {
			get {
				return this.orderIdField;
			}
			set {
				this.orderIdField = value;
				this.orderIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="orderId" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool orderIdSpecified {
			get {
				return this.orderIdFieldSpecified;
			}
			set {
				this.orderIdFieldSpecified = value;
			}
		}

		/// <summary>The unit with which the goal or cap of the <a href='LineItem'>LineItem</a> is
		/// defined. Will be the same value as <a href='Goal#unitType'>Goal#unitType</a> for
		/// both a set line item or a prospective one.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public UnitType unitType {
			get {
				return this.unitTypeField;
			}
			set {
				this.unitTypeField = value;
				this.unitTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="unitType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool unitTypeSpecified {
			get {
				return this.unitTypeFieldSpecified;
			}
			set {
				this.unitTypeFieldSpecified = value;
			}
		}

		/// <summary>The number of units, defined by <a href='Goal#unitType'>Goal#unitType</a>, that
		/// can be booked without affecting the delivery of any reserved line items.
		/// Exceeding this value will not cause an overbook, but lower priority line items
		/// may not run.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public long availableUnits {
			get {
				return this.availableUnitsField;
			}
			set {
				this.availableUnitsField = value;
				this.availableUnitsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="availableUnits" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool availableUnitsSpecified {
			get {
				return this.availableUnitsFieldSpecified;
			}
			set {
				this.availableUnitsFieldSpecified = value;
			}
		}

		/// <summary>The number of units, defined by <a href='Goal#unitType'>Goal#unitType</a>, that
		/// have already been served if the reservation is already running.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public long deliveredUnits {
			get {
				return this.deliveredUnitsField;
			}
			set {
				this.deliveredUnitsField = value;
				this.deliveredUnitsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="deliveredUnits" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool deliveredUnitsSpecified {
			get {
				return this.deliveredUnitsFieldSpecified;
			}
			set {
				this.deliveredUnitsFieldSpecified = value;
			}
		}

		/// <summary>The number of units, defined by <a href='Goal#unitType'>Goal#unitType</a>, that
		/// match the specified targeting and delivery settings.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public long matchedUnits {
			get {
				return this.matchedUnitsField;
			}
			set {
				this.matchedUnitsField = value;
				this.matchedUnitsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="matchedUnits" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool matchedUnitsSpecified {
			get {
				return this.matchedUnitsFieldSpecified;
			}
			set {
				this.matchedUnitsFieldSpecified = value;
			}
		}

		/// <summary>The maximum number of units, defined by <a
		/// href='Goal#unitType'>Goal#unitType</a>, that could be booked by taking inventory
		/// away from lower priority line items and some same priority line items. <p>Please
		/// note: booking this number may cause lower priority line items and some same
		/// priority line items to underdeliver.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public long possibleUnits {
			get {
				return this.possibleUnitsField;
			}
			set {
				this.possibleUnitsField = value;
				this.possibleUnitsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="possibleUnits" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool possibleUnitsSpecified {
			get {
				return this.possibleUnitsFieldSpecified;
			}
			set {
				this.possibleUnitsFieldSpecified = value;
			}
		}

		/// <summary>The number of reserved units, defined by <a
		/// href='Goal#unitType'>Goal#unitType</a>, requested. This can be an absolute or
		/// percentage value.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public long reservedUnits {
			get {
				return this.reservedUnitsField;
			}
			set {
				this.reservedUnitsField = value;
				this.reservedUnitsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="reservedUnits" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reservedUnitsSpecified {
			get {
				return this.reservedUnitsFieldSpecified;
			}
			set {
				this.reservedUnitsFieldSpecified = value;
			}
		}

		/// <summary>The forecast result broken down by the targeting of the forecasted line item.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("targetingCriteriaBreakdowns", Order = 8)]
		public TargetingCriteriaBreakdown[] targetingCriteriaBreakdowns {
			get {
				return this.targetingCriteriaBreakdownsField;
			}
			set {
				this.targetingCriteriaBreakdownsField = value;
			}
		}

		/// <summary>List of <a href='ContendingLineItem'>contending line items</a> for this
		/// forecast.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("contendingLineItems", Order = 9)]
		public ContendingLineItem[] contendingLineItems {
			get {
				return this.contendingLineItemsField;
			}
			set {
				this.contendingLineItemsField = value;
			}
		}

		/// <summary>Views of this forecast, with alternative unit types.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("alternativeUnitTypeForecasts", Order = 10)]
		public AlternativeUnitTypeForecast[] alternativeUnitTypeForecasts {
			get {
				return this.alternativeUnitTypeForecastsField;
			}
			set {
				this.alternativeUnitTypeForecastsField = value;
			}
		}

		/// <summary>The forecast result broken down by demographics.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("demographicBreakdowns", Order = 11)]
		public GrpDemographicBreakdown[] demographicBreakdowns {
			get {
				return this.demographicBreakdownsField;
			}
			set {
				this.demographicBreakdownsField = value;
			}
		}
	}


	/// <summary>Forecasting options for line item availability forecasts.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AvailabilityForecastOptions {
		private bool includeTargetingCriteriaBreakdownField;

		private bool includeTargetingCriteriaBreakdownFieldSpecified;

		private bool includeContendingLineItemsField;

		private bool includeContendingLineItemsFieldSpecified;

		/// <summary>When specified, forecast result for the availability line item will also include
		/// breakdowns by its targeting in <a
		/// href='AvailabilityForecast#targetingCriteriaBreakdowns'>AvailabilityForecast#targetingCriteriaBreakdowns</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool includeTargetingCriteriaBreakdown {
			get {
				return this.includeTargetingCriteriaBreakdownField;
			}
			set {
				this.includeTargetingCriteriaBreakdownField = value;
				this.includeTargetingCriteriaBreakdownSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="includeTargetingCriteriaBreakdown" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool includeTargetingCriteriaBreakdownSpecified {
			get {
				return this.includeTargetingCriteriaBreakdownFieldSpecified;
			}
			set {
				this.includeTargetingCriteriaBreakdownFieldSpecified = value;
			}
		}

		/// <summary>When specified, the forecast result for the availability line item will also
		/// include contending line items in <a
		/// href='AvailabilityForecast#contendingLineItems'>AvailabilityForecast#contendingLineItems</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public bool includeContendingLineItems {
			get {
				return this.includeContendingLineItemsField;
			}
			set {
				this.includeContendingLineItemsField = value;
				this.includeContendingLineItemsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="includeContendingLineItems" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool includeContendingLineItemsSpecified {
			get {
				return this.includeContendingLineItemsFieldSpecified;
			}
			set {
				this.includeContendingLineItemsFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents the creative targeting criteria for a <a
	/// href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreativeTargeting {
		private string nameField;

		private Targeting targetingField;

		/// <summary>The name of this creative targeting. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The <a href='Targeting'>Targeting</a> criteria of this creative targeting. This
		/// attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public Targeting targeting {
			get {
				return this.targetingField;
			}
			set {
				this.targetingField = value;
			}
		}
	}


	/// <summary>Contains targeting criteria for <a href='LineItem'>LineItem</a> objects. See <a
	/// href='LineItem#targeting'>LineItem#targeting</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Targeting {
		private GeoTargeting geoTargetingField;

		private InventoryTargeting inventoryTargetingField;

		private DayPartTargeting dayPartTargetingField;

		private TechnologyTargeting technologyTargetingField;

		private CustomCriteriaSet customTargetingField;

		private UserDomainTargeting userDomainTargetingField;

		private ContentTargeting contentTargetingField;

		private VideoPositionTargeting videoPositionTargetingField;

		private MobileApplicationTargeting mobileApplicationTargetingField;

		/// <summary>Specifies what geographical locations are targeted by the <a
		/// href='LineItem'>LineItem</a>. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public GeoTargeting geoTargeting {
			get {
				return this.geoTargetingField;
			}
			set {
				this.geoTargetingField = value;
			}
		}

		/// <summary>Specifies what inventory is targeted by the <a href='LineItem'>LineItem</a>.
		/// This attribute is required. The line item must target at least one ad unit or
		/// placement.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public InventoryTargeting inventoryTargeting {
			get {
				return this.inventoryTargetingField;
			}
			set {
				this.inventoryTargetingField = value;
			}
		}

		/// <summary>Specifies the days of the week and times that are targeted by the <a
		/// href='LineItem'>LineItem</a>. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public DayPartTargeting dayPartTargeting {
			get {
				return this.dayPartTargetingField;
			}
			set {
				this.dayPartTargetingField = value;
			}
		}

		/// <summary>Specifies the browsing technologies that are targeted by the <a
		/// href='LineItem'>LineItem</a>. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public TechnologyTargeting technologyTargeting {
			get {
				return this.technologyTargetingField;
			}
			set {
				this.technologyTargetingField = value;
			}
		}

		/// <summary>Specifies the collection of custom criteria that is targeted by the <a
		/// href='LineItem'>LineItem</a>. <p>Once the <a href='LineItem'>LineItem</a> is
		/// updated or modified with custom targeting, the server may return a normalized,
		/// but equivalent representation of the custom targeting expression.</p>
		/// <p><code>customTargeting</code> will have up to three levels of expressions
		/// including itself.</p> <p>The top level <code>CustomCriteriaSet</code> i.e. the
		/// <code></code> object can only contain a <a
		/// href='CustomCriteriaSet.LogicalOperator#OR'>CustomCriteriaSet.LogicalOperator#OR</a>
		/// of all its children.</p> <p>The second level of <code>CustomCriteriaSet</code>
		/// objects can only contain <a
		/// href='CustomCriteriaSet.LogicalOperator#AND'>CustomCriteriaSet.LogicalOperator#AND</a>
		/// of all their children. If a <a href='CustomCriteria'>CustomCriteria</a> is
		/// placed on this level, the server will wrap it in a <a
		/// href='CustomCriteriaSet'>CustomCriteriaSet</a>.</p> <p>The third level can only
		/// comprise of <a href='CustomCriteria'>CustomCriteria</a> objects.</p> <p>The
		/// resulting custom targeting tree would be of the form:</p> <br /> <img
		/// src="https://chart.apis.google.com/chart?cht=gv&amp;chl=digraph{customTargeting_LogicalOperator_OR-%3ECustomCriteriaSet_LogicalOperator_AND_1-%3ECustomCriteria_1;CustomCriteriaSet_LogicalOperator_AND_1-%3Eellipsis1;customTargeting_LogicalOperator_OR-%3Eellipsis2;ellipsis1[label=%22...%22,shape=none,fontsize=32];ellipsis2[label=%22...%22,shape=none,fontsize=32]}&amp;chs=450x200"/>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public CustomCriteriaSet customTargeting {
			get {
				return this.customTargetingField;
			}
			set {
				this.customTargetingField = value;
			}
		}

		/// <summary>Specifies the domains or subdomains that are targeted or excluded by the <a
		/// href='LineItem'>LineItem</a>. Users visiting from an IP address associated with
		/// those domains will be targeted or excluded. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public UserDomainTargeting userDomainTargeting {
			get {
				return this.userDomainTargetingField;
			}
			set {
				this.userDomainTargetingField = value;
			}
		}

		/// <summary>Specifies the video categories and individual videos targeted by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public ContentTargeting contentTargeting {
			get {
				return this.contentTargetingField;
			}
			set {
				this.contentTargetingField = value;
			}
		}

		/// <summary>Specifies targeting against video position types.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public VideoPositionTargeting videoPositionTargeting {
			get {
				return this.videoPositionTargetingField;
			}
			set {
				this.videoPositionTargetingField = value;
			}
		}

		/// <summary>Specifies targeting against mobile applications.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public MobileApplicationTargeting mobileApplicationTargeting {
			get {
				return this.mobileApplicationTargetingField;
			}
			set {
				this.mobileApplicationTargetingField = value;
			}
		}
	}


	/// <summary>Provides line items the ability to target geographical locations. By default,
	/// line items target all countries and their subdivisions. With geographical
	/// targeting, you can target line items to specific countries, regions, metro
	/// areas, and cities. You can also exclude the same. <p>The following rules apply
	/// for geographical targeting:</p> <ul> <li>You cannot target and exclude the same
	/// location.</li> <li>You cannot target a child whose parent has been excluded. For
	/// example, if the state of Illinois has been excluded, then you cannot target
	/// Chicago.</li> <li>You must not target a location if you are also targeting its
	/// parent. For example, if you are targeting New York City, you must not have the
	/// state of New York as one of the targeted locations.</li> <li>You cannot
	/// explicitly define inclusions or exclusions that are already implicit. For
	/// example, if you explicitly include California, you implicitly exclude all other
	/// states. You therefore cannot explicitly exclude Florida, because it is already
	/// implicitly excluded. Conversely if you explicitly exclude Florida, you cannot
	/// excplicitly include California.</li> </ul>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class GeoTargeting {
		private Location[] targetedLocationsField;

		private Location[] excludedLocationsField;

		/// <summary>The geographical locations being targeted by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("targetedLocations", Order = 0)]
		public Location[] targetedLocations {
			get {
				return this.targetedLocationsField;
			}
			set {
				this.targetedLocationsField = value;
			}
		}

		/// <summary>The geographical locations being excluded by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("excludedLocations", Order = 1)]
		public Location[] excludedLocations {
			get {
				return this.excludedLocationsField;
			}
			set {
				this.excludedLocationsField = value;
			}
		}
	}


	/// <summary>A <a href='Location'>Location</a> represents a geographical entity that can be
	/// targeted. If a location type is not available because of the API version you are
	/// using, the location will be represented as just the base class, otherwise it
	/// will be sub-classed correctly.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Location {
		private long idField;

		private bool idFieldSpecified;

		private string typeField;

		private int canonicalParentIdField;

		private bool canonicalParentIdFieldSpecified;

		private string displayNameField;

		/// <summary>Uniquely identifies each <code>Location</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The location type for this geographical entity (ex. "COUNTRY", "CITY", "STATE",
		/// "COUNTY", etc.)
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string type {
			get {
				return this.typeField;
			}
			set {
				this.typeField = value;
			}
		}

		/// <summary>The nearest location parent's ID for this geographical entity.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public int canonicalParentId {
			get {
				return this.canonicalParentIdField;
			}
			set {
				this.canonicalParentIdField = value;
				this.canonicalParentIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="canonicalParentId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool canonicalParentIdSpecified {
			get {
				return this.canonicalParentIdFieldSpecified;
			}
			set {
				this.canonicalParentIdFieldSpecified = value;
			}
		}

		/// <summary>The localized name of the geographical entity.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string displayName {
			get {
				return this.displayNameField;
			}
			set {
				this.displayNameField = value;
			}
		}
	}


	/// <summary>A collection of targeted and excluded ad units and placements.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class InventoryTargeting {
		private AdUnitTargeting[] targetedAdUnitsField;

		private AdUnitTargeting[] excludedAdUnitsField;

		private long[] targetedPlacementIdsField;

		/// <summary>A list of targeted <a href='AdUnitTargeting'>AdUnitTargeting</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("targetedAdUnits", Order = 0)]
		public AdUnitTargeting[] targetedAdUnits {
			get {
				return this.targetedAdUnitsField;
			}
			set {
				this.targetedAdUnitsField = value;
			}
		}

		/// <summary>A list of excluded <a href='AdUnitTargeting'>AdUnitTargeting</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("excludedAdUnits", Order = 1)]
		public AdUnitTargeting[] excludedAdUnits {
			get {
				return this.excludedAdUnitsField;
			}
			set {
				this.excludedAdUnitsField = value;
			}
		}

		/// <summary>A list of targeted <a href='Placement'>Placement</a> ids.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("targetedPlacementIds", Order = 2)]
		public long[] targetedPlacementIds {
			get {
				return this.targetedPlacementIdsField;
			}
			set {
				this.targetedPlacementIdsField = value;
			}
		}
	}


	/// <summary>Represents targeted or excluded ad units.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdUnitTargeting {
		private string adUnitIdField;

		private bool includeDescendantsField;

		private bool includeDescendantsFieldSpecified;

		/// <summary>Included or excluded ad unit id.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string adUnitId {
			get {
				return this.adUnitIdField;
			}
			set {
				this.adUnitIdField = value;
			}
		}

		/// <summary>Whether or not all descendants are included (or excluded) as part of including
		/// (or excluding) this ad unit. By default, the value is <code>true</code> which
		/// means targeting this ad unit will target all of its descendants.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public bool includeDescendants {
			get {
				return this.includeDescendantsField;
			}
			set {
				this.includeDescendantsField = value;
				this.includeDescendantsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="includeDescendants" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool includeDescendantsSpecified {
			get {
				return this.includeDescendantsFieldSpecified;
			}
			set {
				this.includeDescendantsFieldSpecified = value;
			}
		}
	}


	/// <summary>Modify the delivery times of line items for particular days of the week. By
	/// default, line items are served at all days and times.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DayPartTargeting {
		private DayPart[] dayPartsField;

		private DeliveryTimeZone timeZoneField;

		private bool timeZoneFieldSpecified;

		/// <summary>Specifies days of the week and times at which a <code>LineItem</code> will be
		/// delivered. <p>If targeting all days and times, this value will be ignored.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("dayParts", Order = 0)]
		public DayPart[] dayParts {
			get {
				return this.dayPartsField;
			}
			set {
				this.dayPartsField = value;
			}
		}

		/// <summary>Specifies the time zone to be used for delivering <a
		/// href='LineItem'>LineItem</a> objects. This attribute is optional and defaults to
		/// <a href='DeliveryTimeZone#BROWSER'>DeliveryTimeZone#BROWSER</a>. <p>Setting this
		/// has no effect if targeting all days and times.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public DeliveryTimeZone timeZone {
			get {
				return this.timeZoneField;
			}
			set {
				this.timeZoneField = value;
				this.timeZoneSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="timeZone"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool timeZoneSpecified {
			get {
				return this.timeZoneFieldSpecified;
			}
			set {
				this.timeZoneFieldSpecified = value;
			}
		}
	}


	/// <summary><code>DayPart</code> represents a time-period within a day of the week which is
	/// targeted by a <a href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DayPart {
		private DayOfWeek dayOfWeekField;

		private bool dayOfWeekFieldSpecified;

		private TimeOfDay startTimeField;

		private TimeOfDay endTimeField;

		/// <summary>Day of the week the target applies to. This field is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public DayOfWeek dayOfWeek {
			get {
				return this.dayOfWeekField;
			}
			set {
				this.dayOfWeekField = value;
				this.dayOfWeekSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="dayOfWeek"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool dayOfWeekSpecified {
			get {
				return this.dayOfWeekFieldSpecified;
			}
			set {
				this.dayOfWeekFieldSpecified = value;
			}
		}

		/// <summary>Represents the start time of the targeted period (inclusive).
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public TimeOfDay startTime {
			get {
				return this.startTimeField;
			}
			set {
				this.startTimeField = value;
			}
		}

		/// <summary>Represents the end time of the targeted period (exclusive).
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public TimeOfDay endTime {
			get {
				return this.endTimeField;
			}
			set {
				this.endTimeField = value;
			}
		}
	}


	/// <summary>Days of the week.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum DayOfWeek {
		/// <summary>The day of week named Monday.
		/// </summary>
		MONDAY = 0,
		/// <summary>The day of week named Tuesday.
		/// </summary>
		TUESDAY = 1,
		/// <summary>The day of week named Wednesday.
		/// </summary>
		WEDNESDAY = 2,
		/// <summary>The day of week named Thursday.
		/// </summary>
		THURSDAY = 3,
		/// <summary>The day of week named Friday.
		/// </summary>
		FRIDAY = 4,
		/// <summary>The day of week named Saturday.
		/// </summary>
		SATURDAY = 5,
		/// <summary>The day of week named Sunday.
		/// </summary>
		SUNDAY = 6,
	}


	/// <summary>Represents a specific time in a day.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class TimeOfDay {
		private int hourField;

		private bool hourFieldSpecified;

		private MinuteOfHour minuteField;

		private bool minuteFieldSpecified;

		/// <summary>Hour in 24 hour time (0..24). This field must be between 0 and 24, inclusive.
		/// This field is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int hour {
			get {
				return this.hourField;
			}
			set {
				this.hourField = value;
				this.hourSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="hour" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool hourSpecified {
			get {
				return this.hourFieldSpecified;
			}
			set {
				this.hourFieldSpecified = value;
			}
		}

		/// <summary>Minutes in an hour. Currently, only 0, 15, 30, and 45 are supported. This field
		/// is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public MinuteOfHour minute {
			get {
				return this.minuteField;
			}
			set {
				this.minuteField = value;
				this.minuteSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="minute" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool minuteSpecified {
			get {
				return this.minuteFieldSpecified;
			}
			set {
				this.minuteFieldSpecified = value;
			}
		}
	}


	/// <summary>Minutes in an hour. Currently, only 0, 15, 30, and 45 are supported. This field
	/// is required.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum MinuteOfHour {
		/// <summary>Zero minutes past hour.
		/// </summary>
		ZERO = 0,
		/// <summary>Fifteen minutes past hour.
		/// </summary>
		FIFTEEN = 1,
		/// <summary>Thirty minutes past hour.
		/// </summary>
		THIRTY = 2,
		/// <summary>Forty-five minutes past hour.
		/// </summary>
		FORTY_FIVE = 3,
	}


	/// <summary>Represents the time zone to be used for <a
	/// href='DayPartTargeting'>DayPartTargeting</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum DeliveryTimeZone {
		/// <summary>Use the time zone of the publisher.
		/// </summary>
		PUBLISHER = 0,
		/// <summary>Use the time zone of the browser.
		/// </summary>
		BROWSER = 1,
	}


	/// <summary>Provides <a href='LineItem'>LineItem</a> objects the ability to target or
	/// exclude technologies.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class TechnologyTargeting {
		private BandwidthGroupTargeting bandwidthGroupTargetingField;

		private BrowserTargeting browserTargetingField;

		private BrowserLanguageTargeting browserLanguageTargetingField;

		private DeviceCapabilityTargeting deviceCapabilityTargetingField;

		private DeviceCategoryTargeting deviceCategoryTargetingField;

		private DeviceManufacturerTargeting deviceManufacturerTargetingField;

		private MobileCarrierTargeting mobileCarrierTargetingField;

		private MobileDeviceTargeting mobileDeviceTargetingField;

		private MobileDeviceSubmodelTargeting mobileDeviceSubmodelTargetingField;

		private OperatingSystemTargeting operatingSystemTargetingField;

		private OperatingSystemVersionTargeting operatingSystemVersionTargetingField;

		/// <summary>The bandwidth groups being targeted by the <a href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public BandwidthGroupTargeting bandwidthGroupTargeting {
			get {
				return this.bandwidthGroupTargetingField;
			}
			set {
				this.bandwidthGroupTargetingField = value;
			}
		}

		/// <summary>The browsers being targeted by the <a href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public BrowserTargeting browserTargeting {
			get {
				return this.browserTargetingField;
			}
			set {
				this.browserTargetingField = value;
			}
		}

		/// <summary>The languages of browsers being targeted by the <a href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public BrowserLanguageTargeting browserLanguageTargeting {
			get {
				return this.browserLanguageTargetingField;
			}
			set {
				this.browserLanguageTargetingField = value;
			}
		}

		/// <summary>The device capabilities being targeted by the <a href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public DeviceCapabilityTargeting deviceCapabilityTargeting {
			get {
				return this.deviceCapabilityTargetingField;
			}
			set {
				this.deviceCapabilityTargetingField = value;
			}
		}

		/// <summary>The device categories being targeted by the <a href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public DeviceCategoryTargeting deviceCategoryTargeting {
			get {
				return this.deviceCategoryTargetingField;
			}
			set {
				this.deviceCategoryTargetingField = value;
			}
		}

		/// <summary>The device manufacturers being targeted by the <a href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public DeviceManufacturerTargeting deviceManufacturerTargeting {
			get {
				return this.deviceManufacturerTargetingField;
			}
			set {
				this.deviceManufacturerTargetingField = value;
			}
		}

		/// <summary>The mobile carriers being targeted by the <a href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public MobileCarrierTargeting mobileCarrierTargeting {
			get {
				return this.mobileCarrierTargetingField;
			}
			set {
				this.mobileCarrierTargetingField = value;
			}
		}

		/// <summary>The mobile devices being targeted by the <a href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public MobileDeviceTargeting mobileDeviceTargeting {
			get {
				return this.mobileDeviceTargetingField;
			}
			set {
				this.mobileDeviceTargetingField = value;
			}
		}

		/// <summary>The mobile device submodels being targeted by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public MobileDeviceSubmodelTargeting mobileDeviceSubmodelTargeting {
			get {
				return this.mobileDeviceSubmodelTargetingField;
			}
			set {
				this.mobileDeviceSubmodelTargetingField = value;
			}
		}

		/// <summary>The operating systems being targeted by the <a href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public OperatingSystemTargeting operatingSystemTargeting {
			get {
				return this.operatingSystemTargetingField;
			}
			set {
				this.operatingSystemTargetingField = value;
			}
		}

		/// <summary>The operating system versions being targeted by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public OperatingSystemVersionTargeting operatingSystemVersionTargeting {
			get {
				return this.operatingSystemVersionTargetingField;
			}
			set {
				this.operatingSystemVersionTargetingField = value;
			}
		}
	}


	/// <summary>Represents bandwidth groups that are being targeted or excluded by the <a
	/// href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class BandwidthGroupTargeting {
		private bool isTargetedField;

		private bool isTargetedFieldSpecified;

		private Technology[] bandwidthGroupsField;

		/// <summary>Indicates whether bandwidth groups should be targeted or excluded. This
		/// attribute is optional and defaults to <code>true</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool isTargeted {
			get {
				return this.isTargetedField;
			}
			set {
				this.isTargetedField = value;
				this.isTargetedSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isTargeted"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isTargetedSpecified {
			get {
				return this.isTargetedFieldSpecified;
			}
			set {
				this.isTargetedFieldSpecified = value;
			}
		}

		/// <summary>The bandwidth groups that are being targeted or excluded by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("bandwidthGroups", Order = 1)]
		public Technology[] bandwidthGroups {
			get {
				return this.bandwidthGroupsField;
			}
			set {
				this.bandwidthGroupsField = value;
			}
		}
	}


	/// <summary>Represents a technology entity that can be targeted.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(OperatingSystemVersion))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(OperatingSystem))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(MobileDeviceSubmodel))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(MobileDevice))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(MobileCarrier))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeviceManufacturer))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeviceCategory))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeviceCapability))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BrowserLanguage))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(Browser))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BandwidthGroup))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Technology {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		/// <summary>The unique ID of the <code>Technology</code>. This value is required for all
		/// forms of <code>TechnologyTargeting</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the technology being targeting. This value is read-only and is
		/// assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}
	}


	/// <summary>Represents a specific version of an operating system.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class OperatingSystemVersion : Technology {
		private int majorVersionField;

		private bool majorVersionFieldSpecified;

		private int minorVersionField;

		private bool minorVersionFieldSpecified;

		private int microVersionField;

		private bool microVersionFieldSpecified;

		/// <summary>The operating system major version.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int majorVersion {
			get {
				return this.majorVersionField;
			}
			set {
				this.majorVersionField = value;
				this.majorVersionSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="majorVersion" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool majorVersionSpecified {
			get {
				return this.majorVersionFieldSpecified;
			}
			set {
				this.majorVersionFieldSpecified = value;
			}
		}

		/// <summary>The operating system minor version.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int minorVersion {
			get {
				return this.minorVersionField;
			}
			set {
				this.minorVersionField = value;
				this.minorVersionSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="minorVersion" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool minorVersionSpecified {
			get {
				return this.minorVersionFieldSpecified;
			}
			set {
				this.minorVersionFieldSpecified = value;
			}
		}

		/// <summary>The operating system micro version.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public int microVersion {
			get {
				return this.microVersionField;
			}
			set {
				this.microVersionField = value;
				this.microVersionSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="microVersion" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool microVersionSpecified {
			get {
				return this.microVersionFieldSpecified;
			}
			set {
				this.microVersionFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents an Operating System, such as Linux, Mac OS or Windows.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class OperatingSystem : Technology {
	}


	/// <summary>Represents a mobile device submodel.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class MobileDeviceSubmodel : Technology {
		private long mobileDeviceCriterionIdField;

		private bool mobileDeviceCriterionIdFieldSpecified;

		private long deviceManufacturerCriterionIdField;

		private bool deviceManufacturerCriterionIdFieldSpecified;

		/// <summary>The mobile device id.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long mobileDeviceCriterionId {
			get {
				return this.mobileDeviceCriterionIdField;
			}
			set {
				this.mobileDeviceCriterionIdField = value;
				this.mobileDeviceCriterionIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="mobileDeviceCriterionId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool mobileDeviceCriterionIdSpecified {
			get {
				return this.mobileDeviceCriterionIdFieldSpecified;
			}
			set {
				this.mobileDeviceCriterionIdFieldSpecified = value;
			}
		}

		/// <summary>The device manufacturer id.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long deviceManufacturerCriterionId {
			get {
				return this.deviceManufacturerCriterionIdField;
			}
			set {
				this.deviceManufacturerCriterionIdField = value;
				this.deviceManufacturerCriterionIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="deviceManufacturerCriterionId" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool deviceManufacturerCriterionIdSpecified {
			get {
				return this.deviceManufacturerCriterionIdFieldSpecified;
			}
			set {
				this.deviceManufacturerCriterionIdFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents a Mobile Device.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class MobileDevice : Technology {
		private long manufacturerCriterionIdField;

		private bool manufacturerCriterionIdFieldSpecified;

		/// <summary>Manufacturer Id.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long manufacturerCriterionId {
			get {
				return this.manufacturerCriterionIdField;
			}
			set {
				this.manufacturerCriterionIdField = value;
				this.manufacturerCriterionIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="manufacturerCriterionId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool manufacturerCriterionIdSpecified {
			get {
				return this.manufacturerCriterionIdFieldSpecified;
			}
			set {
				this.manufacturerCriterionIdFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents a mobile carrier. Carrier targeting is only available to Ad Manager
	/// mobile publishers.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class MobileCarrier : Technology {
	}


	/// <summary>Represents a mobile device's manufacturer.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeviceManufacturer : Technology {
	}


	/// <summary>Represents the category of a device.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeviceCategory : Technology {
	}


	/// <summary>Represents a capability of a physical device.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeviceCapability : Technology {
	}


	/// <summary>Represents a Browser's language.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class BrowserLanguage : Technology {
	}


	/// <summary>Represents an internet browser.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Browser : Technology {
		private string majorVersionField;

		private string minorVersionField;

		/// <summary>Browser major version.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string majorVersion {
			get {
				return this.majorVersionField;
			}
			set {
				this.majorVersionField = value;
			}
		}

		/// <summary>Browser minor version.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string minorVersion {
			get {
				return this.minorVersionField;
			}
			set {
				this.minorVersionField = value;
			}
		}
	}


	/// <summary>Represents a group of bandwidths that are logically organized by some well known
	/// generic names such as 'Cable' or 'DSL'.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class BandwidthGroup : Technology {
	}


	/// <summary>Represents browsers that are being targeted or excluded by the <a
	/// href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class BrowserTargeting {
		private bool isTargetedField;

		private bool isTargetedFieldSpecified;

		private Technology[] browsersField;

		/// <summary>Indicates whether browsers should be targeted or excluded. This attribute is
		/// optional and defaults to <code>true</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool isTargeted {
			get {
				return this.isTargetedField;
			}
			set {
				this.isTargetedField = value;
				this.isTargetedSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isTargeted"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isTargetedSpecified {
			get {
				return this.isTargetedFieldSpecified;
			}
			set {
				this.isTargetedFieldSpecified = value;
			}
		}

		/// <summary>Browsers that are being targeted or excluded by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("browsers", Order = 1)]
		public Technology[] browsers {
			get {
				return this.browsersField;
			}
			set {
				this.browsersField = value;
			}
		}
	}


	/// <summary>Represents browser languages that are being targeted or excluded by the <a
	/// href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class BrowserLanguageTargeting {
		private bool isTargetedField;

		private bool isTargetedFieldSpecified;

		private Technology[] browserLanguagesField;

		/// <summary>Indicates whether browsers languages should be targeted or excluded. This
		/// attribute is optional and defaults to <code>true</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool isTargeted {
			get {
				return this.isTargetedField;
			}
			set {
				this.isTargetedField = value;
				this.isTargetedSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isTargeted"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isTargetedSpecified {
			get {
				return this.isTargetedFieldSpecified;
			}
			set {
				this.isTargetedFieldSpecified = value;
			}
		}

		/// <summary>Browser languages that are being targeted or excluded by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("browserLanguages", Order = 1)]
		public Technology[] browserLanguages {
			get {
				return this.browserLanguagesField;
			}
			set {
				this.browserLanguagesField = value;
			}
		}
	}


	/// <summary>Represents device capabilities that are being targeted or excluded by the <a
	/// href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeviceCapabilityTargeting {
		private Technology[] targetedDeviceCapabilitiesField;

		private Technology[] excludedDeviceCapabilitiesField;

		/// <summary>Device capabilities that are being targeted by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("targetedDeviceCapabilities", Order = 0)]
		public Technology[] targetedDeviceCapabilities {
			get {
				return this.targetedDeviceCapabilitiesField;
			}
			set {
				this.targetedDeviceCapabilitiesField = value;
			}
		}

		/// <summary>Device capabilities that are being excluded by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("excludedDeviceCapabilities", Order = 1)]
		public Technology[] excludedDeviceCapabilities {
			get {
				return this.excludedDeviceCapabilitiesField;
			}
			set {
				this.excludedDeviceCapabilitiesField = value;
			}
		}
	}


	/// <summary>Represents device categories that are being targeted or excluded by the <a
	/// href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeviceCategoryTargeting {
		private Technology[] targetedDeviceCategoriesField;

		private Technology[] excludedDeviceCategoriesField;

		/// <summary>Device categories that are being targeted by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("targetedDeviceCategories", Order = 0)]
		public Technology[] targetedDeviceCategories {
			get {
				return this.targetedDeviceCategoriesField;
			}
			set {
				this.targetedDeviceCategoriesField = value;
			}
		}

		/// <summary>Device categories that are being excluded by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("excludedDeviceCategories", Order = 1)]
		public Technology[] excludedDeviceCategories {
			get {
				return this.excludedDeviceCategoriesField;
			}
			set {
				this.excludedDeviceCategoriesField = value;
			}
		}
	}


	/// <summary>Represents device manufacturer that are being targeted or excluded by the <a
	/// href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeviceManufacturerTargeting {
		private bool isTargetedField;

		private bool isTargetedFieldSpecified;

		private Technology[] deviceManufacturersField;

		/// <summary>Indicates whether device manufacturers should be targeted or excluded. This
		/// attribute is optional and defaults to <code>true</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool isTargeted {
			get {
				return this.isTargetedField;
			}
			set {
				this.isTargetedField = value;
				this.isTargetedSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isTargeted"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isTargetedSpecified {
			get {
				return this.isTargetedFieldSpecified;
			}
			set {
				this.isTargetedFieldSpecified = value;
			}
		}

		/// <summary>Device manufacturers that are being targeted or excluded by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("deviceManufacturers", Order = 1)]
		public Technology[] deviceManufacturers {
			get {
				return this.deviceManufacturersField;
			}
			set {
				this.deviceManufacturersField = value;
			}
		}
	}


	/// <summary>Represents mobile carriers that are being targeted or excluded by the <a
	/// href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class MobileCarrierTargeting {
		private bool isTargetedField;

		private bool isTargetedFieldSpecified;

		private Technology[] mobileCarriersField;

		/// <summary>Indicates whether mobile carriers should be targeted or excluded. This attribute
		/// is optional and defaults to <code>true</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool isTargeted {
			get {
				return this.isTargetedField;
			}
			set {
				this.isTargetedField = value;
				this.isTargetedSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isTargeted"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isTargetedSpecified {
			get {
				return this.isTargetedFieldSpecified;
			}
			set {
				this.isTargetedFieldSpecified = value;
			}
		}

		/// <summary>Mobile carriers that are being targeted or excluded by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("mobileCarriers", Order = 1)]
		public Technology[] mobileCarriers {
			get {
				return this.mobileCarriersField;
			}
			set {
				this.mobileCarriersField = value;
			}
		}
	}


	/// <summary>Represents mobile devices that are being targeted or excluded by the <a
	/// href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class MobileDeviceTargeting {
		private Technology[] targetedMobileDevicesField;

		private Technology[] excludedMobileDevicesField;

		/// <summary>Mobile devices that are being targeted by the <a href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("targetedMobileDevices", Order = 0)]
		public Technology[] targetedMobileDevices {
			get {
				return this.targetedMobileDevicesField;
			}
			set {
				this.targetedMobileDevicesField = value;
			}
		}

		/// <summary>Mobile devices that are being excluded by the <a href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("excludedMobileDevices", Order = 1)]
		public Technology[] excludedMobileDevices {
			get {
				return this.excludedMobileDevicesField;
			}
			set {
				this.excludedMobileDevicesField = value;
			}
		}
	}


	/// <summary>Represents mobile devices that are being targeted or excluded by the <a
	/// href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class MobileDeviceSubmodelTargeting {
		private Technology[] targetedMobileDeviceSubmodelsField;

		private Technology[] excludedMobileDeviceSubmodelsField;

		/// <summary>Mobile device submodels that are being targeted by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("targetedMobileDeviceSubmodels", Order = 0)]
		public Technology[] targetedMobileDeviceSubmodels {
			get {
				return this.targetedMobileDeviceSubmodelsField;
			}
			set {
				this.targetedMobileDeviceSubmodelsField = value;
			}
		}

		/// <summary>Mobile device submodels that are being excluded by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("excludedMobileDeviceSubmodels", Order = 1)]
		public Technology[] excludedMobileDeviceSubmodels {
			get {
				return this.excludedMobileDeviceSubmodelsField;
			}
			set {
				this.excludedMobileDeviceSubmodelsField = value;
			}
		}
	}


	/// <summary>Represents operating systems that are being targeted or excluded by the <a
	/// href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class OperatingSystemTargeting {
		private bool isTargetedField;

		private bool isTargetedFieldSpecified;

		private Technology[] operatingSystemsField;

		/// <summary>Indicates whether operating systems should be targeted or excluded. This
		/// attribute is optional and defaults to <code>true</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool isTargeted {
			get {
				return this.isTargetedField;
			}
			set {
				this.isTargetedField = value;
				this.isTargetedSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isTargeted"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isTargetedSpecified {
			get {
				return this.isTargetedFieldSpecified;
			}
			set {
				this.isTargetedFieldSpecified = value;
			}
		}

		/// <summary>Operating systems that are being targeted or excluded by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("operatingSystems", Order = 1)]
		public Technology[] operatingSystems {
			get {
				return this.operatingSystemsField;
			}
			set {
				this.operatingSystemsField = value;
			}
		}
	}


	/// <summary>Represents operating system versions that are being targeted or excluded by the
	/// <a href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class OperatingSystemVersionTargeting {
		private Technology[] targetedOperatingSystemVersionsField;

		private Technology[] excludedOperatingSystemVersionsField;

		/// <summary>Operating system versions that are being targeted by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("targetedOperatingSystemVersions", Order = 0)]
		public Technology[] targetedOperatingSystemVersions {
			get {
				return this.targetedOperatingSystemVersionsField;
			}
			set {
				this.targetedOperatingSystemVersionsField = value;
			}
		}

		/// <summary>Operating system versions that are being excluded by the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("excludedOperatingSystemVersions", Order = 1)]
		public Technology[] excludedOperatingSystemVersions {
			get {
				return this.excludedOperatingSystemVersionsField;
			}
			set {
				this.excludedOperatingSystemVersionsField = value;
			}
		}
	}


	/// <summary>A <a href='CustomCriteriaSet'>CustomCriteriaSet</a> comprises of a set of <a
	/// href='CustomCriteriaNode'>CustomCriteriaNode</a> objects combined by the <a
	/// href='CustomCriteriaSet.LogicalOperator#logicalOperator'>CustomCriteriaSet.LogicalOperator#logicalOperator</a>.
	/// The custom criteria targeting tree is subject to the rules defined on <a
	/// href='Targeting#customTargeting'>Targeting#customTargeting</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomCriteriaSet : CustomCriteriaNode {
		private CustomCriteriaSetLogicalOperator logicalOperatorField;

		private bool logicalOperatorFieldSpecified;

		private CustomCriteriaNode[] childrenField;

		/// <summary>The logical operator to be applied to <a
		/// href='CustomCriteriaSet#children'>CustomCriteriaSet#children</a>. This attribute
		/// is required. <span class="constraint Required">This attribute is
		/// required.</span>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CustomCriteriaSetLogicalOperator logicalOperator {
			get {
				return this.logicalOperatorField;
			}
			set {
				this.logicalOperatorField = value;
				this.logicalOperatorSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="logicalOperator" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool logicalOperatorSpecified {
			get {
				return this.logicalOperatorFieldSpecified;
			}
			set {
				this.logicalOperatorFieldSpecified = value;
			}
		}

		/// <summary>The custom criteria. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("children", Order = 1)]
		public CustomCriteriaNode[] children {
			get {
				return this.childrenField;
			}
			set {
				this.childrenField = value;
			}
		}
	}


	/// <summary>Specifies the available logical operators.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CustomCriteriaSet.LogicalOperator", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CustomCriteriaSetLogicalOperator {
		AND = 0,
		OR = 1,
	}


	/// <summary>A <a href='CustomCriteriaNode'>CustomCriteriaNode</a> is a node in the custom
	/// targeting tree. A custom criteria node can either be a <a
	/// href='CustomCriteriaSet'>CustomCriteriaSet</a> (a non-leaf node) or a <a
	/// href='CustomCriteria'>CustomCriteria</a> (a leaf node). The custom criteria
	/// targeting tree is subject to the rules defined on <a
	/// href='Targeting#customTargeting'>Targeting#customTargeting</a>.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CustomCriteriaLeaf))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AudienceSegmentCriteria))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CustomCriteria))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CustomCriteriaSet))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class CustomCriteriaNode {
	}


	/// <summary>A <a href='CustomCriteriaLeaf'>CustomCriteriaLeaf</a> object represents a
	/// generic leaf of <a href='CustomCriteria'>CustomCriteria</a> tree structure.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AudienceSegmentCriteria))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CustomCriteria))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class CustomCriteriaLeaf : CustomCriteriaNode {
	}


	/// <summary>An <a href='AudienceSegmentCriteria'>AudienceSegmentCriteria</a> object is used
	/// to target <a href='AudienceSegment'>AudienceSegment</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AudienceSegmentCriteria : CustomCriteriaLeaf {
		private AudienceSegmentCriteriaComparisonOperator operatorField;

		private bool operatorFieldSpecified;

		private long[] audienceSegmentIdsField;

		/// <summary>The comparison operator. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AudienceSegmentCriteriaComparisonOperator @operator {
			get {
				return this.operatorField;
			}
			set {
				this.operatorField = value;
				this.operatorSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="@operator"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool operatorSpecified {
			get {
				return this.operatorFieldSpecified;
			}
			set {
				this.operatorFieldSpecified = value;
			}
		}

		/// <summary>The ids of <a href='AudienceSegment'>AudienceSegment</a> objects used to target
		/// audience segments. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("audienceSegmentIds", Order = 1)]
		public long[] audienceSegmentIds {
			get {
				return this.audienceSegmentIdsField;
			}
			set {
				this.audienceSegmentIdsField = value;
			}
		}
	}


	/// <summary>Specifies the available comparison operators.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AudienceSegmentCriteria.ComparisonOperator", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AudienceSegmentCriteriaComparisonOperator {
		IS = 0,
		IS_NOT = 1,
	}


	/// <summary>A <a href='CustomCriteria'>CustomCriteria</a> object is used to perform custom
	/// criteria targeting on custom targeting keys of type <a
	/// href='CustomTargetingKey.Type#PREDEFINED'>CustomTargetingKey.Type#PREDEFINED</a>
	/// or <a
	/// href='CustomTargetingKey.Type#FREEFORM'>CustomTargetingKey.Type#FREEFORM</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomCriteria : CustomCriteriaLeaf {
		private long keyIdField;

		private bool keyIdFieldSpecified;

		private long[] valueIdsField;

		private CustomCriteriaComparisonOperator operatorField;

		private bool operatorFieldSpecified;

		/// <summary>The <a href='CustomTargetingKey#id'>CustomTargetingKey#id</a> of the <a
		/// href='CustomTargetingKey'>CustomTargetingKey</a> object that was created using
		/// <a href='CustomTargetingService'>CustomTargetingService</a>. This attribute is
		/// required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long keyId {
			get {
				return this.keyIdField;
			}
			set {
				this.keyIdField = value;
				this.keyIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="keyId" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool keyIdSpecified {
			get {
				return this.keyIdFieldSpecified;
			}
			set {
				this.keyIdFieldSpecified = value;
			}
		}

		/// <summary>The ids of <a href='CustomTargetingValue'>CustomTargetingValue</a> objects to
		/// target the custom targeting key with id <a
		/// href='CustomCriteria#keyId'>CustomCriteria#keyId</a>. This attribute is
		/// required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("valueIds", Order = 1)]
		public long[] valueIds {
			get {
				return this.valueIdsField;
			}
			set {
				this.valueIdsField = value;
			}
		}

		/// <summary>The comparison operator. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public CustomCriteriaComparisonOperator @operator {
			get {
				return this.operatorField;
			}
			set {
				this.operatorField = value;
				this.operatorSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="@operator"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool operatorSpecified {
			get {
				return this.operatorFieldSpecified;
			}
			set {
				this.operatorFieldSpecified = value;
			}
		}
	}


	/// <summary>Specifies the available comparison operators.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CustomCriteria.ComparisonOperator", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CustomCriteriaComparisonOperator {
		IS = 0,
		IS_NOT = 1,
	}


	/// <summary>Provides line items the ability to target or exclude users visiting their
	/// websites from a list of domains or subdomains.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UserDomainTargeting {
		private string[] domainsField;

		private bool targetedField;

		private bool targetedFieldSpecified;

		/// <summary>The domains or subdomains that are being targeted or excluded by the <a
		/// href='LineItem'>LineItem</a>. This attribute is required and the maximum length
		/// of each domain is 67 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("domains", Order = 0)]
		public string[] domains {
			get {
				return this.domainsField;
			}
			set {
				this.domainsField = value;
			}
		}

		/// <summary>Indicates whether domains should be targeted or excluded. This attribute is
		/// optional and defaults to <code>true</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public bool targeted {
			get {
				return this.targetedField;
			}
			set {
				this.targetedField = value;
				this.targetedSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="targeted"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool targetedSpecified {
			get {
				return this.targetedFieldSpecified;
			}
			set {
				this.targetedFieldSpecified = value;
			}
		}
	}


	/// <summary>Used to target <a href='LineItem'>LineItem</a>s to specific videos on a
	/// publisher's site.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ContentTargeting {
		private long[] targetedContentIdsField;

		private long[] excludedContentIdsField;

		private long[] targetedVideoContentBundleIdsField;

		private long[] excludedVideoContentBundleIdsField;

		private ContentMetadataKeyHierarchyTargeting[] targetedContentMetadataField;

		private ContentMetadataKeyHierarchyTargeting[] excludedContentMetadataField;

		/// <summary>The IDs of content being targeted by the <code>LineItem</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("targetedContentIds", Order = 0)]
		public long[] targetedContentIds {
			get {
				return this.targetedContentIdsField;
			}
			set {
				this.targetedContentIdsField = value;
			}
		}

		/// <summary>The IDs of content being excluded by the <code>LineItem</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("excludedContentIds", Order = 1)]
		public long[] excludedContentIds {
			get {
				return this.excludedContentIdsField;
			}
			set {
				this.excludedContentIdsField = value;
			}
		}

		/// <summary>A list of video content bundles, represented by <a
		/// href='ContentBundle'>ContentBundle</a> IDs, that are being targeted by the
		/// <code>LineItem</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("targetedVideoContentBundleIds", Order = 2)]
		public long[] targetedVideoContentBundleIds {
			get {
				return this.targetedVideoContentBundleIdsField;
			}
			set {
				this.targetedVideoContentBundleIdsField = value;
			}
		}

		/// <summary>A list of video content bundles, represented by <a
		/// href='ContentBundle'>ContentBundle</a> IDs, that are being excluded by the
		/// <code>LineItem</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("excludedVideoContentBundleIds", Order = 3)]
		public long[] excludedVideoContentBundleIds {
			get {
				return this.excludedVideoContentBundleIdsField;
			}
			set {
				this.excludedVideoContentBundleIdsField = value;
			}
		}

		/// <summary>A list of content metadata within hierarchies that are being targeted by the
		/// <code>LineItem</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("targetedContentMetadata", Order = 4)]
		public ContentMetadataKeyHierarchyTargeting[] targetedContentMetadata {
			get {
				return this.targetedContentMetadataField;
			}
			set {
				this.targetedContentMetadataField = value;
			}
		}

		/// <summary>A list of content metadata within hierarchies that are being excluded by the
		/// <code>LineItem</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("excludedContentMetadata", Order = 5)]
		public ContentMetadataKeyHierarchyTargeting[] excludedContentMetadata {
			get {
				return this.excludedContentMetadataField;
			}
			set {
				this.excludedContentMetadataField = value;
			}
		}
	}


	/// <summary>Represents one or more <a href='CustomTargetingValue'>custom targeting
	/// values</a> from different <a href=''>CustomTargetingKey custom targeting
	/// keys</a> ANDed together.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ContentMetadataKeyHierarchyTargeting {
		private long[] customTargetingValueIdsField;

		/// <summary>The list of IDs of the targeted <a
		/// href='CustomTargetingValue'>CustomTargetingValue</a> objects that are ANDed
		/// together. <p>Targeting values do not need to be in the order of the hierarchy
		/// levels. For example, if the hierarchy is "show &gt; season &gt; genre" the
		/// values could be "season=3, show=30rock, genre=comedy."</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("customTargetingValueIds", Order = 0)]
		public long[] customTargetingValueIds {
			get {
				return this.customTargetingValueIdsField;
			}
			set {
				this.customTargetingValueIdsField = value;
			}
		}
	}


	/// <summary>Represents positions within and around a video where ads can be targeted to.
	/// <p>Example positions could be <code>pre-roll</code> (before the video plays),
	/// <code>post-roll</code> (after a video has completed playback) and
	/// <code>mid-roll</code> (during video playback).</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class VideoPositionTargeting {
		private VideoPositionTarget[] targetedPositionsField;

		/// <summary>The <a href='VideoTargetingPosition'>VideoTargetingPosition</a> objects being
		/// targeted by the video <a href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("targetedPositions", Order = 0)]
		public VideoPositionTarget[] targetedPositions {
			get {
				return this.targetedPositionsField;
			}
			set {
				this.targetedPositionsField = value;
			}
		}
	}


	/// <summary>Represents the options for targetable positions within a video.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class VideoPositionTarget {
		private VideoPosition videoPositionField;

		private VideoBumperType videoBumperTypeField;

		private bool videoBumperTypeFieldSpecified;

		private VideoPositionWithinPod videoPositionWithinPodField;

		/// <summary>The video position to target. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public VideoPosition videoPosition {
			get {
				return this.videoPositionField;
			}
			set {
				this.videoPositionField = value;
			}
		}

		/// <summary>The video bumper type to target. To target a video position or a pod position,
		/// this value must be null. To target a bumper position this value must be
		/// populated and the line item must have a bumper type.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public VideoBumperType videoBumperType {
			get {
				return this.videoBumperTypeField;
			}
			set {
				this.videoBumperTypeField = value;
				this.videoBumperTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="videoBumperType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool videoBumperTypeSpecified {
			get {
				return this.videoBumperTypeFieldSpecified;
			}
			set {
				this.videoBumperTypeFieldSpecified = value;
			}
		}

		/// <summary>The video position within a pod to target. To target a video position or a
		/// bumper position, this value must be null. To target a position within a pod this
		/// value must be populated.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public VideoPositionWithinPod videoPositionWithinPod {
			get {
				return this.videoPositionWithinPodField;
			}
			set {
				this.videoPositionWithinPodField = value;
			}
		}
	}


	/// <summary>Represents a targetable position within a video. A video ad can be targeted to a
	/// position (pre-roll, all mid-rolls, or post-roll), or to a specific mid-roll
	/// index.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class VideoPosition {
		private VideoPositionType positionTypeField;

		private bool positionTypeFieldSpecified;

		private int midrollIndexField;

		private bool midrollIndexFieldSpecified;

		/// <summary>The type of video position (pre-roll, mid-roll, or post-roll).
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public VideoPositionType positionType {
			get {
				return this.positionTypeField;
			}
			set {
				this.positionTypeField = value;
				this.positionTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="positionType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool positionTypeSpecified {
			get {
				return this.positionTypeFieldSpecified;
			}
			set {
				this.positionTypeFieldSpecified = value;
			}
		}

		/// <summary>The index of the mid-roll to target. Only valid if the <a
		/// href='positionType'>positionType</a> is <a
		/// href='VideoPositionType#MIDROLL'>VideoPositionType#MIDROLL</a>, otherwise this
		/// field will be ignored.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int midrollIndex {
			get {
				return this.midrollIndexField;
			}
			set {
				this.midrollIndexField = value;
				this.midrollIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="midrollIndex" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool midrollIndexSpecified {
			get {
				return this.midrollIndexFieldSpecified;
			}
			set {
				this.midrollIndexFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents a targetable position within a video.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "VideoPosition.Type", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum VideoPositionType {
		/// <summary>The position defined as showing before the video starts playing.
		/// </summary>
		PREROLL = 0,
		/// <summary>The position defined as showing within the middle of the playing video.
		/// </summary>
		MIDROLL = 1,
		/// <summary>The position defined as showing after the video is completed.
		/// </summary>
		POSTROLL = 2,
	}


	/// <summary>Represents the options for targetable bumper positions, surrounding an ad pod,
	/// within a video stream. This includes before and after the supported ad pod
	/// positions, <a href='VideoPositionType#PREROLL'>VideoPositionType#PREROLL</a>, <a
	/// href='VideoPositionType#MIDROLL'>VideoPositionType#MIDROLL</a>, and <a
	/// href='VideoPositionType#POSTROLL'>VideoPositionType#POSTROLL</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum VideoBumperType {
		/// <summary>Represents the bumper position before the ad pod.
		/// </summary>
		BEFORE = 0,
		/// <summary>Represents the bumper position after the ad pod.
		/// </summary>
		AFTER = 1,
	}


	/// <summary>Represents a targetable position within a pod within a video stream. A video ad
	/// can be targeted to any position in the pod (first, second, third ... last). If
	/// there is only 1 ad in a pod, either first or last will target that position.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class VideoPositionWithinPod {
		private int indexField;

		private bool indexFieldSpecified;

		/// <summary>The specific index of the pod. The index is defined as: <ul> <li>1 = first</li>
		/// <li>2 = second</li> <li>3 = third</li> <li>....</li> <li>100 = last</li> </ul>
		/// 100 will always be the last position. For example, for a pod with 5 positions,
		/// 100 would target position 5. Multiple targets against the index 100 can
		/// exist.<br /> Positions over 100 are not supported.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int index {
			get {
				return this.indexField;
			}
			set {
				this.indexField = value;
				this.indexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="index" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool indexSpecified {
			get {
				return this.indexFieldSpecified;
			}
			set {
				this.indexFieldSpecified = value;
			}
		}
	}


	/// <summary>Provides line items the ability to target or exclude users' mobile applications.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class MobileApplicationTargeting {
		private long[] mobileApplicationIdsField;

		private bool isTargetedField;

		private bool isTargetedFieldSpecified;

		/// <summary>The <a href='MobileApplication#id'>IDs</a> that are being targeted or excluded
		/// by the <a href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("mobileApplicationIds", Order = 0)]
		public long[] mobileApplicationIds {
			get {
				return this.mobileApplicationIdsField;
			}
			set {
				this.mobileApplicationIdsField = value;
			}
		}

		/// <summary>Indicates whether mobile apps should be targeted or excluded. This attribute is
		/// optional and defaults to <code>true</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public bool isTargeted {
			get {
				return this.isTargetedField;
			}
			set {
				this.isTargetedField = value;
				this.isTargetedSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isTargeted"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isTargetedSpecified {
			get {
				return this.isTargetedFieldSpecified;
			}
			set {
				this.isTargetedFieldSpecified = value;
			}
		}
	}


	/// <summary><code>GrpSettings</code> contains information for a line item that will have a
	/// target demographic when serving. This information will be used to set up
	/// tracking and enable reporting on the demographic information.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class GrpSettings {
		private long minTargetAgeField;

		private bool minTargetAgeFieldSpecified;

		private long maxTargetAgeField;

		private bool maxTargetAgeFieldSpecified;

		private GrpTargetGender targetGenderField;

		private bool targetGenderFieldSpecified;

		private GrpProvider providerField;

		private bool providerFieldSpecified;

		private long targetImpressionGoalField;

		private bool targetImpressionGoalFieldSpecified;

		/// <summary>Specifies the minimum target age (in years) of the <a
		/// href='LineItem'>LineItem</a>. This field is only applicable if <a
		/// href='#provider'>#provider</a> is not null.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long minTargetAge {
			get {
				return this.minTargetAgeField;
			}
			set {
				this.minTargetAgeField = value;
				this.minTargetAgeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="minTargetAge" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool minTargetAgeSpecified {
			get {
				return this.minTargetAgeFieldSpecified;
			}
			set {
				this.minTargetAgeFieldSpecified = value;
			}
		}

		/// <summary>Specifies the maximum target age (in years) of the <a
		/// href='LineItem'>LineItem</a>. This field is only applicable if <a
		/// href='#provider'>#provider</a> is not null.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long maxTargetAge {
			get {
				return this.maxTargetAgeField;
			}
			set {
				this.maxTargetAgeField = value;
				this.maxTargetAgeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="maxTargetAge" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool maxTargetAgeSpecified {
			get {
				return this.maxTargetAgeFieldSpecified;
			}
			set {
				this.maxTargetAgeFieldSpecified = value;
			}
		}

		/// <summary>Specifies the target gender of the <a href='LineItem'>LineItem</a>. This field
		/// is only applicable if <a href='#provider'>#provider</a> is not null.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public GrpTargetGender targetGender {
			get {
				return this.targetGenderField;
			}
			set {
				this.targetGenderField = value;
				this.targetGenderSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="targetGender" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool targetGenderSpecified {
			get {
				return this.targetGenderFieldSpecified;
			}
			set {
				this.targetGenderFieldSpecified = value;
			}
		}

		/// <summary>Specifies the GRP provider of the <a href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public GrpProvider provider {
			get {
				return this.providerField;
			}
			set {
				this.providerField = value;
				this.providerSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="provider"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool providerSpecified {
			get {
				return this.providerFieldSpecified;
			}
			set {
				this.providerFieldSpecified = value;
			}
		}

		/// <summary>Specifies the impression goal for the given target demographic. This field is
		/// only applicable if <a href='#provider'>#provider</a> is not null and
		/// demographics-based goal is selected by the user. If this field is set, <a
		/// href='LineItem#primaryGoal'>LineItem#primaryGoal</a> will have its <a
		/// href='Goal#units'>Goal#units</a> value set by Google to represent the estimated
		/// total quantity.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public long targetImpressionGoal {
			get {
				return this.targetImpressionGoalField;
			}
			set {
				this.targetImpressionGoalField = value;
				this.targetImpressionGoalSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="targetImpressionGoal" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool targetImpressionGoalSpecified {
			get {
				return this.targetImpressionGoalFieldSpecified;
			}
			set {
				this.targetImpressionGoalFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents the target gender for a GRP demographic targeted line item.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum GrpTargetGender {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		/// <summary>Indicates that the GRP target gender is Male.
		/// </summary>
		MALE = 1,
		/// <summary>Indicates that the GRP target gender is Female.
		/// </summary>
		FEMALE = 2,
		/// <summary>Indicates that the GRP target gender is both male and female.
		/// </summary>
		BOTH = 3,
	}


	/// <summary>Represents available GRP providers that a line item will have its target
	/// demographic measured by.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum GrpProvider {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		NIELSEN = 1,
		/// <summary>Renamed to <code>GOOGLE</code> beginning in V201608.
		/// </summary>
		GOOGLE = 3,
	}


	/// <summary>Defines the criteria a <a href='LineItem'>LineItem</a> needs to satisfy to meet
	/// its delivery goal.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Goal {
		private GoalType goalTypeField;

		private bool goalTypeFieldSpecified;

		private UnitType unitTypeField;

		private bool unitTypeFieldSpecified;

		private long unitsField;

		private bool unitsFieldSpecified;

		/// <summary>The type of the goal for the <code>LineItem</code>. It defines the period over
		/// which the goal for <code>LineItem</code> should be reached.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public GoalType goalType {
			get {
				return this.goalTypeField;
			}
			set {
				this.goalTypeField = value;
				this.goalTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="goalType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool goalTypeSpecified {
			get {
				return this.goalTypeFieldSpecified;
			}
			set {
				this.goalTypeFieldSpecified = value;
			}
		}

		/// <summary>The type of the goal unit for the <code>LineItem</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public UnitType unitType {
			get {
				return this.unitTypeField;
			}
			set {
				this.unitTypeField = value;
				this.unitTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="unitType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool unitTypeSpecified {
			get {
				return this.unitTypeFieldSpecified;
			}
			set {
				this.unitTypeFieldSpecified = value;
			}
		}

		/// <summary>If this is a primary goal, it represents the number or percentage of impressions
		/// or clicks that will be reserved for the <code></code>. If the line item is of
		/// type <a href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a>, it
		/// represents the percentage of available impressions reserved. If the line item is
		/// of type <a href='LineItemType#BULK'>LineItemType#BULK</a> or <a
		/// href='LineItemType#PRICE_PRIORITY'>LineItemType#PRICE_PRIORITY</a>, it
		/// represents the number of remaining impressions reserved. If the line item is of
		/// type <a href='LineItemType#NETWORK'>LineItemType#NETWORK</a> or <a
		/// href='LineItemType#HOUSE'>LineItemType#HOUSE</a>, it represents the percentage
		/// of remaining impressions reserved. <p>If this is a secondary goal, it represents
		/// the number of impressions or conversions that the line item will stop serving at
		/// if reached. For valid line item types, see <a
		/// href='LineItem#secondaryGoals'>LineItem#secondaryGoals</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public long units {
			get {
				return this.unitsField;
			}
			set {
				this.unitsField = value;
				this.unitsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="units" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool unitsSpecified {
			get {
				return this.unitsFieldSpecified;
			}
			set {
				this.unitsFieldSpecified = value;
			}
		}
	}


	/// <summary>Specifies the type of the goal for a <a href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum GoalType {
		/// <summary>No goal is specified for the number of ads delivered. The <a
		/// href='LineItem#lineItemType'>LineItem#lineItemType</a> must be one of: <ul>
		/// <li><a href='LineItemType#PRICE_PRIORITY'>LineItemType#PRICE_PRIORITY</a></li>
		/// <li><a href='LineItemType#AD_EXCHANGE'>LineItemType#AD_EXCHANGE</a></li> <li><a
		/// href='LineItemType#CLICK_TRACKING'>LineItemType#CLICK_TRACKING</a></li> </ul>
		/// </summary>
		NONE = 0,
		/// <summary>There is a goal on the number of ads delivered for this line item during its
		/// entire lifetime. The <a href='LineItem#lineItemType'>LineItem#lineItemType</a>
		/// must be one of: <ul> <li><a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a></li> <li><a
		/// href='LineItemType#BULK'>LineItemType#BULK</a></li> <li><a
		/// href='LineItemType#PRICE_PRIORITY'>LineItemType#PRICE_PRIORITY</a></li> <li><a
		/// href='LineItemType#ADSENSE'>LineItemType#ADSENSE</a></li> <li><a
		/// href='LineItemType#AD_EXCHANGE'>LineItemType#AD_EXCHANGE</a></li> <li><a
		/// href='LineItemType#ADMOB'>LineItemType#ADMOB</a></li> <li><a
		/// href='LineItemType#CLICK_TRACKING'>LineItemType#CLICK_TRACKING</a></li> </ul>
		/// </summary>
		LIFETIME = 1,
		/// <summary>There is a daily goal on the number of ads delivered for this line item. The <a
		/// href='LineItem#lineItemType'>LineItem#lineItemType</a> must be one of: <ul>
		/// <li><a href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a></li> <li><a
		/// href='LineItemType#NETWORK'>LineItemType#NETWORK</a></li> <li><a
		/// href='LineItemType#PRICE_PRIORITY'>LineItemType#PRICE_PRIORITY</a></li> <li><a
		/// href='LineItemType#HOUSE'>LineItemType#HOUSE</a></li> <li><a
		/// href='LineItemType#ADSENSE'>LineItemType#ADSENSE</a></li> <li><a
		/// href='LineItemType#AD_EXCHANGE'>LineItemType#AD_EXCHANGE</a></li> <li><a
		/// href='LineItemType#ADMOB'>LineItemType#ADMOB</a></li> <li><a
		/// href='LineItemType#BUMPER'>LineItemType#BUMPER</a></li> </ul>
		/// </summary>
		DAILY = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Contains data used to display information synchronized with Canoe for set-top
	/// box enabled <a href=''>LineItem line items</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SetTopBoxInfo {
		private SetTopBoxSyncStatus syncStatusField;

		private bool syncStatusFieldSpecified;

		private CanoeSyncResult lastSyncResultField;

		private bool lastSyncResultFieldSpecified;

		private string lastSyncCanoeResponseMessageField;

		private string nielsenProductCategoryCodeField;

		/// <summary>Indicates if the line item is ready to be synced with Canoe or if there are
		/// changes on this line item that are waiting to be pushed on the next sync with
		/// Canoe. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public SetTopBoxSyncStatus syncStatus {
			get {
				return this.syncStatusField;
			}
			set {
				this.syncStatusField = value;
				this.syncStatusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="syncStatus"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool syncStatusSpecified {
			get {
				return this.syncStatusFieldSpecified;
			}
			set {
				this.syncStatusFieldSpecified = value;
			}
		}

		/// <summary>The result of the last sync attempt with Canoe. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public CanoeSyncResult lastSyncResult {
			get {
				return this.lastSyncResultField;
			}
			set {
				this.lastSyncResultField = value;
				this.lastSyncResultSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lastSyncResult" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lastSyncResultSpecified {
			get {
				return this.lastSyncResultFieldSpecified;
			}
			set {
				this.lastSyncResultFieldSpecified = value;
			}
		}

		/// <summary>The response that Canoe sent for the last sync attempt. This attribute is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string lastSyncCanoeResponseMessage {
			get {
				return this.lastSyncCanoeResponseMessageField;
			}
			set {
				this.lastSyncCanoeResponseMessageField = value;
			}
		}

		/// <summary>The Nielsen product category code for the line item.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string nielsenProductCategoryCode {
			get {
				return this.nielsenProductCategoryCodeField;
			}
			set {
				this.nielsenProductCategoryCodeField = value;
			}
		}
	}


	/// <summary>The set top box line item sync status.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum SetTopBoxSyncStatus {
		/// <summary>The line item is not ready to be synced.
		/// </summary>
		NOT_READY = 0,
		/// <summary>The line item is currently being synced.
		/// </summary>
		SYNC_PENDING = 1,
		/// <summary>The line item has been synced.
		/// </summary>
		SYNCED = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Represents sync result types between set-top box enabled <a href='LineItem'>line
	/// items</a> and Canoe.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CanoeSyncResult {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		/// <summary>Sync message was accepted by Canoe.
		/// </summary>
		ACCEPTED = 1,
		/// <summary>Sync message was rejected by Canoe.
		/// </summary>
		REJECTED = 2,
	}


	/// <summary>Indicates the delivery performance of the <a href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeliveryIndicator {
		private double expectedDeliveryPercentageField;

		private bool expectedDeliveryPercentageFieldSpecified;

		private double actualDeliveryPercentageField;

		private bool actualDeliveryPercentageFieldSpecified;

		/// <summary>How much the <code>LineItem</code> was expected to deliver as a percentage of <a
		/// href='LineItem#unitsBought'>LineItem#unitsBought</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public double expectedDeliveryPercentage {
			get {
				return this.expectedDeliveryPercentageField;
			}
			set {
				this.expectedDeliveryPercentageField = value;
				this.expectedDeliveryPercentageSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="expectedDeliveryPercentage" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool expectedDeliveryPercentageSpecified {
			get {
				return this.expectedDeliveryPercentageFieldSpecified;
			}
			set {
				this.expectedDeliveryPercentageFieldSpecified = value;
			}
		}

		/// <summary>How much the line item actually delivered as a percentage of <a
		/// href='LineItem#unitsBought'>LineItem#unitsBought</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public double actualDeliveryPercentage {
			get {
				return this.actualDeliveryPercentageField;
			}
			set {
				this.actualDeliveryPercentageField = value;
				this.actualDeliveryPercentageSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="actualDeliveryPercentage" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool actualDeliveryPercentageSpecified {
			get {
				return this.actualDeliveryPercentageFieldSpecified;
			}
			set {
				this.actualDeliveryPercentageFieldSpecified = value;
			}
		}
	}


	/// <summary><code>Stats</code> contains trafficking statistics for <a
	/// href='LineItem'>LineItem</a> and <a
	/// href='LineItemCreativeAssociation'>LineItemCreativeAssociation</a> objects
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Stats {
		private long impressionsDeliveredField;

		private bool impressionsDeliveredFieldSpecified;

		private long clicksDeliveredField;

		private bool clicksDeliveredFieldSpecified;

		private long videoCompletionsDeliveredField;

		private bool videoCompletionsDeliveredFieldSpecified;

		private long videoStartsDeliveredField;

		private bool videoStartsDeliveredFieldSpecified;

		private long viewableImpressionsDeliveredField;

		private bool viewableImpressionsDeliveredFieldSpecified;

		/// <summary>The number of impressions delivered.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long impressionsDelivered {
			get {
				return this.impressionsDeliveredField;
			}
			set {
				this.impressionsDeliveredField = value;
				this.impressionsDeliveredSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="impressionsDelivered" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool impressionsDeliveredSpecified {
			get {
				return this.impressionsDeliveredFieldSpecified;
			}
			set {
				this.impressionsDeliveredFieldSpecified = value;
			}
		}

		/// <summary>The number of clicks delivered.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long clicksDelivered {
			get {
				return this.clicksDeliveredField;
			}
			set {
				this.clicksDeliveredField = value;
				this.clicksDeliveredSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="clicksDelivered" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool clicksDeliveredSpecified {
			get {
				return this.clicksDeliveredFieldSpecified;
			}
			set {
				this.clicksDeliveredFieldSpecified = value;
			}
		}

		/// <summary>The number of video completions delivered.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public long videoCompletionsDelivered {
			get {
				return this.videoCompletionsDeliveredField;
			}
			set {
				this.videoCompletionsDeliveredField = value;
				this.videoCompletionsDeliveredSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="videoCompletionsDelivered" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool videoCompletionsDeliveredSpecified {
			get {
				return this.videoCompletionsDeliveredFieldSpecified;
			}
			set {
				this.videoCompletionsDeliveredFieldSpecified = value;
			}
		}

		/// <summary>The number of video starts delivered.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public long videoStartsDelivered {
			get {
				return this.videoStartsDeliveredField;
			}
			set {
				this.videoStartsDeliveredField = value;
				this.videoStartsDeliveredSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="videoStartsDelivered" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool videoStartsDeliveredSpecified {
			get {
				return this.videoStartsDeliveredFieldSpecified;
			}
			set {
				this.videoStartsDeliveredFieldSpecified = value;
			}
		}

		/// <summary>The number of viewable impressions delivered.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public long viewableImpressionsDelivered {
			get {
				return this.viewableImpressionsDeliveredField;
			}
			set {
				this.viewableImpressionsDeliveredField = value;
				this.viewableImpressionsDeliveredSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="viewableImpressionsDelivered" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool viewableImpressionsDeliveredSpecified {
			get {
				return this.viewableImpressionsDeliveredFieldSpecified;
			}
			set {
				this.viewableImpressionsDeliveredFieldSpecified = value;
			}
		}
	}


	/// <summary>A <code>LineItemActivityAssociation</code> associates a <a
	/// href='LineItem'>LineItem</a> with an <a href='Activity'>Activity</a> so that the
	/// conversions of the <a href='Activity'>Activity</a> can be counted against the <a
	/// href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LineItemActivityAssociation {
		private int activityIdField;

		private bool activityIdFieldSpecified;

		private Money clickThroughConversionCostField;

		private Money viewThroughConversionCostField;

		/// <summary>The ID of the <a href='Activity'>Activity</a> to which the <a
		/// href='LineItem'>LineItem</a> should be associated. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int activityId {
			get {
				return this.activityIdField;
			}
			set {
				this.activityIdField = value;
				this.activityIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="activityId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool activityIdSpecified {
			get {
				return this.activityIdFieldSpecified;
			}
			set {
				this.activityIdFieldSpecified = value;
			}
		}

		/// <summary>The amount of money to attribute per click through conversion. This attribute is
		/// required for creating a <code></code>. The currency code is readonly and should
		/// match the <a href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public Money clickThroughConversionCost {
			get {
				return this.clickThroughConversionCostField;
			}
			set {
				this.clickThroughConversionCostField = value;
			}
		}

		/// <summary>The amount of money to attribute per view through conversion. This attribute is
		/// required for creating a <code></code>. The currency code is readonly and should
		/// match the <a href='LineItem'>LineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public Money viewThroughConversionCost {
			get {
				return this.viewThroughConversionCostField;
			}
			set {
				this.viewThroughConversionCostField = value;
			}
		}
	}


	/// <summary>Represents a money amount.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Money {
		private string currencyCodeField;

		private long microAmountField;

		private bool microAmountFieldSpecified;

		/// <summary>Three letter currency code in string format.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string currencyCode {
			get {
				return this.currencyCodeField;
			}
			set {
				this.currencyCodeField = value;
			}
		}

		/// <summary>Money values are always specified in terms of micros which are a millionth of
		/// the fundamental currency unit. For US dollars, $1 is 1,000,000 micros.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long microAmount {
			get {
				return this.microAmountField;
			}
			set {
				this.microAmountField = value;
				this.microAmountSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="microAmount"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool microAmountSpecified {
			get {
				return this.microAmountFieldSpecified;
			}
			set {
				this.microAmountFieldSpecified = value;
			}
		}
	}


	/// <summary>A <code>CreativePlaceholder</code> describes a slot that a creative is expected
	/// to fill. This is used primarily to help in forecasting, and also to validate
	/// that the correct creatives are associated with the line item. A
	/// <code>CreativePlaceholder</code> must contain a size, and it can optionally
	/// contain companions. Companions are only valid if the line item's environment
	/// type is <a href='EnvironmentType#VIDEO_PLAYER'>EnvironmentType#VIDEO_PLAYER</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreativePlaceholder {
		private Size sizeField;

		private long creativeTemplateIdField;

		private bool creativeTemplateIdFieldSpecified;

		private CreativePlaceholder[] companionsField;

		private AppliedLabel[] appliedLabelsField;

		private AppliedLabel[] effectiveAppliedLabelsField;

		private int expectedCreativeCountField;

		private bool expectedCreativeCountFieldSpecified;

		private CreativeSizeType creativeSizeTypeField;

		private bool creativeSizeTypeFieldSpecified;

		private string targetingNameField;

		/// <summary>The dimensions that the creative is expected to have. This attribute is
		/// required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public Size size {
			get {
				return this.sizeField;
			}
			set {
				this.sizeField = value;
			}
		}

		/// <summary>The native creative template ID. <p>This value is only required if <a
		/// href='#creativeSizeType'>#creativeSizeType</a> is <a
		/// href='CreativeSizeType#NATIVE'>CreativeSizeType#NATIVE</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long creativeTemplateId {
			get {
				return this.creativeTemplateIdField;
			}
			set {
				this.creativeTemplateIdField = value;
				this.creativeTemplateIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="creativeTemplateId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool creativeTemplateIdSpecified {
			get {
				return this.creativeTemplateIdFieldSpecified;
			}
			set {
				this.creativeTemplateIdFieldSpecified = value;
			}
		}

		/// <summary>The companions that the creative is expected to have. This attribute can only be
		/// set if the line item it belongs to has a <a
		/// href='LineItem#environmentType'>LineItem#environmentType</a> of <a
		/// href='EnvironmentType#VIDEO_PLAYER'>EnvironmentType#VIDEO_PLAYER</a> or <a
		/// href='LineItem#roadblockingType'>LineItem#roadblockingType</a> of <a
		/// href='RoadblockingType#CREATIVE_SET'>RoadblockingType#CREATIVE_SET</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("companions", Order = 2)]
		public CreativePlaceholder[] companions {
			get {
				return this.companionsField;
			}
			set {
				this.companionsField = value;
			}
		}

		/// <summary>The set of label frequency caps applied directly to this creative placeholder.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("appliedLabels", Order = 3)]
		public AppliedLabel[] appliedLabels {
			get {
				return this.appliedLabelsField;
			}
			set {
				this.appliedLabelsField = value;
			}
		}

		/// <summary>Contains the set of labels applied directly to this creative placeholder as well
		/// as those inherited from the creative template from which this creative
		/// placeholder was instantiated. This field is readonly and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("effectiveAppliedLabels", Order = 4)]
		public AppliedLabel[] effectiveAppliedLabels {
			get {
				return this.effectiveAppliedLabelsField;
			}
			set {
				this.effectiveAppliedLabelsField = value;
			}
		}

		/// <summary>Expected number of creatives that will be uploaded corresponding to this
		/// creative placeholder. This estimate is used to improve the accuracy of
		/// forecasting; for example, if label frequency capping limits the number of times
		/// a creative may be served.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public int expectedCreativeCount {
			get {
				return this.expectedCreativeCountField;
			}
			set {
				this.expectedCreativeCountField = value;
				this.expectedCreativeCountSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="expectedCreativeCount" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool expectedCreativeCountSpecified {
			get {
				return this.expectedCreativeCountFieldSpecified;
			}
			set {
				this.expectedCreativeCountFieldSpecified = value;
			}
		}

		/// <summary>Describes the types of sizes a creative can be. By default, the creative's size
		/// is <a href='CreativeSizeType#PIXEL'>CreativeSizeType#PIXEL</a>, which is a
		/// dimension based size (width-height pair).
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public CreativeSizeType creativeSizeType {
			get {
				return this.creativeSizeTypeField;
			}
			set {
				this.creativeSizeTypeField = value;
				this.creativeSizeTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="creativeSizeType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool creativeSizeTypeSpecified {
			get {
				return this.creativeSizeTypeFieldSpecified;
			}
			set {
				this.creativeSizeTypeFieldSpecified = value;
			}
		}

		/// <summary>The name of the <a href='CreativeTargeting'>CreativeTargeting</a> for creatives
		/// this placeholder represents. <p>This attribute is optional. Specifying creative
		/// targeting here is for forecasting purposes only and has no effect on serving.
		/// The same creative targeting should be specified on a <a
		/// href='LineItemCreativeAssociation'>LineItemCreativeAssociation</a> when
		/// associating a <a href='Creative'>Creative</a> with the <a
		/// href='LineItem'>LineItem</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public string targetingName {
			get {
				return this.targetingNameField;
			}
			set {
				this.targetingNameField = value;
			}
		}
	}


	/// <summary>Descriptions of the types of sizes a creative can be. Not all creatives can be
	/// described by a height-width pair, this provides additional context.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CreativeSizeType {
		/// <summary>Dimension based size, an actual height and width.
		/// </summary>
		PIXEL = 0,
		/// <summary>Mobile size, that is expressed as a ratio of say 4 by 1, that could be met by a
		/// 100 x 25 sized image.
		/// </summary>
		ASPECT_RATIO = 1,
		/// <summary>Out-of-page size, that is not related to the slot it is served. But rather is a
		/// function of the snippet, and the values set. This must be used with 1x1 size.
		/// </summary>
		INTERSTITIAL = 2,
		/// <summary>Native size, which is a function of the how the client renders the creative.
		/// This must be used with 1x1 size.
		/// </summary>
		NATIVE = 3,
	}


	/// <summary>Represents a limit on the number of times a single viewer can be exposed to the
	/// same <a href='LineItem'>LineItem</a> in a specified time period.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class FrequencyCap {
		private int maxImpressionsField;

		private bool maxImpressionsFieldSpecified;

		private int numTimeUnitsField;

		private bool numTimeUnitsFieldSpecified;

		private TimeUnit timeUnitField;

		private bool timeUnitFieldSpecified;

		/// <summary>The maximum number of impressions than can be served to a user within a
		/// specified time period.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int maxImpressions {
			get {
				return this.maxImpressionsField;
			}
			set {
				this.maxImpressionsField = value;
				this.maxImpressionsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="maxImpressions" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool maxImpressionsSpecified {
			get {
				return this.maxImpressionsFieldSpecified;
			}
			set {
				this.maxImpressionsFieldSpecified = value;
			}
		}

		/// <summary>The number of <code>FrequencyCap#timeUnit</code> to represent the total time
		/// period.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int numTimeUnits {
			get {
				return this.numTimeUnitsField;
			}
			set {
				this.numTimeUnitsField = value;
				this.numTimeUnitsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="numTimeUnits" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool numTimeUnitsSpecified {
			get {
				return this.numTimeUnitsFieldSpecified;
			}
			set {
				this.numTimeUnitsFieldSpecified = value;
			}
		}

		/// <summary>The unit of time for specifying the time period.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public TimeUnit timeUnit {
			get {
				return this.timeUnitField;
			}
			set {
				this.timeUnitField = value;
				this.timeUnitSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="timeUnit"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool timeUnitSpecified {
			get {
				return this.timeUnitFieldSpecified;
			}
			set {
				this.timeUnitFieldSpecified = value;
			}
		}
	}


	/// <summary>Represent the possible time units for frequency capping.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum TimeUnit {
		MINUTE = 0,
		HOUR = 1,
		DAY = 2,
		WEEK = 3,
		MONTH = 4,
		LIFETIME = 5,
		/// <summary>Per pod of ads in a video stream. Only valid for entities in a <a
		/// href='EnvironmentType#VIDEO_PLAYER'>EnvironmentType#VIDEO_PLAYER</a>
		/// environment.
		/// </summary>
		POD = 6,
		/// <summary>Per video stream. Only valid for entities in a <a
		/// href='EnvironmentType#VIDEO_PLAYER'>EnvironmentType#VIDEO_PLAYER</a>
		/// environment.
		/// </summary>
		STREAM = 7,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 8,
	}


	/// <summary>The <code>LineItemSummary</code> represents the base class from which a
	/// <code>LineItem</code> is derived.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(LineItem))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LineItemSummary {
		private long orderIdField;

		private bool orderIdFieldSpecified;

		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private string externalIdField;

		private string orderNameField;

		private DateTime startDateTimeField;

		private StartDateTimeType startDateTimeTypeField;

		private bool startDateTimeTypeFieldSpecified;

		private DateTime endDateTimeField;

		private int autoExtensionDaysField;

		private bool autoExtensionDaysFieldSpecified;

		private bool unlimitedEndDateTimeField;

		private bool unlimitedEndDateTimeFieldSpecified;

		private CreativeRotationType creativeRotationTypeField;

		private bool creativeRotationTypeFieldSpecified;

		private DeliveryRateType deliveryRateTypeField;

		private bool deliveryRateTypeFieldSpecified;

		private RoadblockingType roadblockingTypeField;

		private bool roadblockingTypeFieldSpecified;

		private FrequencyCap[] frequencyCapsField;

		private LineItemType lineItemTypeField;

		private bool lineItemTypeFieldSpecified;

		private int priorityField;

		private bool priorityFieldSpecified;

		private Money costPerUnitField;

		private Money valueCostPerUnitField;

		private CostType costTypeField;

		private bool costTypeFieldSpecified;

		private LineItemDiscountType discountTypeField;

		private bool discountTypeFieldSpecified;

		private double discountField;

		private bool discountFieldSpecified;

		private long contractedUnitsBoughtField;

		private bool contractedUnitsBoughtFieldSpecified;

		private CreativePlaceholder[] creativePlaceholdersField;

		private LineItemActivityAssociation[] activityAssociationsField;

		private EnvironmentType environmentTypeField;

		private bool environmentTypeFieldSpecified;

		private CompanionDeliveryOption companionDeliveryOptionField;

		private bool companionDeliveryOptionFieldSpecified;

		private bool allowOverbookField;

		private bool allowOverbookFieldSpecified;

		private bool skipInventoryCheckField;

		private bool skipInventoryCheckFieldSpecified;

		private bool skipCrossSellingRuleWarningChecksField;

		private bool skipCrossSellingRuleWarningChecksFieldSpecified;

		private bool reserveAtCreationField;

		private bool reserveAtCreationFieldSpecified;

		private Stats statsField;

		private DeliveryIndicator deliveryIndicatorField;

		private long[] deliveryDataField;

		private Money budgetField;

		private ComputedStatus statusField;

		private bool statusFieldSpecified;

		private LineItemSummaryReservationStatus reservationStatusField;

		private bool reservationStatusFieldSpecified;

		private bool isArchivedField;

		private bool isArchivedFieldSpecified;

		private string webPropertyCodeField;

		private AppliedLabel[] appliedLabelsField;

		private AppliedLabel[] effectiveAppliedLabelsField;

		private bool disableSameAdvertiserCompetitiveExclusionField;

		private bool disableSameAdvertiserCompetitiveExclusionFieldSpecified;

		private string lastModifiedByAppField;

		private string notesField;

		private DateTime lastModifiedDateTimeField;

		private DateTime creationDateTimeField;

		private bool isPrioritizedPreferredDealsEnabledField;

		private bool isPrioritizedPreferredDealsEnabledFieldSpecified;

		private int adExchangeAuctionOpeningPriorityField;

		private bool adExchangeAuctionOpeningPriorityFieldSpecified;

		private BaseCustomFieldValue[] customFieldValuesField;

		private bool isSetTopBoxEnabledField;

		private bool isSetTopBoxEnabledFieldSpecified;

		private bool isMissingCreativesField;

		private bool isMissingCreativesFieldSpecified;

		private SetTopBoxInfo setTopBoxDisplayInfoField;

		private ProgrammaticCreativeSource programmaticCreativeSourceField;

		private bool programmaticCreativeSourceFieldSpecified;

		private long videoMaxDurationField;

		private bool videoMaxDurationFieldSpecified;

		private Goal primaryGoalField;

		private Goal[] secondaryGoalsField;

		private GrpSettings grpSettingsField;

		/// <summary>The ID of the <a href='Order'>Order</a> to which the <code></code> belongs. This
		/// attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long orderId {
			get {
				return this.orderIdField;
			}
			set {
				this.orderIdField = value;
				this.orderIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="orderId" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool orderIdSpecified {
			get {
				return this.orderIdFieldSpecified;
			}
			set {
				this.orderIdFieldSpecified = value;
			}
		}

		/// <summary>Uniquely identifies the <code>LineItem</code>. This attribute is read-only and
		/// is assigned by Google when a line item is created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the line item. This attribute is required and has a maximum length
		/// of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>An identifier for the <code>LineItem</code> that is meaningful to the publisher.
		/// This attribute is optional and has a maximum length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string externalId {
			get {
				return this.externalIdField;
			}
			set {
				this.externalIdField = value;
			}
		}

		/// <summary>The name of the <a href='Order'>Order</a>. This value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string orderName {
			get {
				return this.orderNameField;
			}
			set {
				this.orderNameField = value;
			}
		}

		/// <summary>The date and time on which the <code>LineItem</code> is enabled to begin
		/// serving. This attribute is required and must be in the future.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public DateTime startDateTime {
			get {
				return this.startDateTimeField;
			}
			set {
				this.startDateTimeField = value;
			}
		}

		/// <summary>Specifies whether to start serving to the <code>LineItem</code> right away, in
		/// an hour, etc. This attribute is optional and defaults to <a
		/// href='StartDateTimeType#USE_START_DATE_TIME'>StartDateTimeType#USE_START_DATE_TIME</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public StartDateTimeType startDateTimeType {
			get {
				return this.startDateTimeTypeField;
			}
			set {
				this.startDateTimeTypeField = value;
				this.startDateTimeTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="startDateTimeType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startDateTimeTypeSpecified {
			get {
				return this.startDateTimeTypeFieldSpecified;
			}
			set {
				this.startDateTimeTypeFieldSpecified = value;
			}
		}

		/// <summary>The date and time on which the <code>LineItem</code> will stop serving. This
		/// attribute is required unless <a
		/// href='LineItem#unlimitedEndDateTime'>LineItem#unlimitedEndDateTime</a> is set to
		/// <code>true</code>. If specified, it must be after the <a
		/// href='LineItem#startDateTime'>LineItem#startDateTime</a>. This end date and time
		/// does not include auto extension days.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public DateTime endDateTime {
			get {
				return this.endDateTimeField;
			}
			set {
				this.endDateTimeField = value;
			}
		}

		/// <summary>The number of days to allow a line item to deliver past its <a
		/// href='#endDateTime'>#endDateTime</a>. A maximum of 7 days is allowed. This is
		/// feature is only available for Ad Manager 360 accounts.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public int autoExtensionDays {
			get {
				return this.autoExtensionDaysField;
			}
			set {
				this.autoExtensionDaysField = value;
				this.autoExtensionDaysSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="autoExtensionDays" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool autoExtensionDaysSpecified {
			get {
				return this.autoExtensionDaysFieldSpecified;
			}
			set {
				this.autoExtensionDaysFieldSpecified = value;
			}
		}

		/// <summary>Specifies whether or not the <code>LineItem</code> has an end time. This
		/// attribute is optional and defaults to false. It can be be set to
		/// <code>true</code> for only line items of type <a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a>, <a
		/// href='LineItemType#NETWORK'>LineItemType#NETWORK</a>, <a
		/// href='LineItemType#PRICE_PRIORITY'>LineItemType#PRICE_PRIORITY</a> and <a
		/// href='LineItemType#HOUSE'>LineItemType#HOUSE</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public bool unlimitedEndDateTime {
			get {
				return this.unlimitedEndDateTimeField;
			}
			set {
				this.unlimitedEndDateTimeField = value;
				this.unlimitedEndDateTimeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="unlimitedEndDateTime" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool unlimitedEndDateTimeSpecified {
			get {
				return this.unlimitedEndDateTimeFieldSpecified;
			}
			set {
				this.unlimitedEndDateTimeFieldSpecified = value;
			}
		}

		/// <summary>The strategy used for displaying multiple <a href='Creative'>Creative</a>
		/// objects that are associated with the <code></code>. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public CreativeRotationType creativeRotationType {
			get {
				return this.creativeRotationTypeField;
			}
			set {
				this.creativeRotationTypeField = value;
				this.creativeRotationTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="creativeRotationType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool creativeRotationTypeSpecified {
			get {
				return this.creativeRotationTypeFieldSpecified;
			}
			set {
				this.creativeRotationTypeFieldSpecified = value;
			}
		}

		/// <summary>The strategy for delivering ads over the course of the line item's duration.
		/// This attribute is optional and defaults to <a
		/// href='DeliveryRateType#EVENLY'>DeliveryRateType#EVENLY</a> or <a
		/// href='DeliveryRateType#FRONTLOADED'>DeliveryRateType#FRONTLOADED</a> depending
		/// on the network's configuration.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 11)]
		public DeliveryRateType deliveryRateType {
			get {
				return this.deliveryRateTypeField;
			}
			set {
				this.deliveryRateTypeField = value;
				this.deliveryRateTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="deliveryRateType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool deliveryRateTypeSpecified {
			get {
				return this.deliveryRateTypeFieldSpecified;
			}
			set {
				this.deliveryRateTypeFieldSpecified = value;
			}
		}

		/// <summary>The strategy for serving roadblocked creatives, i.e. instances where multiple
		/// creatives must be served together on a single web page. This attribute is
		/// optional and defaults to <a
		/// href='RoadblockingType#ONE_OR_MORE'>RoadblockingType#ONE_OR_MORE</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 12)]
		public RoadblockingType roadblockingType {
			get {
				return this.roadblockingTypeField;
			}
			set {
				this.roadblockingTypeField = value;
				this.roadblockingTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="roadblockingType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool roadblockingTypeSpecified {
			get {
				return this.roadblockingTypeFieldSpecified;
			}
			set {
				this.roadblockingTypeFieldSpecified = value;
			}
		}

		/// <summary>The set of frequency capping units for this <code>LineItem</code>. This
		/// attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("frequencyCaps", Order = 13)]
		public FrequencyCap[] frequencyCaps {
			get {
				return this.frequencyCapsField;
			}
			set {
				this.frequencyCapsField = value;
			}
		}

		/// <summary>Indicates the line item type of a <code>LineItem</code>. This attribute is
		/// required. The line item type determines the default priority of the line item.
		/// More information can be found on the <a
		/// href="https://support.google.com/dfp_premium/answer/177279">Ad Manager Help
		/// Center</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 14)]
		public LineItemType lineItemType {
			get {
				return this.lineItemTypeField;
			}
			set {
				this.lineItemTypeField = value;
				this.lineItemTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lineItemType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lineItemTypeSpecified {
			get {
				return this.lineItemTypeFieldSpecified;
			}
			set {
				this.lineItemTypeFieldSpecified = value;
			}
		}

		/// <summary>The priority for the line item. Valid values range from 1 to 16. This field is
		/// optional and defaults to the default priority of the <a
		/// href='LineItemType'>LineItemType</a>. <p>The following table shows the default,
		/// minimum, and maximum priority values are for each line item type:</p> <table>
		/// <tr> <th colspan="2" scope="col">LineItemType - default priority (minimum
		/// priority, maximum priority)</th> </tr> <tr> <td><a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a></td> <td>4 (2,
		/// 5)</td> </tr> <tr> <td><a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a></td> <td>8 (6, 10)</td>
		/// </tr> <tr> <td><a href='LineItemType#NETWORK'>LineItemType#NETWORK</a></td>
		/// <td>12 (11, 14)</td> </tr> <tr> <td><a
		/// href='LineItemType#BULK'>LineItemType#BULK</a></td> <td>12 (11, 14)</td> </tr>
		/// <tr> <td><a
		/// href='LineItemType#PRICE_PRIORITY'>LineItemType#PRICE_PRIORITY</a></td> <td>12
		/// (11, 14)</td> </tr> <tr> <td><a
		/// href='LineItemType#HOUSE'>LineItemType#HOUSE</a></td> <td>16 (15, 16)</td> </tr>
		/// <tr> <td><a
		/// href='LineItemType#CLICK_TRACKING'>LineItemType#CLICK_TRACKING</a></td> <td>16
		/// (1, 16)</td> </tr> <tr> <td><a
		/// href='LineItemType#AD_EXCHANGE'>LineItemType#AD_EXCHANGE</a></td> <td>12 (1,
		/// 16)</td> </tr> <tr> <td><a
		/// href='LineItemType#ADSENSE'>LineItemType#ADSENSE</a></td> <td>12 (1, 16)</td>
		/// </tr> <tr> <td><a href='LineItemType#BUMPER'>LineItemType#BUMPER</a></td> <td>16
		/// (15, 16)</td> </tr> </table> <p>This field can only be edited by certain
		/// networks, otherwise a <a href='PermissionError'>PermissionError</a> will
		/// occur.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 15)]
		public int priority {
			get {
				return this.priorityField;
			}
			set {
				this.priorityField = value;
				this.prioritySpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="priority"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool prioritySpecified {
			get {
				return this.priorityFieldSpecified;
			}
			set {
				this.priorityFieldSpecified = value;
			}
		}

		/// <summary>The amount of money to spend per impression or click. This attribute is required
		/// for creating a <code>LineItem</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 16)]
		public Money costPerUnit {
			get {
				return this.costPerUnitField;
			}
			set {
				this.costPerUnitField = value;
			}
		}

		/// <summary>An amount to help the adserver rank inventory. <a
		/// href=''>LineItem#valueCostPerUnit</a> artificially raises the value of inventory
		/// over the <a href='LineItem#costPerUnit'>LineItem#costPerUnit</a> but avoids
		/// raising the actual <a href='LineItem#costPerUnit'>LineItem#costPerUnit</a>. This
		/// attribute is optional and defaults to a <a href='Money'>Money</a> object in the
		/// local currency with <a href='Money#microAmount'>Money#microAmount</a> 0.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 17)]
		public Money valueCostPerUnit {
			get {
				return this.valueCostPerUnitField;
			}
			set {
				this.valueCostPerUnitField = value;
			}
		}

		/// <summary>The method used for billing this <code>LineItem</code>. This attribute is
		/// required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 18)]
		public CostType costType {
			get {
				return this.costTypeField;
			}
			set {
				this.costTypeField = value;
				this.costTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="costType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool costTypeSpecified {
			get {
				return this.costTypeFieldSpecified;
			}
			set {
				this.costTypeFieldSpecified = value;
			}
		}

		/// <summary>The type of discount being applied to a <code>LineItem</code>, either percentage
		/// based or absolute. This attribute is optional and defaults to <a
		/// href='LineItemDiscountType#PERCENTAGE'>LineItemDiscountType#PERCENTAGE</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 19)]
		public LineItemDiscountType discountType {
			get {
				return this.discountTypeField;
			}
			set {
				this.discountTypeField = value;
				this.discountTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="discountType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool discountTypeSpecified {
			get {
				return this.discountTypeFieldSpecified;
			}
			set {
				this.discountTypeFieldSpecified = value;
			}
		}

		/// <summary>The number here is either a percentage or an absolute value depending on the
		/// <code>LineItemDiscountType</code>. If the <code></code> is <a
		/// href='LineItemDiscountType#PERCENTAGE'>LineItemDiscountType#PERCENTAGE</a>, then
		/// only non-fractional values are supported.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 20)]
		public double discount {
			get {
				return this.discountField;
			}
			set {
				this.discountField = value;
				this.discountSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="discount"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool discountSpecified {
			get {
				return this.discountFieldSpecified;
			}
			set {
				this.discountFieldSpecified = value;
			}
		}

		/// <summary>This attribute is only applicable for certain <a href='#lineItemType'>line item
		/// types</a> and acts as an "FYI" or note, which does not impact adserving or other
		/// backend systems. <p>For <a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a> line items, this
		/// represents the minimum quantity, which is a lifetime impression volume goal for
		/// reporting purposes only.</p> <p>For <a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a> line items, this
		/// represent the contracted quantity, which is the number of units specified in the
		/// contract the advertiser has bought for this <code>LineItem</code>. This field is
		/// just a "FYI" for traffickers to manually intervene with the
		/// <code>LineItem</code> when needed. This attribute is only available for <a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a> line items if you have
		/// this feature enabled on your network.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 21)]
		public long contractedUnitsBought {
			get {
				return this.contractedUnitsBoughtField;
			}
			set {
				this.contractedUnitsBoughtField = value;
				this.contractedUnitsBoughtSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="contractedUnitsBought" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool contractedUnitsBoughtSpecified {
			get {
				return this.contractedUnitsBoughtFieldSpecified;
			}
			set {
				this.contractedUnitsBoughtFieldSpecified = value;
			}
		}

		/// <summary>Details about the creatives that are expected to serve through this
		/// <code>LineItem</code>. This attribute is required and replaces the
		/// <code>creativeSizes</code> attribute.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("creativePlaceholders", Order = 22)]
		public CreativePlaceholder[] creativePlaceholders {
			get {
				return this.creativePlaceholdersField;
			}
			set {
				this.creativePlaceholdersField = value;
			}
		}

		/// <summary>This attribute is required and meaningful only if the <a
		/// href='LineItem#costType'>LineItem#costType</a> is <a href=''>CostType.CPA</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("activityAssociations", Order = 23)]
		public LineItemActivityAssociation[] activityAssociations {
			get {
				return this.activityAssociationsField;
			}
			set {
				this.activityAssociationsField = value;
			}
		}

		/// <summary>The environment that the <code>LineItem</code> is targeting. The default value
		/// is <a href='EnvironmentType#BROWSER'>EnvironmentType#BROWSER</a>. If this value
		/// is <a href='EnvironmentType#VIDEO_PLAYER'>EnvironmentType#VIDEO_PLAYER</a>, then
		/// this line item can only target <code>AdUnits</code> that have
		/// <code>AdUnitSizes</code> whose <code>environmentType</code> is also
		/// <code></code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 24)]
		public EnvironmentType environmentType {
			get {
				return this.environmentTypeField;
			}
			set {
				this.environmentTypeField = value;
				this.environmentTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="environmentType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool environmentTypeSpecified {
			get {
				return this.environmentTypeFieldSpecified;
			}
			set {
				this.environmentTypeFieldSpecified = value;
			}
		}

		/// <summary>The delivery option for companions. Setting this field is only meaningful if the
		/// following conditions are met: <ol> <li>The <b>Guaranteed roadblocks</b> feature
		/// is enabled on your network.</li> <li>One of the following is true (both cannot
		/// be true, these are mutually exclusive). <ul> <li>The <a
		/// href='#environmentType'>#environmentType</a> is <a
		/// href='EnvironmentType#VIDEO_PLAYER'>EnvironmentType#VIDEO_PLAYER</a>.</li>
		/// <li>The <a href='#roadblockingType'>#roadblockingType</a> is <a
		/// href='RoadblockingType#CREATIVE_SET'>RoadblockingType#CREATIVE_SET</a>.</li>
		/// </ul> </li> </ol> <p>This field is optional and defaults to <a
		/// href='CompanionDeliveryOption#OPTIONAL'>CompanionDeliveryOption#OPTIONAL</a> if
		/// the above conditions are met. In all other cases it defaults to <a
		/// href='CompanionDeliveryOption#UNKNOWN'>CompanionDeliveryOption#UNKNOWN</a> and
		/// is not meaningful.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 25)]
		public CompanionDeliveryOption companionDeliveryOption {
			get {
				return this.companionDeliveryOptionField;
			}
			set {
				this.companionDeliveryOptionField = value;
				this.companionDeliveryOptionSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="companionDeliveryOption" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool companionDeliveryOptionSpecified {
			get {
				return this.companionDeliveryOptionFieldSpecified;
			}
			set {
				this.companionDeliveryOptionFieldSpecified = value;
			}
		}

		/// <summary>The flag indicates whether overbooking should be allowed when creating or
		/// updating reservations of line item types <a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a> and <a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a>. When true, operations on
		/// this line item will never trigger a <a href='ForecastError'>ForecastError</a>,
		/// which corresponds to an overbook warning in the UI. The default value is false.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 26)]
		public bool allowOverbook {
			get {
				return this.allowOverbookField;
			}
			set {
				this.allowOverbookField = value;
				this.allowOverbookSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowOverbook" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowOverbookSpecified {
			get {
				return this.allowOverbookFieldSpecified;
			}
			set {
				this.allowOverbookFieldSpecified = value;
			}
		}

		/// <summary>The flag indicates whether the inventory check should be skipped when performing
		/// an action on this line item. The default value is false.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 27)]
		public bool skipInventoryCheck {
			get {
				return this.skipInventoryCheckField;
			}
			set {
				this.skipInventoryCheckField = value;
				this.skipInventoryCheckSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="skipInventoryCheck" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool skipInventoryCheckSpecified {
			get {
				return this.skipInventoryCheckFieldSpecified;
			}
			set {
				this.skipInventoryCheckFieldSpecified = value;
			}
		}

		/// <summary>True to skip checks for warnings from rules applied to line items targeting
		/// inventory shared by a distributor partner for cross selling when performing an
		/// action on this line item. The default is false.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 28)]
		public bool skipCrossSellingRuleWarningChecks {
			get {
				return this.skipCrossSellingRuleWarningChecksField;
			}
			set {
				this.skipCrossSellingRuleWarningChecksField = value;
				this.skipCrossSellingRuleWarningChecksSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="skipCrossSellingRuleWarningChecks" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool skipCrossSellingRuleWarningChecksSpecified {
			get {
				return this.skipCrossSellingRuleWarningChecksFieldSpecified;
			}
			set {
				this.skipCrossSellingRuleWarningChecksFieldSpecified = value;
			}
		}

		/// <summary>The flag indicates whether inventory should be reserved when creating a line
		/// item of types <a href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a>
		/// and <a href='LineItemType#STANDARD'>LineItemType#STANDARD</a> in an unapproved
		/// <a href='Order'>Order</a>. The default value is false.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 29)]
		public bool reserveAtCreation {
			get {
				return this.reserveAtCreationField;
			}
			set {
				this.reserveAtCreationField = value;
				this.reserveAtCreationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="reserveAtCreation" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reserveAtCreationSpecified {
			get {
				return this.reserveAtCreationFieldSpecified;
			}
			set {
				this.reserveAtCreationFieldSpecified = value;
			}
		}

		/// <summary>Contains trafficking statistics for the line item. This attribute is readonly
		/// and is populated by Google. This will be <code>null</code> in case there are no
		/// statistics for a line item yet.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 30)]
		public Stats stats {
			get {
				return this.statsField;
			}
			set {
				this.statsField = value;
			}
		}

		/// <summary>Indicates how well the line item has been performing. This attribute is readonly
		/// and is populated by Google. This will be <code>null</code> if the delivery
		/// indicator information is not available due to one of the following reasons: <ol>
		/// <li>The line item is not delivering.</li> <li>The line item has an unlimited
		/// goal or cap.</li> <li>The line item has a percentage based goal or cap.</li>
		/// </ol>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 31)]
		public DeliveryIndicator deliveryIndicator {
			get {
				return this.deliveryIndicatorField;
			}
			set {
				this.deliveryIndicatorField = value;
			}
		}

		/// <summary>Delivery data provides the number of clicks or impressions delivered for a <a
		/// href='LineItem'>LineItem</a> in the last 7 days. This attribute is readonly and
		/// is populated by Google. This will be <code>null</code> if the delivery data
		/// cannot be computed due to one of the following reasons: <ol> <li>The line item
		/// is not deliverable.</li> <li>The line item has completed delivering more than 7
		/// days ago.</li> <li>The line item has an absolute-based goal. <a
		/// href='LineItem#deliveryIndicator'>LineItem#deliveryIndicator</a> should be used
		/// to track its progress in this case.</li> </ol>
		/// </summary>
		[System.Xml.Serialization.XmlArrayAttribute(Order = 32)]
		[System.Xml.Serialization.XmlArrayItemAttribute("units", IsNullable = false)]
		public long[] deliveryData {
			get {
				return this.deliveryDataField;
			}
			set {
				this.deliveryDataField = value;
			}
		}

		/// <summary>The amount of money allocated to the <code>LineItem</code>. This attribute is
		/// readonly and is populated by Google. The currency code is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 33)]
		public Money budget {
			get {
				return this.budgetField;
			}
			set {
				this.budgetField = value;
			}
		}

		/// <summary>The status of the <code>LineItem</code>. This attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 34)]
		public ComputedStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>Describes whether or not inventory has been reserved for the <code></code>. This
		/// attribute is readonly and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 35)]
		public LineItemSummaryReservationStatus reservationStatus {
			get {
				return this.reservationStatusField;
			}
			set {
				this.reservationStatusField = value;
				this.reservationStatusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="reservationStatus" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reservationStatusSpecified {
			get {
				return this.reservationStatusFieldSpecified;
			}
			set {
				this.reservationStatusFieldSpecified = value;
			}
		}

		/// <summary>The archival status of the <code>LineItem</code>. This attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 36)]
		public bool isArchived {
			get {
				return this.isArchivedField;
			}
			set {
				this.isArchivedField = value;
				this.isArchivedSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isArchived"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isArchivedSpecified {
			get {
				return this.isArchivedFieldSpecified;
			}
			set {
				this.isArchivedFieldSpecified = value;
			}
		}

		/// <summary>The web property code used for dynamic allocation line items. This web property
		/// is only required with line item types <a
		/// href='LineItemType#AD_EXCHANGE'>LineItemType#AD_EXCHANGE</a> and <a
		/// href='LineItemType#ADSENSE'>LineItemType#ADSENSE</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 37)]
		public string webPropertyCode {
			get {
				return this.webPropertyCodeField;
			}
			set {
				this.webPropertyCodeField = value;
			}
		}

		/// <summary>The set of labels applied directly to this line item.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("appliedLabels", Order = 38)]
		public AppliedLabel[] appliedLabels {
			get {
				return this.appliedLabelsField;
			}
			set {
				this.appliedLabelsField = value;
			}
		}

		/// <summary>Contains the set of labels inherited from the order that contains this line item
		/// and the advertiser that owns the order. If a label has been negated, only the
		/// negated label is returned. This field is readonly and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("effectiveAppliedLabels", Order = 39)]
		public AppliedLabel[] effectiveAppliedLabels {
			get {
				return this.effectiveAppliedLabelsField;
			}
			set {
				this.effectiveAppliedLabelsField = value;
			}
		}

		/// <summary>If a line item has a series of competitive exclusions on it, it could be blocked
		/// from serving with line items from the same advertiser. Setting this to
		/// <code>true</code> will allow line items from the same advertiser to serve
		/// regardless of the other competitive exclusion labels being applied.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 40)]
		public bool disableSameAdvertiserCompetitiveExclusion {
			get {
				return this.disableSameAdvertiserCompetitiveExclusionField;
			}
			set {
				this.disableSameAdvertiserCompetitiveExclusionField = value;
				this.disableSameAdvertiserCompetitiveExclusionSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="disableSameAdvertiserCompetitiveExclusion" />, <code>false</code>
		/// otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool disableSameAdvertiserCompetitiveExclusionSpecified {
			get {
				return this.disableSameAdvertiserCompetitiveExclusionFieldSpecified;
			}
			set {
				this.disableSameAdvertiserCompetitiveExclusionFieldSpecified = value;
			}
		}

		/// <summary>The application that last modified this line item. This attribute is read only
		/// and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 41)]
		public string lastModifiedByApp {
			get {
				return this.lastModifiedByAppField;
			}
			set {
				this.lastModifiedByAppField = value;
			}
		}

		/// <summary>Provides any additional notes that may annotate the <code></code>. This
		/// attribute is optional and has a maximum length of 65,535 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 42)]
		public string notes {
			get {
				return this.notesField;
			}
			set {
				this.notesField = value;
			}
		}

		/// <summary>The date and time this line item was last modified.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 43)]
		public DateTime lastModifiedDateTime {
			get {
				return this.lastModifiedDateTimeField;
			}
			set {
				this.lastModifiedDateTimeField = value;
			}
		}

		/// <summary>This attribute may be <code>null</code> for line items created before this
		/// feature was introduced.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 44)]
		public DateTime creationDateTime {
			get {
				return this.creationDateTimeField;
			}
			set {
				this.creationDateTimeField = value;
			}
		}

		/// <summary>Whether an AdExchange line item has prioritized preferred deals enabled. This
		/// attribute is optional and defaults to false.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 45)]
		public bool isPrioritizedPreferredDealsEnabled {
			get {
				return this.isPrioritizedPreferredDealsEnabledField;
			}
			set {
				this.isPrioritizedPreferredDealsEnabledField = value;
				this.isPrioritizedPreferredDealsEnabledSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isPrioritizedPreferredDealsEnabled" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isPrioritizedPreferredDealsEnabledSpecified {
			get {
				return this.isPrioritizedPreferredDealsEnabledFieldSpecified;
			}
			set {
				this.isPrioritizedPreferredDealsEnabledFieldSpecified = value;
			}
		}

		/// <summary>The priority at which an Ad Exchange line item enters the open Ad Exchange
		/// auction if the preferred deal fails to transact. This attribute is optional. If
		/// prioritized preferred deals are enabled, it defaults to 12. Otherwise, it is
		/// ignored.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 46)]
		public int adExchangeAuctionOpeningPriority {
			get {
				return this.adExchangeAuctionOpeningPriorityField;
			}
			set {
				this.adExchangeAuctionOpeningPriorityField = value;
				this.adExchangeAuctionOpeningPrioritySpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="adExchangeAuctionOpeningPriority" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool adExchangeAuctionOpeningPrioritySpecified {
			get {
				return this.adExchangeAuctionOpeningPriorityFieldSpecified;
			}
			set {
				this.adExchangeAuctionOpeningPriorityFieldSpecified = value;
			}
		}

		/// <summary>The values of the custom fields associated with this line item.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("customFieldValues", Order = 47)]
		public BaseCustomFieldValue[] customFieldValues {
			get {
				return this.customFieldValuesField;
			}
			set {
				this.customFieldValuesField = value;
			}
		}

		/// <summary>Flag that specifies whether this <code>LineItem</code> is a set-top box enabled
		/// line item. Set-top box line items only support the following creative sizes:
		/// 1920x1080 and 640x480. <p>This attribute is read-only after creation.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 48)]
		public bool isSetTopBoxEnabled {
			get {
				return this.isSetTopBoxEnabledField;
			}
			set {
				this.isSetTopBoxEnabledField = value;
				this.isSetTopBoxEnabledSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isSetTopBoxEnabled" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isSetTopBoxEnabledSpecified {
			get {
				return this.isSetTopBoxEnabledFieldSpecified;
			}
			set {
				this.isSetTopBoxEnabledFieldSpecified = value;
			}
		}

		/// <summary>Indicates if a <code>LineItem</code> is missing any <a
		/// href='Creative'>creatives</a> for the <code>creativePlaceholders</code>
		/// specified. <p><a href='Creative'>Creatives</a> can be considered missing for
		/// several reasons including:</p> <ul> <li>Not enough <a
		/// href='Creative'>creatives</a> of a certain size have been uploaded, as
		/// determined by <a
		/// href='CreativePlaceholder#expectedCreativeCount'>CreativePlaceholder#expectedCreativeCount</a>.
		/// For example a <code>LineItem</code> specifies 750x350, 400x200 but only a
		/// 750x350 was uploaded. Or <code>LineItem</code> specifies 750x350 with an
		/// expected count of 2, but only one was uploaded.</li> <li>The <a
		/// href='Creative#appliedLabels'>Creative#appliedLabels</a> of an associated
		/// <code>Creative</code> do not match the <a
		/// href='CreativePlaceholder#effectiveAppliedLabels'>CreativePlaceholder#effectiveAppliedLabels</a>
		/// of the <code>LineItem</code>. For example <code>LineItem</code> specifies
		/// 750x350 with a Foo <code>AppliedLabel</code> but a 750x350 creative without a
		/// <code>AppliedLabel</code> was uploaded.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 49)]
		public bool isMissingCreatives {
			get {
				return this.isMissingCreativesField;
			}
			set {
				this.isMissingCreativesField = value;
				this.isMissingCreativesSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isMissingCreatives" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isMissingCreativesSpecified {
			get {
				return this.isMissingCreativesFieldSpecified;
			}
			set {
				this.isMissingCreativesFieldSpecified = value;
			}
		}

		/// <summary>Additional information for set-top box enabled line items. This attribute is
		/// optional and only meaningful when <a
		/// href='#isSetTopBoxEnabled'>#isSetTopBoxEnabled</a> is <code>true</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 50)]
		public SetTopBoxInfo setTopBoxDisplayInfo {
			get {
				return this.setTopBoxDisplayInfoField;
			}
			set {
				this.setTopBoxDisplayInfoField = value;
			}
		}

		/// <summary>Indicates the <a
		/// href='ProgrammaticCreativeSource'>ProgrammaticCreativeSource</a> of the
		/// programmatic line item. This is a read-only field. Any changes must be made on
		/// the <a href='ProposalLineItem'>ProposalLineItem</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 51)]
		public ProgrammaticCreativeSource programmaticCreativeSource {
			get {
				return this.programmaticCreativeSourceField;
			}
			set {
				this.programmaticCreativeSourceField = value;
				this.programmaticCreativeSourceSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="programmaticCreativeSource" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool programmaticCreativeSourceSpecified {
			get {
				return this.programmaticCreativeSourceFieldSpecified;
			}
			set {
				this.programmaticCreativeSourceFieldSpecified = value;
			}
		}

		/// <summary>The max duration of a video creative associated with this <code></code> in
		/// milliseconds. This attribute is optional, defaults to 0, and only meaningful if
		/// this is a video line item.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 52)]
		public long videoMaxDuration {
			get {
				return this.videoMaxDurationField;
			}
			set {
				this.videoMaxDurationField = value;
				this.videoMaxDurationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="videoMaxDuration" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool videoMaxDurationSpecified {
			get {
				return this.videoMaxDurationFieldSpecified;
			}
			set {
				this.videoMaxDurationFieldSpecified = value;
			}
		}

		/// <summary>The primary goal that this <code>LineItem</code> is associated with, which is
		/// used in its pacing and budgeting.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 53)]
		public Goal primaryGoal {
			get {
				return this.primaryGoalField;
			}
			set {
				this.primaryGoalField = value;
			}
		}

		/// <summary>The secondary goals that this <code>LineItem</code> is associated with. It is
		/// required and meaningful only if the <a
		/// href='LineItem#costType'>LineItem#costType</a> is <a
		/// href='CostType.CPA'>CostType.CPA</a> or if the <a
		/// href=''>LineItem#lineItemType</a> is <a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a> and <a
		/// href='LineItem#costType'>LineItem#costType</a> is <a
		/// href='CostType.CPM'>CostType.CPM</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("secondaryGoals", Order = 54)]
		public Goal[] secondaryGoals {
			get {
				return this.secondaryGoalsField;
			}
			set {
				this.secondaryGoalsField = value;
			}
		}

		/// <summary>Contains the information for a line item which has a target GRP demographic.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 55)]
		public GrpSettings grpSettings {
			get {
				return this.grpSettingsField;
			}
			set {
				this.grpSettingsField = value;
			}
		}
	}


	/// <summary>Specifies the start type to use for an entity with a start date time field. For
	/// example, a <a href='LineItem'>LineItem</a> or <a
	/// href='LineItemCreativeAssociation'>LineItemCreativeAssociation</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum StartDateTimeType {
		/// <summary>Use the value in <a href='#startDateTime'>#startDateTime</a>.
		/// </summary>
		USE_START_DATE_TIME = 0,
		/// <summary>The entity will start serving immediately. <a
		/// href='#startDateTime'>#startDateTime</a> in the request is ignored and will be
		/// set to the current time. Additionally, <a
		/// href='#startDateTimeType'>#startDateTimeType</a> will be set to <a
		/// href='StartDateTimeType#USE_START_DATE_TIME'>StartDateTimeType#USE_START_DATE_TIME</a>.
		/// </summary>
		IMMEDIATELY = 1,
		/// <summary>The entity will start serving one hour from now. <a
		/// href='#startDateTime'>#startDateTime</a> in the request is ignored and will be
		/// set to one hour from the current time. Additionally, <a
		/// href='#startDateTimeType'>#startDateTimeType</a> will be set to <a
		/// href='StartDateTimeType#USE_START_DATE_TIME'>StartDateTimeType#USE_START_DATE_TIME</a>.
		/// </summary>
		ONE_HOUR_FROM_NOW = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>The strategy to use for displaying multiple <a href='Creative'>Creative</a>
	/// objects that are associated with a <a href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CreativeRotationType {
		/// <summary>Creatives are displayed roughly the same number of times over the duration of
		/// the line item.
		/// </summary>
		EVEN = 0,
		/// <summary>Creatives are served roughly proportionally to their performance.
		/// </summary>
		OPTIMIZED = 1,
		/// <summary>Creatives are served roughly proportionally to their weights, set on the <a
		/// href='LineItemCreativeAssociation'>LineItemCreativeAssociation</a>.
		/// </summary>
		MANUAL = 2,
		/// <summary>Creatives are served exactly in sequential order, aka Storyboarding. Set on the
		/// <a href='LineItemCreativeAssociation'>LineItemCreativeAssociation</a>.
		/// </summary>
		SEQUENTIAL = 3,
	}


	/// <summary>Possible delivery rates for a <a href='LineItem'>LineItem</a>, which dictate the
	/// manner in which they are served.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum DeliveryRateType {
		/// <summary>Line items are served as evenly as possible across the number of days specified
		/// in a line item's <a href='LineItem#duration'>LineItem#duration</a>.
		/// </summary>
		EVENLY = 0,
		/// <summary>Line items are served more aggressively in the beginning of the flight date.
		/// </summary>
		FRONTLOADED = 1,
		/// <summary>The booked impressions for a line item may be delivered well before the <a
		/// href='LineItem#endDateTime'>LineItem#endDateTime</a>. Other lower-priority or
		/// lower-value line items will be stopped from delivering until this line item
		/// meets the number of impressions or clicks it is booked for.
		/// </summary>
		AS_FAST_AS_POSSIBLE = 2,
	}


	/// <summary>Describes the roadblocking types.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RoadblockingType {
		/// <summary>Only one creative from a line item can serve at a time.
		/// </summary>
		ONLY_ONE = 0,
		/// <summary>Any number of creatives from a line item can serve together at a time.
		/// </summary>
		ONE_OR_MORE = 1,
		/// <summary>As many creatives from a line item as can fit on a page will serve. This could
		/// mean anywhere from one to all of a line item's creatives given the size
		/// constraints of ad slots on a page.
		/// </summary>
		AS_MANY_AS_POSSIBLE = 2,
		/// <summary>All or none of the creatives from a line item will serve. This option will only
		/// work if served to a GPT tag using SRA (single request architecture mode).
		/// </summary>
		ALL_ROADBLOCK = 3,
		/// <summary>A master/companion <a href='CreativeSet'>CreativeSet</a> roadblocking type. A <a
		/// href='LineItem#creativePlaceholders'>LineItem#creativePlaceholders</a> must be
		/// set accordingly.
		/// </summary>
		CREATIVE_SET = 4,
	}


	/// <summary><code>LineItemType</code> indicates the priority of a <a
	/// href='LineItem'>LineItem</a>, determined by the way in which impressions are
	/// reserved to be served for it.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LineItemType {
		/// <summary>The type of <a href='LineItem'>LineItem</a> for which a percentage of all the
		/// impressions that are being sold are reserved.
		/// </summary>
		SPONSORSHIP = 0,
		/// <summary>The type of <a href='LineItem'>LineItem</a> for which a fixed quantity of
		/// impressions or clicks are reserved.
		/// </summary>
		STANDARD = 1,
		/// <summary>The type of <a href='LineItem'>LineItem</a> most commonly used to fill a site's
		/// unsold inventory if not contractually obligated to deliver a requested number of
		/// impressions. Users specify the daily percentage of unsold impressions or clicks
		/// when creating this line item.
		/// </summary>
		NETWORK = 2,
		/// <summary>The type of <a href='LineItem'>LineItem</a> for which a fixed quantity of
		/// impressions or clicks will be delivered at a priority lower than the <a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a> type.
		/// </summary>
		BULK = 3,
		/// <summary>The type of <a href='LineItem'>LineItem</a> most commonly used to fill a site's
		/// unsold inventory if not contractually obligated to deliver a requested number of
		/// impressions. Users specify the fixed quantity of unsold impressions or clicks
		/// when creating this line item.
		/// </summary>
		PRICE_PRIORITY = 4,
		/// <summary>The type of <a href='LineItem'>LineItem</a> typically used for ads that promote
		/// products and services chosen by the publisher. These usually do not generate
		/// revenue and have the lowest delivery priority.
		/// </summary>
		HOUSE = 5,
		/// <summary>Represents a legacy <a href='LineItem'>LineItem</a> that has been migrated from
		/// the DFP system. Such line items cannot be created any more. Also, these line
		/// items cannot be activated or resumed.
		/// </summary>
		LEGACY_DFP = 6,
		/// <summary>The type of <a href='LineItem'>LineItem</a> used for ads that track ads being
		/// served externally of Ad Manager, for example an email newsletter. The click
		/// through would reference this ad, and the click would be tracked via this ad.
		/// </summary>
		CLICK_TRACKING = 7,
		/// <summary>A <a href='LineItem'>LineItem</a> using dynamic allocation backed by AdSense.
		/// </summary>
		ADSENSE = 8,
		/// <summary>A <a href='LineItem'>LineItem</a> using dynamic allocation backed by the Google
		/// Ad Exchange.
		/// </summary>
		AD_EXCHANGE = 9,
		/// <summary>Represents a non-monetizable video <a href='LineItem'>LineItem</a> that targets
		/// one or more bumper positions, which are short house video messages used by
		/// publishers to separate content from ad breaks.
		/// </summary>
		BUMPER = 10,
		/// <summary>A <a href='LineItem'>LineItem</a> using dynamic allocation backed by AdMob.
		/// </summary>
		ADMOB = 11,
		/// <summary>The type of <a href='LineItem'>LineItem</a> for which there are no impressions
		/// reserved, and will serve for a second price bid. All <a
		/// href='LineItem'>LineItem</a>s of type <a
		/// href='LineItemType#PREFERRED_DEAL'>LineItemType#PREFERRED_DEAL</a> should be
		/// created via a <a href='ProposalLineItem'>ProposalLineItem</a> with a matching
		/// type. When creating a <a href='LineItem'>LineItem</a> of type <a
		/// href='LineItemType#PREFERRED_DEAL'>LineItemType#PREFERRED_DEAL</a>, the <a
		/// href='ProposalLineItem#estimatedMinimumImpressions'>ProposalLineItem#estimatedMinimumImpressions</a>
		/// field is required.
		/// </summary>
		PREFERRED_DEAL = 13,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 12,
	}


	/// <summary>Describes the <a href='LineItem'>LineItem</a> actions that are billable.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CostType {
		/// <summary>Cost per action. The <a href='LineItem#lineItemType'>LineItem#lineItemType</a>
		/// must be one of: <ul> <li><a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a></li> <li><a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a></li> <li><a
		/// href='LineItemType#BULK'>LineItemType#BULK</a></li> <li><a
		/// href='LineItemType#NETWORK'>LineItemType#NETWORK</a></li> </ul>
		/// </summary>
		CPA = 0,
		/// <summary>Cost per click. The <a href='LineItem#lineItemType'>LineItem#lineItemType</a>
		/// must be one of: <ul> <li><a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a></li> <li><a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a></li> <li><a
		/// href='LineItemType#BULK'>LineItemType#BULK</a></li> <li><a
		/// href='LineItemType#NETWORK'>LineItemType#NETWORK</a></li> <li><a
		/// href='LineItemType#PRICE_PRIORITY'>LineItemType#PRICE_PRIORITY</a></li> <li><a
		/// href='LineItemType#HOUSE'>LineItemType#HOUSE</a></li> </ul>
		/// </summary>
		CPC = 1,
		/// <summary>Cost per day. The <a href='LineItem#lineItemType'>LineItem#lineItemType</a> must
		/// be one of: <ul> <li><a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a></li> <li><a
		/// href='LineItemType#NETWORK'>LineItemType#NETWORK</a></li> </ul>
		/// </summary>
		CPD = 2,
		/// <summary>Cost per mille (cost per thousand impressions). The <a
		/// href='LineItem#lineItemType'>LineItem#lineItemType</a> must be one of: <ul>
		/// <li><a href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a></li> <li><a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a></li> <li><a
		/// href='LineItemType#BULK'>LineItemType#BULK</a></li> <li><a
		/// href='LineItemType#NETWORK'>LineItemType#NETWORK</a></li> <li><a
		/// href='LineItemType#PRICE_PRIORITY'>LineItemType#PRICE_PRIORITY</a></li> <li><a
		/// href='LineItemType#HOUSE'>LineItemType#HOUSE</a></li> </ul>
		/// </summary>
		CPM = 3,
		/// <summary>Cost per thousand Active View viewable impressions. The <a
		/// href='LineItem#lineItemType'>LineItem#lineItemType</a> must be <a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a>.
		/// </summary>
		VCPM = 5,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>Describes the possible discount types on the cost of booking a <a
	/// href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LineItemDiscountType {
		/// <summary>An absolute value will be discounted from the line item's cost.
		/// </summary>
		ABSOLUTE_VALUE = 0,
		/// <summary>A percentage of the cost will be applied as discount for booking the line item.
		/// </summary>
		PERCENTAGE = 1,
	}


	/// <summary>Enum for the valid environments in which ads can be shown.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum EnvironmentType {
		/// <summary>A regular web browser.
		/// </summary>
		BROWSER = 0,
		/// <summary>Video players.
		/// </summary>
		VIDEO_PLAYER = 1,
	}


	/// <summary>The delivery option for companions. Used for line items whose environmentType is
	/// <a href='EnvironmentType#VIDEO_PLAYER'>EnvironmentType#VIDEO_PLAYER</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CompanionDeliveryOption {
		/// <summary>Companions are not required to serve a creative set. The creative set can serve
		/// to inventory that has zero or more matching companions.
		/// </summary>
		OPTIONAL = 0,
		/// <summary>At least one companion must be served in order for the creative set to be used.
		/// </summary>
		AT_LEAST_ONE = 1,
		/// <summary>All companions in the set must be served in order for the creative set to be
		/// used. This can still serve to inventory that has more companions than can be
		/// filled.
		/// </summary>
		ALL = 2,
		/// <summary>The delivery type is unknown.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Describes the computed <a href='LineItem'>LineItem</a> status that is derived
	/// from the current state of the line item.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ComputedStatus {
		/// <summary>The <a href='LineItem'>LineItem</a> has past its <a
		/// href='LineItem#endDateTime'>LineItem#endDateTime</a> with an auto extension, but
		/// hasn't met its goal.
		/// </summary>
		DELIVERY_EXTENDED = 0,
		/// <summary>The <a href='LineItem'>LineItem</a> has begun serving.
		/// </summary>
		DELIVERING = 1,
		/// <summary>The <a href='LineItem'>LineItem</a> has been activated and is ready to serve.
		/// </summary>
		READY = 2,
		/// <summary>The <a href='LineItem'>LineItem</a> has been paused from serving.
		/// </summary>
		PAUSED = 3,
		/// <summary>The <a href='LineItem'>LineItem</a> is inactive. It is either caused by missing
		/// creatives or the network disabling auto-activation.
		/// </summary>
		INACTIVE = 4,
		/// <summary>The <a href='LineItem'>LineItem</a> has been paused and its reserved inventory
		/// has been released. The <code>LineItem</code> will not serve.
		/// </summary>
		PAUSED_INVENTORY_RELEASED = 5,
		/// <summary>The <a href='LineItem'>LineItem</a> has been submitted for approval.
		/// </summary>
		PENDING_APPROVAL = 6,
		/// <summary>The <a href='LineItem'>LineItem</a> has completed its run.
		/// </summary>
		COMPLETED = 7,
		/// <summary>The <a href='LineItem'>LineItem</a> has been disapproved and is not eligible to
		/// serve.
		/// </summary>
		DISAPPROVED = 8,
		/// <summary>The <a href='LineItem'>LineItem</a> is still being drafted.
		/// </summary>
		DRAFT = 9,
		/// <summary>The <a href='LineItem'>LineItem</a> has been canceled and is no longer eligible
		/// to serve. This is a legacy status imported from Google Ad Manager orders.
		/// </summary>
		CANCELED = 10,
	}


	/// <summary>Specifies the reservation status of the <a href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "LineItemSummary.ReservationStatus", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LineItemSummaryReservationStatus {
		/// <summary>Indicates that inventory has been reserved for the line item.
		/// </summary>
		RESERVED = 0,
		/// <summary>Indicates that inventory has not been reserved for the line item.
		/// </summary>
		UNRESERVED = 1,
	}


	/// <summary>Types of programmatic creative sources.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProgrammaticCreativeSource {
		/// <summary>Indicates that the programmatic line item is associated with creatives provided
		/// by the publisher.
		/// </summary>
		PUBLISHER = 0,
		/// <summary>Indicates that the programmatic line item is associated with creatives provided
		/// by the advertiser.
		/// </summary>
		ADVERTISER = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary><code>LineItem</code> is an advertiser's commitment to purchase a specific
	/// number of ad impressions, clicks, or time.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LineItem : LineItemSummary {
		private Targeting targetingField;

		private CreativeTargeting[] creativeTargetingsField;

		/// <summary>Contains the targeting criteria for the ad campaign. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public Targeting targeting {
			get {
				return this.targetingField;
			}
			set {
				this.targetingField = value;
			}
		}

		/// <summary>A list of <a href='CreativeTargeting'>CreativeTargeting</a> objects that can be
		/// used to specify creative level targeting for this line item. Creative level
		/// targeting is specified in a creative placeholder's <a
		/// href='CreativePlaceholder#targetingName'>CreativePlaceholder#targetingName</a>
		/// field by referencing the creative targeting's <a
		/// href='CreativeTargeting#name'>name</a>. It also needs to be re-specified in the
		/// <a
		/// href='LineItemCreativeAssociation#targetingName'>LineItemCreativeAssociation#targetingName</a>
		/// field when associating a line item with a creative that fits into that
		/// placeholder.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("creativeTargetings", Order = 1)]
		public CreativeTargeting[] creativeTargetings {
			get {
				return this.creativeTargetingsField;
			}
			set {
				this.creativeTargetingsField = value;
			}
		}
	}


	/// <summary>Represents a prospective line item to be forecasted.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProspectiveLineItem {
		private LineItem lineItemField;

		private long advertiserIdField;

		private bool advertiserIdFieldSpecified;

		/// <summary>The target of the forecast. If <a href='LineItem#id'>LineItem#id</a> is null or
		/// no line item exists with that ID, then a forecast is computed for the subject,
		/// predicting what would happen if it were added to the network. If a line item
		/// already exists with <a href='LineItem#id'>LineItem#id</a>, the forecast is
		/// computed for the subject, predicting what would happen if the existing line
		/// item's settings were modified to match the subject.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public LineItem lineItem {
			get {
				return this.lineItemField;
			}
			set {
				this.lineItemField = value;
			}
		}

		/// <summary>When set, the line item is assumed to be from this advertiser, and unified
		/// blocking rules will apply accordingly. If absent, line items without an existing
		/// order won't be subject to unified blocking rules.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long advertiserId {
			get {
				return this.advertiserIdField;
			}
			set {
				this.advertiserIdField = value;
				this.advertiserIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="advertiserId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool advertiserIdSpecified {
			get {
				return this.advertiserIdFieldSpecified;
			}
			set {
				this.advertiserIdFieldSpecified = value;
			}
		}
	}


	/// <summary>Lists all errors related to <a
	/// href='VideoPositionTargeting'>VideoPositionTargeting</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class VideoPositionTargetingError : ApiError {
		private VideoPositionTargetingErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public VideoPositionTargetingErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the video position targeting error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "VideoPositionTargetingError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum VideoPositionTargetingErrorReason {
		/// <summary>Video position targeting cannot contain both bumper and non-bumper targeting
		/// values.
		/// </summary>
		CANNOT_MIX_BUMPER_AND_NON_BUMPER_TARGETING = 0,
		/// <summary>The bumper video position targeting is invalid.
		/// </summary>
		INVALID_BUMPER_TARGETING = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Lists all errors related to user domain targeting for a line item.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UserDomainTargetingError : ApiError {
		private UserDomainTargetingErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public UserDomainTargetingErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary><a href='ApiErrorReason'>ApiErrorReason</a> enum for user domain targeting
	/// error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "UserDomainTargetingError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum UserDomainTargetingErrorReason {
		/// <summary>Invalid domain names. Domain names must be at most 67 characters long. And must
		/// contain only alphanumeric characters and hyphens.
		/// </summary>
		INVALID_DOMAIN_NAMES = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>Errors related to timezones.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class TimeZoneError : ApiError {
		private TimeZoneErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public TimeZoneErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes reasons for invalid timezone.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "TimeZoneError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum TimeZoneErrorReason {
		/// <summary>Indicates that the timezone ID provided is not supported.
		/// </summary>
		INVALID_TIMEZONE_ID = 0,
		/// <summary>Indicates that the timezone ID provided is in the wrong format. The timezone ID
		/// must be in tz database format (e.g. "America/Los_Angeles").
		/// </summary>
		TIMEZONE_ID_IN_WRONG_FORMAT = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Technology targeting validation errors.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class TechnologyTargetingError : ApiError {
		private TechnologyTargetingErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public TechnologyTargetingErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "TechnologyTargetingError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum TechnologyTargetingErrorReason {
		/// <summary>Mobile line item cannot target web-only targeting criteria.
		/// </summary>
		MOBILE_LINE_ITEM_CONTAINS_WEB_TECH_CRITERIA = 0,
		/// <summary>Web line item cannot target mobile-only targeting criteria.
		/// </summary>
		WEB_LINE_ITEM_CONTAINS_MOBILE_TECH_CRITERIA = 1,
		/// <summary>The mobile carrier targeting feature is not enabled.
		/// </summary>
		MOBILE_CARRIER_TARGETING_FEATURE_NOT_ENABLED = 2,
		/// <summary>The device capability targeting feature is not enabled.
		/// </summary>
		DEVICE_CAPABILITY_TARGETING_FEATURE_NOT_ENABLED = 3,
		/// <summary>The device category targeting feature is not enabled.
		/// </summary>
		DEVICE_CATEGORY_TARGETING_FEATURE_NOT_ENABLED = 4,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 5,
	}


	/// <summary>Errors related to a Team.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class TeamError : ApiError {
		private TeamErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public TeamErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "TeamError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum TeamErrorReason {
		/// <summary>User cannot use this entity because it is not on any of the user's teams.
		/// </summary>
		ENTITY_NOT_ON_USERS_TEAMS = 0,
		/// <summary>The targeted or excluded ad unit must be on the order's teams.
		/// </summary>
		AD_UNITS_NOT_ON_ORDER_TEAMS = 1,
		/// <summary>The targeted placement must be on the order's teams.
		/// </summary>
		PLACEMENTS_NOT_ON_ORDER_TEAMS = 2,
		/// <summary>Entity cannot be created because it is not on any of the user's teams.
		/// </summary>
		MISSING_USERS_TEAM = 3,
		/// <summary>A team that gives access to all entities of a given type cannot be associated
		/// with an entity of that type.
		/// </summary>
		ALL_TEAM_ASSOCIATION_NOT_ALLOWED = 4,
		/// <summary>The assignment of team to entities is invalid.
		/// </summary>
		INVALID_TEAM_ASSIGNMENT = 7,
		/// <summary>The all entities team access type cannot be overridden.
		/// </summary>
		ALL_TEAM_ACCESS_OVERRIDE_NOT_ALLOWED = 5,
		/// <summary>Cannot modify or create a team with an inactive status.
		/// </summary>
		CANNOT_UPDATE_INACTIVE_TEAM = 8,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 6,
	}


	/// <summary>Errors associated with set-top box <a href='LineItem'>line items</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SetTopBoxLineItemError : ApiError {
		private SetTopBoxLineItemErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public SetTopBoxLineItemErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Reason for set-top box error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "SetTopBoxLineItemError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum SetTopBoxLineItemErrorReason {
		/// <summary>The set-top box line item cannot target an ad unit that doesn't have an external
		/// set-top box channel ID.
		/// </summary>
		NON_SET_TOP_BOX_AD_UNIT_TARGETED = 0,
		/// <summary>The set-top box line item must target at least one ad unit.
		/// </summary>
		AT_LEAST_ONE_AD_UNIT_MUST_BE_TARGETED = 1,
		/// <summary>The set-top box line item cannot exclude ad units.
		/// </summary>
		CANNOT_EXCLUDE_AD_UNITS = 2,
		/// <summary>The set-top box line item can only target pod positions 1 - 15.
		/// </summary>
		POD_POSITION_OUT_OF_RANGE = 3,
		/// <summary>The set-top box line item can only target midroll positions 4 - 100.
		/// </summary>
		MIDROLL_POSITION_OUT_OF_RANGE = 4,
		/// <summary>The set-top box feature is not enabled.
		/// </summary>
		FEATURE_NOT_ENABLED = 5,
		/// <summary>Only <a href='EnvironmentType#VIDEO_PLAYER'>EnvironmentType#VIDEO_PLAYER</a> is
		/// supported for set-top box line items.
		/// </summary>
		INVALID_ENVIRONMENT_TYPE = 6,
		/// <summary>Companions are not supported for set-top box line items.
		/// </summary>
		COMPANIONS_NOT_SUPPORTED = 7,
		/// <summary>Set-top box line items only support sizes supported by Canoe.
		/// </summary>
		INVALID_CREATIVE_SIZE = 8,
		/// <summary>Set-top box line items only support <a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a>, <a
		/// href='LineItemType#HOUSE'>LineItemType#HOUSE</a>, and <a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a> line item types.
		/// </summary>
		INVALID_LINE_ITEM_TYPE = 9,
		/// <summary><a href='Order'>orders</a> containing <a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a> set-top box line items
		/// cannot contain set-top box line items of type <a
		/// href='LineItemType#HOUSE'>LineItemType#HOUSE</a> or <a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a>.
		/// </summary>
		ORDERS_WITH_STANDARD_LINE_ITEMS_CANNOT_CONTAIN_HOUSE_OR_SPONSORSHIP_LINE_ITEMS = 10,
		/// <summary>Set-top box line items only support <a href='CostType#CPM'>CostType#CPM</a>.
		/// </summary>
		INVALID_COST_TYPE = 11,
		/// <summary>Set-top box line items do not support a cost per unit.
		/// </summary>
		COST_PER_UNIT_NOT_ALLOWED = 12,
		/// <summary>Set-top box line items do not support discounts.
		/// </summary>
		DISCOUNT_NOT_ALLOWED = 13,
		/// <summary>Set-top box line items do not support <a
		/// href='DeliveryRateType#FRONTLOADED'>DeliveryRateType#FRONTLOADED</a>.
		/// </summary>
		FRONTLOADED_DELIVERY_RATE_NOT_SUPPORTED = 14,
		/// <summary>Set-top box line items cannot go from a state that is ready to be synced to a
		/// state that is not ready to be synced.
		/// </summary>
		INVALID_LINE_ITEM_STATUS_CHANGE = 15,
		/// <summary>Set-top box line items can only have certain priorities for different <a
		/// href='ReservationType'>reservation types</a>: <ul> <li><a
		/// href='ReservationType#SPONSORSHIP'>ReservationType#SPONSORSHIP</a> =&gt; 1</li>
		/// <li><a href='ReservationType#HOUSE'>ReservationType#HOUSE</a> =&gt; 16</li>
		/// <li><a href='ReservationType#STANDARD'>ReservationType#STANDARD</a> =&gt;
		/// Between 1 and 16 inclusive.</li> </ul>
		/// </summary>
		INVALID_LINE_ITEM_PRIORITY = 16,
		/// <summary>When a set-top box line item is pushed to Canoe, a revision number is used to
		/// keep track of the last version of the line item that Ad Manager synced with
		/// Canoe. The only change allowed on revisions within Ad Manager is increasing the
		/// revision number.
		/// </summary>
		SYNC_REVISION_NOT_INCREASING = 17,
		/// <summary>When a set-top box line item is pushed to Canoe, a revision number is used to
		/// keep track of the last version of the line item that Ad Manager synced with
		/// Canoe. Sync revisions begin at one and can only increase in value.
		/// </summary>
		SYNC_REVISION_MUST_BE_GREATER_THAN_ZERO = 18,
		/// <summary>Set Top box line items cannot be unarchived.
		/// </summary>
		CANNOT_UNARCHIVE_SET_TOP_BOX_LINE_ITEMS = 19,
		/// <summary>Set-top box enabled line items cannot be copied for V0 of the video Canoe
		/// campaign push.
		/// </summary>
		COPY_SET_TOP_BOX_ENABLED_LINE_ITEM_NOT_ALLOWED = 20,
		/// <summary>Standard set-top box line items cannot be updated to be <a
		/// href='LineItemType#House'>LineItemType#House</a> or <a
		/// href='LineItemType#Sponsorship'>LineItemType#Sponsorship</a> line items and vice
		/// versa.
		/// </summary>
		INVALID_LINE_ITEM_TYPE_CHANGE = 21,
		/// <summary>Set-top box line items can only have a creative rotation type of <a
		/// href='CreativeRotationType.EVEN'>CreativeRotationType.EVEN</a> or <a
		/// href='CreativeRotationType#MANUAL'>CreativeRotationType#MANUAL</a>.
		/// </summary>
		CREATIVE_ROTATION_TYPE_MUST_BE_EVENLY_OR_WEIGHTED = 22,
		/// <summary>Set-top box line items can only have frequency capping with time units of <a
		/// href='TimeUnit#DAY'>TimeUnit#DAY</a>, <a href='TimeUnit#HOUR'>TimeUnit#HOUR</a>,
		/// <a href='TimeUnit#POD'>TimeUnit#POD</a>, or <a
		/// href='TimeUnit#STREAM'>TimeUnit#STREAM</a>.
		/// </summary>
		INVALID_FREQUENCY_CAP_TIME_UNIT = 23,
		/// <summary>Set-top box line items can only have specific time ranges for certain time
		/// units: <ul> <li><a href='TimeUnit#HOUR'>TimeUnit#HOUR</a> =&gt; 1, 2, 6</li>
		/// <li><a href='TimeUnit#DAY'>TimeUnit#DAY</a> =&gt; 1, 3</li> </ul>
		/// </summary>
		INVALID_FREQUENCY_CAP_TIME_RANGE = 24,
		/// <summary>Set-top box line items can only have a unit type of <a
		/// href='UnitType#IMPRESSIONS'>UnitType#IMPRESSIONS</a>.
		/// </summary>
		INVALID_PRIMARY_GOAL_UNIT_TYPE = 25,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 26,
	}


	/// <summary>Errors that could occur on audience segment related requests.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AudienceSegmentError : ApiError {
		private AudienceSegmentErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AudienceSegmentErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Reason of the given <a href='AudienceSegmentError'>AudienceSegmentError</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AudienceSegmentError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AudienceSegmentErrorReason {
		/// <summary>First party audience segment is not supported.
		/// </summary>
		FIRST_PARTY_AUDIENCE_SEGMENT_NOT_SUPPORTED = 0,
		/// <summary>Only rule-based first-party audience segments can be created.
		/// </summary>
		ONLY_RULE_BASED_FIRST_PARTY_AUDIENCE_SEGMENTS_CAN_BE_CREATED = 1,
		/// <summary>Audience segment for the given id is not found.
		/// </summary>
		AUDIENCE_SEGMENT_ID_NOT_FOUND = 2,
		/// <summary>Audience segment rule is invalid.
		/// </summary>
		INVALID_AUDIENCE_SEGMENT_RULE = 3,
		/// <summary>Audience segment rule contains too many ad units and/or custom criteria.
		/// </summary>
		AUDIENCE_SEGMENT_RULE_TOO_LONG = 4,
		/// <summary>Audience segment name is invalid.
		/// </summary>
		INVALID_AUDIENCE_SEGMENT_NAME = 5,
		/// <summary>Audience segment with this name already exists.
		/// </summary>
		DUPLICATE_AUDIENCE_SEGMENT_NAME = 6,
		/// <summary>Audience segment description is invalid.
		/// </summary>
		INVALID_AUDIENCE_SEGMENT_DESCRIPTION = 7,
		/// <summary>Audience segment pageviews value is invalid. It must be between 1 and 12.
		/// </summary>
		INVALID_AUDIENCE_SEGMENT_PAGEVIEWS = 8,
		/// <summary>Audience segment recency value is invalid. It must be between 1 and 90 if
		/// pageviews &gt; 1.
		/// </summary>
		INVALID_AUDIENCE_SEGMENT_RECENCY = 9,
		/// <summary>Audience segment membership expiration value is invalid. It must be between 1
		/// and 180.
		/// </summary>
		INVALID_AUDIENCE_SEGMENT_MEMBERSHIP_EXPIRATION = 10,
		/// <summary>The given custom key cannot be part of audience segment rule due to unsupported
		/// characters.
		/// </summary>
		INVALID_AUDIENCE_SEGMENT_CUSTOM_KEY_NAME = 11,
		/// <summary>The given custom value cannot be part of audience segment rule due to
		/// unsupported characters.
		/// </summary>
		INVALID_AUDIENCE_SEGMENT_CUSTOM_VALUE_NAME = 12,
		/// <summary>Broad-match custom value cannot be part of audience segment rule.
		/// </summary>
		INVALID_AUDIENCE_SEGMENT_CUSTOM_VALUE_MATCH_TYPE = 13,
		/// <summary>Audience segment rule cannot contain itself.
		/// </summary>
		INVALID_NESTED_FIRST_PARTY_AUDIENCE_SEGMENT = 14,
		/// <summary>Audience segment rule cannot contain a nested third-party segment.
		/// </summary>
		INVALID_NESTED_THIRD_PARTY_AUDIENCE_SEGMENT = 15,
		/// <summary>Audience segment rule cannot contain a nested inactive segment.
		/// </summary>
		INACTIVE_NESTED_AUDIENCE_SEGMENT = 16,
		/// <summary>An error occured when purchasing global licenses.
		/// </summary>
		AUDIENCE_SEGMENT_GLOBAL_LICENSE_ERROR = 17,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 18,
	}


	/// <summary>Lists all errors associated with LineItem's reservation details.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReservationDetailsError : ApiError {
		private ReservationDetailsErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ReservationDetailsErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ReservationDetailsError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ReservationDetailsErrorReason {
		/// <summary>There is no limit on the number of ads delivered for a line item when you set <a
		/// href='LineItem#duration'>LineItem#duration</a> to be <a
		/// href='LineItemSummary.Duration#NONE'>LineItemSummary.Duration#NONE</a>. This can
		/// only be set for line items of type <a
		/// href='LineItemType#PRICE_PRIORITY'>LineItemType#PRICE_PRIORITY</a>.
		/// </summary>
		UNLIMITED_UNITS_BOUGHT_NOT_ALLOWED = 0,
		/// <summary><a href='LineItem#unlimitedEndDateTime'>LineItem#unlimitedEndDateTime</a> can be
		/// set to true for only line items of type <a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a>, <a
		/// href='LineItemType#NETWORK'>LineItemType#NETWORK</a>, <a
		/// href='LineItemType#PRICE_PRIORITY'>LineItemType#PRICE_PRIORITY</a> and <a
		/// href='LineItemType#HOUSE'>LineItemType#HOUSE</a>.
		/// </summary>
		UNLIMITED_END_DATE_TIME_NOT_ALLOWED = 1,
		/// <summary>When <a href='LineItem#lineItemType'>LineItem#lineItemType</a> is <a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a>, then <a
		/// href='LineItem#unitsBought'>LineItem#unitsBought</a> represents the percentage
		/// of available impressions reserved. That value cannot exceed 100.
		/// </summary>
		PERCENTAGE_UNITS_BOUGHT_TOO_HIGH = 2,
		/// <summary>The line item type does not support the specified duration. See <a
		/// href='LineItemSummary.Duration'>LineItemSummary.Duration</a> for allowed values.
		/// </summary>
		DURATION_NOT_ALLOWED = 3,
		/// <summary>The <a href='LineItem#unitType'>LineItem#unitType</a> is not allowed for the
		/// given <a href='LineItem#lineItemType'>LineItem#lineItemType</a>. See <a
		/// href='UnitType'>UnitType</a> for allowed values.
		/// </summary>
		UNIT_TYPE_NOT_ALLOWED = 4,
		/// <summary>The <a href='LineItem#costType'>LineItem#costType</a> is not allowed for the <a
		/// href='LineItem#lineItemType'>LineItem#lineItemType</a>. See <a
		/// href='CostType'>CostType</a> for allowed values.
		/// </summary>
		COST_TYPE_NOT_ALLOWED = 5,
		/// <summary>When <a href='LineItem#costType'>LineItem#costType</a> is <a
		/// href='CostType#CPM'>CostType#CPM</a>, <a
		/// href='LineItem#unitType'>LineItem#unitType</a> must be <a
		/// href='UnitType#IMPRESSIONS'>UnitType#IMPRESSIONS</a> and when <a
		/// href='LineItem#costType'>LineItem#costType</a> is <a
		/// href='CostType#CPC'>CostType#CPC</a>, <a
		/// href='LineItem#unitType'>LineItem#unitType</a> must be <a
		/// href='UnitType#CLICKS'>UnitType#CLICKS</a>.
		/// </summary>
		COST_TYPE_UNIT_TYPE_MISMATCH_NOT_ALLOWED = 6,
		/// <summary>Inventory cannot be reserved for line items which are not of type <a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a> or <a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a>.
		/// </summary>
		LINE_ITEM_TYPE_NOT_ALLOWED = 7,
		/// <summary>Network remnant line items cannot be changed to other line item types once
		/// delivery begins. This restriction does not apply to any new line items created
		/// in Ad Manager.
		/// </summary>
		NETWORK_REMNANT_ORDER_CANNOT_UPDATE_LINEITEM_TYPE = 8,
		/// <summary>A dynamic allocation web property can only be set on a line item of type AdSense
		/// or Ad Exchange.
		/// </summary>
		BACKFILL_WEBPROPERTY_CODE_NOT_ALLOWED = 9,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 10,
	}


	/// <summary>Caused by supplying a value for an object attribute that does not conform to a
	/// documented valid regular expression.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RegExError : ApiError {
		private RegExErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public RegExErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "RegExError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RegExErrorReason {
		/// <summary>Invalid value found.
		/// </summary>
		INVALID = 0,
		/// <summary>Null value found.
		/// </summary>
		NULL = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Errors associated with programmatic line items.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProgrammaticError : ApiError {
		private ProgrammaticErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ProgrammaticErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Possible error reasons for a programmatic error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ProgrammaticError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProgrammaticErrorReason {
		/// <summary>Audience extension is not supported by programmatic line items.
		/// </summary>
		AUDIENCE_EXTENSION_NOT_SUPPORTED = 0,
		/// <summary>Auto extension days is not supported by programmatic line items.
		/// </summary>
		AUTO_EXTENSION_DAYS_NOT_SUPPORTED = 1,
		/// <summary>Video is currently not supported.
		/// </summary>
		VIDEO_NOT_SUPPORTED = 2,
		/// <summary>Roadblocking is not supported by programmatic line items.
		/// </summary>
		ROADBLOCKING_NOT_SUPPORTED = 3,
		/// <summary>Programmatic line items do not support <a
		/// href='CreativeRotationType#SEQUENTIAL'>CreativeRotationType#SEQUENTIAL</a>.
		/// </summary>
		INVALID_CREATIVE_ROTATION = 4,
		/// <summary>Programmatic line items only support <a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a> and <a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a> if the relevant
		/// feature is on.
		/// </summary>
		INVALID_LINE_ITEM_TYPE = 5,
		/// <summary>Programmatic line items only support <a href='CostType#CPM'>CostType#CPM</a>.
		/// </summary>
		INVALID_COST_TYPE = 6,
		/// <summary>Programmatic line items only support a creative size that is supported by AdX.
		/// The list of supported sizes is maintained based on the list published in the
		/// help docs: <a
		/// href="https://support.google.com/adxseller/answer/1100453">https://support.google.com/adxseller/answer/1100453</a>
		/// </summary>
		SIZE_NOT_SUPPORTED = 7,
		/// <summary>Zero cost per unit is not supported by programmatic line items.
		/// </summary>
		ZERO_COST_PER_UNIT_NOT_SUPPORTED = 8,
		/// <summary>Some fields cannot be updated on approved line items.
		/// </summary>
		CANNOT_UPDATE_FIELD_FOR_APPROVED_LINE_ITEMS = 9,
		/// <summary>Creating a new line item in an approved order is not allowed.
		/// </summary>
		CANNOT_CREATE_LINE_ITEM_FOR_APPROVED_ORDER = 10,
		/// <summary>Cannot change backfill web property for a programmatic line item whose order has
		/// been approved.
		/// </summary>
		CANNOT_UPDATE_BACKFILL_WEB_PROPERTY_FOR_APPROVED_LINE_ITEMS = 11,
		/// <summary>Cost per unit is too low. It has to be at least 0.005 USD.
		/// </summary>
		COST_PER_UNIT_TOO_LOW = 13,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 12,
	}


	/// <summary>Lists all errors associated with orders.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class OrderError : ApiError {
		private OrderErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public OrderErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "OrderError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum OrderErrorReason {
		/// <summary>Updating a canceled order is not allowed.
		/// </summary>
		UPDATE_CANCELED_ORDER_NOT_ALLOWED = 0,
		/// <summary>Updating an order that has its approval pending is not allowed.
		/// </summary>
		UPDATE_PENDING_APPROVAL_ORDER_NOT_ALLOWED = 1,
		/// <summary>Updating an archived order is not allowed.
		/// </summary>
		UPDATE_ARCHIVED_ORDER_NOT_ALLOWED = 2,
		/// <summary>DSM can set the proposal ID only at the time of creation of order. Setting or
		/// changing proposal ID at the time of order update is not allowed.
		/// </summary>
		CANNOT_MODIFY_PROPOSAL_ID = 3,
		/// <summary>Cannot have secondary user without a primary user.
		/// </summary>
		PRIMARY_USER_REQUIRED = 4,
		/// <summary>Primary user cannot be added as a secondary user too.
		/// </summary>
		PRIMARY_USER_CANNOT_BE_SECONDARY = 5,
		/// <summary>A team associated with the order must also be associated with the advertiser.
		/// </summary>
		ORDER_TEAM_NOT_ASSOCIATED_WITH_ADVERTISER = 6,
		/// <summary>The user assigned to the order, like salesperson or trafficker, must be on one
		/// of the order's teams.
		/// </summary>
		USER_NOT_ON_ORDERS_TEAMS = 7,
		/// <summary>The agency assigned to the order must belong to one of the order's teams.
		/// </summary>
		AGENCY_NOT_ON_ORDERS_TEAMS = 8,
		/// <summary>Programmatic info fields should not be set for a non-programmatic order.
		/// </summary>
		INVALID_FIELDS_SET_FOR_NON_PROGRAMMATIC_ORDER = 9,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 10,
	}


	/// <summary>Lists all errors associated with performing actions on <a href='Order'>Order</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class OrderActionError : ApiError {
		private OrderActionErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public OrderActionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "OrderActionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum OrderActionErrorReason {
		/// <summary>The operation is not allowed due to lack of permissions.
		/// </summary>
		PERMISSION_DENIED = 0,
		/// <summary>The operation is not applicable for the current state of the <a
		/// href='Order'>Order</a>.
		/// </summary>
		NOT_APPLICABLE = 1,
		/// <summary>The <a href='Order'>Order</a> is archived, an <a
		/// href='OrderAction'>OrderAction</a> cannot be applied to an archived order.
		/// </summary>
		IS_ARCHIVED = 2,
		/// <summary>The <a href='Order'>Order</a> is past its end date, An <a
		/// href='OrderAction'>OrderAction</a> cannot be applied to a order that has ended.
		/// </summary>
		HAS_ENDED = 3,
		/// <summary>A <a href='Order'>Order</a> cannot be approved if it contains reservable <a
		/// href='LineItem'>LineItem</a>s that are unreserved.
		/// </summary>
		CANNOT_APPROVE_WITH_UNRESERVED_LINE_ITEMS = 4,
		/// <summary>Deleting an <a href='Order'>Order</a> with delivered line items is not allowed
		/// </summary>
		CANNOT_DELETE_ORDER_WITH_DELIVERED_LINEITEMS = 5,
		/// <summary>Cannot approve because company credit status is not active.
		/// </summary>
		CANNOT_APPROVE_COMPANY_CREDIT_STATUS_NOT_ACTIVE = 6,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 7,
	}


	/// <summary>Lists all errors for executing operations on line items
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LineItemOperationError : ApiError {
		private LineItemOperationErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public LineItemOperationErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "LineItemOperationError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LineItemOperationErrorReason {
		/// <summary>The operation is not allowed due to lack of permissions.
		/// </summary>
		NOT_ALLOWED = 0,
		/// <summary>The operation is not applicable for the current state of the <a
		/// href='LineItem'>LineItem</a>.
		/// </summary>
		NOT_APPLICABLE = 1,
		/// <summary>The <a href='LineItem'>LineItem</a> is completed. A <a
		/// href='LineItemAction'>LineItemAction</a> cannot be applied to a line item that
		/// is completed.
		/// </summary>
		HAS_COMPLETED = 2,
		/// <summary>The <a href='LineItem'>LineItem</a> has no active creatives. A line item cannot
		/// be activated with no active creatives.
		/// </summary>
		HAS_NO_ACTIVE_CREATIVES = 3,
		/// <summary>A <a href='LineItem'>LineItem</a> of type <a
		/// href='LineItemType#LEGACY_DFP'>LineItemType#LEGACY_DFP</a> cannot be Activated.
		/// </summary>
		CANNOT_ACTIVATE_LEGACY_DFP_LINE_ITEM = 4,
		/// <summary>Deleting an <a href='LineItem'>LineItem</a> that has delivered is not allowed
		/// </summary>
		CANNOT_DELETE_DELIVERED_LINE_ITEM = 5,
		/// <summary>Reservation cannot be made for line item because the <a
		/// href='LineItem#advertiserId'>LineItem#advertiserId</a> it is associated with has
		/// <a href='Company#creditStatus'>Company#creditStatus</a> that is not
		/// <code>ACTIVE</code> or <code>ON_HOLD</code>.
		/// </summary>
		CANNOT_RESERVE_COMPANY_CREDIT_STATUS_NOT_ACTIVE = 6,
		/// <summary>Cannot activate line item because the <a
		/// href='LineItem#advertiserId'>LineItem#advertiserId</a> it is associated with has
		/// <a href='Company#creditStatus'>Company#creditStatus</a> that is not
		/// <code>ACTIVE</code>, <code>INACTIVE</code>, or <code>ON_HOLD</code>.
		/// </summary>
		CANNOT_ACTIVATE_INVALID_COMPANY_CREDIT_STATUS = 7,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 8,
	}


	/// <summary>Lists all errors associated with LineItem start and end dates.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LineItemFlightDateError : ApiError {
		private LineItemFlightDateErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public LineItemFlightDateErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "LineItemFlightDateError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LineItemFlightDateErrorReason {
		START_DATE_TIME_IS_IN_PAST = 0,
		END_DATE_TIME_IS_IN_PAST = 1,
		END_DATE_TIME_NOT_AFTER_START_TIME = 2,
		END_DATE_TIME_TOO_LATE = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>A catch-all error that lists all generic errors associated with LineItem.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LineItemError : ApiError {
		private LineItemErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public LineItemErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "LineItemError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LineItemErrorReason {
		/// <summary>Some changes may not be allowed because a line item has already started.
		/// </summary>
		ALREADY_STARTED = 0,
		/// <summary>Update reservation is not allowed because a line item has already started, users
		/// must pause the line item first.
		/// </summary>
		UPDATE_RESERVATION_NOT_ALLOWED = 1,
		/// <summary>Roadblocking to display all creatives is not allowed.
		/// </summary>
		ALL_ROADBLOCK_NOT_ALLOWED = 2,
		/// <summary>Roadblocking to display all master and companion creative set is not allowed.
		/// </summary>
		CREATIVE_SET_ROADBLOCK_NOT_ALLOWED = 3,
		/// <summary>Fractional percentage is not allowed.
		/// </summary>
		FRACTIONAL_PERCENTAGE_NOT_ALLOWED = 4,
		/// <summary>For certain LineItem configurations discounts are not allowed.
		/// </summary>
		DISCOUNT_NOT_ALLOWED = 5,
		/// <summary>Updating a canceled line item is not allowed.
		/// </summary>
		UPDATE_CANCELED_LINE_ITEM_NOT_ALLOWED = 6,
		/// <summary>Updating a pending approval line item is not allowed.
		/// </summary>
		UPDATE_PENDING_APPROVAL_LINE_ITEM_NOT_ALLOWED = 7,
		/// <summary>Updating an archived line item is not allowed.
		/// </summary>
		UPDATE_ARCHIVED_LINE_ITEM_NOT_ALLOWED = 8,
		/// <summary>Create or update legacy dfp line item type is not allowed.
		/// </summary>
		CREATE_OR_UPDATE_LEGACY_DFP_LINE_ITEM_TYPE_NOT_ALLOWED = 9,
		/// <summary>Copying line item from different company (advertiser) to the same order is not
		/// allowed.
		/// </summary>
		COPY_LINE_ITEM_FROM_DIFFERENT_COMPANY_NOT_ALLOWED = 10,
		/// <summary>The size is invalid for the specified platform.
		/// </summary>
		INVALID_SIZE_FOR_PLATFORM = 11,
		/// <summary>The line item type is invalid for the specified platform.
		/// </summary>
		INVALID_LINE_ITEM_TYPE_FOR_PLATFORM = 12,
		/// <summary>The web property cannot be served on the specified platform.
		/// </summary>
		INVALID_WEB_PROPERTY_FOR_PLATFORM = 13,
		/// <summary>The web property cannot be served on the specified environment.
		/// </summary>
		INVALID_WEB_PROPERTY_FOR_ENVIRONMENT = 14,
		/// <summary>AFMA backfill not supported.
		/// </summary>
		AFMA_BACKFILL_NOT_ALLOWED = 15,
		/// <summary>Environment type cannot change once saved.
		/// </summary>
		UPDATE_ENVIRONMENT_TYPE_NOT_ALLOWED = 16,
		/// <summary>The placeholders are invalid because they contain companions, but the line item
		/// does not support companions.
		/// </summary>
		COMPANIONS_NOT_ALLOWED = 17,
		/// <summary>The placeholders are invalid because some of them are roadblocks, and some are
		/// not. Either all roadblock placeholders must contain companions, or no
		/// placeholders may contain companions. This does not apply to video creative sets.
		/// </summary>
		ROADBLOCKS_WITH_NONROADBLOCKS_NOT_ALLOWED = 18,
		/// <summary>A line item cannot be updated from having <a
		/// href='RoadblockingType#CREATIVE_SET'>RoadblockingType#CREATIVE_SET</a> to having
		/// a different RoadblockingType, or vice versa.
		/// </summary>
		CANNOT_UPDATE_TO_OR_FROM_CREATIVE_SET_ROADBLOCK = 19,
		/// <summary>Can not change from a backfill line item type once creatives have been assigned.
		/// </summary>
		UPDATE_FROM_BACKFILL_LINE_ITEM_TYPE_NOT_ALLOWED = 20,
		/// <summary>Can not change to a backfill line item type once creatives have been assigned.
		/// </summary>
		UPDATE_TO_BACKFILL_LINE_ITEM_TYPE_NOT_ALLOWED = 21,
		/// <summary>Can not change to backfill web property once creatives have been assigned.
		/// </summary>
		UPDATE_BACKFILL_WEB_PROPERTY_NOT_ALLOWED = 22,
		/// <summary>The companion delivery option is not valid for your environment type.
		/// </summary>
		INVALID_COMPANION_DELIVERY_OPTION_FOR_ENVIRONMENT_TYPE = 23,
		/// <summary>Companion backfill is enabled but environment type not video.
		/// </summary>
		COMPANION_BACKFILL_REQUIRES_VIDEO = 24,
		/// <summary>Companion delivery options require Ad Manager 360 networks.
		/// </summary>
		COMPANION_DELIVERY_OPTION_REQUIRE_PREMIUM = 25,
		/// <summary>The master size of placeholders have duplicates.
		/// </summary>
		DUPLICATE_MASTER_SIZES = 26,
		/// <summary>The line item priority is invalid if for dynamic allocation line items it is
		/// different than the default for free publishers. When allowed, Ad Manager 360
		/// users can change the priority to any value.
		/// </summary>
		INVALID_PRIORITY_FOR_LINE_ITEM_TYPE = 27,
		/// <summary>The environment type is not valid.
		/// </summary>
		INVALID_ENVIRONMENT_TYPE = 28,
		/// <summary>The environment type is not valid for the target platform.
		/// </summary>
		INVALID_ENVIRONMENT_TYPE_FOR_PLATFORM = 29,
		/// <summary>Only <a href='LineItemType#STANDARD'>LineItemType#STANDARD</a> line items can be
		/// auto extended.
		/// </summary>
		INVALID_TYPE_FOR_AUTO_EXTENSION = 30,
		/// <summary>Video line items cannot change the roadblocking type.
		/// </summary>
		VIDEO_INVALID_ROADBLOCKING = 31,
		/// <summary>The backfill feature is not enabled according to your features.
		/// </summary>
		BACKFILL_TYPE_NOT_ALLOWED = 32,
		/// <summary>The web property is invalid. A line item must have an appropriate web property
		/// selected.
		/// </summary>
		INVALID_BACKFILL_LINK_TYPE = 33,
		/// <summary>All line items in a programmatic order must have web property codes from the
		/// same account.
		/// </summary>
		DIFFERENT_BACKFILL_ACCOUNT = 51,
		/// <summary>Companion delivery options are not allowed with dynamic allocation line items.
		/// </summary>
		COMPANION_DELIVERY_OPTIONS_NOT_ALLOWED_WITH_BACKFILL = 35,
		/// <summary>Dynamic allocation using the AdExchange should always use an AFC web property.
		/// </summary>
		INVALID_WEB_PROPERTY_FOR_ADX_BACKFILL = 36,
		/// <summary>Aspect ratio sizes cannot be used with video line items.
		/// </summary>
		INVALID_SIZE_FOR_ENVIRONMENT = 37,
		/// <summary>The specified target platform is not allowed.
		/// </summary>
		TARGET_PLATOFRM_NOT_ALLOWED = 38,
		/// <summary>Currency on a line item must be one of the specified network currencies.
		/// </summary>
		INVALID_LINE_ITEM_CURRENCY = 39,
		/// <summary>All money fields on a line item must specify the same currency.
		/// </summary>
		LINE_ITEM_CANNOT_HAVE_MULTIPLE_CURRENCIES = 40,
		/// <summary>Once a line item has moved into a a delivering state the currency cannot be
		/// changed.
		/// </summary>
		CANNOT_CHANGE_CURRENCY = 41,
		/// <summary>The line item settings are invalid for an offline lineitem.
		/// </summary>
		INVALID_FOR_OFFLINE = 42,
		/// <summary>A DateTime associated with the line item is not valid.
		/// </summary>
		INVALID_LINE_ITEM_DATE_TIME = 43,
		/// <summary>CPA <a href='LineItem'>line items</a> must specify a zero cost for the <a
		/// href='LineItem#costPerUnit'>LineItem#costPerUnit</a>.
		/// </summary>
		INVALID_COST_PER_UNIT_FOR_CPA = 44,
		/// <summary>Once a <a href='LineItem'>LineItem</a> is activated its <a
		/// href='LineItem#costPerUnit'>LineItem#costPerUnit</a> cannot be updated to/from
		/// CPA.
		/// </summary>
		UPDATE_CPA_COST_TYPE_NOT_ALLOWED = 45,
		/// <summary>Once a <a href='LineItem'>LineItem</a> is activated its <a
		/// href='LineItem#costPerUnit'>LineItem#costPerUnit</a> cannot be updated to/from
		/// Viewable CPM.
		/// </summary>
		UPDATE_VCPM_COST_TYPE_NOT_ALLOWED = 59,
		/// <summary>A <a href='LineItem'>LineItem</a> with master/companion creative placeholders
		/// cannot have Viewable CPM as its <a
		/// href='LineItem#costPerUnit'>LineItem#costPerUnit</a>.
		/// </summary>
		MASTER_COMPANION_LINE_ITEM_CANNOT_HAVE_VCPM_COST_TYPE = 60,
		/// <summary>There cannot be goals with duplicated unit type among the secondary goals for a
		/// <a href='LineItem'>line items</a>.
		/// </summary>
		DUPLICATED_UNIT_TYPE = 46,
		/// <summary>The secondary goals of a <a href='LineItem'>line items</a> must have the same
		/// goal type.
		/// </summary>
		MULTIPLE_GOAL_TYPE_NOT_ALLOWED = 47,
		/// <summary>For a CPA <a href='LineItem'>line item</a>, the possible combinations for
		/// secondary goals must be either click-through conversion only, click-through
		/// conversion with view-through conversion or total conversion only. For a Viewable
		/// CPM <a href='LineItem'>line item</a> or a CPM based Sponsorship <a
		/// href='LineItem'>line item</a>, its secondary goal has to be impression-based.
		/// </summary>
		INVALID_UNIT_TYPE_COMBINATION_FOR_SECONDARY_GOALS = 48,
		/// <summary>One or more of the targeting names specified by a creative placeholder or line
		/// item creative association were not found on the line item.
		/// </summary>
		INVALID_CREATIVE_TARGETING_NAME = 52,
		/// <summary>Creative targeting expressions on the line item can only have custom criteria
		/// targeting with <a
		/// href='CustomTargetingValue.MatchType#EXACT'>CustomTargetingValue.MatchType#EXACT</a>.
		/// </summary>
		INVALID_CREATIVE_CUSTOM_TARGETING_MATCH_TYPE = 53,
		/// <summary>Line item with creative targeting expressions cannot have creative rotation type
		/// set to <a
		/// href='CreativeRotationType#SEQUENTIAL'>CreativeRotationType#SEQUENTIAL</a>.
		/// </summary>
		INVALID_CREATIVE_ROTATION_TYPE_WITH_CREATIVE_TARGETING = 54,
		/// <summary>Line items cannot overbook inventory when applying creative-level targeting if
		/// the originating proposal line item did not overbook inventory. Remove
		/// creative-level targeting and try again.
		/// </summary>
		CANNOT_OVERBOOK_WITH_CREATIVE_TARGETING = 58,
		/// <summary>For a managed line item, inventory sizes must match sizes that are set on the
		/// originating proposal line item. In the case that a size is broken out by
		/// creative-level targeting, the sum of the creative counts for each size must
		/// equal the expected creative count that is set for that size on the originating
		/// proposal line item.
		/// </summary>
		PLACEHOLDERS_DO_NOT_MATCH_PROPOSAL = 61,
		/// <summary>The line item type is not supported for this API version.
		/// </summary>
		UNSUPPORTED_LINE_ITEM_TYPE_FOR_THIS_API_VERSION = 49,
		/// <summary>Placeholders can only have native creative templates.
		/// </summary>
		NATIVE_CREATIVE_TEMPLATE_REQUIRED = 55,
		/// <summary>Non-native placeholders cannot have creative templates.
		/// </summary>
		CANNOT_HAVE_CREATIVE_TEMPLATE = 56,
		/// <summary>Cannot include native creative templates in the placeholders for Ad Exchange
		/// line items.
		/// </summary>
		CANNOT_INCLUDE_NATIVE_CREATIVE_TEMPLATE = 63,
		/// <summary>Cannot include native placeholders without native creative templates for
		/// direct-sold line items.
		/// </summary>
		CANNOT_INCLUDE_NATIVE_PLACEHOLDER_WITHOUT_TEMPLATE_ID = 64,
		/// <summary>For forecasting only, error when line item has duration, but no creative sizes
		/// specified.
		/// </summary>
		NO_SIZE_WITH_DURATION = 62,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 50,
	}


	/// <summary>Errors specific to associating activities to line items.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LineItemActivityAssociationError : ApiError {
		private LineItemActivityAssociationErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public LineItemActivityAssociationErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "LineItemActivityAssociationError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LineItemActivityAssociationErrorReason {
		/// <summary>When associating an activity to a line item the activity must belong to the same
		/// advertiser as the line item.
		/// </summary>
		INVALID_ACTIVITY_FOR_ADVERTISER = 0,
		/// <summary>Activities can only be associated with line items of <a
		/// href='CostType.CPA'>CostType.CPA</a>.
		/// </summary>
		INVALID_COST_TYPE_FOR_ASSOCIATION = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Lists the generic errors associated with <a href='AdUnit'>AdUnit</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class InventoryUnitError : ApiError {
		private InventoryUnitErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public InventoryUnitErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Possible reasons for the error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "InventoryUnitError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum InventoryUnitErrorReason {
		/// <summary><a href='AdUnit#explicitlyTargeted'>AdUnit#explicitlyTargeted</a> can be set to
		/// <code>true</code> only in an Ad Manager 360 account.
		/// </summary>
		EXPLICIT_TARGETING_NOT_ALLOWED = 0,
		/// <summary>The specified target platform is not applicable for the inventory unit.
		/// </summary>
		TARGET_PLATFORM_NOT_APPLICABLE = 1,
		/// <summary>AdSense cannot be enabled on this inventory unit if it is disabled for the
		/// network.
		/// </summary>
		ADSENSE_CANNOT_BE_ENABLED = 2,
		/// <summary>A root unit cannot be deactivated.
		/// </summary>
		ROOT_UNIT_CANNOT_BE_DEACTIVATED = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>Lists all inventory errors caused by associating a line item with a targeting
	/// expression.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class InventoryTargetingError : ApiError {
		private InventoryTargetingErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public InventoryTargetingErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "InventoryTargetingError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum InventoryTargetingErrorReason {
		/// <summary>At least one placement or inventory unit is required
		/// </summary>
		AT_LEAST_ONE_PLACEMENT_OR_INVENTORY_UNIT_REQUIRED = 0,
		/// <summary>The same inventory unit or placement cannot be targeted and excluded at the same
		/// time
		/// </summary>
		INVENTORY_CANNOT_BE_TARGETED_AND_EXCLUDED = 1,
		/// <summary>A child inventory unit cannot be targeted if its ancestor inventory unit is also
		/// targeted.
		/// </summary>
		INVENTORY_UNIT_CANNOT_BE_TARGETED_IF_ANCESTOR_IS_TARGETED = 4,
		/// <summary>A child inventory unit cannot be targeted if its ancestor inventory unit is
		/// excluded.
		/// </summary>
		INVENTORY_UNIT_CANNOT_BE_TARGETED_IF_ANCESTOR_IS_EXCLUDED = 5,
		/// <summary>A child inventory unit cannot be excluded if its ancestor inventory unit is also
		/// excluded.
		/// </summary>
		INVENTORY_UNIT_CANNOT_BE_EXCLUDED_IF_ANCESTOR_IS_EXCLUDED = 6,
		/// <summary>An explicitly targeted inventory unit cannot be targeted.
		/// </summary>
		EXPLICITLY_TARGETED_INVENTORY_UNIT_CANNOT_BE_TARGETED = 7,
		/// <summary>An explicitly targeted inventory unit cannot be excluded.
		/// </summary>
		EXPLICITLY_TARGETED_INVENTORY_UNIT_CANNOT_BE_EXCLUDED = 8,
		/// <summary>A landing page-only ad unit cannot be targeted.
		/// </summary>
		SELF_ONLY_INVENTORY_UNIT_NOT_ALLOWED = 9,
		/// <summary>A landing page-only ad unit cannot be targeted if it doesn't have any children.
		/// </summary>
		SELF_ONLY_INVENTORY_UNIT_WITHOUT_DESCENDANTS = 10,
		/// <summary>Audience segments shared from YouTube can only be targeted with inventory shared
		/// from YouTube for cross selling.
		/// </summary>
		YOUTUBE_AUDIENCE_SEGMENTS_CAN_ONLY_BE_TARGETED_WITH_YOUTUBE_SHARED_INVENTORY = 11,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 13,
	}


	/// <summary>Errors associated with line items with GRP settings.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class GrpSettingsError : ApiError {
		private GrpSettingsErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public GrpSettingsErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Reason for GRP settings error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "GrpSettingsError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum GrpSettingsErrorReason {
		/// <summary>Age range for GRP audience is not valid. Please see the <a
		/// href="https://support.google.com/dfp_premium/answer/6135438">Ad Manager Help
		/// Center</a> for more information.
		/// </summary>
		INVALID_AGE_RANGE = 0,
		/// <summary>GRP settings are only supported for video line items.
		/// </summary>
		LINE_ITEM_ENVIRONMENT_TYPE_NOT_SUPPORTED = 1,
		/// <summary>GRP settings are not supported for the given line item type.
		/// </summary>
		LINE_ITEM_TYPE_NOT_SUPPORTED = 2,
		/// <summary>GRP audience gender cannot be specified for the selected age range.
		/// </summary>
		CANNOT_SPECIFY_GENDER_FOR_GIVEN_AGE_RANGE = 3,
		/// <summary>Minimum age for GRP audience is not valid.
		/// </summary>
		INVALID_MIN_AGE = 4,
		/// <summary>Maximum age for GRP audience is not valid.
		/// </summary>
		INVALID_MAX_AGE = 5,
		/// <summary>GRP settings cannot be disabled.
		/// </summary>
		CANNOT_DISABLE_GRP_AFTER_ENABLING = 6,
		/// <summary>GRP provider cannot be updated.
		/// </summary>
		CANNOT_CHANGE_GRP_PROVIDERS = 7,
		/// <summary>GRP settings cannot be updated once the line item has started serving.
		/// </summary>
		CANNOT_CHANGE_GRP_SETTINGS = 15,
		/// <summary>Impression goal based on GRP audience is not supported.
		/// </summary>
		GRP_AUDIENCE_GOAL_NOT_SUPPORTED = 16,
		/// <summary>Impression goal based on GRP audience cannot be set once the line item has
		/// started serving.
		/// </summary>
		CANNOT_SET_GRP_AUDIENCE_GOAL = 17,
		/// <summary>Impression goal based on GRP audience cannot be removed once the line item has
		/// started serving.
		/// </summary>
		CANNOT_REMOVE_GRP_AUDIENCE_GOAL = 18,
		/// <summary>Unsupported geographic location targeted for line item with GRP audience goal.
		/// </summary>
		UNSUPPORTED_GEO_TARGETING = 12,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 13,
	}


	/// <summary>Lists all errors associated with geographical targeting for a <a
	/// href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class GeoTargetingError : ApiError {
		private GeoTargetingErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public GeoTargetingErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "GeoTargetingError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum GeoTargetingErrorReason {
		/// <summary>A location that is targeted cannot also be excluded.
		/// </summary>
		TARGETED_LOCATIONS_NOT_EXCLUDABLE = 0,
		/// <summary>Excluded locations cannot have any of their children targeted.
		/// </summary>
		EXCLUDED_LOCATIONS_CANNOT_HAVE_CHILDREN_TARGETED = 1,
		/// <summary>Postal codes cannot be excluded.
		/// </summary>
		POSTAL_CODES_CANNOT_BE_EXCLUDED = 2,
		/// <summary>Indicates that location targeting is not allowed.
		/// </summary>
		UNTARGETABLE_LOCATION = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>Targeting validation errors that can be used by different targeting types.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class GenericTargetingError : ApiError {
		private GenericTargetingErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public GenericTargetingErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "GenericTargetingError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum GenericTargetingErrorReason {
		/// <summary>Both including and excluding sibling criteria is disallowed.
		/// </summary>
		CONFLICTING_INCLUSION_OR_EXCLUSION_OF_SIBLINGS = 0,
		/// <summary>Including descendants of excluded criteria is disallowed.
		/// </summary>
		INCLUDING_DESCENDANTS_OF_EXCLUDED_CRITERIA = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Lists all errors associated with frequency caps.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class FrequencyCapError : ApiError {
		private FrequencyCapErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public FrequencyCapErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "FrequencyCapError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum FrequencyCapErrorReason {
		IMPRESSION_LIMIT_EXCEEDED = 0,
		IMPRESSIONS_TOO_LOW = 1,
		RANGE_LIMIT_EXCEEDED = 2,
		RANGE_TOO_LOW = 3,
		DUPLICATE_TIME_RANGE = 4,
		TOO_MANY_FREQUENCY_CAPS = 5,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 6,
	}


	/// <summary>Errors that can result from a forecast request.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ForecastError : ApiError {
		private ForecastErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The reason for the forecast error.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ForecastErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Reason why a forecast could not be retrieved.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ForecastError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ForecastErrorReason {
		/// <summary>The forecast could not be retrieved due to a server side connection problem.
		/// Please try again soon.
		/// </summary>
		SERVER_NOT_AVAILABLE = 0,
		/// <summary>There was an unexpected internal error.
		/// </summary>
		INTERNAL_ERROR = 1,
		/// <summary>The forecast could not be retrieved because there is not enough forecasting data
		/// available yet. It may take up to one week before enough data is available.
		/// </summary>
		NO_FORECAST_YET = 2,
		/// <summary>There's not enough inventory for the requested reservation.
		/// </summary>
		NOT_ENOUGH_INVENTORY = 3,
		/// <summary>No error from forecast.
		/// </summary>
		SUCCESS = 4,
		/// <summary>The requested reservation is of zero length. No forecast is returned.
		/// </summary>
		ZERO_LENGTH_RESERVATION = 5,
		/// <summary>The number of requests made per second is too high and has exceeded the
		/// allowable limit. The recommended approach to handle this error is to wait about
		/// 5 seconds and then retry the request. Note that this does not guarantee the
		/// request will succeed. If it fails again, try increasing the wait time.
		/// <p>Another way to mitigate this error is to limit requests to 2 per second. Once
		/// again this does not guarantee that every request will succeed, but may help
		/// reduce the number of times you receive this error.</p>
		/// </summary>
		EXCEEDED_QUOTA = 6,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 7,
	}


	/// <summary>Lists all errors associated with day-part targeting for a line item.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DayPartTargetingError : ApiError {
		private DayPartTargetingErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public DayPartTargetingErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "DayPartTargetingError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum DayPartTargetingErrorReason {
		/// <summary>Hour of day must be between 0 and 24, inclusive.
		/// </summary>
		INVALID_HOUR = 0,
		/// <summary>Minute of hour must be one of 0, 15,30, 45.
		/// </summary>
		INVALID_MINUTE = 1,
		/// <summary>The <a href='DayPart#endTime'>DayPart#endTime</a> cannot be after <a
		/// href='DayPart#startTime'>DayPart#startTime</a>.
		/// </summary>
		END_TIME_NOT_AFTER_START_TIME = 2,
		/// <summary>Cannot create day-parts that overlap.
		/// </summary>
		TIME_PERIODS_OVERLAP = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>Lists all date time range errors caused by associating a line item with a
	/// targeting expression.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DateTimeRangeTargetingError : ApiError {
		private DateTimeRangeTargetingErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public DateTimeRangeTargetingErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary><a href='ApiErrorReason'>ApiErrorReason</a> enum for date time range targeting
	/// error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "DateTimeRangeTargetingError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum DateTimeRangeTargetingErrorReason {
		/// <summary>No targeted ranges exists.
		/// </summary>
		EMPTY_RANGES = 0,
		/// <summary>Type of lineitem is not sponsorship.
		/// </summary>
		NOT_SPONSORSHIP_LINEITEM = 1,
		/// <summary>Past ranges are changed.
		/// </summary>
		PAST_RANGES_CHANGED = 2,
		/// <summary>Targeted date time ranges overlap.
		/// </summary>
		RANGES_OVERLAP = 3,
		/// <summary>Targeted date time ranges fall out the active period of lineitem.
		/// </summary>
		RANGES_OUT_OF_LINEITEM_ACTIVE_PERIOD = 4,
		/// <summary>Start time of range (except the earliest range) is not at start of day. Start of
		/// day is 00:00:00.
		/// </summary>
		START_TIME_IS_NOT_START_OF_DAY = 5,
		/// <summary>End time of range (except the latest range) is not at end of day. End of day is
		/// 23:59:59.
		/// </summary>
		END_TIME_IS_NOT_END_OF_DAY = 6,
		/// <summary>Start date time of earliest targeted ranges is in past.
		/// </summary>
		START_DATE_TIME_IS_IN_PAST = 7,
		/// <summary>The end time of range is before the start time. Could happen when start type is
		/// IMMEDIATE or ONE_HOUR_LATER.
		/// </summary>
		RANGE_END_TIME_BEFORE_START_TIME = 8,
		/// <summary>End date time of latest targeted ranges is too late.
		/// </summary>
		END_DATE_TIME_IS_TOO_LATE = 9,
		LIMITED_RANGES_IN_UNLIMITED_LINEITEM = 10,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 11,
	}


	/// <summary>Lists all errors associated with cross selling.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CrossSellError : ApiError {
		private CrossSellErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CrossSellErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reason of the error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CrossSellError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CrossSellErrorReason {
		/// <summary>A company for cross-sell partner must be of type <a
		/// href='Company.Type#PARTNER'>Company.Type#PARTNER</a>.
		/// </summary>
		COMPANY_IS_NOT_DISTRIBUTION_PARTNER = 2,
		/// <summary>The network code of a cross-sell partner cannot be changed.
		/// </summary>
		CHANGING_PARTNER_NETWORK_IS_NOT_SUPPORTED = 3,
		/// <summary>A cross-sell partner must have a partner name.
		/// </summary>
		MISSING_DISTRIBUTOR_PARTNER_NAME = 4,
		/// <summary>The cross-sell distributor publisher feature must be enabled.
		/// </summary>
		DISTRIBUTOR_NETWORK_MISSING_PUBLISHER_FEATURE = 5,
		/// <summary>The cross-sell content provider publisher feature must be enabled on the
		/// partner's network.
		/// </summary>
		CONTENT_PROVIDER_NETWORK_MISSING_PUBLISHER_FEATURE = 6,
		/// <summary>The cross-sell partner name conflicts with an ad unit name on the partner's
		/// network.
		/// </summary>
		INVALID_DISTRIBUTOR_PARTNER_NAME = 7,
		/// <summary>The network code of a cross-sell partner is invalid.
		/// </summary>
		INVALID_CONTENT_PROVIDER_NETWORK = 8,
		/// <summary>The content provider network must be different than the distributor network.
		/// </summary>
		CONTENT_PROVIDER_NETWORK_CANNOT_BE_ACTIVE_NETWORK = 9,
		/// <summary>The same network code was already enabled for cross-sell in a different company.
		/// </summary>
		CONTENT_PROVIDER_NETWORK_ALREADY_ENABLED_FOR_CROSS_SELLING = 10,
		/// <summary>A rule defined by the cross selling distributor has been violated by a line item
		/// targeting a shared ad unit. Violating this rule is an error.
		/// </summary>
		DISTRIBUTOR_RULE_VIOLATION_ERROR = 11,
		/// <summary>A rule defined by the cross selling distributor has been violated by a line item
		/// targeting a shared ad unit. Violating this rule is a warning. <p>By setting <a
		/// href='LineItem#skipCrossSellingRuleWarningChecks'>LineItem#skipCrossSellingRuleWarningChecks</a>,
		/// the content partner can suppress the warning (and create or save the line
		/// item).</p> <p>This flag is available beginning in V201411.</p>
		/// </summary>
		DISTRIBUTOR_RULE_VIOLATION_WARNING = 12,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 13,
	}


	/// <summary>Lists all errors related to <a
	/// href='ContentMetadataTargeting'>ContentMetadataTargeting</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ContentMetadataTargetingError : ApiError {
		private ContentMetadataTargetingErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ContentMetadataTargetingErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the metadata targeting error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ContentMetadataTargetingError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ContentMetadataTargetingErrorReason {
		/// <summary>One or more of the values specified in a <code></code> do not belong to the keys
		/// defined in any of the hierarchies on the network.
		/// </summary>
		VALUES_DO_NOT_BELONG_TO_A_HIERARCHY = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>Lists all errors due to <a href='Company#creditStatus'>Company#creditStatus</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CompanyCreditStatusError : ApiError {
		private CompanyCreditStatusErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CompanyCreditStatusErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CompanyCreditStatusError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CompanyCreditStatusErrorReason {
		/// <summary>The user's role does not have permission to change <a
		/// href='Company#creditStatus'>Company#creditStatus</a> from the default value. The
		/// default value is <a
		/// href='Company.CreditStatus#ACTIVE'>Company.CreditStatus#ACTIVE</a> for the Basic
		/// credit status setting and <a
		/// href='Company.CreditStatus#ON_HOLD'>Company.CreditStatus#ON_HOLD</a> for the
		/// Advanced credit status setting.
		/// </summary>
		COMPANY_CREDIT_STATUS_CHANGE_NOT_ALLOWED = 0,
		/// <summary>The network has not been enabled for editing credit status settings for
		/// companies.
		/// </summary>
		CANNOT_USE_CREDIT_STATUS_SETTING = 1,
		/// <summary>The network has not been enabled for the Advanced credit status settings for
		/// companies. <a href='Company#creditStatus'>Company#creditStatus</a> must be
		/// either <code>ACTIVE</code> or <code>INACTIVE</code>.
		/// </summary>
		CANNOT_USE_ADVANCED_CREDIT_STATUS_SETTING = 2,
		/// <summary>An order cannot be created or updated because the <a
		/// href='Order#advertiserId'>Order#advertiserId</a> or the <a
		/// href='Order#agencyId'>Order#agencyId</a> it is associated with has <a
		/// href='Company#creditStatus'>Company#creditStatus</a> that is not
		/// <code>ACTIVE</code> or <code>ON_HOLD</code>.
		/// </summary>
		UNACCEPTABLE_COMPANY_CREDIT_STATUS_FOR_ORDER = 3,
		/// <summary>A line item cannot be created for the order because the <a
		/// href='Order#advertiserId'>Order#advertiserId</a> or {Order#agencyId} it is
		/// associated with has <a href='Company#creditStatus'>Company#creditStatus</a> that
		/// is not <code></code> or <code>ON_HOLD</code>.
		/// </summary>
		UNACCEPTABLE_COMPANY_CREDIT_STATUS_FOR_LINE_ITEM = 4,
		/// <summary>The company cannot be blocked because there are more than 200 approved orders of
		/// the company. Archive some, so that there are less than 200 of them.
		/// </summary>
		CANNOT_BLOCK_COMPANY_TOO_MANY_APPROVED_ORDERS = 5,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 6,
	}


	/// <summary>Click tracking is a special line item type with a number of unique errors as
	/// described below.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ClickTrackingLineItemError : ApiError {
		private ClickTrackingLineItemErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ClickTrackingLineItemErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ClickTrackingLineItemError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ClickTrackingLineItemErrorReason {
		/// <summary>The line item type cannot be changed once created.
		/// </summary>
		TYPE_IMMUTABLE = 0,
		/// <summary>Click tracking line items can only be targeted at ad unit inventory, all other
		/// types are invalid, as well as placements.
		/// </summary>
		INVALID_TARGETING_TYPE = 1,
		/// <summary>Click tracking line items do not allow us to control creative delivery so are by
		/// nature one or more as entered by the third party.
		/// </summary>
		INVALID_ROADBLOCKING_TYPE = 2,
		/// <summary>Click tracking line items do not support the <a
		/// href='CreativeRotationType#OPTIMIZED'>CreativeRotationType#OPTIMIZED</a>
		/// creative rotation type.
		/// </summary>
		INVALID_CREATIVEROTATION_TYPE = 3,
		/// <summary>Click tracking line items do not allow us to control line item delivery so we
		/// can not control the rate at which they are served.
		/// </summary>
		INVALID_DELIVERY_RATE_TYPE = 4,
		/// <summary>Not all fields are supported by the click tracking line items.
		/// </summary>
		UNSUPPORTED_FIELD = 5,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 6,
	}


	/// <summary>Errors associated with audience extension enabled line items
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AudienceExtensionError : ApiError {
		private AudienceExtensionErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AudienceExtensionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Specific audience extension error reasons.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AudienceExtensionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AudienceExtensionErrorReason {
		/// <summary>Frequency caps are not supported by audience extension line items
		/// </summary>
		FREQUENCY_CAPS_NOT_SUPPORTED = 0,
		/// <summary>Audience extension line items can only target geography
		/// </summary>
		INVALID_TARGETING = 1,
		/// <summary>Audience extension line items can only target audience extension inventory units
		/// </summary>
		INVENTORY_UNIT_TARGETING_INVALID = 2,
		/// <summary>Audience extension line items do not support <a
		/// href='CreativeRotationType#SEQUENTIAL'>CreativeRotationType#SEQUENTIAL</a>.
		/// </summary>
		INVALID_CREATIVE_ROTATION = 3,
		/// <summary>The given ID of the external entity is not valid
		/// </summary>
		INVALID_EXTERNAL_ENTITY_ID = 4,
		/// <summary>Audience extension line items only support <a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a>.
		/// </summary>
		INVALID_LINE_ITEM_TYPE = 5,
		/// <summary>Audience extension max bid is invalid when it is greater then the max budget.
		/// </summary>
		INVALID_MAX_BID = 6,
		/// <summary>Bulk update for audience extension line items is not allowed.
		/// </summary>
		AUDIENCE_EXTENSION_BULK_UPDATE_NOT_ALLOWED = 7,
		/// <summary>An unexpected error occurred.
		/// </summary>
		UNEXPECTED_AUDIENCE_EXTENSION_ERROR = 8,
		/// <summary>The value entered for the maximum daily budget on an audience extension line
		/// item exceeds the maximum allowed.
		/// </summary>
		MAX_DAILY_BUDGET_AMOUNT_EXCEEDED = 9,
		/// <summary>Creating a campaign for a line item that already has an associated campaign is
		/// not allowed.
		/// </summary>
		EXTERNAL_CAMPAIGN_ALREADY_EXISTS = 10,
		/// <summary>Audience extension was specified on a line item but the feature was not enabled.
		/// </summary>
		AUDIENCE_EXTENSION_WITHOUT_FEATURE = 11,
		/// <summary>Audience extension was specified on a line item but no audience extension
		/// account has been linked.
		/// </summary>
		AUDIENCE_EXTENSION_WITHOUT_LINKED_ACCOUNT = 12,
		/// <summary>Assocation creative size overrides are not allowed with audience extension.
		/// </summary>
		CANNOT_OVERRIDE_CREATIVE_SIZE_WITH_AUDIENCE_EXTENSION = 13,
		/// <summary>Some association overrides are not allowed with audience extension.
		/// </summary>
		CANNOT_OVERRIDE_FIELD_WITH_AUDIENCE_EXTENSION = 14,
		/// <summary>Only one creative placeholder is allowed for an audience extension line item.
		/// </summary>
		ONLY_ONE_CREATIVE_PLACEHOLDER_ALLOWED = 15,
		/// <summary>Only one audience extension line item can be associated with a given order.
		/// </summary>
		MULTIPLE_AUDIENCE_EXTENSION_LINE_ITEMS_ON_ORDER = 16,
		/// <summary>Audience extension line items must be copied separately from their associated
		/// creatives.
		/// </summary>
		CANNOT_COPY_AUDIENCE_EXTENSION_LINE_ITEMS_AND_CREATIVES_TOGETHER = 17,
		/// <summary>Audience extension is no longer supported and cannot be used.
		/// </summary>
		FEATURE_DEPRECATED = 18,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 19,
	}


	/// <summary>Lists the generic errors associated with <a
	/// href='AdUnit#adUnitCode'>AdUnit#adUnitCode</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdUnitCodeError : ApiError {
		private AdUnitCodeErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AdUnitCodeErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AdUnitCodeError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdUnitCodeErrorReason {
		/// <summary>For <a href='AdUnit#adUnitCode'>AdUnit#adUnitCode</a>, only alpha-numeric
		/// characters, underscores, hyphens, periods, asterisks, double quotes, back
		/// slashes, forward slashes, exclamations, left angle brackets, colons and
		/// parentheses are allowed.
		/// </summary>
		INVALID_CHARACTERS = 0,
		/// <summary>For <a href='AdUnit#adUnitCode'>AdUnit#adUnitCode</a>, only letters, numbers,
		/// underscores, hyphens, periods, asterisks, double quotes, back slashes, forward
		/// slashes, exclamations, left angle brackets, colons and parentheses are allowed.
		/// </summary>
		INVALID_CHARACTERS_WHEN_UTF_CHARACTERS_ARE_ALLOWED = 1,
		/// <summary>For <a href='AdUnit#adUnitCode'>AdUnit#adUnitCode</a>, forward slashes are not
		/// allowed as the first character.
		/// </summary>
		LEADING_FORWARD_SLASH = 2,
		/// <summary>Specific codes matching ca-*pub-*-tag are reserved for "Web Property IUs"
		/// generated as part of the SlotCode migration.
		/// </summary>
		RESERVED_CODE = 4,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Errors related to ad rule slots.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdRuleSlotError : ApiError {
		private AdRuleSlotErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AdRuleSlotErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes reason for <code>AdRuleSlotError</code>s.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AdRuleSlotError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdRuleSlotErrorReason {
		/// <summary>Has a different status than the ad rule to which it belongs.
		/// </summary>
		DIFFERENT_STATUS_THAN_AD_RULE = 0,
		/// <summary>Min video ad duration is greater than max video ad duration.
		/// </summary>
		INVALID_VIDEO_AD_DURATION_RANGE = 1,
		/// <summary>Video mid-roll frequency type other than NONE for pre-roll or post-roll.
		/// </summary>
		INVALID_VIDEO_MIDROLL_FREQUENCY_TYPE = 2,
		/// <summary>Invalid format for video mid-roll frequency when expecting a CSV list of
		/// numbers. Valid formats are the following: <ul> <li>empty</li>
		/// <li>comma-separated list of numbers (time milliseconds or cue points)</li> <li>a
		/// single number (every n milliseconds or cue points, or one specific time / cue
		/// point)</li> </ul>
		/// </summary>
		MALFORMED_VIDEO_MIDROLL_FREQUENCY_CSV = 3,
		/// <summary>Invalid format for video mid-roll frequency when expecting a single number only,
		/// e.g., every n seconds or every n cue points.
		/// </summary>
		MALFORMED_VIDEO_MIDROLL_FREQUENCY_SINGLE_NUMBER = 4,
		/// <summary>Min overlay ad duration is greater than max overlay ad duration.
		/// </summary>
		INVALID_OVERLAY_AD_DURATION_RANGE = 5,
		/// <summary>Overlay mid-roll frequency type other than NONE for pre-roll or post-roll.
		/// </summary>
		INVALID_OVERLAY_MIDROLL_FREQUENCY_TYPE = 6,
		/// <summary>Invalid format for overlay mid-roll frequency for list of numbers. See valid
		/// formats above.
		/// </summary>
		MALFORMED_OVERLAY_MIDROLL_FREQUENCY_CSV = 7,
		/// <summary>Invalid format for overlay mid-roll frequency for a single number.
		/// </summary>
		MALFORMED_OVERLAY_MIDROLL_FREQUENCY_SINGLE_NUMBER = 8,
		/// <summary>Non-positive bumper duration when expecting a positive number.
		/// </summary>
		INVALID_BUMPER_MAX_DURATION = 9,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 10,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ForecastServiceInterface")]
	public interface ForecastServiceInterface
	{
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(LineItemSummary))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.AvailabilityForecast getAvailabilityForecast(Google.Api.Ads.AdManager.v201802.ProspectiveLineItem lineItem, Google.Api.Ads.AdManager.v201802.AvailabilityForecastOptions forecastOptions);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AvailabilityForecast> getAvailabilityForecastAsync(Google.Api.Ads.AdManager.v201802.ProspectiveLineItem lineItem, Google.Api.Ads.AdManager.v201802.AvailabilityForecastOptions forecastOptions);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(LineItemSummary))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.AvailabilityForecast getAvailabilityForecastById(long lineItemId, Google.Api.Ads.AdManager.v201802.AvailabilityForecastOptions forecastOptions);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AvailabilityForecast> getAvailabilityForecastByIdAsync(long lineItemId, Google.Api.Ads.AdManager.v201802.AvailabilityForecastOptions forecastOptions);

		// CODEGEN: Parameter 'lineItems' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(LineItemSummary))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ForecastService.getDeliveryForecastResponse getDeliveryForecast(Wrappers.ForecastService.getDeliveryForecastRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ForecastService.getDeliveryForecastResponse> getDeliveryForecastAsync(Wrappers.ForecastService.getDeliveryForecastRequest request);

		// CODEGEN: Parameter 'lineItemIds' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(LineItemSummary))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ForecastService.getDeliveryForecastByIdsResponse getDeliveryForecastByIds(Wrappers.ForecastService.getDeliveryForecastByIdsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ForecastService.getDeliveryForecastByIdsResponse> getDeliveryForecastByIdsAsync(Wrappers.ForecastService.getDeliveryForecastByIdsRequest request);
	}


	/// <summary>Forecasting options for line item delivery forecasts.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeliveryForecastOptions {
		private long[] ignoredLineItemIdsField;

		/// <summary>Line item IDs to be ignored while performing the delivery simulation.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("ignoredLineItemIds", Order = 0)]
		public long[] ignoredLineItemIds {
			get {
				return this.ignoredLineItemIdsField;
			}
			set {
				this.ignoredLineItemIdsField = value;
			}
		}
	}


	/// <summary>The forecast of delivery for a list of <a
	/// href='ProspectiveLineItem'>ProspectiveLineItem</a> objects to be reserved at the
	/// same time.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeliveryForecast {
		private LineItemDeliveryForecast[] lineItemDeliveryForecastsField;

		/// <summary>The delivery forecasts of the forecasted line items.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("lineItemDeliveryForecasts", Order = 0)]
		public LineItemDeliveryForecast[] lineItemDeliveryForecasts {
			get {
				return this.lineItemDeliveryForecastsField;
			}
			set {
				this.lineItemDeliveryForecastsField = value;
			}
		}
	}


	/// <summary>The forecasted delivery of a <a
	/// href='ProspectiveLineItem'>ProspectiveLineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LineItemDeliveryForecast {
		private long lineItemIdField;

		private bool lineItemIdFieldSpecified;

		private long orderIdField;

		private bool orderIdFieldSpecified;

		private UnitType unitTypeField;

		private bool unitTypeFieldSpecified;

		private long predictedDeliveryUnitsField;

		private bool predictedDeliveryUnitsFieldSpecified;

		private long deliveredUnitsField;

		private bool deliveredUnitsFieldSpecified;

		private long matchedUnitsField;

		private bool matchedUnitsFieldSpecified;

		/// <summary>Uniquely identifies this line item delivery forecast. This value is read-only
		/// and will be either the ID of the <a href='LineItem'>LineItem</a> object it
		/// represents, or <code>null</code> if the forecast represents a prospective line
		/// item.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long lineItemId {
			get {
				return this.lineItemIdField;
			}
			set {
				this.lineItemIdField = value;
				this.lineItemIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="lineItemId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lineItemIdSpecified {
			get {
				return this.lineItemIdFieldSpecified;
			}
			set {
				this.lineItemIdFieldSpecified = value;
			}
		}

		/// <summary>The unique ID for the <a href='Order'>Order</a> object that this line item
		/// belongs to, or <code>null</code> if the forecast represents a prospective line
		/// item without an <a href='LineItem#orderId'>LineItem#orderId</a> set.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long orderId {
			get {
				return this.orderIdField;
			}
			set {
				this.orderIdField = value;
				this.orderIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="orderId" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool orderIdSpecified {
			get {
				return this.orderIdFieldSpecified;
			}
			set {
				this.orderIdFieldSpecified = value;
			}
		}

		/// <summary>The unit with which the goal or cap of the <a href='LineItem'>LineItem</a> is
		/// defined. Will be the same value as <a href='Goal#unitType'>Goal#unitType</a> for
		/// both a set line item or a prospective one.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public UnitType unitType {
			get {
				return this.unitTypeField;
			}
			set {
				this.unitTypeField = value;
				this.unitTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="unitType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool unitTypeSpecified {
			get {
				return this.unitTypeFieldSpecified;
			}
			set {
				this.unitTypeFieldSpecified = value;
			}
		}

		/// <summary>The number of units, defined by <a href='Goal#unitType'>Goal#unitType</a>, that
		/// will be delivered by the line item. Delivery of existing line items that are of
		/// same or lower priorities may be impacted.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public long predictedDeliveryUnits {
			get {
				return this.predictedDeliveryUnitsField;
			}
			set {
				this.predictedDeliveryUnitsField = value;
				this.predictedDeliveryUnitsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="predictedDeliveryUnits" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool predictedDeliveryUnitsSpecified {
			get {
				return this.predictedDeliveryUnitsFieldSpecified;
			}
			set {
				this.predictedDeliveryUnitsFieldSpecified = value;
			}
		}

		/// <summary>The number of units, defined by <a href='Goal#unitType'>Goal#unitType</a>, that
		/// have already been served if the reservation is already running.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public long deliveredUnits {
			get {
				return this.deliveredUnitsField;
			}
			set {
				this.deliveredUnitsField = value;
				this.deliveredUnitsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="deliveredUnits" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool deliveredUnitsSpecified {
			get {
				return this.deliveredUnitsFieldSpecified;
			}
			set {
				this.deliveredUnitsFieldSpecified = value;
			}
		}

		/// <summary>The number of units, defined by <a href='Goal#unitType'>Goal#unitType</a>, that
		/// match the specified <a href='LineItem#targeting'>LineItem#targeting</a> and
		/// delivery settings.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public long matchedUnits {
			get {
				return this.matchedUnitsField;
			}
			set {
				this.matchedUnitsField = value;
				this.matchedUnitsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="matchedUnits" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool matchedUnitsSpecified {
			get {
				return this.matchedUnitsFieldSpecified;
			}
			set {
				this.matchedUnitsFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ForecastServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ForecastServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for estimating traffic (clicks/impressions) for line items.
	/// Forecasts can be provided for <a href='LineItem'>LineItem</a> objects that exist
	/// in the system or which have not had an ID set yet. <h4>Test network
	/// behavior</h4> <p>Test networks are unable to provide forecasts that would be
	/// comparable to the production environment because forecasts require traffic
	/// history. For test networks, a consistent behavior can be expected for forecast
	/// requests, according to the following rules:</p> <table> <tr> <th
	/// colspan="2">Inputs<br /> (<a href='LineItem'>LineItem</a> Fields)</th> <th
	/// colspan="4">Outputs<br /> (<a href='Forecast'>Forecast</a> Fields)</th> </tr>
	/// <tr> <th><a href='LineItem#lineItemType'>lineItemType</a></th> <th><a
	/// href='LineItem#unitsBought'>unitsBought</a></th> <th><a
	/// href='Forecast#availableUnits'>availableUnits</a></th> <th><a
	/// href='Forecast#forecastUnits'>forecastUnits (matchedUnits)</a></th> <th><a
	/// href='Forecast#deliveredUnits'>deliveredUnits</a></th> <th>Exception </th> </tr>
	/// <tr> <td>Sponsorship</td> <td>13</td> <td>#x2013;#x2013;</td>
	/// <td>#x2013;#x2013;</td> <td>#x2013;#x2013;</td> <td><a
	/// href='ForecastError.Reason#NO_FORECAST_YET'>NO_FORECAST_YET</a> </td> </tr> <tr>
	/// <td>Sponsorship</td> <td>20</td> <td>#x2013;#x2013;</td> <td>#x2013;#x2013;</td>
	/// <td>#x2013;#x2013;</td> <td><a
	/// href='ForecastError.Reason#SERVER_NOT_AVAILABLE'>SERVER_NOT_AVAILABLE</a> </td>
	/// </tr> <tr> <td>Sponsorship</td> <td>50</td> <td>1,200,000</td>
	/// <td>6,000,000</td> <td>600,000<br /> For prospective: 0</td>
	/// <td>#x2013;#x2013;</td> </tr> <tr> <td>Sponsorship</td> <td>!= 20 and<br /> !=
	/// 50</td> <td>1,200,000</td> <td>1,200,000</td> <td>600,000<br /> For prospective:
	/// 0</td> <td>#x2013;#x2013;</td> </tr> <tr> <td>Not Sponsorship</td> <td>&lt;=
	/// 500,000</td> <td>3 * unitsBought / 2</td> <td>unitsBought * 6</td>
	/// <td>600,000<br /> For prospective: 0</td> <td>#x2013;#x2013;</td> </tr> <tr>
	/// <td>Not Sponsorship</td> <td>&gt; 500,000 and &lt;= 1,000,000</td>
	/// <td>unitsBought / 2</td> <td>unitsBought * 6</td> <td>600,000<br /> For
	/// prospective: 0</td> <td>#x2013;#x2013;</td> </tr> <tr> <td>Not Sponsorship</td>
	/// <td>&gt; 1,000,000 and &lt;= 1,500,000</td> <td>unitsBought / 2</td> <td>3 *
	/// unitsBought / 2</td> <td>600,000<br /> For prospective: 0</td>
	/// <td>#x2013;#x2013;</td> </tr> <tr> <td>Not Sponsorship</td> <td>&gt;
	/// 1,500,000</td> <td>unitsBought / 4</td> <td>3 * unitsBought / 2</td>
	/// <td>600,000<br /> For prospective: 0</td> <td>#x2013;#x2013;</td> </tr> </table>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ForecastService : AdManagerSoapClient<IForecastService>, IForecastService {
		/// <summary> Creates a new instance of the <see cref="ForecastService"/> class.
		/// </summary>
		public ForecastService() {
		}

		/// <summary> Creates a new instance of the <see cref="ForecastService"/> class.
		/// </summary>
		public ForecastService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="ForecastService"/> class.
		/// </summary>
		public ForecastService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ForecastService"/> class.
		/// </summary>
		public ForecastService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ForecastService"/> class.
		/// </summary>
		public ForecastService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		/// <summary>Gets the availability forecast for a <a
		/// href='ProspectiveLineItem'>ProspectiveLineItem</a>. An availability forecast
		/// reports the maximum number of available units that the line item can book, and
		/// the total number of units matching the line item's targeting.
		/// </summary><param name='lineItem'>the prospective line item (new or existing) to be
		/// forecasted for availability</param>
		/// <param name='forecastOptions'>options controlling the forecast</param>
		public virtual Google.Api.Ads.AdManager.v201802.AvailabilityForecast getAvailabilityForecast(Google.Api.Ads.AdManager.v201802.ProspectiveLineItem lineItem, Google.Api.Ads.AdManager.v201802.AvailabilityForecastOptions forecastOptions) {
			return base.Channel.getAvailabilityForecast(lineItem, forecastOptions);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AvailabilityForecast> getAvailabilityForecastAsync(Google.Api.Ads.AdManager.v201802.ProspectiveLineItem lineItem, Google.Api.Ads.AdManager.v201802.AvailabilityForecastOptions forecastOptions) {
			return base.Channel.getAvailabilityForecastAsync(lineItem, forecastOptions);
		}

		/// <summary>Gets an <a href='AvailabilityForecast'>AvailabilityForecast</a> for an existing
		/// <a href='LineItem'>LineItem</a> object. An availability forecast reports the
		/// maximum number of available units that the line item can be booked with, and
		/// also the total number of units matching the line item's targeting. <p>Only line
		/// items having type <a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a> or <a
		/// href=''>LineItemType#STANDARD</a> are valid. Other types will result in <a
		/// href=''>ReservationDetailsError.Reason#LINE_ITEM_TYPE_NOT_ALLOWED</a>. </p>
		/// </summary><param name='lineItemId'>the ID of a <a href='LineItem'>LineItem</a> to run the
		/// forecast on.</param>
		/// <param name='forecastOptions'>options controlling the forecast</param>
		public virtual Google.Api.Ads.AdManager.v201802.AvailabilityForecast getAvailabilityForecastById(long lineItemId, Google.Api.Ads.AdManager.v201802.AvailabilityForecastOptions forecastOptions) {
			return base.Channel.getAvailabilityForecastById(lineItemId, forecastOptions);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AvailabilityForecast> getAvailabilityForecastByIdAsync(long lineItemId, Google.Api.Ads.AdManager.v201802.AvailabilityForecastOptions forecastOptions) {
			return base.Channel.getAvailabilityForecastByIdAsync(lineItemId, forecastOptions);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ForecastService.getDeliveryForecastResponse Google.Api.Ads.AdManager.v201802.ForecastServiceInterface.getDeliveryForecast(Wrappers.ForecastService.getDeliveryForecastRequest request) {
			return base.Channel.getDeliveryForecast(request);
		}

		/// <summary>Gets the delivery forecast for a list of <a
		/// href='ProspectiveLineItem'>ProspectiveLineItem</a> objects in a single delivery
		/// simulation with line items potentially contending with each other. A delivery
		/// forecast reports the number of units that will be delivered to each line item
		/// given the line item goals and contentions from other line items.
		/// </summary><param name='lineItems'>line items to be forecasted for delivery</param>
		/// <param name='forecastOptions'>options controlling the forecast</param>
		public virtual Google.Api.Ads.AdManager.v201802.DeliveryForecast getDeliveryForecast(Google.Api.Ads.AdManager.v201802.ProspectiveLineItem[] lineItems, Google.Api.Ads.AdManager.v201802.DeliveryForecastOptions forecastOptions) {
			Wrappers.ForecastService.getDeliveryForecastRequest inValue = new Wrappers.ForecastService.getDeliveryForecastRequest();
			inValue.lineItems = lineItems;
			inValue.forecastOptions = forecastOptions;
			Wrappers.ForecastService.getDeliveryForecastResponse retVal = ((Google.Api.Ads.AdManager.v201802.ForecastServiceInterface)(this)).getDeliveryForecast(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ForecastService.getDeliveryForecastResponse> Google.Api.Ads.AdManager.v201802.ForecastServiceInterface.getDeliveryForecastAsync(Wrappers.ForecastService.getDeliveryForecastRequest request) {
			return base.Channel.getDeliveryForecastAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.DeliveryForecast> getDeliveryForecastAsync(Google.Api.Ads.AdManager.v201802.ProspectiveLineItem[] lineItems, Google.Api.Ads.AdManager.v201802.DeliveryForecastOptions forecastOptions) {
			Wrappers.ForecastService.getDeliveryForecastRequest inValue = new Wrappers.ForecastService.getDeliveryForecastRequest();
			inValue.lineItems = lineItems;
			inValue.forecastOptions = forecastOptions;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.DeliveryForecast>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ForecastServiceInterface)(this)).getDeliveryForecastAsync(inValue)).Result.rval);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ForecastService.getDeliveryForecastByIdsResponse Google.Api.Ads.AdManager.v201802.ForecastServiceInterface.getDeliveryForecastByIds(Wrappers.ForecastService.getDeliveryForecastByIdsRequest request) {
			return base.Channel.getDeliveryForecastByIds(request);
		}

		/// <summary>Gets the delivery forecast for a list of existing <a
		/// href='LineItem'>LineItem</a> objects in a single delivery simulation. A delivery
		/// forecast reports the number of units that will be delivered to each line item
		/// given the line item goals and contentions from other line items.
		/// </summary><param name='lineItemIds'>the IDs of line items to be forecasted for
		/// delivery</param>
		/// <param name='forecastOptions'>options controlling the forecast</param>
		public virtual Google.Api.Ads.AdManager.v201802.DeliveryForecast getDeliveryForecastByIds(long[] lineItemIds, Google.Api.Ads.AdManager.v201802.DeliveryForecastOptions forecastOptions) {
			Wrappers.ForecastService.getDeliveryForecastByIdsRequest inValue = new Wrappers.ForecastService.getDeliveryForecastByIdsRequest();
			inValue.lineItemIds = lineItemIds;
			inValue.forecastOptions = forecastOptions;
			Wrappers.ForecastService.getDeliveryForecastByIdsResponse retVal = ((Google.Api.Ads.AdManager.v201802.ForecastServiceInterface)(this)).getDeliveryForecastByIds(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ForecastService.getDeliveryForecastByIdsResponse> Google.Api.Ads.AdManager.v201802.ForecastServiceInterface.getDeliveryForecastByIdsAsync(Wrappers.ForecastService.getDeliveryForecastByIdsRequest request) {
			return base.Channel.getDeliveryForecastByIdsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.DeliveryForecast> getDeliveryForecastByIdsAsync(long[] lineItemIds, Google.Api.Ads.AdManager.v201802.DeliveryForecastOptions forecastOptions) {
			Wrappers.ForecastService.getDeliveryForecastByIdsRequest inValue = new Wrappers.ForecastService.getDeliveryForecastByIdsRequest();
			inValue.lineItemIds = lineItemIds;
			inValue.forecastOptions = forecastOptions;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.DeliveryForecast>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ForecastServiceInterface)(this)).getDeliveryForecastByIdsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.ActivityService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createActivities", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createActivitiesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("activities")]
			public Google.Api.Ads.AdManager.v201802.Activity[] activities;

			/// <summary> Creates a new instance of the <see cref="createActivitiesRequest"/>
			/// class. </summary>
			public createActivitiesRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createActivitiesRequest"/>
			/// class. </summary>
			public createActivitiesRequest(Google.Api.Ads.AdManager.v201802.Activity[] activities) {
				this.activities = activities;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createActivitiesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createActivitiesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Activity[] rval;

			/// <summary> Creates a new instance of the <see cref="createActivitiesResponse"/>
			/// class. </summary>
			public createActivitiesResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createActivitiesResponse"/>
			/// class. </summary>
			public createActivitiesResponse(Google.Api.Ads.AdManager.v201802.Activity[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateActivities", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateActivitiesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("activities")]
			public Google.Api.Ads.AdManager.v201802.Activity[] activities;

			/// <summary> Creates a new instance of the <see cref="updateActivitiesRequest"/>
			/// class. </summary>
			public updateActivitiesRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updateActivitiesRequest"/>
			/// class. </summary>
			public updateActivitiesRequest(Google.Api.Ads.AdManager.v201802.Activity[] activities) {
				this.activities = activities;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateActivitiesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateActivitiesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Activity[] rval;

			/// <summary> Creates a new instance of the <see cref="updateActivitiesResponse"/>
			/// class. </summary>
			public updateActivitiesResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updateActivitiesResponse"/>
			/// class. </summary>
			public updateActivitiesResponse(Google.Api.Ads.AdManager.v201802.Activity[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary><p>An activity is a specific user action that an advertiser wants to track, such
	/// as the completion of a purchase or a visit to a webpage. You create and manage
	/// activities in Ad Manager. When a user performs the action after seeing an
	/// advertiser's ad, that's a conversion.</p> <p>For example, you set up an activity
	/// in Ad Manager to track how many users visit an advertiser's promotional website
	/// after viewing or clicking on an ad. When a user views an ad, then visits the
	/// page, that's one conversion.</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Activity {
		private int idField;

		private bool idFieldSpecified;

		private int activityGroupIdField;

		private bool activityGroupIdFieldSpecified;

		private string nameField;

		private string expectedURLField;

		private ActivityStatus statusField;

		private bool statusFieldSpecified;

		private ActivityType typeField;

		private bool typeFieldSpecified;

		/// <summary>The unique ID of the <code>Activity</code>. This value is readonly and is
		/// assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The ID of the <a href='ActivityGroup'>ActivityGroup</a> that this <a
		/// href='Activity'>Activity</a> belongs to.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int activityGroupId {
			get {
				return this.activityGroupIdField;
			}
			set {
				this.activityGroupIdField = value;
				this.activityGroupIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="activityGroupId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool activityGroupIdSpecified {
			get {
				return this.activityGroupIdFieldSpecified;
			}
			set {
				this.activityGroupIdFieldSpecified = value;
			}
		}

		/// <summary>The name of the <code>Activity</code>. This attribute is required and has a
		/// maximum length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The URL of the webpage where the tags from this activity will be placed. This
		/// attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string expectedURL {
			get {
				return this.expectedURLField;
			}
			set {
				this.expectedURLField = value;
			}
		}

		/// <summary>The status of this activity. This attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public ActivityStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>The activity type. This attribute is optional and defaults to <a
		/// href='Activity.Type#PAGE_VIEWS'>Activity.Type#PAGE_VIEWS</a>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public ActivityType type {
			get {
				return this.typeField;
			}
			set {
				this.typeField = value;
				this.typeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="type" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool typeSpecified {
			get {
				return this.typeFieldSpecified;
			}
			set {
				this.typeFieldSpecified = value;
			}
		}
	}


	/// <summary>The activity status.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "Activity.Status", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ActivityStatus {
		ACTIVE = 0,
		INACTIVE = 1,
	}


	/// <summary>The activity type.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "Activity.Type", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ActivityType {
		/// <summary>Tracks conversions for each visit to a webpage. This is a counter type.
		/// </summary>
		PAGE_VIEWS = 0,
		/// <summary>Tracks conversions for visits to a webpage, but only counts one conversion per
		/// user per day, even if a user visits the page multiple times. This is a counter
		/// type.
		/// </summary>
		DAILY_VISITS = 1,
		/// <summary>Tracks conversions for visits to a webpage, but only counts one conversion per
		/// user per user session. Session length is set by the advertiser. This is a
		/// counter type.
		/// </summary>
		CUSTOM = 2,
		/// <summary>Tracks conversions where the user has made a purchase, the monetary value of
		/// each purchase, plus the number of items that were purchased and the order ID.
		/// This is a sales type.
		/// </summary>
		ITEMS_PURCHASED = 3,
		/// <summary>Tracks conversions where the user has made a purchase, the monetary value of
		/// each purchase, plus the order ID (but not the number of items purchased). This
		/// is a sales type.
		/// </summary>
		TRANSACTIONS = 4,
		/// <summary>Tracks conversions where the user has installed an iOS application. This is a
		/// counter type.
		/// </summary>
		IOS_APPLICATION_DOWNLOADS = 5,
		/// <summary>Tracks conversions where the user has installed an Android application. This is
		/// a counter type.
		/// </summary>
		ANDROID_APPLICATION_DOWNLOADS = 6,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 7,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ActivityServiceInterface")]
	public interface ActivityServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ActivityService.createActivitiesResponse createActivities(Wrappers.ActivityService.createActivitiesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ActivityService.createActivitiesResponse> createActivitiesAsync(Wrappers.ActivityService.createActivitiesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ActivityPage getActivitiesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ActivityPage> getActivitiesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ActivityService.updateActivitiesResponse updateActivities(Wrappers.ActivityService.updateActivitiesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ActivityService.updateActivitiesResponse> updateActivitiesAsync(Wrappers.ActivityService.updateActivitiesRequest request);
	}


	/// <summary>Captures a page of <a href='Activity'>Activity</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivityPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private Activity[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of activities contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public Activity[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ActivityServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ActivityServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='Activity'>Activity</a> objects. <p>An activity group contains <a
	/// href='Activity'>Activity</a> objects. Activities have a many-to-one relationship
	/// with activity groups, meaning each activity can belong to only one activity
	/// group, but activity groups can have multiple activities. An activity group can
	/// be used to manage the activities it contains.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ActivityService : AdManagerSoapClient<IActivityService>, IActivityService {
		/// <summary> Creates a new instance of the <see cref="ActivityService"/> class.
		/// </summary>
		public ActivityService() {
		}

		/// <summary> Creates a new instance of the <see cref="ActivityService"/> class.
		/// </summary>
		public ActivityService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="ActivityService"/> class.
		/// </summary>
		public ActivityService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ActivityService"/> class.
		/// </summary>
		public ActivityService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ActivityService"/> class.
		/// </summary>
		public ActivityService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ActivityService.createActivitiesResponse Google.Api.Ads.AdManager.v201802.ActivityServiceInterface.createActivities(Wrappers.ActivityService.createActivitiesRequest request) {
			return base.Channel.createActivities(request);
		}

		/// <summary>Creates a new <a href='Activity'>Activity</a> objects.
		/// </summary><param name='activities'>to be created.</param>
		/// <returns>the created activities with its IDs filled in.</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Activity[] createActivities(Google.Api.Ads.AdManager.v201802.Activity[] activities) {
			Wrappers.ActivityService.createActivitiesRequest inValue = new Wrappers.ActivityService.createActivitiesRequest();
			inValue.activities = activities;
			Wrappers.ActivityService.createActivitiesResponse retVal = ((Google.Api.Ads.AdManager.v201802.ActivityServiceInterface)(this)).createActivities(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ActivityService.createActivitiesResponse> Google.Api.Ads.AdManager.v201802.ActivityServiceInterface.createActivitiesAsync(Wrappers.ActivityService.createActivitiesRequest request) {
			return base.Channel.createActivitiesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Activity[]> createActivitiesAsync(Google.Api.Ads.AdManager.v201802.Activity[] activities) {
			Wrappers.ActivityService.createActivitiesRequest inValue = new Wrappers.ActivityService.createActivitiesRequest();
			inValue.activities = activities;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Activity[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ActivityServiceInterface)(this)).createActivitiesAsync(inValue)).Result.rval);
		}

		/// <summary>Gets an <a href='ActivityPage'>ActivityPage</a> of <a
		/// href='Activity'>Activity</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='Activity#id'>Activity#id</a></td> </tr> <tr> <td><code>name</code></td>
		/// <td><a href='Activity#name'>Activity#name</a></td> </tr> <tr>
		/// <td><code>expectedURL</code></td> <td><a
		/// href='Activity#expectedURL'>Activity#expectedURL</a></td> </tr> <tr>
		/// <td><code>status</code></td> <td><a
		/// href='Activity#status'>Activity#status</a></td> </tr> <tr>
		/// <td><code>activityGroupId</code></td> <td><a
		/// href='Activity#activityGroupId'>Activity#activityGroupId</a></td> </tr> </table>
		/// </summary><param name='filterStatement'>a statement used to filter a set of
		/// activities.</param>
		/// <returns>the activities that match the given filter.</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ActivityPage getActivitiesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getActivitiesByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ActivityPage> getActivitiesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getActivitiesByStatementAsync(filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ActivityService.updateActivitiesResponse Google.Api.Ads.AdManager.v201802.ActivityServiceInterface.updateActivities(Wrappers.ActivityService.updateActivitiesRequest request) {
			return base.Channel.updateActivities(request);
		}

		/// <summary>Updates the specified <a href='Activity'>Activity</a> objects.
		/// </summary><param name='activities'>to be updated.</param>
		/// <returns>the updated activities.</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Activity[] updateActivities(Google.Api.Ads.AdManager.v201802.Activity[] activities) {
			Wrappers.ActivityService.updateActivitiesRequest inValue = new Wrappers.ActivityService.updateActivitiesRequest();
			inValue.activities = activities;
			Wrappers.ActivityService.updateActivitiesResponse retVal = ((Google.Api.Ads.AdManager.v201802.ActivityServiceInterface)(this)).updateActivities(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ActivityService.updateActivitiesResponse> Google.Api.Ads.AdManager.v201802.ActivityServiceInterface.updateActivitiesAsync(Wrappers.ActivityService.updateActivitiesRequest request) {
			return base.Channel.updateActivitiesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Activity[]> updateActivitiesAsync(Google.Api.Ads.AdManager.v201802.Activity[] activities) {
			Wrappers.ActivityService.updateActivitiesRequest inValue = new Wrappers.ActivityService.updateActivitiesRequest();
			inValue.activities = activities;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Activity[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ActivityServiceInterface)(this)).updateActivitiesAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.InventoryService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createAdUnits", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createAdUnitsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("adUnits")]
			public Google.Api.Ads.AdManager.v201802.AdUnit[] adUnits;

			/// <summary> Creates a new instance of the <see cref="createAdUnitsRequest"/>
			/// class. </summary>
			public createAdUnitsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createAdUnitsRequest"/>
			/// class. </summary>
			public createAdUnitsRequest(Google.Api.Ads.AdManager.v201802.AdUnit[] adUnits) {
				this.adUnits = adUnits;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createAdUnitsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createAdUnitsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.AdUnit[] rval;

			/// <summary> Creates a new instance of the <see cref="createAdUnitsResponse"/>
			/// class. </summary>
			public createAdUnitsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createAdUnitsResponse"/>
			/// class. </summary>
			public createAdUnitsResponse(Google.Api.Ads.AdManager.v201802.AdUnit[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "getAdUnitSizesByStatement", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class getAdUnitSizesByStatementRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			public Google.Api.Ads.AdManager.v201802.Statement filterStatement;

			/// <summary> Creates a new instance of the <see
			/// cref="getAdUnitSizesByStatementRequest"/> class. </summary>
			public getAdUnitSizesByStatementRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="getAdUnitSizesByStatementRequest"/> class. </summary>
			public getAdUnitSizesByStatementRequest(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
				this.filterStatement = filterStatement;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "getAdUnitSizesByStatementResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class getAdUnitSizesByStatementResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.AdUnitSize[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="getAdUnitSizesByStatementResponse"/> class. </summary>
			public getAdUnitSizesByStatementResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="getAdUnitSizesByStatementResponse"/> class. </summary>
			public getAdUnitSizesByStatementResponse(Google.Api.Ads.AdManager.v201802.AdUnitSize[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateAdUnits", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateAdUnitsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("adUnits")]
			public Google.Api.Ads.AdManager.v201802.AdUnit[] adUnits;

			/// <summary> Creates a new instance of the <see cref="updateAdUnitsRequest"/>
			/// class. </summary>
			public updateAdUnitsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updateAdUnitsRequest"/>
			/// class. </summary>
			public updateAdUnitsRequest(Google.Api.Ads.AdManager.v201802.AdUnit[] adUnits) {
				this.adUnits = adUnits;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateAdUnitsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateAdUnitsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.AdUnit[] rval;

			/// <summary> Creates a new instance of the <see cref="updateAdUnitsResponse"/>
			/// class. </summary>
			public updateAdUnitsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updateAdUnitsResponse"/>
			/// class. </summary>
			public updateAdUnitsResponse(Google.Api.Ads.AdManager.v201802.AdUnit[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>A <code>LabelFrequencyCap</code> assigns a frequency cap to a label. The
	/// frequency cap will limit the cumulative number of impressions of any ad units
	/// with this label that may be shown to a particular user over a time unit.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LabelFrequencyCap {
		private FrequencyCap frequencyCapField;

		private long labelIdField;

		private bool labelIdFieldSpecified;

		/// <summary>The frequency cap to be applied with this label.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public FrequencyCap frequencyCap {
			get {
				return this.frequencyCapField;
			}
			set {
				this.frequencyCapField = value;
			}
		}

		/// <summary>ID of the label being capped on the <a href='AdUnit'>AdUnit</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long labelId {
			get {
				return this.labelIdField;
			}
			set {
				this.labelIdField = value;
				this.labelIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="labelId" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool labelIdSpecified {
			get {
				return this.labelIdFieldSpecified;
			}
			set {
				this.labelIdFieldSpecified = value;
			}
		}
	}


	/// <summary>Contains the AdSense configuration for an <a href='AdUnit'>AdUnit</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdSenseSettings {
		private bool adSenseEnabledField;

		private bool adSenseEnabledFieldSpecified;

		private string borderColorField;

		private string titleColorField;

		private string backgroundColorField;

		private string textColorField;

		private string urlColorField;

		private AdSenseSettingsAdType adTypeField;

		private bool adTypeFieldSpecified;

		private AdSenseSettingsBorderStyle borderStyleField;

		private bool borderStyleFieldSpecified;

		private AdSenseSettingsFontFamily fontFamilyField;

		private bool fontFamilyFieldSpecified;

		private AdSenseSettingsFontSize fontSizeField;

		private bool fontSizeFieldSpecified;

		/// <summary>Specifies whether or not the <a href='AdUnit'>AdUnit</a> is enabled for serving
		/// ads from the AdSense content network. This attribute is optional and defaults to
		/// the ad unit's parent or ancestor's setting if one has been set. If no ancestor
		/// of the ad unit has set <code></code>, the attribute is defaulted to
		/// <code>true</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool adSenseEnabled {
			get {
				return this.adSenseEnabledField;
			}
			set {
				this.adSenseEnabledField = value;
				this.adSenseEnabledSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="adSenseEnabled" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool adSenseEnabledSpecified {
			get {
				return this.adSenseEnabledFieldSpecified;
			}
			set {
				this.adSenseEnabledFieldSpecified = value;
			}
		}

		/// <summary>Specifies the Hexadecimal border color, from <code>000000</code> to
		/// <code>FFFFFF</code>. This attribute is optional and defaults to the ad unit's
		/// parent or ancestor's setting if one has been set. If no ancestor of the ad unit
		/// has set <code>borderColor</code>, the attribute is defaulted to
		/// <code>FFFFFF</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string borderColor {
			get {
				return this.borderColorField;
			}
			set {
				this.borderColorField = value;
			}
		}

		/// <summary>Specifies the Hexadecimal title color of an ad, from <code>000000</code> to
		/// <code>FFFFFF</code>. This attribute is optional and defaults to the ad unit's
		/// parent or ancestor's setting if one has been set. If no ancestor of the ad unit
		/// has set <code>titleColor</code>, the attribute is defaulted to
		/// <code>0000FF</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string titleColor {
			get {
				return this.titleColorField;
			}
			set {
				this.titleColorField = value;
			}
		}

		/// <summary>Specifies the Hexadecimal background color of an ad, from <code></code> to
		/// <code>FFFFFF</code>. This attribute is optional and defaults to the ad unit's
		/// parent or ancestor's setting if one has been set. If no ancestor of the ad unit
		/// has set <code>backgroundColor</code>, the attribute is defaulted to
		/// <code>FFFFFF</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string backgroundColor {
			get {
				return this.backgroundColorField;
			}
			set {
				this.backgroundColorField = value;
			}
		}

		/// <summary>Specifies the Hexadecimal color of the text of an ad, from <code></code> to
		/// <code>FFFFFF</code>. This attribute is optional and defaults to the ad unit's
		/// parent or ancestor's setting if one has been set. If no ancestor of the ad unit
		/// has set <code>textColor</code>, the attribute is defaulted to
		/// <code>000000</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string textColor {
			get {
				return this.textColorField;
			}
			set {
				this.textColorField = value;
			}
		}

		/// <summary>Specifies the Hexadecimal color of the URL of an ad, from <code></code> to
		/// <code>FFFFFF</code>. This attribute is optional and defaults to the ad unit's
		/// parent or ancestor's setting if one has been set. If no ancestor of the ad unit
		/// has set <code>urlColor</code>, the attribute is defaulted to <code>008000</code>
		/// .
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public string urlColor {
			get {
				return this.urlColorField;
			}
			set {
				this.urlColorField = value;
			}
		}

		/// <summary>Specifies what kind of ad can be served by this <a href='AdUnit'>AdUnit</a> from
		/// the AdSense Content Network. This attribute is optional and defaults to the ad
		/// unit's parent or ancestor's setting if one has been set. If no ancestor of the
		/// ad unit has set <code>adType</code>, the attribute is defaulted to <a
		/// href=''>AdType#TEXT_AND_IMAGE</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public AdSenseSettingsAdType adType {
			get {
				return this.adTypeField;
			}
			set {
				this.adTypeField = value;
				this.adTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="adType" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool adTypeSpecified {
			get {
				return this.adTypeFieldSpecified;
			}
			set {
				this.adTypeFieldSpecified = value;
			}
		}

		/// <summary>Specifies the border-style of the <a href='AdUnit'>AdUnit</a>. This attribute is
		/// optional and defaults to the ad unit's parent or ancestor's setting if one has
		/// been set. If no ancestor of the ad unit has set <code>borderStyle</code>, the
		/// attribute is defaulted to <a href='BorderStyle#DEFAULT'>BorderStyle#DEFAULT</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public AdSenseSettingsBorderStyle borderStyle {
			get {
				return this.borderStyleField;
			}
			set {
				this.borderStyleField = value;
				this.borderStyleSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="borderStyle"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool borderStyleSpecified {
			get {
				return this.borderStyleFieldSpecified;
			}
			set {
				this.borderStyleFieldSpecified = value;
			}
		}

		/// <summary>Specifies the font family of the <a href='AdUnit'>AdUnit</a>. This attribute is
		/// optional and defaults to the ad unit's parent or ancestor's setting if one has
		/// been set. If no ancestor of the ad unit has set <code>fontFamily</code>, the
		/// attribute is defaulted to <a href='FontFamily#DEFAULT'>FontFamily#DEFAULT</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public AdSenseSettingsFontFamily fontFamily {
			get {
				return this.fontFamilyField;
			}
			set {
				this.fontFamilyField = value;
				this.fontFamilySpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="fontFamily"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool fontFamilySpecified {
			get {
				return this.fontFamilyFieldSpecified;
			}
			set {
				this.fontFamilyFieldSpecified = value;
			}
		}

		/// <summary>Specifies the font size of the <a href='AdUnit'>AdUnit</a>. This attribute is
		/// optional and defaults to the ad unit's parent or ancestor's setting if one has
		/// been set. If no ancestor of the ad unit has set <code>fontSize</code>, the
		/// attribute is defaulted to <a href='FontSize#DEFAULT'>FontSize#DEFAULT</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public AdSenseSettingsFontSize fontSize {
			get {
				return this.fontSizeField;
			}
			set {
				this.fontSizeField = value;
				this.fontSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="fontSize"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool fontSizeSpecified {
			get {
				return this.fontSizeFieldSpecified;
			}
			set {
				this.fontSizeFieldSpecified = value;
			}
		}
	}


	/// <summary>Specifies the type of ads that can be served through this <a
	/// href='AdUnit'>AdUnit</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AdSenseSettings.AdType", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdSenseSettingsAdType {
		/// <summary>Allows text-only ads.
		/// </summary>
		TEXT = 0,
		/// <summary>Allows image-only ads.
		/// </summary>
		IMAGE = 1,
		/// <summary>Allows both text and image ads.
		/// </summary>
		TEXT_AND_IMAGE = 2,
	}


	/// <summary>Describes the border of the HTML elements used to surround an ad displayed by
	/// the <a href='AdUnit'>AdUnit</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AdSenseSettings.BorderStyle", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdSenseSettingsBorderStyle {
		/// <summary>Uses the default border-style of the browser.
		/// </summary>
		DEFAULT = 0,
		/// <summary>Uses a cornered border-style.
		/// </summary>
		NOT_ROUNDED = 1,
		/// <summary>Uses a slightly rounded border-style.
		/// </summary>
		SLIGHTLY_ROUNDED = 2,
		/// <summary>Uses a rounded border-style.
		/// </summary>
		VERY_ROUNDED = 3,
	}


	/// <summary>List of all possible font families.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AdSenseSettings.FontFamily", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdSenseSettingsFontFamily {
		DEFAULT = 0,
		ARIAL = 1,
		TAHOMA = 2,
		GEORGIA = 3,
		TIMES = 4,
		VERDANA = 5,
	}


	/// <summary>List of all possible font sizes the user can choose.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AdSenseSettings.FontSize", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdSenseSettingsFontSize {
		DEFAULT = 0,
		SMALL = 1,
		MEDIUM = 2,
		LARGE = 3,
	}


	/// <summary>An <code>AdUnitSize</code> represents the size of an ad in an ad unit. This also
	/// represents the environment and companions of a particular ad in an ad unit. In
	/// most cases, it is a simple size with just a width and a height (sometimes
	/// representing an aspect ratio).
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdUnitSize {
		private Size sizeField;

		private EnvironmentType environmentTypeField;

		private bool environmentTypeFieldSpecified;

		private AdUnitSize[] companionsField;

		private string fullDisplayStringField;

		/// <summary>The permissible creative size that can be served inside this ad unit.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public Size size {
			get {
				return this.sizeField;
			}
			set {
				this.sizeField = value;
			}
		}

		/// <summary>The environment type of the ad unit size. The default value is <a
		/// href='EnvironmentType#BROWSER'>EnvironmentType#BROWSER</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public EnvironmentType environmentType {
			get {
				return this.environmentTypeField;
			}
			set {
				this.environmentTypeField = value;
				this.environmentTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="environmentType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool environmentTypeSpecified {
			get {
				return this.environmentTypeFieldSpecified;
			}
			set {
				this.environmentTypeFieldSpecified = value;
			}
		}

		/// <summary>The companions for this ad unit size. Companions are only valid if the
		/// environment is <a
		/// href='EnvironmentType#VIDEO_PLAYER'>EnvironmentType#VIDEO_PLAYER</a>. If the
		/// environment is <a href='EnvironmentType#BROWSER'>EnvironmentType#BROWSER</a>
		/// including companions results in an error.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("companions", Order = 2)]
		public AdUnitSize[] companions {
			get {
				return this.companionsField;
			}
			set {
				this.companionsField = value;
			}
		}

		/// <summary>The full (including companion sizes, if applicable) display string of the size,
		/// e.g. <code>"300x250"</code> or <code>"300x250v (180x150)"</code>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string fullDisplayString {
			get {
				return this.fullDisplayStringField;
			}
			set {
				this.fullDisplayStringField = value;
			}
		}
	}


	/// <summary>The summary of a parent <a href='AdUnit'>AdUnit</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdUnitParent {
		private string idField;

		private string nameField;

		private string adUnitCodeField;

		/// <summary>The ID of the parent <code>AdUnit</code>. This value is readonly and is
		/// populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
			}
		}

		/// <summary>The name of the parent <code>AdUnit</code>. This value is readonly and is
		/// populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>A string used to uniquely identify the ad unit for the purposes of serving the
		/// ad. This attribute is read-only and is assigned by Google when an ad unit is
		/// created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string adUnitCode {
			get {
				return this.adUnitCodeField;
			}
			set {
				this.adUnitCodeField = value;
			}
		}
	}


	/// <summary>An <code>AdUnit</code> represents a chunk of identified inventory for the
	/// publisher. It contains all the settings that need to be associated with
	/// inventory in order to serve ads to it. An <code></code> can also be the parent
	/// of other ad units in the inventory hierarchy.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdUnit {
		private string idField;

		private string parentIdField;

		private bool hasChildrenField;

		private bool hasChildrenFieldSpecified;

		private AdUnitParent[] parentPathField;

		private string nameField;

		private string descriptionField;

		private AdUnitTargetWindow targetWindowField;

		private bool targetWindowFieldSpecified;

		private InventoryStatus statusField;

		private bool statusFieldSpecified;

		private string adUnitCodeField;

		private AdUnitSize[] adUnitSizesField;

		private bool isFluidField;

		private bool isFluidFieldSpecified;

		private bool explicitlyTargetedField;

		private bool explicitlyTargetedFieldSpecified;

		private AdSenseSettings adSenseSettingsField;

		private ValueSourceType adSenseSettingsSourceField;

		private bool adSenseSettingsSourceFieldSpecified;

		private LabelFrequencyCap[] appliedLabelFrequencyCapsField;

		private LabelFrequencyCap[] effectiveLabelFrequencyCapsField;

		private AppliedLabel[] appliedLabelsField;

		private AppliedLabel[] effectiveAppliedLabelsField;

		private long[] effectiveTeamIdsField;

		private long[] appliedTeamIdsField;

		private DateTime lastModifiedDateTimeField;

		private SmartSizeMode smartSizeModeField;

		private bool smartSizeModeFieldSpecified;

		private int refreshRateField;

		private bool refreshRateFieldSpecified;

		private string externalSetTopBoxChannelIdField;

		private bool isSetTopBoxEnabledField;

		private bool isSetTopBoxEnabledFieldSpecified;

		/// <summary>Uniquely identifies the <code>AdUnit</code>. This value is read-only and is
		/// assigned by Google when an ad unit is created. This attribute is required for
		/// updates.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
			}
		}

		/// <summary>The ID of the ad unit's parent. Every ad unit has a parent except for the root
		/// ad unit, which is created by Google. This attribute is required when creating
		/// the ad unit. Once the ad unit is created this value will be read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string parentId {
			get {
				return this.parentIdField;
			}
			set {
				this.parentIdField = value;
			}
		}

		/// <summary>This field is set to <code>true</code> if the ad unit has any children. This
		/// attribute is read-only and is populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public bool hasChildren {
			get {
				return this.hasChildrenField;
			}
			set {
				this.hasChildrenField = value;
				this.hasChildrenSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="hasChildren"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool hasChildrenSpecified {
			get {
				return this.hasChildrenFieldSpecified;
			}
			set {
				this.hasChildrenFieldSpecified = value;
			}
		}

		/// <summary>The path to this ad unit in the ad unit hierarchy represented as a list from the
		/// root to this ad unit's parent. For root ad units, this list is empty. This
		/// attribute is read-only and is populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("parentPath", Order = 3)]
		public AdUnitParent[] parentPath {
			get {
				return this.parentPathField;
			}
			set {
				this.parentPathField = value;
			}
		}

		/// <summary>The name of the ad unit. This attribute is required and its maximum length is
		/// 255 characters. This attribute must also be case-insensitive unique.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>A description of the ad unit. This value is optional and its maximum length is
		/// 65,535 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public string description {
			get {
				return this.descriptionField;
			}
			set {
				this.descriptionField = value;
			}
		}

		/// <summary>The value to use for the HTML link's <code>target</code> attribute. This value
		/// is optional and will be interpreted as <a
		/// href='TargetWindow#TOP'>TargetWindow#TOP</a> if left blank.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public AdUnitTargetWindow targetWindow {
			get {
				return this.targetWindowField;
			}
			set {
				this.targetWindowField = value;
				this.targetWindowSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="targetWindow" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool targetWindowSpecified {
			get {
				return this.targetWindowFieldSpecified;
			}
			set {
				this.targetWindowFieldSpecified = value;
			}
		}

		/// <summary>The status of this ad unit. It defaults to <a
		/// href='InventoryStatus#ACTIVE'>InventoryStatus#ACTIVE</a>. This value cannot be
		/// updated directly using <a
		/// href='InventoryService#updateAdUnit'>InventoryService#updateAdUnit</a>. It can
		/// only be modified by performing actions via <a
		/// href='InventoryService#performAdUnitAction'>InventoryService#performAdUnitAction</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public InventoryStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>A string used to uniquely identify the ad unit for the purposes of serving the
		/// ad. This attribute is optional and can be set during ad unit creation. If it is
		/// not provided, it will be assigned by Google based off of the inventory unit ID.
		/// Once an ad unit is created, its <code>adUnitCode</code> cannot be changed.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public string adUnitCode {
			get {
				return this.adUnitCodeField;
			}
			set {
				this.adUnitCodeField = value;
			}
		}

		/// <summary>The permissible creative sizes that can be served inside this ad unit. This
		/// attribute is optional. This attribute replaces the <code>sizes</code> attribute.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("adUnitSizes", Order = 9)]
		public AdUnitSize[] adUnitSizes {
			get {
				return this.adUnitSizesField;
			}
			set {
				this.adUnitSizesField = value;
			}
		}

		/// <summary>Whether this is a fluid ad unit.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public bool isFluid {
			get {
				return this.isFluidField;
			}
			set {
				this.isFluidField = value;
				this.isFluidSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isFluid" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isFluidSpecified {
			get {
				return this.isFluidFieldSpecified;
			}
			set {
				this.isFluidFieldSpecified = value;
			}
		}

		/// <summary>If this field is set to <code>true</code>, then the <code>AdUnit</code> will not
		/// be implicitly targeted when its parent is. Traffickers must explicitly target
		/// such an ad unit or else no line items will serve to it. This feature is only
		/// available for Ad Manager 360 accounts.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 11)]
		public bool explicitlyTargeted {
			get {
				return this.explicitlyTargetedField;
			}
			set {
				this.explicitlyTargetedField = value;
				this.explicitlyTargetedSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="explicitlyTargeted" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool explicitlyTargetedSpecified {
			get {
				return this.explicitlyTargetedFieldSpecified;
			}
			set {
				this.explicitlyTargetedFieldSpecified = value;
			}
		}

		/// <summary>AdSense specific settings. To overwrite this, set the <a
		/// href='#adSenseSettingsSource'>#adSenseSettingsSource</a> to <a
		/// href='PropertySourceType#DIRECTLY_SPECIFIED'>PropertySourceType#DIRECTLY_SPECIFIED</a>
		/// when setting the value of this field.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 12)]
		public AdSenseSettings adSenseSettings {
			get {
				return this.adSenseSettingsField;
			}
			set {
				this.adSenseSettingsField = value;
			}
		}

		/// <summary>Specifies the source of <a href='#adSenseSettings'>#adSenseSettings</a> value.
		/// To revert an overridden value to its default, set this field to <a
		/// href='PropertySourceType#PARENT'>PropertySourceType#PARENT</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 13)]
		public ValueSourceType adSenseSettingsSource {
			get {
				return this.adSenseSettingsSourceField;
			}
			set {
				this.adSenseSettingsSourceField = value;
				this.adSenseSettingsSourceSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="adSenseSettingsSource" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool adSenseSettingsSourceSpecified {
			get {
				return this.adSenseSettingsSourceFieldSpecified;
			}
			set {
				this.adSenseSettingsSourceFieldSpecified = value;
			}
		}

		/// <summary>The set of label frequency caps applied directly to this ad unit. There is a
		/// limit of 10 label frequency caps per ad unit.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("appliedLabelFrequencyCaps", Order = 14)]
		public LabelFrequencyCap[] appliedLabelFrequencyCaps {
			get {
				return this.appliedLabelFrequencyCapsField;
			}
			set {
				this.appliedLabelFrequencyCapsField = value;
			}
		}

		/// <summary>Contains the set of labels applied directly to the ad unit as well as those
		/// inherited from parent ad units. This field is readonly and is assigned by
		/// Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("effectiveLabelFrequencyCaps", Order = 15)]
		public LabelFrequencyCap[] effectiveLabelFrequencyCaps {
			get {
				return this.effectiveLabelFrequencyCapsField;
			}
			set {
				this.effectiveLabelFrequencyCapsField = value;
			}
		}

		/// <summary>The set of labels applied directly to this ad unit.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("appliedLabels", Order = 16)]
		public AppliedLabel[] appliedLabels {
			get {
				return this.appliedLabelsField;
			}
			set {
				this.appliedLabelsField = value;
			}
		}

		/// <summary>Contains the set of labels applied directly to the ad unit as well as those
		/// inherited from the parent ad units. If a label has been negated, only the
		/// negated label is returned. This field is readonly and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("effectiveAppliedLabels", Order = 17)]
		public AppliedLabel[] effectiveAppliedLabels {
			get {
				return this.effectiveAppliedLabelsField;
			}
			set {
				this.effectiveAppliedLabelsField = value;
			}
		}

		/// <summary>The IDs of all teams that this ad unit is on as well as those inherited from
		/// parent ad units. This value is read-only and is set by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("effectiveTeamIds", Order = 18)]
		public long[] effectiveTeamIds {
			get {
				return this.effectiveTeamIdsField;
			}
			set {
				this.effectiveTeamIdsField = value;
			}
		}

		/// <summary>The IDs of all teams that this ad unit is on directly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("appliedTeamIds", Order = 19)]
		public long[] appliedTeamIds {
			get {
				return this.appliedTeamIdsField;
			}
			set {
				this.appliedTeamIdsField = value;
			}
		}

		/// <summary>The date and time this ad unit was last modified.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 20)]
		public DateTime lastModifiedDateTime {
			get {
				return this.lastModifiedDateTimeField;
			}
			set {
				this.lastModifiedDateTimeField = value;
			}
		}

		/// <summary>The smart size mode for this ad unit. This attribute is optional and defaults to
		/// <a href=''>SmartSizeMode#NONE</a> for fixed sizes.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 21)]
		public SmartSizeMode smartSizeMode {
			get {
				return this.smartSizeModeField;
			}
			set {
				this.smartSizeModeField = value;
				this.smartSizeModeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="smartSizeMode" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool smartSizeModeSpecified {
			get {
				return this.smartSizeModeFieldSpecified;
			}
			set {
				this.smartSizeModeFieldSpecified = value;
			}
		}

		/// <summary>The interval in seconds which ad units in mobile apps automatically refresh.
		/// Valid values are between 30 and 120 seconds. This attribute is optional and only
		/// applies to ad units in mobile apps. If this value is not set, then the mobile
		/// app ad will not refresh.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 22)]
		public int refreshRate {
			get {
				return this.refreshRateField;
			}
			set {
				this.refreshRateField = value;
				this.refreshRateSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="refreshRate"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool refreshRateSpecified {
			get {
				return this.refreshRateFieldSpecified;
			}
			set {
				this.refreshRateFieldSpecified = value;
			}
		}

		/// <summary>Specifies an ID for a channel in an external set-top box campaign management
		/// system. This attribute is only meaningful if <a
		/// href='#isSetTopBoxEnabled'>#isSetTopBoxEnabled</a> is <code>true</code>. This
		/// attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 23)]
		public string externalSetTopBoxChannelId {
			get {
				return this.externalSetTopBoxChannelIdField;
			}
			set {
				this.externalSetTopBoxChannelIdField = value;
			}
		}

		/// <summary>Flag that specifies whether this ad unit represents an external set-top box
		/// channel. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 24)]
		public bool isSetTopBoxEnabled {
			get {
				return this.isSetTopBoxEnabledField;
			}
			set {
				this.isSetTopBoxEnabledField = value;
				this.isSetTopBoxEnabledSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isSetTopBoxEnabled" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isSetTopBoxEnabledSpecified {
			get {
				return this.isSetTopBoxEnabledFieldSpecified;
			}
			set {
				this.isSetTopBoxEnabledFieldSpecified = value;
			}
		}
	}


	/// <summary>Corresponds to an HTML link's <code>target</code> attribute.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AdUnit.TargetWindow", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdUnitTargetWindow {
		/// <summary>Specifies that the link should open in the full body of the page.
		/// </summary>
		TOP = 0,
		/// <summary>Specifies that the link should open in a new window.
		/// </summary>
		BLANK = 1,
	}


	/// <summary>Represents the status of objects that represent inventory - ad units and
	/// placements.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum InventoryStatus {
		/// <summary>The object is active.
		/// </summary>
		ACTIVE = 0,
		/// <summary>The object is no longer active.
		/// </summary>
		INACTIVE = 1,
		/// <summary>The object has been archived.
		/// </summary>
		ARCHIVED = 2,
	}


	/// <summary>Identifies the source of a field's value.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ValueSourceType {
		/// <summary>The field's value is inherited from the parent object.
		/// </summary>
		PARENT = 0,
		/// <summary>The field's value is user specified and not inherited.
		/// </summary>
		DIRECTLY_SPECIFIED = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Represents smart size modes.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum SmartSizeMode {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		/// <summary>Fixed size mode (default).
		/// </summary>
		NONE = 1,
		/// <summary>The height is fixed for the request, the width is a range.
		/// </summary>
		SMART_BANNER = 2,
		/// <summary>Height and width are ranges.
		/// </summary>
		DYNAMIC_SIZE = 3,
	}


	/// <summary>An error specifically for InventoryUnitSizes.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class InventoryUnitSizesError : ApiError {
		private InventoryUnitSizesErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public InventoryUnitSizesErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>All possible reasons the error can be thrown.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "InventoryUnitSizesError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum InventoryUnitSizesErrorReason {
		/// <summary>A size in the ad unit is too large or too small.
		/// </summary>
		INVALID_SIZES = 0,
		/// <summary>A size is an aspect ratio, but the ad unit is not a mobile ad unit.
		/// </summary>
		INVALID_SIZE_FOR_PLATFORM = 1,
		/// <summary>A size is video, but the video feature is not enabled.
		/// </summary>
		VIDEO_FEATURE_MISSING = 2,
		/// <summary>A size is video in a mobile ad unit, but the mobile video feature is not
		/// enabled.
		/// </summary>
		VIDEO_MOBILE_LINE_ITEM_FEATURE_MISSING = 3,
		/// <summary>A size that has companions must have an environment of VIDEO_PLAYER.
		/// </summary>
		INVALID_SIZE_FOR_MASTER = 4,
		/// <summary>A size that is a companion must have an environment of BROWSER.
		/// </summary>
		INVALID_SIZE_FOR_COMPANION = 5,
		/// <summary>Duplicate video master sizes are not allowed.
		/// </summary>
		DUPLICATE_MASTER_SIZES = 6,
		/// <summary>A size is an aspect ratio, but aspect ratio sizes are not enabled.
		/// </summary>
		ASPECT_RATIO_NOT_SUPPORTED = 7,
		/// <summary>A video size has companions, but companions are not allowed for the network
		/// </summary>
		VIDEO_COMPANIONS_NOT_SUPPORTED = 8,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 9,
	}


	/// <summary>Lists errors relating to <a href='AdUnit#refreshRate'>AdUnit#refreshRate</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class InventoryUnitRefreshRateError : ApiError {
		private InventoryUnitRefreshRateErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public InventoryUnitRefreshRateErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Reasons for the error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "InventoryUnitRefreshRateError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum InventoryUnitRefreshRateErrorReason {
		/// <summary>The refresh rate must be between 30 and 120 seconds.
		/// </summary>
		INVALID_RANGE = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>A list of all errors associated with a color attribute.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class InvalidColorError : ApiError {
		private InvalidColorErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public InvalidColorErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "InvalidColorError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum InvalidColorErrorReason {
		/// <summary>The provided value is not a valid hexadecimal color.
		/// </summary>
		INVALID_FORMAT = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>A list of all errors associated with companies.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CompanyError : ApiError {
		private CompanyErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CompanyErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Enumerates all possible company specific errors.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CompanyError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CompanyErrorReason {
		/// <summary>Indicates that an attempt was made to set a third party company for a company
		/// whose type is not the same as the third party company.
		/// </summary>
		CANNOT_SET_THIRD_PARTY_COMPANY_DUE_TO_TYPE = 0,
		/// <summary>Indicates that an invalid attempt was made to change a company's type.
		/// </summary>
		CANNOT_UPDATE_COMPANY_TYPE = 1,
		/// <summary>Indicates that this type of company is not supported.
		/// </summary>
		INVALID_COMPANY_TYPE = 2,
		/// <summary>Indicates that an attempt was made to assign a primary contact who does not
		/// belong to the specified company.
		/// </summary>
		PRIMARY_CONTACT_DOES_NOT_BELONG_TO_THIS_COMPANY = 3,
		/// <summary>Indicates that the user specified as the third party stats provider is of the
		/// wrong role type. The user must have the third party stats provider role.
		/// </summary>
		THIRD_PARTY_STATS_PROVIDER_IS_WRONG_ROLE_TYPE = 4,
		/// <summary>Labels can only be applied to <a
		/// href='Company.Type#ADVERTISER'>Company.Type#ADVERTISER</a>, <a
		/// href='Company.Type#HOUSE_ADVERTISER'>Company.Type#HOUSE_ADVERTISER</a>, and <a
		/// href='Company.Type#AD_NETWORK'>Company.Type#AD_NETWORK</a> company types.
		/// </summary>
		INVALID_LABEL_ASSOCIATION = 6,
		/// <summary>Indicates that the <a href='Company.Type'>Company.Type</a> does not support
		/// default billing settings.
		/// </summary>
		INVALID_COMPANY_TYPE_FOR_DEFAULT_BILLING_SETTING = 7,
		/// <summary>Indicates that the format of the default billing setting is wrong.
		/// </summary>
		INVALID_DEFAULT_BILLING_SETTING = 8,
		/// <summary>Cannot remove the cross selling config from a company that has active share
		/// assignments.
		/// </summary>
		COMPANY_HAS_ACTIVE_SHARE_ASSIGNMENTS = 9,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 5,
	}


	/// <summary>Caused by creating an <a href='AdUnit'>AdUnit</a> object with an invalid
	/// hierarchy.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdUnitHierarchyError : ApiError {
		private AdUnitHierarchyErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AdUnitHierarchyErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AdUnitHierarchyError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdUnitHierarchyErrorReason {
		/// <summary>The depth of the <a href='AdUnit'>AdUnit</a> in the inventory hierarchy is
		/// greater than is allowed. The maximum allowed depth is two below the effective
		/// root ad unit for Ad Manager 360 accounts and is one level below the effective
		/// root ad unit for Ad Manager accounts.
		/// </summary>
		INVALID_DEPTH = 0,
		/// <summary>The only valid <a href='AdUnit#parentId'>AdUnit#parentId</a> for an Ad Manager
		/// account is the <a
		/// href='Network#effectiveRootAdUnitId'>Network#effectiveRootAdUnitId</a>, Ad
		/// Manager 360 accounts can specify an ad unit hierarchy with more than two levels.
		/// </summary>
		INVALID_PARENT = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Error for AdSense related API calls.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdSenseAccountError : ApiError {
		private AdSenseAccountErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AdSenseAccountErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AdSenseAccountError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdSenseAccountErrorReason {
		/// <summary>An error occurred while trying to associate an AdSense account with Ad Manager.
		/// Unable to create an association with AdSense or Ad Exchange account.
		/// </summary>
		ASSOCIATE_ACCOUNT_API_ERROR = 0,
		/// <summary>An error occured while trying to get an associated web property's ad slots.
		/// Unable to retrieve ad slot information from AdSense or Ad Exchange account.
		/// </summary>
		GET_AD_SLOT_API_ERROR = 1,
		/// <summary>An error occurred while trying to get an associated web property's ad channels.
		/// </summary>
		GET_CHANNEL_API_ERROR = 2,
		/// <summary>An error occured while trying to retrieve account statues from AdSense API.
		/// Unable to retrieve account status information. Please try again later.
		/// </summary>
		GET_BULK_ACCOUNT_STATUSES_API_ERROR = 3,
		/// <summary>An error occured while trying to resend the account association verification
		/// email. Error resending verification email. Please try again.
		/// </summary>
		RESEND_VERIFICATION_EMAIL_ERROR = 4,
		/// <summary>An error occured while trying to retrieve a response from the AdSense API. There
		/// was a problem processing your request. Please try again later.
		/// </summary>
		UNEXPECTED_API_RESPONSE_ERROR = 5,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 6,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.InventoryServiceInterface")]
	public interface InventoryServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.InventoryService.createAdUnitsResponse createAdUnits(Wrappers.InventoryService.createAdUnitsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.InventoryService.createAdUnitsResponse> createAdUnitsAsync(Wrappers.InventoryService.createAdUnitsRequest request);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.InventoryService.getAdUnitSizesByStatementResponse getAdUnitSizesByStatement(Wrappers.InventoryService.getAdUnitSizesByStatementRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.InventoryService.getAdUnitSizesByStatementResponse> getAdUnitSizesByStatementAsync(Wrappers.InventoryService.getAdUnitSizesByStatementRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.AdUnitPage getAdUnitsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdUnitPage> getAdUnitsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performAdUnitAction(Google.Api.Ads.AdManager.v201802.AdUnitAction adUnitAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performAdUnitActionAsync(Google.Api.Ads.AdManager.v201802.AdUnitAction adUnitAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.InventoryService.updateAdUnitsResponse updateAdUnits(Wrappers.InventoryService.updateAdUnitsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.InventoryService.updateAdUnitsResponse> updateAdUnitsAsync(Wrappers.InventoryService.updateAdUnitsRequest request);
	}


	/// <summary>Captures a page of <a href='AdUnit'>AdUnit</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdUnitPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private AdUnit[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of ad units contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public AdUnit[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a href='AdUnit'>AdUnit</a>
	/// objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeactivateAdUnits))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ArchiveAdUnits))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateAdUnits))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class AdUnitAction {
	}


	/// <summary>The action used for deactivating <a href='AdUnit'>AdUnit</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeactivateAdUnits : AdUnitAction {
	}


	/// <summary>The action used for archiving <a href='AdUnit'>AdUnit</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ArchiveAdUnits : AdUnitAction {
	}


	/// <summary>The action used for activating <a href='AdUnit'>AdUnit</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateAdUnits : AdUnitAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface InventoryServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.InventoryServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides operations for creating, updating and retrieving <a
	/// href='AdUnit'>AdUnit</a> objects. <p>Line items connect a creative with its
	/// associated ad unit through targeting.</p> <p>An ad unit represents a piece of
	/// inventory within a publisher. It contains all the settings that need to be
	/// associated with the inventory in order to serve ads. For example, the ad unit
	/// contains creative size restrictions and AdSense settings.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class InventoryService : AdManagerSoapClient<IInventoryService>, IInventoryService {
		/// <summary> Creates a new instance of the <see cref="InventoryService"/> class.
		/// </summary>
		public InventoryService() {
		}

		/// <summary> Creates a new instance of the <see cref="InventoryService"/> class.
		/// </summary>
		public InventoryService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="InventoryService"/> class.
		/// </summary>
		public InventoryService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="InventoryService"/> class.
		/// </summary>
		public InventoryService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="InventoryService"/> class.
		/// </summary>
		public InventoryService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.InventoryService.createAdUnitsResponse Google.Api.Ads.AdManager.v201802.InventoryServiceInterface.createAdUnits(Wrappers.InventoryService.createAdUnitsRequest request) {
			return base.Channel.createAdUnits(request);
		}

		/// <summary>Creates new <a href='AdUnit'>AdUnit</a> objects.
		/// </summary><param name='adUnits'>the ad units to create</param>
		/// <returns>the created ad units, with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.AdUnit[] createAdUnits(Google.Api.Ads.AdManager.v201802.AdUnit[] adUnits) {
			Wrappers.InventoryService.createAdUnitsRequest inValue = new Wrappers.InventoryService.createAdUnitsRequest();
			inValue.adUnits = adUnits;
			Wrappers.InventoryService.createAdUnitsResponse retVal = ((Google.Api.Ads.AdManager.v201802.InventoryServiceInterface)(this)).createAdUnits(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.InventoryService.createAdUnitsResponse> Google.Api.Ads.AdManager.v201802.InventoryServiceInterface.createAdUnitsAsync(Wrappers.InventoryService.createAdUnitsRequest request) {
			return base.Channel.createAdUnitsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdUnit[]> createAdUnitsAsync(Google.Api.Ads.AdManager.v201802.AdUnit[] adUnits) {
			Wrappers.InventoryService.createAdUnitsRequest inValue = new Wrappers.InventoryService.createAdUnitsRequest();
			inValue.adUnits = adUnits;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdUnit[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.InventoryServiceInterface)(this)).createAdUnitsAsync(inValue)).Result.rval);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.InventoryService.getAdUnitSizesByStatementResponse Google.Api.Ads.AdManager.v201802.InventoryServiceInterface.getAdUnitSizesByStatement(Wrappers.InventoryService.getAdUnitSizesByStatementRequest request) {
			return base.Channel.getAdUnitSizesByStatement(request);
		}

		/// <summary>Gets a set of <a href='AdUnitSize'>AdUnitSize</a> objects that satisfy the given
		/// <a href='Statement#query'>Statement#query</a>. The following fields are
		/// supported for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>targetPlatform</code></td>
		/// <td><a href='TargetPlatform'>TargetPlatform</a></td> </tr> </table> An exception
		/// will be thrown for queries with unsupported fields. Paging is not supported, as
		/// aren't the LIMIT and OFFSET PQL keywords. Only "=" operator is supported.
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of ad unit sizes</param>
		/// <returns>the ad unit sizes that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.AdUnitSize[] getAdUnitSizesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			Wrappers.InventoryService.getAdUnitSizesByStatementRequest inValue = new Wrappers.InventoryService.getAdUnitSizesByStatementRequest();
			inValue.filterStatement = filterStatement;
			Wrappers.InventoryService.getAdUnitSizesByStatementResponse retVal = ((Google.Api.Ads.AdManager.v201802.InventoryServiceInterface)(this)).getAdUnitSizesByStatement(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.InventoryService.getAdUnitSizesByStatementResponse> Google.Api.Ads.AdManager.v201802.InventoryServiceInterface.getAdUnitSizesByStatementAsync(Wrappers.InventoryService.getAdUnitSizesByStatementRequest request) {
			return base.Channel.getAdUnitSizesByStatementAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdUnitSize[]> getAdUnitSizesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			Wrappers.InventoryService.getAdUnitSizesByStatementRequest inValue = new Wrappers.InventoryService.getAdUnitSizesByStatementRequest();
			inValue.filterStatement = filterStatement;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdUnitSize[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.InventoryServiceInterface)(this)).getAdUnitSizesByStatementAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='AdUnitPage'>AdUnitPage</a> of <a href='AdUnit'>AdUnit</a>
		/// objects that satisfy the given <a href='Statement#query'>Statement#query</a>.
		/// The following fields are supported for filtering: <table> <tr> <th
		/// scope="col">PQL Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>adUnitCode</code></td> <td><a
		/// href='AdUnit#adUnitCode'>AdUnit#adUnitCode</a></td> </tr> <tr>
		/// <td><code>id</code></td> <td><a href='AdUnit#id'>AdUnit#id</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a href='AdUnit#name'>AdUnit#name</a></td> </tr>
		/// <tr> <td><code>parentId</code></td> <td><a
		/// href='AdUnit#parentId'>AdUnit#parentId</a></td> </tr> <tr>
		/// <td><code>status</code></td> <td><a href='AdUnit#status'>AdUnit#status</a></td>
		/// </tr> <tr> <td><code>lastModifiedDateTime</code></td> <td><a
		/// href='AdUnit#lastModifiedDateTime'>AdUnit#lastModifiedDateTime</a></td> </tr>
		/// </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of ad units</param>
		/// <returns>the ad units that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.AdUnitPage getAdUnitsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getAdUnitsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdUnitPage> getAdUnitsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getAdUnitsByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='AdUnit'>AdUnit</a> objects that match the given <a
		/// href='Statement#query'>Statement#query</a>.
		/// </summary><param name='adUnitAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of ad units</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performAdUnitAction(Google.Api.Ads.AdManager.v201802.AdUnitAction adUnitAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performAdUnitAction(adUnitAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performAdUnitActionAsync(Google.Api.Ads.AdManager.v201802.AdUnitAction adUnitAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performAdUnitActionAsync(adUnitAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.InventoryService.updateAdUnitsResponse Google.Api.Ads.AdManager.v201802.InventoryServiceInterface.updateAdUnits(Wrappers.InventoryService.updateAdUnitsRequest request) {
			return base.Channel.updateAdUnits(request);
		}

		/// <summary>Updates the specified <a href='AdUnit'>AdUnit</a> objects.
		/// </summary><param name='adUnits'>the ad units to update</param>
		/// <returns>the updated ad units</returns>
		public virtual Google.Api.Ads.AdManager.v201802.AdUnit[] updateAdUnits(Google.Api.Ads.AdManager.v201802.AdUnit[] adUnits) {
			Wrappers.InventoryService.updateAdUnitsRequest inValue = new Wrappers.InventoryService.updateAdUnitsRequest();
			inValue.adUnits = adUnits;
			Wrappers.InventoryService.updateAdUnitsResponse retVal = ((Google.Api.Ads.AdManager.v201802.InventoryServiceInterface)(this)).updateAdUnits(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.InventoryService.updateAdUnitsResponse> Google.Api.Ads.AdManager.v201802.InventoryServiceInterface.updateAdUnitsAsync(Wrappers.InventoryService.updateAdUnitsRequest request) {
			return base.Channel.updateAdUnitsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdUnit[]> updateAdUnitsAsync(Google.Api.Ads.AdManager.v201802.AdUnit[] adUnits) {
			Wrappers.InventoryService.updateAdUnitsRequest inValue = new Wrappers.InventoryService.updateAdUnitsRequest();
			inValue.adUnits = adUnits;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdUnit[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.InventoryServiceInterface)(this)).updateAdUnitsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.LabelService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createLabels", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createLabelsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("labels")]
			public Google.Api.Ads.AdManager.v201802.Label[] labels;

			/// <summary> Creates a new instance of the <see cref="createLabelsRequest"/> class.
			/// </summary>
			public createLabelsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createLabelsRequest"/> class.
			/// </summary>
			public createLabelsRequest(Google.Api.Ads.AdManager.v201802.Label[] labels) {
				this.labels = labels;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createLabelsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createLabelsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Label[] rval;

			/// <summary> Creates a new instance of the <see cref="createLabelsResponse"/>
			/// class. </summary>
			public createLabelsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createLabelsResponse"/>
			/// class. </summary>
			public createLabelsResponse(Google.Api.Ads.AdManager.v201802.Label[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateLabels", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateLabelsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("labels")]
			public Google.Api.Ads.AdManager.v201802.Label[] labels;

			/// <summary> Creates a new instance of the <see cref="updateLabelsRequest"/> class.
			/// </summary>
			public updateLabelsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updateLabelsRequest"/> class.
			/// </summary>
			public updateLabelsRequest(Google.Api.Ads.AdManager.v201802.Label[] labels) {
				this.labels = labels;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateLabelsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateLabelsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Label[] rval;

			/// <summary> Creates a new instance of the <see cref="updateLabelsResponse"/>
			/// class. </summary>
			public updateLabelsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updateLabelsResponse"/>
			/// class. </summary>
			public updateLabelsResponse(Google.Api.Ads.AdManager.v201802.Label[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>A <code>Label</code> is additional information that can be added to an entity.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Label {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private string descriptionField;

		private bool isActiveField;

		private bool isActiveFieldSpecified;

		private LabelType[] typesField;

		/// <summary>Unique ID of the <code>Label</code>. This value is readonly and is assigned by
		/// Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>Name of the <code>Label</code>. This is value is required to create a label and
		/// has a maximum length of 127 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>A description of the label. This value is optional and its maximum length is 255
		/// characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string description {
			get {
				return this.descriptionField;
			}
			set {
				this.descriptionField = value;
			}
		}

		/// <summary>Specifies whether or not the label is active. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public bool isActive {
			get {
				return this.isActiveField;
			}
			set {
				this.isActiveField = value;
				this.isActiveSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isActive"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isActiveSpecified {
			get {
				return this.isActiveFieldSpecified;
			}
			set {
				this.isActiveFieldSpecified = value;
			}
		}

		/// <summary>The types of the <code>Label</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("types", Order = 4)]
		public LabelType[] types {
			get {
				return this.typesField;
			}
			set {
				this.typesField = value;
			}
		}
	}


	/// <summary>Represents the types of labels supported.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LabelType {
		/// <summary>Allows for the creation of labels to exclude competing ads from showing on the
		/// same page.
		/// </summary>
		COMPETITIVE_EXCLUSION = 0,
		/// <summary>Allows for the creation of limits on the frequency that a user sees a particular
		/// type of creative over a portion of the inventory.
		/// </summary>
		AD_UNIT_FREQUENCY_CAP = 1,
		/// <summary>Allows for the creation of labels to exclude ads from showing against a tag that
		/// specifies the label as an exclusion.
		/// </summary>
		AD_EXCLUSION = 2,
		/// <summary>Allows for the creation of labels that can be used to force the wrapping of a
		/// delivering creative with header/footer creatives. These labels are paired with a
		/// <a href='CreativeWrapper'>CreativeWrapper</a>.
		/// </summary>
		CREATIVE_WRAPPER = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.LabelServiceInterface")]
	public interface LabelServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.LabelService.createLabelsResponse createLabels(Wrappers.LabelService.createLabelsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.LabelService.createLabelsResponse> createLabelsAsync(Wrappers.LabelService.createLabelsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.LabelPage getLabelsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LabelPage> getLabelsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performLabelAction(Google.Api.Ads.AdManager.v201802.LabelAction labelAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performLabelActionAsync(Google.Api.Ads.AdManager.v201802.LabelAction labelAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.LabelService.updateLabelsResponse updateLabels(Wrappers.LabelService.updateLabelsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.LabelService.updateLabelsResponse> updateLabelsAsync(Wrappers.LabelService.updateLabelsRequest request);
	}


	/// <summary>Captures a page of <a href='Label'>Label</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LabelPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private Label[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of labels contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public Label[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a href='Label'>Label</a>
	/// objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeactivateLabels))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateLabels))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class LabelAction {
	}


	/// <summary>The action used for deactivating <a href='Label'>Label</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeactivateLabels : LabelAction {
	}


	/// <summary>The action used for activating <a href='Label'>Label</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateLabels : LabelAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface LabelServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.LabelServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for the creation and management of Labels.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class LabelService : AdManagerSoapClient<ILabelService>, ILabelService {
		/// <summary> Creates a new instance of the <see cref="LabelService"/> class.
		/// </summary>
		public LabelService() {
		}

		/// <summary> Creates a new instance of the <see cref="LabelService"/> class.
		/// </summary>
		public LabelService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="LabelService"/> class.
		/// </summary>
		public LabelService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="LabelService"/> class.
		/// </summary>
		public LabelService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="LabelService"/> class.
		/// </summary>
		public LabelService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.LabelService.createLabelsResponse Google.Api.Ads.AdManager.v201802.LabelServiceInterface.createLabels(Wrappers.LabelService.createLabelsRequest request) {
			return base.Channel.createLabels(request);
		}

		/// <summary>Creates new <a href='Label'>Label</a> objects.
		/// </summary><param name='labels'>the labels to create</param>
		/// <returns>the created labels with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Label[] createLabels(Google.Api.Ads.AdManager.v201802.Label[] labels) {
			Wrappers.LabelService.createLabelsRequest inValue = new Wrappers.LabelService.createLabelsRequest();
			inValue.labels = labels;
			Wrappers.LabelService.createLabelsResponse retVal = ((Google.Api.Ads.AdManager.v201802.LabelServiceInterface)(this)).createLabels(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.LabelService.createLabelsResponse> Google.Api.Ads.AdManager.v201802.LabelServiceInterface.createLabelsAsync(Wrappers.LabelService.createLabelsRequest request) {
			return base.Channel.createLabelsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Label[]> createLabelsAsync(Google.Api.Ads.AdManager.v201802.Label[] labels) {
			Wrappers.LabelService.createLabelsRequest inValue = new Wrappers.LabelService.createLabelsRequest();
			inValue.labels = labels;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Label[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.LabelServiceInterface)(this)).createLabelsAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='LabelPage'>LabelPage</a> of <a href='Label'>Label</a> objects
		/// that satisfy the given <a href='Statement#query'>Statement#query</a>. The
		/// following fields are supported for filtering: <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>id</code></td> <td><a href='Label#id'>Label#id</a></td> </tr> <tr>
		/// <td><code>type</code></td> <td><a href='Label#type'>Label#type</a></td> </tr>
		/// <tr> <td><code>name</code></td> <td><a href='Label#name'>Label#name</a></td>
		/// </tr> <tr> <td><code>description</code></td> <td><a
		/// href='Label#description'>Label#description</a></td> </tr> <tr>
		/// <td><code>isActive</code></td> <td><a
		/// href='Label#isActive'>Label#isActive</a></td> </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of labels.</param>
		/// <returns>the labels that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.LabelPage getLabelsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getLabelsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LabelPage> getLabelsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getLabelsByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='Label'>Label</a> objects that match the given <a
		/// href='Statement#query'>Statement#query</a>.
		/// </summary><param name='labelAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of labels</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performLabelAction(Google.Api.Ads.AdManager.v201802.LabelAction labelAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performLabelAction(labelAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performLabelActionAsync(Google.Api.Ads.AdManager.v201802.LabelAction labelAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performLabelActionAsync(labelAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.LabelService.updateLabelsResponse Google.Api.Ads.AdManager.v201802.LabelServiceInterface.updateLabels(Wrappers.LabelService.updateLabelsRequest request) {
			return base.Channel.updateLabels(request);
		}

		/// <summary>Updates the specified <a href='Label'>Label</a> objects.
		/// </summary><param name='labels'>the labels to update</param>
		/// <returns>the updated labels</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Label[] updateLabels(Google.Api.Ads.AdManager.v201802.Label[] labels) {
			Wrappers.LabelService.updateLabelsRequest inValue = new Wrappers.LabelService.updateLabelsRequest();
			inValue.labels = labels;
			Wrappers.LabelService.updateLabelsResponse retVal = ((Google.Api.Ads.AdManager.v201802.LabelServiceInterface)(this)).updateLabels(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.LabelService.updateLabelsResponse> Google.Api.Ads.AdManager.v201802.LabelServiceInterface.updateLabelsAsync(Wrappers.LabelService.updateLabelsRequest request) {
			return base.Channel.updateLabelsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Label[]> updateLabelsAsync(Google.Api.Ads.AdManager.v201802.Label[] labels) {
			Wrappers.LabelService.updateLabelsRequest inValue = new Wrappers.LabelService.updateLabelsRequest();
			inValue.labels = labels;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Label[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.LabelServiceInterface)(this)).updateLabelsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.LineItemCreativeAssociationService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createLineItemCreativeAssociations", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createLineItemCreativeAssociationsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("lineItemCreativeAssociations")]
			public Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] lineItemCreativeAssociations;

			/// <summary> Creates a new instance of the <see
			/// cref="createLineItemCreativeAssociationsRequest"/> class. </summary>
			public createLineItemCreativeAssociationsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createLineItemCreativeAssociationsRequest"/> class. </summary>
			public createLineItemCreativeAssociationsRequest(Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] lineItemCreativeAssociations) {
				this.lineItemCreativeAssociations = lineItemCreativeAssociations;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createLineItemCreativeAssociationsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createLineItemCreativeAssociationsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createLineItemCreativeAssociationsResponse"/> class. </summary>
			public createLineItemCreativeAssociationsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createLineItemCreativeAssociationsResponse"/> class. </summary>
			public createLineItemCreativeAssociationsResponse(Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "getPreviewUrlsForNativeStyles", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class getPreviewUrlsForNativeStylesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			public long lineItemId;

			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 1)]
			public long creativeId;

			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 2)]
			public string siteUrl;

			/// <summary> Creates a new instance of the <see
			/// cref="getPreviewUrlsForNativeStylesRequest"/> class. </summary>
			public getPreviewUrlsForNativeStylesRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="getPreviewUrlsForNativeStylesRequest"/> class. </summary>
			public getPreviewUrlsForNativeStylesRequest(long lineItemId, long creativeId, string siteUrl) {
				this.lineItemId = lineItemId;
				this.creativeId = creativeId;
				this.siteUrl = siteUrl;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "getPreviewUrlsForNativeStylesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class getPreviewUrlsForNativeStylesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.CreativeNativeStylePreview[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="getPreviewUrlsForNativeStylesResponse"/> class. </summary>
			public getPreviewUrlsForNativeStylesResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="getPreviewUrlsForNativeStylesResponse"/> class. </summary>
			public getPreviewUrlsForNativeStylesResponse(Google.Api.Ads.AdManager.v201802.CreativeNativeStylePreview[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateLineItemCreativeAssociations", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateLineItemCreativeAssociationsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("lineItemCreativeAssociations")]
			public Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] lineItemCreativeAssociations;

			/// <summary> Creates a new instance of the <see
			/// cref="updateLineItemCreativeAssociationsRequest"/> class. </summary>
			public updateLineItemCreativeAssociationsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateLineItemCreativeAssociationsRequest"/> class. </summary>
			public updateLineItemCreativeAssociationsRequest(Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] lineItemCreativeAssociations) {
				this.lineItemCreativeAssociations = lineItemCreativeAssociations;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateLineItemCreativeAssociationsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateLineItemCreativeAssociationsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateLineItemCreativeAssociationsResponse"/> class. </summary>
			public updateLineItemCreativeAssociationsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateLineItemCreativeAssociationsResponse"/> class. </summary>
			public updateLineItemCreativeAssociationsResponse(Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>This represents an entry in a map with a key of type Long and value of type
	/// Stats.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Long_StatsMapEntry {
		private long keyField;

		private bool keyFieldSpecified;

		private Stats valueField;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long key {
			get {
				return this.keyField;
			}
			set {
				this.keyField = value;
				this.keySpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="key" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool keySpecified {
			get {
				return this.keyFieldSpecified;
			}
			set {
				this.keyFieldSpecified = value;
			}
		}

		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public Stats value {
			get {
				return this.valueField;
			}
			set {
				this.valueField = value;
			}
		}
	}


	/// <summary>Contains statistics such as impressions, clicks delivered and cost for <a
	/// href='LineItemCreativeAssociation'>LineItemCreativeAssociation</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LineItemCreativeAssociationStats {
		private Stats statsField;

		private Long_StatsMapEntry[] creativeSetStatsField;

		private Money costInOrderCurrencyField;

		/// <summary>A <a href='Stats'>Stats</a> object that holds delivered impressions and clicks
		/// statistics.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public Stats stats {
			get {
				return this.statsField;
			}
			set {
				this.statsField = value;
			}
		}

		/// <summary>A map containing <a href='Stats'>Stats</a> objects for each creative belonging
		/// to a creative set, <code>null</code> for non creative set associations.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("creativeSetStats", Order = 1)]
		public Long_StatsMapEntry[] creativeSetStats {
			get {
				return this.creativeSetStatsField;
			}
			set {
				this.creativeSetStatsField = value;
			}
		}

		/// <summary>The revenue generated thus far by the creative from its association with the
		/// particular line item in the publisher's currency.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public Money costInOrderCurrency {
			get {
				return this.costInOrderCurrencyField;
			}
			set {
				this.costInOrderCurrencyField = value;
			}
		}
	}


	/// <summary>A <code>LineItemCreativeAssociation</code> associates a <a
	/// href='Creative'>Creative</a> or <a href='CreativeSet'>CreativeSet</a> with a <a
	/// href='LineItem'>LineItem</a> so that the creative can be served in ad units
	/// targeted by the line item.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LineItemCreativeAssociation {
		private long lineItemIdField;

		private bool lineItemIdFieldSpecified;

		private long creativeIdField;

		private bool creativeIdFieldSpecified;

		private long creativeSetIdField;

		private bool creativeSetIdFieldSpecified;

		private double manualCreativeRotationWeightField;

		private bool manualCreativeRotationWeightFieldSpecified;

		private int sequentialCreativeRotationIndexField;

		private bool sequentialCreativeRotationIndexFieldSpecified;

		private DateTime startDateTimeField;

		private StartDateTimeType startDateTimeTypeField;

		private bool startDateTimeTypeFieldSpecified;

		private DateTime endDateTimeField;

		private string destinationUrlField;

		private Size[] sizesField;

		private LineItemCreativeAssociationStatus statusField;

		private bool statusFieldSpecified;

		private LineItemCreativeAssociationStats statsField;

		private DateTime lastModifiedDateTimeField;

		private string targetingNameField;

		/// <summary>The ID of the <a href='LineItem'>LineItem</a> to which the <a
		/// href='Creative'>Creative</a> should be associated. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long lineItemId {
			get {
				return this.lineItemIdField;
			}
			set {
				this.lineItemIdField = value;
				this.lineItemIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="lineItemId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lineItemIdSpecified {
			get {
				return this.lineItemIdFieldSpecified;
			}
			set {
				this.lineItemIdFieldSpecified = value;
			}
		}

		/// <summary>The ID of the <a href='Creative'>Creative</a> being associated with a <a
		/// href='LineItem'>LineItem</a>. <p>This attribute is required if this is an
		/// association between a line item and a creative.<br /> This attribute is ignored
		/// if this is an association between a line item and a creative set.</p> <p>If this
		/// is an association between a line item and a creative, when retrieving the line
		/// item creative association, the <a href='#creativeId'>#creativeId</a> will be the
		/// creative's ID.<br /> If this is an association between a line item and a
		/// creative set, when retrieving the line item creative association, the <a
		/// href='#creativeId'>#creativeId</a> will be the ID of the <a
		/// href='CreativeSet#masterCreativeId'>master creative</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long creativeId {
			get {
				return this.creativeIdField;
			}
			set {
				this.creativeIdField = value;
				this.creativeIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="creativeId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool creativeIdSpecified {
			get {
				return this.creativeIdFieldSpecified;
			}
			set {
				this.creativeIdFieldSpecified = value;
			}
		}

		/// <summary>The ID of the <a href='CreativeSet'>CreativeSet</a> being associated with a <a
		/// href='LineItem'>LineItem</a>. This attribute is required if this is an
		/// association between a line item and a creative set. <p>This field will be
		/// <code>null</code> when retrieving associations between line items and creatives
		/// not belonging to a set.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public long creativeSetId {
			get {
				return this.creativeSetIdField;
			}
			set {
				this.creativeSetIdField = value;
				this.creativeSetIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="creativeSetId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool creativeSetIdSpecified {
			get {
				return this.creativeSetIdFieldSpecified;
			}
			set {
				this.creativeSetIdFieldSpecified = value;
			}
		}

		/// <summary>The weight of the <a href='Creative'>Creative</a>. This value is only used if
		/// the line item's <code>creativeRotationType</code> is set to <a
		/// href='CreativeRotationType#MANUAL'>CreativeRotationType#MANUAL</a>. This
		/// attribute is optional and defaults to 10.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public double manualCreativeRotationWeight {
			get {
				return this.manualCreativeRotationWeightField;
			}
			set {
				this.manualCreativeRotationWeightField = value;
				this.manualCreativeRotationWeightSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="manualCreativeRotationWeight" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool manualCreativeRotationWeightSpecified {
			get {
				return this.manualCreativeRotationWeightFieldSpecified;
			}
			set {
				this.manualCreativeRotationWeightFieldSpecified = value;
			}
		}

		/// <summary>The sequential rotation index of the <a href='Creative'>Creative</a>. This value
		/// is used only if the associated line item's <a
		/// href='LineItem#creativeRotationType'>LineItem#creativeRotationType</a> is set to
		/// <a href='CreativeRotationType#SEQUENTIAL'>CreativeRotationType#SEQUENTIAL</a>.
		/// This attribute is optional and defaults to 1.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public int sequentialCreativeRotationIndex {
			get {
				return this.sequentialCreativeRotationIndexField;
			}
			set {
				this.sequentialCreativeRotationIndexField = value;
				this.sequentialCreativeRotationIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="sequentialCreativeRotationIndex" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sequentialCreativeRotationIndexSpecified {
			get {
				return this.sequentialCreativeRotationIndexFieldSpecified;
			}
			set {
				this.sequentialCreativeRotationIndexFieldSpecified = value;
			}
		}

		/// <summary>Overrides the value set for <a
		/// href='LineItem#startDateTime'>LineItem#startDateTime</a>. This value is optional
		/// and is only valid for Ad Manager 360 networks.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public DateTime startDateTime {
			get {
				return this.startDateTimeField;
			}
			set {
				this.startDateTimeField = value;
			}
		}

		/// <summary>Specifies whether to start serving to the <code></code> right away, in an hour,
		/// etc. This attribute is optional and defaults to <a
		/// href='StartDateTimeType#USE_START_DATE_TIME'>StartDateTimeType#USE_START_DATE_TIME</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public StartDateTimeType startDateTimeType {
			get {
				return this.startDateTimeTypeField;
			}
			set {
				this.startDateTimeTypeField = value;
				this.startDateTimeTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="startDateTimeType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startDateTimeTypeSpecified {
			get {
				return this.startDateTimeTypeFieldSpecified;
			}
			set {
				this.startDateTimeTypeFieldSpecified = value;
			}
		}

		/// <summary>Overrides <a href='LineItem#endDateTime'>LineItem#endDateTime</a>. This value is
		/// optional and is only valid for Ad Manager 360 networks.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public DateTime endDateTime {
			get {
				return this.endDateTimeField;
			}
			set {
				this.endDateTimeField = value;
			}
		}

		/// <summary>Overrides the value set for <a
		/// href='HasDestinationUrlCreative#destinationUrl'>HasDestinationUrlCreative#destinationUrl</a>.
		/// This value is optional and is only valid for Ad Manager 360 networks.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public string destinationUrl {
			get {
				return this.destinationUrlField;
			}
			set {
				this.destinationUrlField = value;
			}
		}

		/// <summary>Overrides the value set for <a href='Creative#size'>Creative#size</a>, which
		/// allows the creative to be served to ad units that would otherwise not be
		/// compatible for its actual size. This value is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("sizes", Order = 9)]
		public Size[] sizes {
			get {
				return this.sizesField;
			}
			set {
				this.sizesField = value;
			}
		}

		/// <summary>The status of the association. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public LineItemCreativeAssociationStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>Contains trafficking statistics for the association. This attribute is readonly
		/// and is populated by Google. This will be <code>null</code> in case there are no
		/// statistics for the association yet.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 11)]
		public LineItemCreativeAssociationStats stats {
			get {
				return this.statsField;
			}
			set {
				this.statsField = value;
			}
		}

		/// <summary>The date and time this association was last modified.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 12)]
		public DateTime lastModifiedDateTime {
			get {
				return this.lastModifiedDateTimeField;
			}
			set {
				this.lastModifiedDateTimeField = value;
			}
		}

		/// <summary>Specifies <a href='CreativeTargeting'>CreativeTargeting</a> for this line item
		/// creative association. <p>This attribute is optional. It should match the
		/// creative targeting specified on the corresponding <a
		/// href='CreativePlaceholder'>CreativePlaceholder</a> in the <a
		/// href='LineItem'>LineItem</a> that is being associated with the <a
		/// href='Creative'>Creative</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 13)]
		public string targetingName {
			get {
				return this.targetingNameField;
			}
			set {
				this.targetingNameField = value;
			}
		}
	}


	/// <summary>Describes the status of the association.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "LineItemCreativeAssociation.Status", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LineItemCreativeAssociationStatus {
		/// <summary>The association is active and the associated <a href='Creative'>Creative</a> can
		/// be served.
		/// </summary>
		ACTIVE = 0,
		/// <summary>The association is active but the associated <a href='Creative'>Creative</a> may
		/// not be served, because its size is not targeted by the line item.
		/// </summary>
		NOT_SERVING = 1,
		/// <summary>The association is inactive and the associated <a href='Creative'>Creative</a>
		/// is ineligible for being served.
		/// </summary>
		INACTIVE = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>Lists all errors for executing operations on line item-to-creative associations
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LineItemCreativeAssociationOperationError : ApiError {
		private LineItemCreativeAssociationOperationErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public LineItemCreativeAssociationOperationErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "LineItemCreativeAssociationOperationError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LineItemCreativeAssociationOperationErrorReason {
		/// <summary>The operation is not allowed due to permissions
		/// </summary>
		NOT_ALLOWED = 0,
		/// <summary>The operation is not applicable to the current state
		/// </summary>
		NOT_APPLICABLE = 1,
		/// <summary>Cannot activate an invalid creative
		/// </summary>
		CANNOT_ACTIVATE_INVALID_CREATIVE = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Errors associated with generation of creative preview URIs.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreativePreviewError : ApiError {
		private CreativePreviewErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CreativePreviewErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CreativePreviewError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CreativePreviewErrorReason {
		/// <summary>The creative cannot be previewed on this page.
		/// </summary>
		CANNOT_GENERATE_PREVIEW_URL = 0,
		/// <summary>Preview URLs for native creatives must be retrieved with <a
		/// href=''>LineItemCreativeAssociationService#getPreviewUrlsForNativeStyles</a>.
		/// </summary>
		CANNOT_GENERATE_PREVIEW_URL_FOR_NATIVE_CREATIVES = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationServiceInterface")]
	public interface LineItemCreativeAssociationServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.LineItemCreativeAssociationService.createLineItemCreativeAssociationsResponse createLineItemCreativeAssociations(Wrappers.LineItemCreativeAssociationService.createLineItemCreativeAssociationsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.LineItemCreativeAssociationService.createLineItemCreativeAssociationsResponse> createLineItemCreativeAssociationsAsync(Wrappers.LineItemCreativeAssociationService.createLineItemCreativeAssociationsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationPage getLineItemCreativeAssociationsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationPage> getLineItemCreativeAssociationsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		string getPreviewUrl(long lineItemId, long creativeId, string siteUrl);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<string> getPreviewUrlAsync(long lineItemId, long creativeId, string siteUrl);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.LineItemCreativeAssociationService.getPreviewUrlsForNativeStylesResponse getPreviewUrlsForNativeStyles(Wrappers.LineItemCreativeAssociationService.getPreviewUrlsForNativeStylesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.LineItemCreativeAssociationService.getPreviewUrlsForNativeStylesResponse> getPreviewUrlsForNativeStylesAsync(Wrappers.LineItemCreativeAssociationService.getPreviewUrlsForNativeStylesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performLineItemCreativeAssociationAction(Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationAction lineItemCreativeAssociationAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performLineItemCreativeAssociationActionAsync(Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationAction lineItemCreativeAssociationAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.LineItemCreativeAssociationService.updateLineItemCreativeAssociationsResponse updateLineItemCreativeAssociations(Wrappers.LineItemCreativeAssociationService.updateLineItemCreativeAssociationsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.LineItemCreativeAssociationService.updateLineItemCreativeAssociationsResponse> updateLineItemCreativeAssociationsAsync(Wrappers.LineItemCreativeAssociationService.updateLineItemCreativeAssociationsRequest request);
	}


	/// <summary>Captures a page of <a
	/// href='LineItemCreativeAssociation'>LineItemCreativeAssociation</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LineItemCreativeAssociationPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private LineItemCreativeAssociation[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of line item creative associations contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public LineItemCreativeAssociation[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the <a href='NativeStyle'>NativeStyle</a> of a <a
	/// href='Creative'>Creative</a> and its corresponding preview URL.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreativeNativeStylePreview {
		private long nativeStyleIdField;

		private bool nativeStyleIdFieldSpecified;

		private string previewUrlField;

		/// <summary>The id of the <a href='NativeStyle'>NativeStyle</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long nativeStyleId {
			get {
				return this.nativeStyleIdField;
			}
			set {
				this.nativeStyleIdField = value;
				this.nativeStyleIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="nativeStyleId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool nativeStyleIdSpecified {
			get {
				return this.nativeStyleIdFieldSpecified;
			}
			set {
				this.nativeStyleIdFieldSpecified = value;
			}
		}

		/// <summary>The URL for previewing this creative using this particular <a
		/// href='NativeStyle'>NativeStyle</a>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string previewUrl {
			get {
				return this.previewUrlField;
			}
			set {
				this.previewUrlField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a
	/// href='LineItemCreativeAssociation'>LineItemCreativeAssociation</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeleteLineItemCreativeAssociations))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeactivateLineItemCreativeAssociations))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateLineItemCreativeAssociations))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class LineItemCreativeAssociationAction {
	}


	/// <summary>The action used for deleting <a
	/// href='LineItemCreativeAssociation'>LineItemCreativeAssociation</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeleteLineItemCreativeAssociations : LineItemCreativeAssociationAction {
	}


	/// <summary>The action used for deactivating <a
	/// href='LineItemCreativeAssociation'>LineItemCreativeAssociation</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeactivateLineItemCreativeAssociations : LineItemCreativeAssociationAction {
	}


	/// <summary>The action used for activating <a
	/// href='LineItemCreativeAssociation'>LineItemCreativeAssociation</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateLineItemCreativeAssociations : LineItemCreativeAssociationAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface LineItemCreativeAssociationServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides operations for creating, updating and retrieving <a
	/// href='LineItemCreativeAssociation'>LineItemCreativeAssociation</a> objects. <p>A
	/// line item creative association (LICA) associates a <a
	/// href='Creative'>Creative</a> with a <a href='LineItem'>LineItem</a>. When a line
	/// item is selected to serve, the LICAs specify which creatives can appear for the
	/// ad units that are targeted by the line item. In order to be associated with a
	/// line item, the creative must have a size that exists within the attribute <a
	/// href='LineItem#creativeSizes'>LineItem#creativeSizes</a>.</p> <p>Each LICA has a
	/// start and end date and time that defines when the creative should be
	/// displayed.</p> <p>To read more about associating creatives with line items, see
	/// this <a href="https://support.google.com/dfp_premium/answer/3187916">DFP Help
	/// Center</a> article.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class LineItemCreativeAssociationService : AdManagerSoapClient<ILineItemCreativeAssociationService>, ILineItemCreativeAssociationService {
		/// <summary> Creates a new instance of the <see
		/// cref="LineItemCreativeAssociationService"/> class. </summary>
		public LineItemCreativeAssociationService() {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="LineItemCreativeAssociationService"/> class. </summary>
		public LineItemCreativeAssociationService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="LineItemCreativeAssociationService"/> class. </summary>
		public LineItemCreativeAssociationService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="LineItemCreativeAssociationService"/> class. </summary>
		public LineItemCreativeAssociationService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="LineItemCreativeAssociationService"/> class. </summary>
		public LineItemCreativeAssociationService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.LineItemCreativeAssociationService.createLineItemCreativeAssociationsResponse Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationServiceInterface.createLineItemCreativeAssociations(Wrappers.LineItemCreativeAssociationService.createLineItemCreativeAssociationsRequest request) {
			return base.Channel.createLineItemCreativeAssociations(request);
		}

		/// <summary>Creates new <a
		/// href='LineItemCreativeAssociation'>LineItemCreativeAssociation</a> objects
		/// </summary><param name='lineItemCreativeAssociations'>the line item creative associations
		/// to create</param>
		/// <returns>the created line item creative associations with their IDs filled
		/// in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] createLineItemCreativeAssociations(Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] lineItemCreativeAssociations) {
			Wrappers.LineItemCreativeAssociationService.createLineItemCreativeAssociationsRequest inValue = new Wrappers.LineItemCreativeAssociationService.createLineItemCreativeAssociationsRequest();
			inValue.lineItemCreativeAssociations = lineItemCreativeAssociations;
			Wrappers.LineItemCreativeAssociationService.createLineItemCreativeAssociationsResponse retVal = ((Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationServiceInterface)(this)).createLineItemCreativeAssociations(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.LineItemCreativeAssociationService.createLineItemCreativeAssociationsResponse> Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationServiceInterface.createLineItemCreativeAssociationsAsync(Wrappers.LineItemCreativeAssociationService.createLineItemCreativeAssociationsRequest request) {
			return base.Channel.createLineItemCreativeAssociationsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[]> createLineItemCreativeAssociationsAsync(Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] lineItemCreativeAssociations) {
			Wrappers.LineItemCreativeAssociationService.createLineItemCreativeAssociationsRequest inValue = new Wrappers.LineItemCreativeAssociationService.createLineItemCreativeAssociationsRequest();
			inValue.lineItemCreativeAssociations = lineItemCreativeAssociations;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationServiceInterface)(this)).createLineItemCreativeAssociationsAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a
		/// href='LineItemCreativeAssociationPage'>LineItemCreativeAssociationPage</a> of <a
		/// href='LineItemCreativeAssociation'>LineItemCreativeAssociation</a> objects that
		/// satisfy the given <a href='Statement#query'>Statement#query</a>. The following
		/// fields are supported for filtering: <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>creativeId</code></td> <td><a
		/// href='LineItemCreativeAssociation#creativeId'>LineItemCreativeAssociation#creativeId</a></td>
		/// </tr> <tr> <td><code>manualCreativeRotationWeight</code></td> <td><a
		/// href='LineItemCreativeAssociation#manualCreativeRotationWeight'>LineItemCreativeAssociation#manualCreativeRotationWeight</a></td>
		/// </tr> <tr> <td><code>destinationUrl</code></td> <td><a
		/// href='LineItemCreativeAssociation#destinationUrl'>LineItemCreativeAssociation#destinationUrl</a></td>
		/// </tr> <tr> <td><code>lineItemId</code></td> <td><a
		/// href='LineItemCreativeAssociation#lineItemId'>LineItemCreativeAssociation#lineItemId</a></td>
		/// </tr> <tr> <td><code>status</code></td> <td><a
		/// href='LineItemCreativeAssociation#status'>LineItemCreativeAssociation#status</a></td>
		/// </tr> <tr> <td><code>lastModifiedDateTime</code></td> <td><a
		/// href='LineItemCreativeAssociation#lastModifiedDateTime'>LineItemCreativeAssociation#lastModifiedDateTime</a></td>
		/// </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of line item creative associations</param>
		/// <returns>the line item creative associations that match the given
		/// filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationPage getLineItemCreativeAssociationsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getLineItemCreativeAssociationsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationPage> getLineItemCreativeAssociationsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getLineItemCreativeAssociationsByStatementAsync(filterStatement);
		}

		/// <summary>Returns an insite preview URL that references the specified site URL with the
		/// specified creative from the association served to it. For Creative Set
		/// previewing you may specify the master creative Id.
		/// </summary><param name='lineItemId'>the ID of the line item, which must already
		/// exist</param>
		/// <param name='creativeId'>the ID of the creative, which must already
		/// exist</param>
		/// <param name='siteUrl'>the URL of the site that the creative should be previewed
		/// in</param>
		/// <returns>a URL that references the specified site URL with the specified
		/// creative served to it</returns>
		public virtual string getPreviewUrl(long lineItemId, long creativeId, string siteUrl) {
			return base.Channel.getPreviewUrl(lineItemId, creativeId, siteUrl);
		}

		public virtual System.Threading.Tasks.Task<string> getPreviewUrlAsync(long lineItemId, long creativeId, string siteUrl) {
			return base.Channel.getPreviewUrlAsync(lineItemId, creativeId, siteUrl);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.LineItemCreativeAssociationService.getPreviewUrlsForNativeStylesResponse Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationServiceInterface.getPreviewUrlsForNativeStyles(Wrappers.LineItemCreativeAssociationService.getPreviewUrlsForNativeStylesRequest request) {
			return base.Channel.getPreviewUrlsForNativeStyles(request);
		}

		/// <summary>Returns a list of URLs that reference the specified site URL with the specified
		/// creative from the association served to it. For Creative Set previewing you may
		/// specify the master creative Id. Each URL corresponds to one available native
		/// style for previewing the specified creative.
		/// </summary><param name='lineItemId'>the ID of the line item, which must already
		/// exist</param>
		/// <param name='creativeId'>the ID of the creative, which must already exist and
		/// must be a native creative</param>
		/// <param name='siteUrl'>the URL of the site that the creative should be previewed
		/// in</param>
		/// <returns>the URLs that references the specified site URL and can be used to
		/// preview the specified creative with the available native styles</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CreativeNativeStylePreview[] getPreviewUrlsForNativeStyles(long lineItemId, long creativeId, string siteUrl) {
			Wrappers.LineItemCreativeAssociationService.getPreviewUrlsForNativeStylesRequest inValue = new Wrappers.LineItemCreativeAssociationService.getPreviewUrlsForNativeStylesRequest();
			inValue.lineItemId = lineItemId;
			inValue.creativeId = creativeId;
			inValue.siteUrl = siteUrl;
			Wrappers.LineItemCreativeAssociationService.getPreviewUrlsForNativeStylesResponse retVal = ((Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationServiceInterface)(this)).getPreviewUrlsForNativeStyles(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.LineItemCreativeAssociationService.getPreviewUrlsForNativeStylesResponse> Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationServiceInterface.getPreviewUrlsForNativeStylesAsync(Wrappers.LineItemCreativeAssociationService.getPreviewUrlsForNativeStylesRequest request) {
			return base.Channel.getPreviewUrlsForNativeStylesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeNativeStylePreview[]> getPreviewUrlsForNativeStylesAsync(long lineItemId, long creativeId, string siteUrl) {
			Wrappers.LineItemCreativeAssociationService.getPreviewUrlsForNativeStylesRequest inValue = new Wrappers.LineItemCreativeAssociationService.getPreviewUrlsForNativeStylesRequest();
			inValue.lineItemId = lineItemId;
			inValue.creativeId = creativeId;
			inValue.siteUrl = siteUrl;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeNativeStylePreview[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationServiceInterface)(this)).getPreviewUrlsForNativeStylesAsync(inValue)).Result.rval);
		}

		/// <summary>Performs actions on <a
		/// href='LineItemCreativeAssociation'>LineItemCreativeAssociation</a> objects that
		/// match the given <a href='Statement#query'>Statement#query</a>.
		/// </summary><param name='lineItemCreativeAssociationAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of line item creative associations</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performLineItemCreativeAssociationAction(Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationAction lineItemCreativeAssociationAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performLineItemCreativeAssociationAction(lineItemCreativeAssociationAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performLineItemCreativeAssociationActionAsync(Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationAction lineItemCreativeAssociationAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performLineItemCreativeAssociationActionAsync(lineItemCreativeAssociationAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.LineItemCreativeAssociationService.updateLineItemCreativeAssociationsResponse Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationServiceInterface.updateLineItemCreativeAssociations(Wrappers.LineItemCreativeAssociationService.updateLineItemCreativeAssociationsRequest request) {
			return base.Channel.updateLineItemCreativeAssociations(request);
		}

		/// <summary>Updates the specified <a
		/// href='LineItemCreativeAssociation'>LineItemCreativeAssociation</a> objects
		/// </summary><param name='lineItemCreativeAssociations'>the line item creative associations
		/// to update</param>
		/// <returns>the updated line item creative associations</returns>
		public virtual Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] updateLineItemCreativeAssociations(Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] lineItemCreativeAssociations) {
			Wrappers.LineItemCreativeAssociationService.updateLineItemCreativeAssociationsRequest inValue = new Wrappers.LineItemCreativeAssociationService.updateLineItemCreativeAssociationsRequest();
			inValue.lineItemCreativeAssociations = lineItemCreativeAssociations;
			Wrappers.LineItemCreativeAssociationService.updateLineItemCreativeAssociationsResponse retVal = ((Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationServiceInterface)(this)).updateLineItemCreativeAssociations(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.LineItemCreativeAssociationService.updateLineItemCreativeAssociationsResponse> Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationServiceInterface.updateLineItemCreativeAssociationsAsync(Wrappers.LineItemCreativeAssociationService.updateLineItemCreativeAssociationsRequest request) {
			return base.Channel.updateLineItemCreativeAssociationsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[]> updateLineItemCreativeAssociationsAsync(Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] lineItemCreativeAssociations) {
			Wrappers.LineItemCreativeAssociationService.updateLineItemCreativeAssociationsRequest inValue = new Wrappers.LineItemCreativeAssociationService.updateLineItemCreativeAssociationsRequest();
			inValue.lineItemCreativeAssociations = lineItemCreativeAssociations;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociationServiceInterface)(this)).updateLineItemCreativeAssociationsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.LineItemService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createLineItems", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createLineItemsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("lineItems")]
			public Google.Api.Ads.AdManager.v201802.LineItem[] lineItems;

			/// <summary> Creates a new instance of the <see cref="createLineItemsRequest"/>
			/// class. </summary>
			public createLineItemsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createLineItemsRequest"/>
			/// class. </summary>
			public createLineItemsRequest(Google.Api.Ads.AdManager.v201802.LineItem[] lineItems) {
				this.lineItems = lineItems;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createLineItemsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createLineItemsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.LineItem[] rval;

			/// <summary> Creates a new instance of the <see cref="createLineItemsResponse"/>
			/// class. </summary>
			public createLineItemsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createLineItemsResponse"/>
			/// class. </summary>
			public createLineItemsResponse(Google.Api.Ads.AdManager.v201802.LineItem[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateLineItems", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateLineItemsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("lineItems")]
			public Google.Api.Ads.AdManager.v201802.LineItem[] lineItems;

			/// <summary> Creates a new instance of the <see cref="updateLineItemsRequest"/>
			/// class. </summary>
			public updateLineItemsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updateLineItemsRequest"/>
			/// class. </summary>
			public updateLineItemsRequest(Google.Api.Ads.AdManager.v201802.LineItem[] lineItems) {
				this.lineItems = lineItems;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateLineItemsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateLineItemsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.LineItem[] rval;

			/// <summary> Creates a new instance of the <see cref="updateLineItemsResponse"/>
			/// class. </summary>
			public updateLineItemsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updateLineItemsResponse"/>
			/// class. </summary>
			public updateLineItemsResponse(Google.Api.Ads.AdManager.v201802.LineItem[] rval) {
				this.rval = rval;
			}
		}
	}
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.LineItemServiceInterface")]
	public interface LineItemServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(LineItemSummary))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.LineItemService.createLineItemsResponse createLineItems(Wrappers.LineItemService.createLineItemsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.LineItemService.createLineItemsResponse> createLineItemsAsync(Wrappers.LineItemService.createLineItemsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(LineItemSummary))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.LineItemPage getLineItemsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LineItemPage> getLineItemsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(LineItemSummary))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performLineItemAction(Google.Api.Ads.AdManager.v201802.LineItemAction lineItemAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performLineItemActionAsync(Google.Api.Ads.AdManager.v201802.LineItemAction lineItemAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(LineItemSummary))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.LineItemService.updateLineItemsResponse updateLineItems(Wrappers.LineItemService.updateLineItemsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.LineItemService.updateLineItemsResponse> updateLineItemsAsync(Wrappers.LineItemService.updateLineItemsRequest request);
	}


	/// <summary>Captures a page of <a href='LineItem'>LineItem</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LineItemPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private LineItem[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of line items contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public LineItem[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a href='LineItem'>LineItem</a>
	/// objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UnarchiveLineItems))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ResumeLineItems))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ResumeAndOverbookLineItems))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ReserveLineItems))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ReserveAndOverbookLineItems))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ReleaseLineItems))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(PauseLineItems))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeleteLineItems))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ArchiveLineItems))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateLineItems))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class LineItemAction {
	}


	/// <summary>The action used for unarchiving <a href='LineItem'>LineItem</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UnarchiveLineItems : LineItemAction {
	}


	/// <summary>The action used for resuming <a href='LineItem'>LineItem</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ResumeAndOverbookLineItems))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ResumeLineItems : LineItemAction {
		private bool skipInventoryCheckField;

		private bool skipInventoryCheckFieldSpecified;

		/// <summary>Indicates whether the inventory check should be skipped when performing this
		/// action. The default value is false.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool skipInventoryCheck {
			get {
				return this.skipInventoryCheckField;
			}
			set {
				this.skipInventoryCheckField = value;
				this.skipInventoryCheckSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="skipInventoryCheck" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool skipInventoryCheckSpecified {
			get {
				return this.skipInventoryCheckFieldSpecified;
			}
			set {
				this.skipInventoryCheckFieldSpecified = value;
			}
		}
	}


	/// <summary>The action used for resuming and overbooking <a href='LineItem'>LineItem</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ResumeAndOverbookLineItems : ResumeLineItems {
	}


	/// <summary>The action used for reserving <a href='LineItem'>LineItem</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ReserveAndOverbookLineItems))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReserveLineItems : LineItemAction {
		private bool skipInventoryCheckField;

		private bool skipInventoryCheckFieldSpecified;

		/// <summary>Indicates whether the inventory check should be skipped when performing this
		/// action. The default value is false.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool skipInventoryCheck {
			get {
				return this.skipInventoryCheckField;
			}
			set {
				this.skipInventoryCheckField = value;
				this.skipInventoryCheckSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="skipInventoryCheck" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool skipInventoryCheckSpecified {
			get {
				return this.skipInventoryCheckFieldSpecified;
			}
			set {
				this.skipInventoryCheckFieldSpecified = value;
			}
		}
	}


	/// <summary>The action used for reserving and overbooking <a href='LineItem'>LineItem</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReserveAndOverbookLineItems : ReserveLineItems {
	}


	/// <summary>The action used for releasing <a href='LineItem'>LineItem</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReleaseLineItems : LineItemAction {
	}


	/// <summary>The action used for pausing <a href='LineItem'>LineItem</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PauseLineItems : LineItemAction {
	}


	/// <summary>The action used for deleting <a href='LineItem'>LineItem</a> objects. A line
	/// item can be deleted if it has never been eligible to serve.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeleteLineItems : LineItemAction {
	}


	/// <summary>The action used for archiving <a href='LineItem'>LineItem</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ArchiveLineItems : LineItemAction {
	}


	/// <summary>The action used for activating <a href='LineItem'>LineItem</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateLineItems : LineItemAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface LineItemServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.LineItemServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='LineItem'>LineItem</a> objects. <p>Line items define the campaign. For
	/// example, line items define:</p> <ul> <li>a budget</li> <li>a span of time to
	/// run</li> <li>ad unit targeting</li> </ul> <p>In short, line items connect all of
	/// the elements of an ad campaign.</p> <p>Line items and creatives can be
	/// associated with each other through <a href=''>LineItemCreativeAssociation</a>
	/// objects. An ad unit will host a creative through both this association and the
	/// <a href='LineItem#targeting'>LineItem#targeting</a> to it. The delivery of a
	/// line item depends on its priority. More information on line item priorities can
	/// be found on the <a
	/// href="https://support.google.com/dfp_premium/answer/177279">DFP Help
	/// Center</a>.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class LineItemService : AdManagerSoapClient<ILineItemService>, ILineItemService {
		/// <summary> Creates a new instance of the <see cref="LineItemService"/> class.
		/// </summary>
		public LineItemService() {
		}

		/// <summary> Creates a new instance of the <see cref="LineItemService"/> class.
		/// </summary>
		public LineItemService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="LineItemService"/> class.
		/// </summary>
		public LineItemService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="LineItemService"/> class.
		/// </summary>
		public LineItemService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="LineItemService"/> class.
		/// </summary>
		public LineItemService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.LineItemService.createLineItemsResponse Google.Api.Ads.AdManager.v201802.LineItemServiceInterface.createLineItems(Wrappers.LineItemService.createLineItemsRequest request) {
			return base.Channel.createLineItems(request);
		}

		/// <summary>Creates new <a href='LineItem'>LineItem</a> objects.
		/// </summary><param name='lineItems'>the line items to create</param>
		/// <returns>the created line items with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.LineItem[] createLineItems(Google.Api.Ads.AdManager.v201802.LineItem[] lineItems) {
			Wrappers.LineItemService.createLineItemsRequest inValue = new Wrappers.LineItemService.createLineItemsRequest();
			inValue.lineItems = lineItems;
			Wrappers.LineItemService.createLineItemsResponse retVal = ((Google.Api.Ads.AdManager.v201802.LineItemServiceInterface)(this)).createLineItems(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.LineItemService.createLineItemsResponse> Google.Api.Ads.AdManager.v201802.LineItemServiceInterface.createLineItemsAsync(Wrappers.LineItemService.createLineItemsRequest request) {
			return base.Channel.createLineItemsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LineItem[]> createLineItemsAsync(Google.Api.Ads.AdManager.v201802.LineItem[] lineItems) {
			Wrappers.LineItemService.createLineItemsRequest inValue = new Wrappers.LineItemService.createLineItemsRequest();
			inValue.lineItems = lineItems;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LineItem[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.LineItemServiceInterface)(this)).createLineItemsAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='LineItemPage'>LineItemPage</a> of <a
		/// href='LineItem'>LineItem</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th>PQL property</th> <th>Entity property</th> </tr>
		/// <tr> <td><code>CostType</code></td> <td><a
		/// href='LineItem#costType'>LineItem#costType</a></td> </tr> <tr>
		/// <td><code>CreationDateTime</code></td> <td><a
		/// href='LineItem#creationDateTime'>LineItem#creationDateTime</a></td> </tr> <tr>
		/// <td><code>DeliveryRateType</code></td> <td><a
		/// href='LineItem#deliveryRateType'>LineItem#deliveryRateType</a></td> </tr> <tr>
		/// <td><code>EndDateTime</code></td> <td><a
		/// href='LineItem#endDateTime'>LineItem#endDateTime</a></td> </tr> <tr>
		/// <td><code>ExternalId</code></td> <td><a
		/// href='LineItem#externalId'>LineItem#externalId</a></td> </tr> <tr>
		/// <td><code>Id</code></td> <td><a href='LineItem#id'>LineItem#id</a></td> </tr>
		/// <tr> <td><code>IsMissingCreatives</code></td> <td><a
		/// href='LineItem#isMissingCreatives'>LineItem#isMissingCreatives</a></td> </tr>
		/// <tr> <td><code>IsSetTopBoxEnabled</code></td> <td><a
		/// href='LineItem#isSetTopBoxEnabled'>LineItem#isSetTopBoxEnabled</a></td> </tr>
		/// <tr> <td><code>LastModifiedDateTime</code></td> <td><a
		/// href='LineItem#lastModifiedDateTime'>LineItem#lastModifiedDateTime</a></td>
		/// </tr> <tr> <td><code>LineItemType</code></td> <td><a
		/// href='LineItem#lineItemType'>LineItem#lineItemType</a></td> </tr> <tr>
		/// <td><code>Name</code></td> <td><a href='LineItem#name'>LineItem#name</a></td>
		/// </tr> <tr> <td><code>OrderId</code></td> <td><a
		/// href='LineItem#orderId'>LineItem#orderId</a></td> </tr> <tr>
		/// <td><code>StartDateTime</code></td> <td><a
		/// href='LineItem#startDateTime'>LineItem#startDateTime</a></td> </tr> <tr>
		/// <td><code>Status</code></td> <td><a
		/// href='LineItem#status'>LineItem#status</a></td> </tr> <tr>
		/// <td><code>Targeting</code></td> <td><a
		/// href='LineItem#targeting'>LineItem#targeting</a></td> </tr> <tr>
		/// <td><code>UnitsBought</code></td> <td><a
		/// href='LineItem#unitsBought'>LineItem#unitsBought</a></td> </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of line items.</param>
		/// <returns>the line items that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.LineItemPage getLineItemsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getLineItemsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LineItemPage> getLineItemsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getLineItemsByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='LineItem'>LineItem</a> objects that match the given
		/// <a href='Statement#query'>Statement#query</a>.
		/// </summary><param name='lineItemAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of line items</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performLineItemAction(Google.Api.Ads.AdManager.v201802.LineItemAction lineItemAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performLineItemAction(lineItemAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performLineItemActionAsync(Google.Api.Ads.AdManager.v201802.LineItemAction lineItemAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performLineItemActionAsync(lineItemAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.LineItemService.updateLineItemsResponse Google.Api.Ads.AdManager.v201802.LineItemServiceInterface.updateLineItems(Wrappers.LineItemService.updateLineItemsRequest request) {
			return base.Channel.updateLineItems(request);
		}

		/// <summary>Updates the specified <a href='LineItem'>LineItem</a> objects.
		/// </summary><param name='lineItems'>the line items to update</param>
		/// <returns>the updated line items</returns>
		public virtual Google.Api.Ads.AdManager.v201802.LineItem[] updateLineItems(Google.Api.Ads.AdManager.v201802.LineItem[] lineItems) {
			Wrappers.LineItemService.updateLineItemsRequest inValue = new Wrappers.LineItemService.updateLineItemsRequest();
			inValue.lineItems = lineItems;
			Wrappers.LineItemService.updateLineItemsResponse retVal = ((Google.Api.Ads.AdManager.v201802.LineItemServiceInterface)(this)).updateLineItems(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.LineItemService.updateLineItemsResponse> Google.Api.Ads.AdManager.v201802.LineItemServiceInterface.updateLineItemsAsync(Wrappers.LineItemService.updateLineItemsRequest request) {
			return base.Channel.updateLineItemsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LineItem[]> updateLineItemsAsync(Google.Api.Ads.AdManager.v201802.LineItem[] lineItems) {
			Wrappers.LineItemService.updateLineItemsRequest inValue = new Wrappers.LineItemService.updateLineItemsRequest();
			inValue.lineItems = lineItems;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LineItem[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.LineItemServiceInterface)(this)).updateLineItemsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.LineItemTemplateService
	{
	}
	/// <summary>Represents the template that populates the fields of a new line item being
	/// created.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LineItemTemplate {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private bool isDefaultField;

		private bool isDefaultFieldSpecified;

		private string lineItemNameField;

		private bool enabledForSameAdvertiserExceptionField;

		private bool enabledForSameAdvertiserExceptionFieldSpecified;

		private string notesField;

		private LineItemType lineItemTypeField;

		private bool lineItemTypeFieldSpecified;

		private DateTime startTimeField;

		private DateTime endTimeField;

		private DeliveryRateType deliveryRateTypeField;

		private bool deliveryRateTypeFieldSpecified;

		private RoadblockingType roadblockingTypeField;

		private bool roadblockingTypeFieldSpecified;

		private CreativeRotationType creativeRotationTypeField;

		private bool creativeRotationTypeFieldSpecified;

		/// <summary>Uniquely identifies the <code>LineItemTemplate</code>. This attribute is
		/// read-only and is assigned by Google when a template is created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the <code>LineItemTemplate</code>. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>Whether or not the <code>LineItemTemplate</code> represents the default choices
		/// for creating a <code>LineItem</code>. Only one default <code></code> is allowed
		/// per <code>Network</code>. This attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public bool isDefault {
			get {
				return this.isDefaultField;
			}
			set {
				this.isDefaultField = value;
				this.isDefaultSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isDefault"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isDefaultSpecified {
			get {
				return this.isDefaultFieldSpecified;
			}
			set {
				this.isDefaultFieldSpecified = value;
			}
		}

		/// <summary>The default <a href='LineItem#name'>name</a> of a new <code></code>. This
		/// attribute is optional and has a maximum length of 127 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string lineItemName {
			get {
				return this.lineItemNameField;
			}
			set {
				this.lineItemNameField = value;
			}
		}

		/// <summary>The default value for the <a
		/// href='LineItem#enabledForSameAdvertiserException'>LineItem#enabledForSameAdvertiserException</a>
		/// field of a new <code>LineItem</code>. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public bool enabledForSameAdvertiserException {
			get {
				return this.enabledForSameAdvertiserExceptionField;
			}
			set {
				this.enabledForSameAdvertiserExceptionField = value;
				this.enabledForSameAdvertiserExceptionSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="enabledForSameAdvertiserException" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool enabledForSameAdvertiserExceptionSpecified {
			get {
				return this.enabledForSameAdvertiserExceptionFieldSpecified;
			}
			set {
				this.enabledForSameAdvertiserExceptionFieldSpecified = value;
			}
		}

		/// <summary>The default <a href='LineItem#notes'>notes</a> for a new <code></code>. This
		/// attribute is optional and has a maximum length of 65,535 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public string notes {
			get {
				return this.notesField;
			}
			set {
				this.notesField = value;
			}
		}

		/// <summary>The default <a href='LineItem#lineItemType'>type</a> of a new
		/// <code>LineItem</code>. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public LineItemType lineItemType {
			get {
				return this.lineItemTypeField;
			}
			set {
				this.lineItemTypeField = value;
				this.lineItemTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lineItemType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lineItemTypeSpecified {
			get {
				return this.lineItemTypeFieldSpecified;
			}
			set {
				this.lineItemTypeFieldSpecified = value;
			}
		}

		/// <summary>The default time of the <a
		/// href='LineItem#startDateTime'>LineItem#startDateTime</a> field of a new
		/// <code>LineItem</code>. Only the time part is used, and the date part is ignored.
		/// This attribute is deprecated.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public DateTime startTime {
			get {
				return this.startTimeField;
			}
			set {
				this.startTimeField = value;
			}
		}

		/// <summary>The default time of the <a href='LineItem#endDateTime'>LineItem#endDateTime</a>
		/// field of a new <code>LineItem</code>. Only the time part is used, and the date
		/// part is ignored. This attribute is deprecated.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public DateTime endTime {
			get {
				return this.endTimeField;
			}
			set {
				this.endTimeField = value;
			}
		}

		/// <summary>The default <a href='LineItem#deliveryRateType'>delivery strategy</a> for a new
		/// <code>LineItem</code>. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public DeliveryRateType deliveryRateType {
			get {
				return this.deliveryRateTypeField;
			}
			set {
				this.deliveryRateTypeField = value;
				this.deliveryRateTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="deliveryRateType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool deliveryRateTypeSpecified {
			get {
				return this.deliveryRateTypeFieldSpecified;
			}
			set {
				this.deliveryRateTypeFieldSpecified = value;
			}
		}

		/// <summary>The default <a href='LineItem#roadblockingType'>roadblocking strategy</a> for a
		/// new <code>LineItem</code>. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public RoadblockingType roadblockingType {
			get {
				return this.roadblockingTypeField;
			}
			set {
				this.roadblockingTypeField = value;
				this.roadblockingTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="roadblockingType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool roadblockingTypeSpecified {
			get {
				return this.roadblockingTypeFieldSpecified;
			}
			set {
				this.roadblockingTypeFieldSpecified = value;
			}
		}

		/// <summary>The default <a href='LineItem#creativeRotationType'>creative rotation
		/// strategy</a> for a new <code>LineItem</code>. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 11)]
		public CreativeRotationType creativeRotationType {
			get {
				return this.creativeRotationTypeField;
			}
			set {
				this.creativeRotationTypeField = value;
				this.creativeRotationTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="creativeRotationType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool creativeRotationTypeSpecified {
			get {
				return this.creativeRotationTypeFieldSpecified;
			}
			set {
				this.creativeRotationTypeFieldSpecified = value;
			}
		}
	}


	/// <summary>Captures a page of <a href='LineItemTemplate'>LineItemTemplate</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LineItemTemplatePage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private LineItemTemplate[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of line item templates contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public LineItemTemplate[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.LineItemTemplateServiceInterface")]
	public interface LineItemTemplateServiceInterface
	{
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.LineItemTemplatePage getLineItemTemplatesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LineItemTemplatePage> getLineItemTemplatesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface LineItemTemplateServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.LineItemTemplateServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='LineItemTemplate'>LineItemTemplate</a> objects.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class LineItemTemplateService : AdManagerSoapClient<ILineItemTemplateService>, ILineItemTemplateService {
		/// <summary> Creates a new instance of the <see cref="LineItemTemplateService"/>
		/// class. </summary>
		public LineItemTemplateService() {
		}

		/// <summary> Creates a new instance of the <see cref="LineItemTemplateService"/>
		/// class. </summary>
		public LineItemTemplateService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="LineItemTemplateService"/>
		/// class. </summary>
		public LineItemTemplateService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="LineItemTemplateService"/>
		/// class. </summary>
		public LineItemTemplateService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="LineItemTemplateService"/>
		/// class. </summary>
		public LineItemTemplateService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		/// <summary>Gets a <a href='LineItemTemplatePage'>LineItemTemplatePage</a> of <a
		/// href='LineItemTemplate'>LineItemTemplate</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='LineItemTemplate#id'>LineItemTemplate#id</a></td> </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of line item templates</param>
		/// <returns>the line item templates that match the given filter</returns>
		/// <exception cref='ApiException'>if a RuntimeException is thrown</exception>
		public virtual Google.Api.Ads.AdManager.v201802.LineItemTemplatePage getLineItemTemplatesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getLineItemTemplatesByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LineItemTemplatePage> getLineItemTemplatesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getLineItemTemplatesByStatementAsync(filterStatement);
		}
	}
	namespace Wrappers.LiveStreamEventService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createLiveStreamEvents", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createLiveStreamEventsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("liveStreamEvents")]
			public Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] liveStreamEvents;

			/// <summary> Creates a new instance of the <see
			/// cref="createLiveStreamEventsRequest"/> class. </summary>
			public createLiveStreamEventsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createLiveStreamEventsRequest"/> class. </summary>
			public createLiveStreamEventsRequest(Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] liveStreamEvents) {
				this.liveStreamEvents = liveStreamEvents;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createLiveStreamEventsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createLiveStreamEventsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createLiveStreamEventsResponse"/> class. </summary>
			public createLiveStreamEventsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createLiveStreamEventsResponse"/> class. </summary>
			public createLiveStreamEventsResponse(Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "registerSessionsForMonitoring", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class registerSessionsForMonitoringRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("sessionIds")]
			public string[] sessionIds;

			/// <summary> Creates a new instance of the <see
			/// cref="registerSessionsForMonitoringRequest"/> class. </summary>
			public registerSessionsForMonitoringRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="registerSessionsForMonitoringRequest"/> class. </summary>
			public registerSessionsForMonitoringRequest(string[] sessionIds) {
				this.sessionIds = sessionIds;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "registerSessionsForMonitoringResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class registerSessionsForMonitoringResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public string[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="registerSessionsForMonitoringResponse"/> class. </summary>
			public registerSessionsForMonitoringResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="registerSessionsForMonitoringResponse"/> class. </summary>
			public registerSessionsForMonitoringResponse(string[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateLiveStreamEvents", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateLiveStreamEventsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("liveStreamEvents")]
			public Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] liveStreamEvents;

			/// <summary> Creates a new instance of the <see
			/// cref="updateLiveStreamEventsRequest"/> class. </summary>
			public updateLiveStreamEventsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateLiveStreamEventsRequest"/> class. </summary>
			public updateLiveStreamEventsRequest(Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] liveStreamEvents) {
				this.liveStreamEvents = liveStreamEvents;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateLiveStreamEventsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateLiveStreamEventsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateLiveStreamEventsResponse"/> class. </summary>
			public updateLiveStreamEventsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateLiveStreamEventsResponse"/> class. </summary>
			public updateLiveStreamEventsResponse(Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary><a href='LiveStream'>LiveStream</a> settings that are specific to the HTTP live
	/// streaming (HLS) protocol.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class HlsSettings {
		private PlaylistType playlistTypeField;

		private bool playlistTypeFieldSpecified;

		/// <summary>Indicates the type of the playlist associated with this live stream. The
		/// playlist type is analagous to the EXT-X-PLAYLIST-TYPE HLS tag. This field is
		/// optional and will default to <a href=''>PlaylistType#LIVE</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public PlaylistType playlistType {
			get {
				return this.playlistTypeField;
			}
			set {
				this.playlistTypeField = value;
				this.playlistTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="playlistType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool playlistTypeSpecified {
			get {
				return this.playlistTypeFieldSpecified;
			}
			set {
				this.playlistTypeFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes the type of the playlist associated with this live stream. This is
	/// analagous to the EXT-X-PLAYLIST-TYPE HLS tag. Use <a
	/// href='PlaylistType.EVENT'>PlaylistType.EVENT</a> for streams with the value
	/// "#EXT-X-PLAYLIST-TYPE:EVENT" and use <a
	/// href='PlaylistType.LIVE'>PlaylistType.LIVE</a> for streams without the tag.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum PlaylistType {
		/// <summary>The playlist is an event, which means that media segments can only be added to
		/// the end of the playlist. This allows viewers to scrub back to the beginning of
		/// the playlist.
		/// </summary>
		EVENT = 0,
		/// <summary>The playlist is a live stream and there are no restrictions on whether media
		/// segments can be removed from the beginning of the playlist.
		/// </summary>
		LIVE = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>A set of security requirements to authenticate against in order to access video
	/// content. Different locations (e.g. different CDNs) can have different security
	/// policies.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SecurityPolicySettings {
		private SecurityPolicyType securityPolicyTypeField;

		private bool securityPolicyTypeFieldSpecified;

		private string tokenAuthenticationKeyField;

		private bool disableServerSideUrlSigningField;

		private bool disableServerSideUrlSigningFieldSpecified;

		private OriginForwardingType originForwardingTypeField;

		private bool originForwardingTypeFieldSpecified;

		private string originPathPrefixField;

		/// <summary>Type of security policy. This determines which other fields should be populated.
		/// This value is required for a valid security policy.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public SecurityPolicyType securityPolicyType {
			get {
				return this.securityPolicyTypeField;
			}
			set {
				this.securityPolicyTypeField = value;
				this.securityPolicyTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="securityPolicyType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool securityPolicyTypeSpecified {
			get {
				return this.securityPolicyTypeFieldSpecified;
			}
			set {
				this.securityPolicyTypeFieldSpecified = value;
			}
		}

		/// <summary>Shared security key used to generate the Akamai HMAC token for authenticating
		/// requests. This field is only applicable when the value of <a
		/// href='#securityPolicyType'>#securityPolicyType</a> is equal to <a
		/// href=''>SecurityPolicyType#AKAMAI</a> and will be set to null otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string tokenAuthenticationKey {
			get {
				return this.tokenAuthenticationKeyField;
			}
			set {
				this.tokenAuthenticationKeyField = value;
			}
		}

		/// <summary>Whether the segment URLs should be signed using the <a
		/// href='#tokenAuthenticationKey'>#tokenAuthenticationKey</a> on the server. This
		/// is only applicable for delivery media locations that have token authentication
		/// enabled.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public bool disableServerSideUrlSigning {
			get {
				return this.disableServerSideUrlSigningField;
			}
			set {
				this.disableServerSideUrlSigningField = value;
				this.disableServerSideUrlSigningSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="disableServerSideUrlSigning" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool disableServerSideUrlSigningSpecified {
			get {
				return this.disableServerSideUrlSigningFieldSpecified;
			}
			set {
				this.disableServerSideUrlSigningFieldSpecified = value;
			}
		}

		/// <summary>The type of origin forwarding used to support Akamai authentication policies.
		/// This field is not applicable to ingest locations, and is only applicable to
		/// delivery media locations with the <a
		/// href='#securityPolicyType'>#securityPolicyType</a> set to <a
		/// href='SecurityPolicyType#AKAMAI'>SecurityPolicyType#AKAMAI</a>. If set elsewhere
		/// it will be reset to null.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public OriginForwardingType originForwardingType {
			get {
				return this.originForwardingTypeField;
			}
			set {
				this.originForwardingTypeField = value;
				this.originForwardingTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="originForwardingType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool originForwardingTypeSpecified {
			get {
				return this.originForwardingTypeFieldSpecified;
			}
			set {
				this.originForwardingTypeFieldSpecified = value;
			}
		}

		/// <summary>The origin path prefix provided by the publisher. This field is only applicable
		/// for delivery media locations with the value of <a
		/// href='#originForwardingType'>#originForwardingType</a> set to <a
		/// href=''>OriginForwardingType#CONVENTIONAL</a>, and will be set to null
		/// otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string originPathPrefix {
			get {
				return this.originPathPrefixField;
			}
			set {
				this.originPathPrefixField = value;
			}
		}
	}


	/// <summary>Indicates the type of security policy associated with access to a CDN. Different
	/// security policies require different parameters in a <a
	/// href='SecurityPolicy'>SecurityPolicy</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum SecurityPolicyType {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		/// <summary>Indicates that no authentication is necessary.
		/// </summary>
		NONE = 1,
		/// <summary>Security policy for accessing content on the Akamai CDN.
		/// </summary>
		AKAMAI = 2,
	}


	/// <summary>Indicates the type of origin forwarding used to support Akamai authentication
	/// policies for <a href='LiveStreamEvent'>LiveStreamEvent</a>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum OriginForwardingType {
		/// <summary>Indicates that origin forwarding is set up by passing an originpath query string
		/// parameter (necessary for Akamai dynamic packaging to work)
		/// </summary>
		ORIGIN_PATH = 0,
		/// <summary>Indicates that conventional origin forwarding is used.
		/// </summary>
		CONVENTIONAL = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Configuration that associates a media location with a security policy and the
	/// authentication credentials needed to access the content.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class MediaLocationSettings {
		private string nameField;

		private string urlPrefixField;

		private SecurityPolicySettings securityPolicyField;

		/// <summary>The name of the media location. This value is read-only and is assigned by
		/// Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The url prefix of the media location. This value is required for a valid media
		/// location.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string urlPrefix {
			get {
				return this.urlPrefixField;
			}
			set {
				this.urlPrefixField = value;
			}
		}

		/// <summary>The security policy and authentication credentials needed to access the content
		/// in this media location. This value is required for a valid media location.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public SecurityPolicySettings securityPolicy {
			get {
				return this.securityPolicyField;
			}
			set {
				this.securityPolicyField = value;
			}
		}
	}


	/// <summary>Parameters about this CDN configuration as a source of content. This facilitates
	/// fetching the original content for conditioning and delivering the original
	/// content as part of a modified stream.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SourceContentConfiguration {
		private MediaLocationSettings ingestSettingsField;

		private MediaLocationSettings defaultDeliverySettingsField;

		/// <summary>Configuration for how DAI should ingest media. At ingest time, we match the url
		/// prefix of media in a stream's playlist with an ingest location and use the
		/// authentication credentials from the corresponding ingest settings to download
		/// the media. This value is required for a valid source content configuration.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public MediaLocationSettings ingestSettings {
			get {
				return this.ingestSettingsField;
			}
			set {
				this.ingestSettingsField = value;
			}
		}

		/// <summary>Default configuration for how DAI should deliver the non-modified media
		/// segments. At delivery time, we replace the ingest location's url prefix with the
		/// delivery location's URL prefix and use the security policy from the delivery
		/// settings to determine how DAI needs to deliver the media so that users can
		/// access it. This value is required for a valid source content configuration.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public MediaLocationSettings defaultDeliverySettings {
			get {
				return this.defaultDeliverySettingsField;
			}
			set {
				this.defaultDeliverySettingsField = value;
			}
		}
	}


	/// <summary>A <a href='CdnConfiguration'>CdnConfiguration</a> encapsulates information about
	/// where and how to ingest and deliver content enabled for DAI (Dynamic Ad
	/// Insertion).
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CdnConfiguration {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private CdnConfigurationType cdnConfigurationTypeField;

		private bool cdnConfigurationTypeFieldSpecified;

		private SourceContentConfiguration sourceContentConfigurationField;

		/// <summary>The unique ID of the <a href='CdnConfiguration'>CdnConfiguration</a>. This value
		/// is read-only and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the <a href='CdnConfiguration'>CdnConfiguration</a>. This value is
		/// required to create a CDN configuration and has a maximum length of 255
		/// characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The type of CDN configuration represented by this <a
		/// href='CdnConfiguration'>CdnConfiguration</a>. This value is required to create a
		/// CDN configuration
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public CdnConfigurationType cdnConfigurationType {
			get {
				return this.cdnConfigurationTypeField;
			}
			set {
				this.cdnConfigurationTypeField = value;
				this.cdnConfigurationTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="cdnConfigurationType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool cdnConfigurationTypeSpecified {
			get {
				return this.cdnConfigurationTypeFieldSpecified;
			}
			set {
				this.cdnConfigurationTypeFieldSpecified = value;
			}
		}

		/// <summary>Parameters about this CDN configuration as a source of content. This facilitates
		/// fetching the original content for conditioning and delivering the original
		/// content as part of a modified stream.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public SourceContentConfiguration sourceContentConfiguration {
			get {
				return this.sourceContentConfigurationField;
			}
			set {
				this.sourceContentConfigurationField = value;
			}
		}
	}


	/// <summary>Indicates the type of CDN configuration for <a
	/// href='CdnConfiguration'>CdnConfiguration</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CdnConfigurationType {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		/// <summary>A configuration that specifies where and how <a
		/// href='LiveStreamEvent'>LiveStreamEvent</a> content should be ingested and
		/// delivered.
		/// </summary>
		LIVE_STREAM_SOURCE_CONTENT = 1,
	}


	/// <summary>A <code>LiveStreamEvent</code> encapsulates all the information necessary to
	/// enable DAI (Dynamic Ad Insertion) into a live video stream. <p>This includes
	/// information such as the start and expected end time of the event, the URL of the
	/// actual content for Ad Manager to pull and insert ads into, as well as the
	/// metadata necessary to generate ad requests during the event.</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LiveStreamEvent {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private string descriptionField;

		private LiveStreamEventStatus statusField;

		private bool statusFieldSpecified;

		private DateTime creationDateTimeField;

		private DateTime lastModifiedDateTimeField;

		private DateTime startDateTimeField;

		private StartDateTimeType startDateTimeTypeField;

		private bool startDateTimeTypeFieldSpecified;

		private DateTime endDateTimeField;

		private long totalEstimatedConcurrentUsersField;

		private bool totalEstimatedConcurrentUsersFieldSpecified;

		private string[] contentUrlsField;

		private string[] adTagsField;

		private string liveStreamEventCodeField;

		private int dvrWindowSecondsField;

		private bool dvrWindowSecondsFieldSpecified;

		private AdBreakFillType adBreakFillTypeField;

		private bool adBreakFillTypeFieldSpecified;

		private long adHolidayDurationField;

		private bool adHolidayDurationFieldSpecified;

		private bool enableDurationlessAdBreaksField;

		private bool enableDurationlessAdBreaksFieldSpecified;

		private long defaultAdBreakDurationField;

		private bool defaultAdBreakDurationFieldSpecified;

		private CdnConfiguration[] sourceContentConfigurationsField;

		private HlsSettings hlsSettingsField;

		/// <summary>The unique ID of the <code>LiveStreamEvent</code>. This value is read-only and
		/// is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the <code>LiveStreamEvent</code>. This value is required to create a
		/// live stream event and has a maximum length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>Additional notes to annotate the event with. This attribute is optional and has
		/// a maximum length of 65,535 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string description {
			get {
				return this.descriptionField;
			}
			set {
				this.descriptionField = value;
			}
		}

		/// <summary>The status of this <code>LiveStreamEvent</code>. This attribute is read-only and
		/// is assigned by Google. Live stream events are created in the <a
		/// href='LiveStreamEventStatus#PAUSED'>LiveStreamEventStatus#PAUSED</a> state.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public LiveStreamEventStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>The date and time this <code>LiveStreamEvent</code> was created. This attribute
		/// is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public DateTime creationDateTime {
			get {
				return this.creationDateTimeField;
			}
			set {
				this.creationDateTimeField = value;
			}
		}

		/// <summary>The date and time this <code>LiveStreamEvent</code> was last modified. This
		/// attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public DateTime lastModifiedDateTime {
			get {
				return this.lastModifiedDateTimeField;
			}
			set {
				this.lastModifiedDateTimeField = value;
			}
		}

		/// <summary>The start date and time of this <code>LiveStreamEvent</code>. This attribute is
		/// required if the <a
		/// href='LiveStreamEvent#startDateTimeType'>LiveStreamEvent#startDateTimeType</a>
		/// is <a
		/// href='StartDateTimeType#USE_START_DATE_TIME'>StartDateTimeType#USE_START_DATE_TIME</a>
		/// and is ignored for all other values of <a
		/// href='StartDateTimeType'>StartDateTimeType</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public DateTime startDateTime {
			get {
				return this.startDateTimeField;
			}
			set {
				this.startDateTimeField = value;
			}
		}

		/// <summary>Specifies whether to start the <a href='LiveStreamEvent'>LiveStreamEvent</a>
		/// right away, in an hour, etc. This attribute is optional and defaults to <a
		/// href='StartDateTimeType#USE_START_DATE_TIME'>StartDateTimeType#USE_START_DATE_TIME</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public StartDateTimeType startDateTimeType {
			get {
				return this.startDateTimeTypeField;
			}
			set {
				this.startDateTimeTypeField = value;
				this.startDateTimeTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="startDateTimeType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startDateTimeTypeSpecified {
			get {
				return this.startDateTimeTypeFieldSpecified;
			}
			set {
				this.startDateTimeTypeFieldSpecified = value;
			}
		}

		/// <summary>The scheduled end date and time of this <code>LiveStreamEvent</code>. This
		/// attribute is required if <code>unlimitedEndDateTime</code> is false and ignored
		/// if <code>unlimitedEndDateTime</code> is true.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public DateTime endDateTime {
			get {
				return this.endDateTimeField;
			}
			set {
				this.endDateTimeField = value;
			}
		}

		/// <summary>The total number of concurrent users expected to watch this event across all
		/// regions. This attribute is optional and default value is 0.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public long totalEstimatedConcurrentUsers {
			get {
				return this.totalEstimatedConcurrentUsersField;
			}
			set {
				this.totalEstimatedConcurrentUsersField = value;
				this.totalEstimatedConcurrentUsersSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalEstimatedConcurrentUsers" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalEstimatedConcurrentUsersSpecified {
			get {
				return this.totalEstimatedConcurrentUsersFieldSpecified;
			}
			set {
				this.totalEstimatedConcurrentUsersFieldSpecified = value;
			}
		}

		/// <summary>The list of URLs pointing to the live stream content in Content Delivery
		/// Network. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("contentUrls", Order = 10)]
		public string[] contentUrls {
			get {
				return this.contentUrlsField;
			}
			set {
				this.contentUrlsField = value;
			}
		}

		/// <summary>The list of Ad Manager ad tag URLs generated by the Ad Manager trafficking
		/// workflow that are associated with this live stream event. This attribute is
		/// required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("adTags", Order = 11)]
		public string[] adTags {
			get {
				return this.adTagsField;
			}
			set {
				this.adTagsField = value;
			}
		}

		/// <summary>This code is used in constructing a live stream event master playlist URL. This
		/// attribute is read-only and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 12)]
		public string liveStreamEventCode {
			get {
				return this.liveStreamEventCodeField;
			}
			set {
				this.liveStreamEventCodeField = value;
			}
		}

		/// <summary>Length of the DVR window in seconds. This value is optional. If unset the
		/// default window as provided by the input encoder will be used.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 13)]
		public int dvrWindowSeconds {
			get {
				return this.dvrWindowSecondsField;
			}
			set {
				this.dvrWindowSecondsField = value;
				this.dvrWindowSecondsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="dvrWindowSeconds" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool dvrWindowSecondsSpecified {
			get {
				return this.dvrWindowSecondsFieldSpecified;
			}
			set {
				this.dvrWindowSecondsFieldSpecified = value;
			}
		}

		/// <summary>The type of content that should be used to fill an empty ad break. This value is
		/// optional and defaults to <a
		/// href='AdBreakFillType#SLATE'>AdBreakFillType#SLATE</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 14)]
		public AdBreakFillType adBreakFillType {
			get {
				return this.adBreakFillTypeField;
			}
			set {
				this.adBreakFillTypeField = value;
				this.adBreakFillTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="adBreakFillType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool adBreakFillTypeSpecified {
			get {
				return this.adBreakFillTypeFieldSpecified;
			}
			set {
				this.adBreakFillTypeFieldSpecified = value;
			}
		}

		/// <summary>The duration (in seconds), starting from the time the user enters the DAI
		/// stream, for which mid-roll decisioning will be skipped. This field is only
		/// applicable when an ad holiday is requested in the stream create request. This
		/// value is optional and defaults to 0.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 15)]
		public long adHolidayDuration {
			get {
				return this.adHolidayDurationField;
			}
			set {
				this.adHolidayDurationField = value;
				this.adHolidayDurationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="adHolidayDuration" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool adHolidayDurationSpecified {
			get {
				return this.adHolidayDurationFieldSpecified;
			}
			set {
				this.adHolidayDurationFieldSpecified = value;
			}
		}

		/// <summary>Whether there will be durationless ad breaks in this live stream. If true,
		/// <code>defaultAdBreakDuration</code> should be specified. This field is optional
		/// and defaults to false;
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 16)]
		public bool enableDurationlessAdBreaks {
			get {
				return this.enableDurationlessAdBreaksField;
			}
			set {
				this.enableDurationlessAdBreaksField = value;
				this.enableDurationlessAdBreaksSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="enableDurationlessAdBreaks" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool enableDurationlessAdBreaksSpecified {
			get {
				return this.enableDurationlessAdBreaksFieldSpecified;
			}
			set {
				this.enableDurationlessAdBreaksFieldSpecified = value;
			}
		}

		/// <summary>The default ad pod duration (in seconds) that will be requested when an ad break
		/// cue-out does not specify a duration. This field is optional and defaults to 0;
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 17)]
		public long defaultAdBreakDuration {
			get {
				return this.defaultAdBreakDurationField;
			}
			set {
				this.defaultAdBreakDurationField = value;
				this.defaultAdBreakDurationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="defaultAdBreakDuration" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool defaultAdBreakDurationSpecified {
			get {
				return this.defaultAdBreakDurationFieldSpecified;
			}
			set {
				this.defaultAdBreakDurationFieldSpecified = value;
			}
		}

		/// <summary>The list of <a href='CdnConfiguration'>CdnConfiguration</a>s that provide
		/// settings for ingesting and delivering the videos associated with this source.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("sourceContentConfigurations", Order = 18)]
		public CdnConfiguration[] sourceContentConfigurations {
			get {
				return this.sourceContentConfigurationsField;
			}
			set {
				this.sourceContentConfigurationsField = value;
			}
		}

		/// <summary>The settings that are specific to HTTPS live streaming (HLS) protocol. This
		/// field is optional and if it is not set will use the default HLS settings.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 19)]
		public HlsSettings hlsSettings {
			get {
				return this.hlsSettingsField;
			}
			set {
				this.hlsSettingsField = value;
			}
		}
	}


	/// <summary>Describes the status of a <a href='LiveStreamEvent'>LiveStreamEvent</a> object.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LiveStreamEventStatus {
		/// <summary>Indicates the <a href='LiveStreamEvent'>LiveStreamEvent</a> has been created and
		/// is eligible for streaming.
		/// </summary>
		ACTIVE = 0,
		/// <summary>Indicates the <a href='LiveStreamEvent'>LiveStreamEvent</a> has been archived.
		/// </summary>
		ARCHIVED = 1,
		/// <summary>Indicates the <a href='LiveStreamEvent'>LiveStreamEvent</a> has been paused.
		/// This can be made <a href='#ACTIVE'>#ACTIVE</a> at later time.
		/// </summary>
		PAUSED = 2,
		/// <summary>Indicates that the stream is still being served, but ad insertion should be
		/// paused temporarily.
		/// </summary>
		ADS_PAUSED = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>Describes what should be used to fill an empty ad break during a live stream.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdBreakFillType {
		/// <summary>Ad break should be filled with slate.
		/// </summary>
		SLATE = 0,
		/// <summary>Ad break should be filled with underlying content.
		/// </summary>
		UNDERLYING_CONTENT = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Lists all errors associated with the Session Activity Monitor (SAM).
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SamSessionError : ApiError {
		private SamSessionErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public SamSessionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes reasons for SAM session errors.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "SamSessionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum SamSessionErrorReason {
		/// <summary>SAM session could not be registered for monitoring.
		/// </summary>
		COULD_NOT_REGISTER_SESSION = 0,
		/// <summary>User specified an invalid format for a session ID. <p>Session IDs are UUIDs and
		/// look like "123e4567-e89b-12d3-a456-426655440000".</p>
		/// </summary>
		MALFORMED_SESSION_ID = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Lists all errors associated with live stream event start and end date times.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LiveStreamEventDateTimeError : ApiError {
		private LiveStreamEventDateTimeErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public LiveStreamEventDateTimeErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes reasons for <code>LiveStreamEventDateTimeError</code>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "LiveStreamEventDateTimeError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LiveStreamEventDateTimeErrorReason {
		/// <summary>Cannot create a new live stream event with a start date in the past.
		/// </summary>
		START_DATE_TIME_IS_IN_PAST = 0,
		/// <summary>End date must be after the start date.
		/// </summary>
		END_DATE_TIME_NOT_AFTER_START_DATE_TIME = 1,
		/// <summary><code>DateTime</code>s after 1 January 2037 are not supported.
		/// </summary>
		END_DATE_TIME_TOO_LATE = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Lists all errors associated with <a href='LiveStreamEvent'>LiveStreamEvent</a>
	/// CDN configurations.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LiveStreamEventCdnSettingsError : ApiError {
		private LiveStreamEventCdnSettingsErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public LiveStreamEventCdnSettingsErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes reasons for <code>LiveStreamEventCdnSettingsError</code>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "LiveStreamEventCdnSettingsError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LiveStreamEventCdnSettingsErrorReason {
		/// <summary>CDN configurations in a single <a href='LiveStreamEvent'>LiveStreamEvent</a>
		/// cannot have duplicate URL prefixes.
		/// </summary>
		CDN_CONFIGURATIONS_MUST_HAVE_UNIQUE_CDN_URL_PREFIXES = 0,
		/// <summary>Only CDN configurations of type <code></code> can be listed in <a
		/// href='LiveStreamEvent#sourceContentConfigurations'>LiveStreamEvent#sourceContentConfigurations</a>.
		/// </summary>
		MUST_BE_LIVE_CDN_CONFIGURATION = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Lists all errors associated with live stream event action.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LiveStreamEventActionError : ApiError {
		private LiveStreamEventActionErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public LiveStreamEventActionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes reasons for <code>LiveStreamEventActionError</code>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "LiveStreamEventActionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LiveStreamEventActionErrorReason {
		/// <summary>The operation is not applicable to the current status.
		/// </summary>
		INVALID_STATUS_TRANSITION = 0,
		/// <summary>The operation cannot be applied because the live stream event is archived.
		/// </summary>
		IS_ARCHIVED = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.LiveStreamEventServiceInterface")]
	public interface LiveStreamEventServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.LiveStreamEventService.createLiveStreamEventsResponse createLiveStreamEvents(Wrappers.LiveStreamEventService.createLiveStreamEventsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.LiveStreamEventService.createLiveStreamEventsResponse> createLiveStreamEventsAsync(Wrappers.LiveStreamEventService.createLiveStreamEventsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.LiveStreamEventPage getLiveStreamEventsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LiveStreamEventPage> getLiveStreamEventsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performLiveStreamEventAction(Google.Api.Ads.AdManager.v201802.LiveStreamEventAction liveStreamEventAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performLiveStreamEventActionAsync(Google.Api.Ads.AdManager.v201802.LiveStreamEventAction liveStreamEventAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.LiveStreamEventService.registerSessionsForMonitoringResponse registerSessionsForMonitoring(Wrappers.LiveStreamEventService.registerSessionsForMonitoringRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.LiveStreamEventService.registerSessionsForMonitoringResponse> registerSessionsForMonitoringAsync(Wrappers.LiveStreamEventService.registerSessionsForMonitoringRequest request);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.LiveStreamEventService.updateLiveStreamEventsResponse updateLiveStreamEvents(Wrappers.LiveStreamEventService.updateLiveStreamEventsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.LiveStreamEventService.updateLiveStreamEventsResponse> updateLiveStreamEventsAsync(Wrappers.LiveStreamEventService.updateLiveStreamEventsRequest request);
	}


	/// <summary>Captures a page of <a href='LiveStreamEvent'>LiveStreamEvent</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class LiveStreamEventPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private LiveStreamEvent[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of live stream events contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public LiveStreamEvent[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a
	/// href='LiveStreamEvent'>LiveStreamEvent</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(PauseLiveStreamEvents))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(PauseLiveStreamEventAds))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ArchiveLiveStreamEvents))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateLiveStreamEvents))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class LiveStreamEventAction {
	}


	/// <summary>The action used for pausing <a href='LiveStreamEvent'>LiveStreamEvent</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PauseLiveStreamEvents : LiveStreamEventAction {
	}


	/// <summary>The action used for pausing ads for <a
	/// href='LiveStreamEvent'>LiveStreamEvent</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PauseLiveStreamEventAds : LiveStreamEventAction {
	}


	/// <summary>The action used for archiving <a href='LiveStreamEvent'>LiveStreamEvent</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ArchiveLiveStreamEvents : LiveStreamEventAction {
	}


	/// <summary>The action used for activating <a href='LiveStreamEvent'>LiveStreamEvent</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateLiveStreamEvents : LiveStreamEventAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface LiveStreamEventServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.LiveStreamEventServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='LiveStreamEvent'>LiveStreamEvent</a> objects. <p>This feature is not yet
	/// openly available for DFP Video publishers. Publishers will need to apply for
	/// access for this feature through their account managers.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class LiveStreamEventService : AdManagerSoapClient<ILiveStreamEventService>, ILiveStreamEventService {
		/// <summary> Creates a new instance of the <see cref="LiveStreamEventService"/>
		/// class. </summary>
		public LiveStreamEventService() {
		}

		/// <summary> Creates a new instance of the <see cref="LiveStreamEventService"/>
		/// class. </summary>
		public LiveStreamEventService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="LiveStreamEventService"/>
		/// class. </summary>
		public LiveStreamEventService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="LiveStreamEventService"/>
		/// class. </summary>
		public LiveStreamEventService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="LiveStreamEventService"/>
		/// class. </summary>
		public LiveStreamEventService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.LiveStreamEventService.createLiveStreamEventsResponse Google.Api.Ads.AdManager.v201802.LiveStreamEventServiceInterface.createLiveStreamEvents(Wrappers.LiveStreamEventService.createLiveStreamEventsRequest request) {
			return base.Channel.createLiveStreamEvents(request);
		}

		/// <summary>Creates new <a href='LiveStreamEvent'>LiveStreamEvent</a> objects. The following
		/// fields are required: <ul> <li><a
		/// href='LiveStreamEvent#name'>LiveStreamEvent#name</a></li> <li><a
		/// href='LiveStreamEvent#startDateTime'>LiveStreamEvent#startDateTime</a></li>
		/// <li><a href='LiveStreamEvent#endDateTime'>LiveStreamEvent#endDateTime</a></li>
		/// <li><a href='LiveStreamEvent#contentUrls'>LiveStreamEvent#contentUrls</a></li>
		/// <li><a href='LiveStreamEvent#adTags'>LiveStreamEvent#adTags</a></li> </ul>
		/// </summary><param name='liveStreamEvents'>the live stream events to create</param>
		/// <returns>the created live stream events with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] createLiveStreamEvents(Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] liveStreamEvents) {
			Wrappers.LiveStreamEventService.createLiveStreamEventsRequest inValue = new Wrappers.LiveStreamEventService.createLiveStreamEventsRequest();
			inValue.liveStreamEvents = liveStreamEvents;
			Wrappers.LiveStreamEventService.createLiveStreamEventsResponse retVal = ((Google.Api.Ads.AdManager.v201802.LiveStreamEventServiceInterface)(this)).createLiveStreamEvents(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.LiveStreamEventService.createLiveStreamEventsResponse> Google.Api.Ads.AdManager.v201802.LiveStreamEventServiceInterface.createLiveStreamEventsAsync(Wrappers.LiveStreamEventService.createLiveStreamEventsRequest request) {
			return base.Channel.createLiveStreamEventsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LiveStreamEvent[]> createLiveStreamEventsAsync(Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] liveStreamEvents) {
			Wrappers.LiveStreamEventService.createLiveStreamEventsRequest inValue = new Wrappers.LiveStreamEventService.createLiveStreamEventsRequest();
			inValue.liveStreamEvents = liveStreamEvents;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LiveStreamEvent[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.LiveStreamEventServiceInterface)(this)).createLiveStreamEventsAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='LiveStreamEventPage'>LiveStreamEventPage</a> of <a
		/// href='LiveStreamEvent'>LiveStreamEvent</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='LiveStreamEvent#id'>LiveStreamEvent#id</a></td> </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement to filter a
		/// list of live stream events</param>
		/// <returns>the live stream events that match the filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.LiveStreamEventPage getLiveStreamEventsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getLiveStreamEventsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LiveStreamEventPage> getLiveStreamEventsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getLiveStreamEventsByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='LiveStreamEvent'>LiveStreamEvent</a> objects that
		/// match the given <a href='Statement#query'>Statement#query</a>.
		/// </summary><param name='liveStreamEventAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of live stream events</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performLiveStreamEventAction(Google.Api.Ads.AdManager.v201802.LiveStreamEventAction liveStreamEventAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performLiveStreamEventAction(liveStreamEventAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performLiveStreamEventActionAsync(Google.Api.Ads.AdManager.v201802.LiveStreamEventAction liveStreamEventAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performLiveStreamEventActionAsync(liveStreamEventAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.LiveStreamEventService.registerSessionsForMonitoringResponse Google.Api.Ads.AdManager.v201802.LiveStreamEventServiceInterface.registerSessionsForMonitoring(Wrappers.LiveStreamEventService.registerSessionsForMonitoringRequest request) {
			return base.Channel.registerSessionsForMonitoring(request);
		}

		/// <summary>Registers the specified list of <code>sessionIds</code> for monitoring. Once the
		/// session IDs have been registered, all logged information about the sessions will
		/// be persisted and can be viewed via the Ad Manager UI. <p>A session ID is a
		/// unique identifier of a single user watching a live stream event. </p>
		/// </summary><param name='sessionIds'>a list of session IDs to register for
		/// monitoring</param>
		/// <returns>the list of session IDs that were registered for monitoring</returns>
		/// <exception cref='ApiException'>if there is an error registering any of the
		/// session IDs</exception>
		public virtual string[] registerSessionsForMonitoring(string[] sessionIds) {
			Wrappers.LiveStreamEventService.registerSessionsForMonitoringRequest inValue = new Wrappers.LiveStreamEventService.registerSessionsForMonitoringRequest();
			inValue.sessionIds = sessionIds;
			Wrappers.LiveStreamEventService.registerSessionsForMonitoringResponse retVal = ((Google.Api.Ads.AdManager.v201802.LiveStreamEventServiceInterface)(this)).registerSessionsForMonitoring(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.LiveStreamEventService.registerSessionsForMonitoringResponse> Google.Api.Ads.AdManager.v201802.LiveStreamEventServiceInterface.registerSessionsForMonitoringAsync(Wrappers.LiveStreamEventService.registerSessionsForMonitoringRequest request) {
			return base.Channel.registerSessionsForMonitoringAsync(request);
		}

		public virtual System.Threading.Tasks.Task<string[]> registerSessionsForMonitoringAsync(string[] sessionIds) {
			Wrappers.LiveStreamEventService.registerSessionsForMonitoringRequest inValue = new Wrappers.LiveStreamEventService.registerSessionsForMonitoringRequest();
			inValue.sessionIds = sessionIds;
			return System.Threading.Tasks.Task<string[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.LiveStreamEventServiceInterface)(this)).registerSessionsForMonitoringAsync(inValue)).Result.rval);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.LiveStreamEventService.updateLiveStreamEventsResponse Google.Api.Ads.AdManager.v201802.LiveStreamEventServiceInterface.updateLiveStreamEvents(Wrappers.LiveStreamEventService.updateLiveStreamEventsRequest request) {
			return base.Channel.updateLiveStreamEvents(request);
		}

		/// <summary>Updates the specified <a href='LiveStreamEvent'>LiveStreamEvent</a> objects.
		/// </summary><param name='liveStreamEvents'>the live stream events to update</param>
		/// <returns>the updated live stream events</returns>
		/// <exception cref='ApiException'>if there is an error updating the live stream
		/// events</exception>
		public virtual Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] updateLiveStreamEvents(Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] liveStreamEvents) {
			Wrappers.LiveStreamEventService.updateLiveStreamEventsRequest inValue = new Wrappers.LiveStreamEventService.updateLiveStreamEventsRequest();
			inValue.liveStreamEvents = liveStreamEvents;
			Wrappers.LiveStreamEventService.updateLiveStreamEventsResponse retVal = ((Google.Api.Ads.AdManager.v201802.LiveStreamEventServiceInterface)(this)).updateLiveStreamEvents(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.LiveStreamEventService.updateLiveStreamEventsResponse> Google.Api.Ads.AdManager.v201802.LiveStreamEventServiceInterface.updateLiveStreamEventsAsync(Wrappers.LiveStreamEventService.updateLiveStreamEventsRequest request) {
			return base.Channel.updateLiveStreamEventsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LiveStreamEvent[]> updateLiveStreamEventsAsync(Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] liveStreamEvents) {
			Wrappers.LiveStreamEventService.updateLiveStreamEventsRequest inValue = new Wrappers.LiveStreamEventService.updateLiveStreamEventsRequest();
			inValue.liveStreamEvents = liveStreamEvents;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LiveStreamEvent[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.LiveStreamEventServiceInterface)(this)).updateLiveStreamEventsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.MobileApplicationService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createMobileApplications", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createMobileApplicationsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("mobileApplications")]
			public Google.Api.Ads.AdManager.v201802.MobileApplication[] mobileApplications;

			/// <summary> Creates a new instance of the <see
			/// cref="createMobileApplicationsRequest"/> class. </summary>
			public createMobileApplicationsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createMobileApplicationsRequest"/> class. </summary>
			public createMobileApplicationsRequest(Google.Api.Ads.AdManager.v201802.MobileApplication[] mobileApplications) {
				this.mobileApplications = mobileApplications;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createMobileApplicationsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createMobileApplicationsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.MobileApplication[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createMobileApplicationsResponse"/> class. </summary>
			public createMobileApplicationsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createMobileApplicationsResponse"/> class. </summary>
			public createMobileApplicationsResponse(Google.Api.Ads.AdManager.v201802.MobileApplication[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateMobileApplications", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateMobileApplicationsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("mobileApplications")]
			public Google.Api.Ads.AdManager.v201802.MobileApplication[] mobileApplications;

			/// <summary> Creates a new instance of the <see
			/// cref="updateMobileApplicationsRequest"/> class. </summary>
			public updateMobileApplicationsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateMobileApplicationsRequest"/> class. </summary>
			public updateMobileApplicationsRequest(Google.Api.Ads.AdManager.v201802.MobileApplication[] mobileApplications) {
				this.mobileApplications = mobileApplications;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateMobileApplicationsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateMobileApplicationsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.MobileApplication[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateMobileApplicationsResponse"/> class. </summary>
			public updateMobileApplicationsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateMobileApplicationsResponse"/> class. </summary>
			public updateMobileApplicationsResponse(Google.Api.Ads.AdManager.v201802.MobileApplication[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>A mobile application that has been added to or "claimed" by the network to be
	/// used for targeting purposes. These mobile apps can come from various app stores.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class MobileApplication {
		private long idField;

		private bool idFieldSpecified;

		private string displayNameField;

		private string appStoreIdField;

		private MobileApplicationStore appStoreField;

		private bool appStoreFieldSpecified;

		private bool isArchivedField;

		private bool isArchivedFieldSpecified;

		private string appStoreNameField;

		private string developerNameField;

		private MobileApplicationPlatform platformField;

		private bool platformFieldSpecified;

		private bool isFreeField;

		private bool isFreeFieldSpecified;

		private string downloadUrlField;

		/// <summary>Uniquely identifies the mobile application. This attribute is read-only and is
		/// assigned by Google when a mobile application is claimed.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The display name of the mobile application. This attribute is required and has a
		/// maximum length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string displayName {
			get {
				return this.displayNameField;
			}
			set {
				this.displayNameField = value;
			}
		}

		/// <summary>The app store ID of the app to claim. This attribute is required for creation
		/// and then is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string appStoreId {
			get {
				return this.appStoreIdField;
			}
			set {
				this.appStoreIdField = value;
			}
		}

		/// <summary>The app store the mobile application belongs to. This attribute is required for
		/// creation and then is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public MobileApplicationStore appStore {
			get {
				return this.appStoreField;
			}
			set {
				this.appStoreField = value;
				this.appStoreSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="appStore"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool appStoreSpecified {
			get {
				return this.appStoreFieldSpecified;
			}
			set {
				this.appStoreFieldSpecified = value;
			}
		}

		/// <summary>The archival status of the mobile application. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public bool isArchived {
			get {
				return this.isArchivedField;
			}
			set {
				this.isArchivedField = value;
				this.isArchivedSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isArchived"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isArchivedSpecified {
			get {
				return this.isArchivedFieldSpecified;
			}
			set {
				this.isArchivedFieldSpecified = value;
			}
		}

		/// <summary>The name of the application on the app store. This attribute is read-only and
		/// populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public string appStoreName {
			get {
				return this.appStoreNameField;
			}
			set {
				this.appStoreNameField = value;
			}
		}

		/// <summary>The name of the developer of the mobile application. This attribute is read-only
		/// and populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public string developerName {
			get {
				return this.developerNameField;
			}
			set {
				this.developerNameField = value;
			}
		}

		/// <summary>The platform the mobile application runs on. This attribute is read-only and
		/// populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public MobileApplicationPlatform platform {
			get {
				return this.platformField;
			}
			set {
				this.platformField = value;
				this.platformSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="platform"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool platformSpecified {
			get {
				return this.platformFieldSpecified;
			}
			set {
				this.platformFieldSpecified = value;
			}
		}

		/// <summary>Whether the mobile application is free on the app store it belongs to. This
		/// attribute is read-only and populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public bool isFree {
			get {
				return this.isFreeField;
			}
			set {
				this.isFreeField = value;
				this.isFreeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isFree" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isFreeSpecified {
			get {
				return this.isFreeFieldSpecified;
			}
			set {
				this.isFreeFieldSpecified = value;
			}
		}

		/// <summary>The download URL of the mobile application on the app store it belongs to. This
		/// attribute is read-only and populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public string downloadUrl {
			get {
				return this.downloadUrlField;
			}
			set {
				this.downloadUrlField = value;
			}
		}
	}


	/// <summary>A store a <a href='MobileApplication'>MobileApplication</a> is available on.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum MobileApplicationStore {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		APPLE_ITUNES = 1,
		GOOGLE_PLAY = 2,
	}


	/// <summary>A platform a <a href='MobileApplication'>MobileApplication</a> can run on.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum MobileApplicationPlatform {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		ANDROID = 1,
		IOS = 2,
	}


	/// <summary>Lists all errors associated with <a
	/// href='MobileApplication'>MobileApplication</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class MobileApplicationError : ApiError {
		private MobileApplicationErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public MobileApplicationErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the <a href='MobileApplication'>MobileApplication</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "MobileApplicationError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum MobileApplicationErrorReason {
		/// <summary>Could not find the ID of the app being claimed in any app stores.
		/// </summary>
		INVALID_APP_ID = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>Lists all error reasons associated with performing actions on <a
	/// href='MobileApplication'>MobileApplication</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class MobileApplicationActionError : ApiError {
		private MobileApplicationActionErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public MobileApplicationActionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "MobileApplicationActionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum MobileApplicationActionErrorReason {
		/// <summary>The operation is not applicable to the current mobile application status.
		/// </summary>
		NOT_APPLICABLE = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.MobileApplicationServiceInterface")]
	public interface MobileApplicationServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.MobileApplicationService.createMobileApplicationsResponse createMobileApplications(Wrappers.MobileApplicationService.createMobileApplicationsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.MobileApplicationService.createMobileApplicationsResponse> createMobileApplicationsAsync(Wrappers.MobileApplicationService.createMobileApplicationsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.MobileApplicationPage getMobileApplicationsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.MobileApplicationPage> getMobileApplicationsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performMobileApplicationAction(Google.Api.Ads.AdManager.v201802.MobileApplicationAction mobileApplicationAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performMobileApplicationActionAsync(Google.Api.Ads.AdManager.v201802.MobileApplicationAction mobileApplicationAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.MobileApplicationService.updateMobileApplicationsResponse updateMobileApplications(Wrappers.MobileApplicationService.updateMobileApplicationsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.MobileApplicationService.updateMobileApplicationsResponse> updateMobileApplicationsAsync(Wrappers.MobileApplicationService.updateMobileApplicationsRequest request);
	}


	/// <summary>Captures a page of <a href='MobileApplication'>mobile applications</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class MobileApplicationPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private MobileApplication[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of mobile applications contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public MobileApplication[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a
	/// href='MobileApplication'>mobile applications</a>.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ArchiveMobileApplications))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UnarchiveMobileApplications))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class MobileApplicationAction {
	}


	/// <summary>The action used to deactivate <a href='MobileApplication'>MobileApplication</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ArchiveMobileApplications : MobileApplicationAction {
	}


	/// <summary>The action used to activate <a href='MobileApplication'>MobileApplication</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UnarchiveMobileApplications : MobileApplicationAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface MobileApplicationServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.MobileApplicationServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for retrieving <a
	/// href='MobileApplication'>MobileApplication</a> objects.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class MobileApplicationService : AdManagerSoapClient<IMobileApplicationService>, IMobileApplicationService {
		/// <summary> Creates a new instance of the <see cref="MobileApplicationService"/>
		/// class. </summary>
		public MobileApplicationService() {
		}

		/// <summary> Creates a new instance of the <see cref="MobileApplicationService"/>
		/// class. </summary>
		public MobileApplicationService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="MobileApplicationService"/>
		/// class. </summary>
		public MobileApplicationService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="MobileApplicationService"/>
		/// class. </summary>
		public MobileApplicationService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="MobileApplicationService"/>
		/// class. </summary>
		public MobileApplicationService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.MobileApplicationService.createMobileApplicationsResponse Google.Api.Ads.AdManager.v201802.MobileApplicationServiceInterface.createMobileApplications(Wrappers.MobileApplicationService.createMobileApplicationsRequest request) {
			return base.Channel.createMobileApplications(request);
		}

		/// <summary>Creates and claims <a href='MobileApplication'>mobile applications</a> to be
		/// used for targeting in the network.
		/// </summary><param name='mobileApplications'>the mobileApplications to create</param>
		/// <returns>the created mobileApplications with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.MobileApplication[] createMobileApplications(Google.Api.Ads.AdManager.v201802.MobileApplication[] mobileApplications) {
			Wrappers.MobileApplicationService.createMobileApplicationsRequest inValue = new Wrappers.MobileApplicationService.createMobileApplicationsRequest();
			inValue.mobileApplications = mobileApplications;
			Wrappers.MobileApplicationService.createMobileApplicationsResponse retVal = ((Google.Api.Ads.AdManager.v201802.MobileApplicationServiceInterface)(this)).createMobileApplications(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.MobileApplicationService.createMobileApplicationsResponse> Google.Api.Ads.AdManager.v201802.MobileApplicationServiceInterface.createMobileApplicationsAsync(Wrappers.MobileApplicationService.createMobileApplicationsRequest request) {
			return base.Channel.createMobileApplicationsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.MobileApplication[]> createMobileApplicationsAsync(Google.Api.Ads.AdManager.v201802.MobileApplication[] mobileApplications) {
			Wrappers.MobileApplicationService.createMobileApplicationsRequest inValue = new Wrappers.MobileApplicationService.createMobileApplicationsRequest();
			inValue.mobileApplications = mobileApplications;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.MobileApplication[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.MobileApplicationServiceInterface)(this)).createMobileApplicationsAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='MobileApplicationPage'>mobileApplicationPage</a> of <a
		/// href='MobileApplication'>mobile applications</a> that satisfy the given <a
		/// href='Statement'>Statement</a>. The following fields are supported for
		/// filtering: <table> <tr> <th scope="col">PQL Property</th> <th scope="col">Object
		/// Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='MobileApplication#id'>MobileApplication#id</a></td> </tr> <tr>
		/// <td><code>displayName</code></td> <td><a
		/// href='MobileApplication#displayName'>MobileApplication#displayName</a></td>
		/// </tr> <tr> <td><code>appStore</code></td> <td><a
		/// href='MobileApplication#appStore'>MobileApplication#appStore</a></td> </tr> <tr>
		/// <td><code>appStoreId</code></td> <td><a
		/// href='MobileApplication#appStoreId'>MobileApplication#appStoreId</a></td> </tr>
		/// <tr> </tr><tr> <td><code>isArchived</code></td> <td><a
		/// href='MobileApplication#isArchived'>MobileApplication#isArchived</a></td> </tr>
		/// </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of mobile applications.</param>
		/// <returns>the mobile applications that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.MobileApplicationPage getMobileApplicationsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getMobileApplicationsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.MobileApplicationPage> getMobileApplicationsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getMobileApplicationsByStatementAsync(filterStatement);
		}

		/// <summary>Performs an action on <a href='MobileApplication'>mobile applications</a>.
		/// </summary><param name='mobileApplicationAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of mobile applications.</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performMobileApplicationAction(Google.Api.Ads.AdManager.v201802.MobileApplicationAction mobileApplicationAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performMobileApplicationAction(mobileApplicationAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performMobileApplicationActionAsync(Google.Api.Ads.AdManager.v201802.MobileApplicationAction mobileApplicationAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performMobileApplicationActionAsync(mobileApplicationAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.MobileApplicationService.updateMobileApplicationsResponse Google.Api.Ads.AdManager.v201802.MobileApplicationServiceInterface.updateMobileApplications(Wrappers.MobileApplicationService.updateMobileApplicationsRequest request) {
			return base.Channel.updateMobileApplications(request);
		}

		/// <summary>Updates the specified <a href='MobileApplication'>mobile applications</a>.
		/// </summary><param name='mobileApplications'>the mobile applications to be updated</param>
		/// <returns>the updated mobileApplications</returns>
		public virtual Google.Api.Ads.AdManager.v201802.MobileApplication[] updateMobileApplications(Google.Api.Ads.AdManager.v201802.MobileApplication[] mobileApplications) {
			Wrappers.MobileApplicationService.updateMobileApplicationsRequest inValue = new Wrappers.MobileApplicationService.updateMobileApplicationsRequest();
			inValue.mobileApplications = mobileApplications;
			Wrappers.MobileApplicationService.updateMobileApplicationsResponse retVal = ((Google.Api.Ads.AdManager.v201802.MobileApplicationServiceInterface)(this)).updateMobileApplications(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.MobileApplicationService.updateMobileApplicationsResponse> Google.Api.Ads.AdManager.v201802.MobileApplicationServiceInterface.updateMobileApplicationsAsync(Wrappers.MobileApplicationService.updateMobileApplicationsRequest request) {
			return base.Channel.updateMobileApplicationsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.MobileApplication[]> updateMobileApplicationsAsync(Google.Api.Ads.AdManager.v201802.MobileApplication[] mobileApplications) {
			Wrappers.MobileApplicationService.updateMobileApplicationsRequest inValue = new Wrappers.MobileApplicationService.updateMobileApplicationsRequest();
			inValue.mobileApplications = mobileApplications;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.MobileApplication[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.MobileApplicationServiceInterface)(this)).updateMobileApplicationsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.NetworkService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "getAllNetworks", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class getAllNetworksRequest {
			/// <summary> Creates a new instance of the <see cref="getAllNetworksRequest"/>
			/// class. </summary>
			public getAllNetworksRequest() {
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "getAllNetworksResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class getAllNetworksResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Network[] rval;

			/// <summary> Creates a new instance of the <see cref="getAllNetworksResponse"/>
			/// class. </summary>
			public getAllNetworksResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="getAllNetworksResponse"/>
			/// class. </summary>
			public getAllNetworksResponse(Google.Api.Ads.AdManager.v201802.Network[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary><code>Network</code> represents a network.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Network {
		private long idField;

		private bool idFieldSpecified;

		private string displayNameField;

		private string networkCodeField;

		private string propertyCodeField;

		private string timeZoneField;

		private string currencyCodeField;

		private string[] secondaryCurrencyCodesField;

		private string effectiveRootAdUnitIdField;

		private bool isTestField;

		private bool isTestFieldSpecified;

		/// <summary>The unique ID of the <code>Network</code>. This value is readonly and is
		/// assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The display name of the network.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string displayName {
			get {
				return this.displayNameField;
			}
			set {
				this.displayNameField = value;
			}
		}

		/// <summary>The network code. If the current login has access to multiple networks, then the
		/// network code must be provided in the SOAP request headers for all requests.
		/// Otherwise, it is optional to provide the network code in the SOAP headers. This
		/// field is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string networkCode {
			get {
				return this.networkCodeField;
			}
			set {
				this.networkCodeField = value;
			}
		}

		/// <summary>The property code. This field is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string propertyCode {
			get {
				return this.propertyCodeField;
			}
			set {
				this.propertyCodeField = value;
			}
		}

		/// <summary>The time zone associated with the delivery of orders and reporting. This field
		/// is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string timeZone {
			get {
				return this.timeZoneField;
			}
			set {
				this.timeZoneField = value;
			}
		}

		/// <summary>The primary currency code. This field is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public string currencyCode {
			get {
				return this.currencyCodeField;
			}
			set {
				this.currencyCodeField = value;
			}
		}

		/// <summary>Currencies that can be used as an alternative to the <a
		/// href='Network#currencyCode'>Network#currencyCode</a> for trafficking <a
		/// href='LineItem'>line items</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("secondaryCurrencyCodes", Order = 6)]
		public string[] secondaryCurrencyCodes {
			get {
				return this.secondaryCurrencyCodesField;
			}
			set {
				this.secondaryCurrencyCodesField = value;
			}
		}

		/// <summary>The <a href='AdUnit#id'>AdUnit#id</a> of the top most ad unit to which
		/// descendant ad units can be added. Should be used for the <a
		/// href='AdUnit#parentId'>AdUnit#parentId</a> when first building inventory
		/// hierarchy. This field is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public string effectiveRootAdUnitId {
			get {
				return this.effectiveRootAdUnitIdField;
			}
			set {
				this.effectiveRootAdUnitIdField = value;
			}
		}

		/// <summary>Whether this is a test network. This field is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public bool isTest {
			get {
				return this.isTestField;
			}
			set {
				this.isTestField = value;
				this.isTestSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isTest" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isTestSpecified {
			get {
				return this.isTestFieldSpecified;
			}
			set {
				this.isTestFieldSpecified = value;
			}
		}
	}


	/// <summary>Encapsulates the generic errors thrown when there's an error with user request.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RequestError : ApiError {
		private RequestErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public RequestErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "RequestError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RequestErrorReason {
		/// <summary>Error reason is unknown.
		/// </summary>
		UNKNOWN = 0,
		/// <summary>Invalid input.
		/// </summary>
		INVALID_INPUT = 1,
		/// <summary>The api version in the request has been discontinued. Please update to the new
		/// AdWords API version.
		/// </summary>
		UNSUPPORTED_VERSION = 2,
	}


	/// <summary>List all errors associated with number precisions.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PrecisionError : ApiError {
		private PrecisionErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public PrecisionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes reasons for precision errors.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "PrecisionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum PrecisionErrorReason {
		/// <summary>The lowest N digits of the number must be zero.
		/// </summary>
		WRONG_PRECISION = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>An error for a network.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class NetworkError : ApiError {
		private NetworkErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public NetworkErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Possible reasons for <a href='NetworkError'>NetworkError</a>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "NetworkError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum NetworkErrorReason {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		/// <summary>Multi-currency support is not enabled for this network. This is an Ad Manager
		/// 360 feature.
		/// </summary>
		MULTI_CURRENCY_NOT_SUPPORTED = 1,
		/// <summary>Currency provided is not supported.
		/// </summary>
		UNSUPPORTED_CURRENCY = 2,
		/// <summary>The network currency cannot also be specified as a secondary currency.
		/// </summary>
		NETWORK_CURRENCY_CANNOT_BE_SAME_AS_SECONDARY = 3,
		/// <summary>The currency cannot be deleted as it is still being used by active rate cards.
		/// </summary>
		CANNOT_DELETE_CURRENCY_WITH_ACTIVE_RATE_CARDS = 4,
	}


	/// <summary>Caused by supplying a value for an email attribute that is not a valid email
	/// address.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class InvalidEmailError : ApiError {
		private InvalidEmailErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public InvalidEmailErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes reasons for an email to be invalid.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "InvalidEmailError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum InvalidEmailErrorReason {
		/// <summary>The value is not a valid email address.
		/// </summary>
		INVALID_FORMAT = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.NetworkServiceInterface")]
	public interface NetworkServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.NetworkService.getAllNetworksResponse getAllNetworks(Wrappers.NetworkService.getAllNetworksRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.NetworkService.getAllNetworksResponse> getAllNetworksAsync(Wrappers.NetworkService.getAllNetworksRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.Network getCurrentNetwork();

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Network> getCurrentNetworkAsync();

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.Network makeTestNetwork();

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Network> makeTestNetworkAsync();

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.Network updateNetwork(Google.Api.Ads.AdManager.v201802.Network network);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Network> updateNetworkAsync(Google.Api.Ads.AdManager.v201802.Network network);
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface NetworkServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.NetworkServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides operations for retrieving information related to the publisher's
	/// networks. This service can be used to obtain the list of all networks that the
	/// current login has access to, or to obtain information about a specific network.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class NetworkService : AdManagerSoapClient<INetworkService>, INetworkService {
		/// <summary> Creates a new instance of the <see cref="NetworkService"/> class.
		/// </summary>
		public NetworkService() {
		}

		/// <summary> Creates a new instance of the <see cref="NetworkService"/> class.
		/// </summary>
		public NetworkService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="NetworkService"/> class.
		/// </summary>
		public NetworkService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="NetworkService"/> class.
		/// </summary>
		public NetworkService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="NetworkService"/> class.
		/// </summary>
		public NetworkService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.NetworkService.getAllNetworksResponse Google.Api.Ads.AdManager.v201802.NetworkServiceInterface.getAllNetworks(Wrappers.NetworkService.getAllNetworksRequest request) {
			return base.Channel.getAllNetworks(request);
		}

		/// <summary>Returns the list of <a href='Network'>Network</a> objects to which the current
		/// login has access. <p>Intended to be used without a network code in the SOAP
		/// header when the login may have more than one network associated with it.</p>
		/// </summary><returns>the networks to which the current login has access</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Network[] getAllNetworks() {
			Wrappers.NetworkService.getAllNetworksRequest inValue = new Wrappers.NetworkService.getAllNetworksRequest();
			Wrappers.NetworkService.getAllNetworksResponse retVal = ((Google.Api.Ads.AdManager.v201802.NetworkServiceInterface)(this)).getAllNetworks(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.NetworkService.getAllNetworksResponse> Google.Api.Ads.AdManager.v201802.NetworkServiceInterface.getAllNetworksAsync(Wrappers.NetworkService.getAllNetworksRequest request) {
			return base.Channel.getAllNetworksAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Network[]> getAllNetworksAsync() {
			Wrappers.NetworkService.getAllNetworksRequest inValue = new Wrappers.NetworkService.getAllNetworksRequest();
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Network[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.NetworkServiceInterface)(this)).getAllNetworksAsync(inValue)).Result.rval);
		}

		/// <summary>Returns the current network for which requests are being made.
		/// </summary><returns>the network for which the user is currently making the
		/// request</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Network getCurrentNetwork() {
			return base.Channel.getCurrentNetwork();
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Network> getCurrentNetworkAsync() {
			return base.Channel.getCurrentNetworkAsync();
		}

		/// <summary>Creates a new blank network for testing purposes using the current login.
		/// <p>Each login(i.e. email address) can only have one test network. Data from any
		/// of your existing networks will not be transferred to the new test network. Once
		/// the test network is created, the test network can be used in the API by
		/// supplying the <a href='Network#networkCode'>Network#networkCode</a> in the SOAP
		/// header or by logging into the Ad Manager UI.</p> <p>Test networks are limited in
		/// the following ways:</p> <ul> <li>Test networks cannot serve ads.</li>
		/// <li>Because test networks cannot serve ads, reports will always come back
		/// without data.</li> <li>Since forecasting requires serving history, forecast
		/// service results will be faked. See <a href='ForecastService'>ForecastService</a>
		/// for more info.</li> <li>Test networks are, by default, Ad Manager networks and
		/// don't have any features from Ad Manager 360. To have additional features turned
		/// on, please contact your account manager.</li> <li>Test networks are limited to
		/// 10,000 objects per entity type.</li> </ul> <br /> <br />
		/// </summary>
		public virtual Google.Api.Ads.AdManager.v201802.Network makeTestNetwork() {
			return base.Channel.makeTestNetwork();
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Network> makeTestNetworkAsync() {
			return base.Channel.makeTestNetworkAsync();
		}

		/// <summary>Updates the specified network. Currently, only the network display name can be
		/// updated.
		/// </summary><param name='network'>the network that needs to be updated</param>
		/// <returns>the updated network</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Network updateNetwork(Google.Api.Ads.AdManager.v201802.Network network) {
			return base.Channel.updateNetwork(network);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Network> updateNetworkAsync(Google.Api.Ads.AdManager.v201802.Network network) {
			return base.Channel.updateNetworkAsync(network);
		}
	}
	namespace Wrappers.OrderService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createOrders", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createOrdersRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("orders")]
			public Google.Api.Ads.AdManager.v201802.Order[] orders;

			/// <summary> Creates a new instance of the <see cref="createOrdersRequest"/> class.
			/// </summary>
			public createOrdersRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createOrdersRequest"/> class.
			/// </summary>
			public createOrdersRequest(Google.Api.Ads.AdManager.v201802.Order[] orders) {
				this.orders = orders;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createOrdersResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createOrdersResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Order[] rval;

			/// <summary> Creates a new instance of the <see cref="createOrdersResponse"/>
			/// class. </summary>
			public createOrdersResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createOrdersResponse"/>
			/// class. </summary>
			public createOrdersResponse(Google.Api.Ads.AdManager.v201802.Order[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateOrders", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateOrdersRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("orders")]
			public Google.Api.Ads.AdManager.v201802.Order[] orders;

			/// <summary> Creates a new instance of the <see cref="updateOrdersRequest"/> class.
			/// </summary>
			public updateOrdersRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updateOrdersRequest"/> class.
			/// </summary>
			public updateOrdersRequest(Google.Api.Ads.AdManager.v201802.Order[] orders) {
				this.orders = orders;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateOrdersResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateOrdersResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Order[] rval;

			/// <summary> Creates a new instance of the <see cref="updateOrdersResponse"/>
			/// class. </summary>
			public updateOrdersResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updateOrdersResponse"/>
			/// class. </summary>
			public updateOrdersResponse(Google.Api.Ads.AdManager.v201802.Order[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>An <code>Order</code> represents a grouping of individual <a
	/// href='LineItem'>LineItem</a> objects, each of which fulfill an ad request from a
	/// particular advertiser.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Order {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private DateTime startDateTimeField;

		private DateTime endDateTimeField;

		private bool unlimitedEndDateTimeField;

		private bool unlimitedEndDateTimeFieldSpecified;

		private OrderStatus statusField;

		private bool statusFieldSpecified;

		private bool isArchivedField;

		private bool isArchivedFieldSpecified;

		private string notesField;

		private int externalOrderIdField;

		private bool externalOrderIdFieldSpecified;

		private string poNumberField;

		private string currencyCodeField;

		private long advertiserIdField;

		private bool advertiserIdFieldSpecified;

		private long[] advertiserContactIdsField;

		private long agencyIdField;

		private bool agencyIdFieldSpecified;

		private long[] agencyContactIdsField;

		private long creatorIdField;

		private bool creatorIdFieldSpecified;

		private long traffickerIdField;

		private bool traffickerIdFieldSpecified;

		private long[] secondaryTraffickerIdsField;

		private long salespersonIdField;

		private bool salespersonIdFieldSpecified;

		private long[] secondarySalespersonIdsField;

		private long totalImpressionsDeliveredField;

		private bool totalImpressionsDeliveredFieldSpecified;

		private long totalClicksDeliveredField;

		private bool totalClicksDeliveredFieldSpecified;

		private long totalViewableImpressionsDeliveredField;

		private bool totalViewableImpressionsDeliveredFieldSpecified;

		private Money totalBudgetField;

		private AppliedLabel[] appliedLabelsField;

		private AppliedLabel[] effectiveAppliedLabelsField;

		private string lastModifiedByAppField;

		private bool isProgrammaticField;

		private bool isProgrammaticFieldSpecified;

		private long[] appliedTeamIdsField;

		private DateTime lastModifiedDateTimeField;

		private BaseCustomFieldValue[] customFieldValuesField;

		/// <summary>The unique ID of the <code>Order</code>. This value is readonly and is assigned
		/// by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the <code>Order</code>. This value is required to create an order
		/// and has a maximum length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The date and time at which the <code>Order</code> and its associated line items
		/// are eligible to begin serving. This attribute is readonly and is derived from
		/// the line item of the order which has the earliest <a
		/// href='LineItem#startDateTime'>LineItem#startDateTime</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public DateTime startDateTime {
			get {
				return this.startDateTimeField;
			}
			set {
				this.startDateTimeField = value;
			}
		}

		/// <summary>The date and time at which the <code>Order</code> and its associated line items
		/// stop being served. This attribute is readonly and is derived from the line item
		/// of the order which has the latest <a
		/// href='LineItem#endDateTime'>LineItem#endDateTime</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public DateTime endDateTime {
			get {
				return this.endDateTimeField;
			}
			set {
				this.endDateTimeField = value;
			}
		}

		/// <summary>Specifies whether or not the <code>Order</code> has an unlimited end date. This
		/// attribute is readonly and is <code>true</code> if any of the order's line items
		/// has <a href='LineItem#unlimitedEndDateTime'>LineItem#unlimitedEndDateTime</a>
		/// set to <code>true</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public bool unlimitedEndDateTime {
			get {
				return this.unlimitedEndDateTimeField;
			}
			set {
				this.unlimitedEndDateTimeField = value;
				this.unlimitedEndDateTimeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="unlimitedEndDateTime" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool unlimitedEndDateTimeSpecified {
			get {
				return this.unlimitedEndDateTimeFieldSpecified;
			}
			set {
				this.unlimitedEndDateTimeFieldSpecified = value;
			}
		}

		/// <summary>The status of the <code>Order</code>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public OrderStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>The archival status of the <code>Order</code>. This attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public bool isArchived {
			get {
				return this.isArchivedField;
			}
			set {
				this.isArchivedField = value;
				this.isArchivedSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isArchived"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isArchivedSpecified {
			get {
				return this.isArchivedFieldSpecified;
			}
			set {
				this.isArchivedFieldSpecified = value;
			}
		}

		/// <summary>Provides any additional notes that may annotate the <code>Order</code>. This
		/// attribute is optional and has a maximum length of 65,535 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public string notes {
			get {
				return this.notesField;
			}
			set {
				this.notesField = value;
			}
		}

		/// <summary>An arbitrary ID to associate to the <code>Order</code>, which can be used as a
		/// key to an external system. This value is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public int externalOrderId {
			get {
				return this.externalOrderIdField;
			}
			set {
				this.externalOrderIdField = value;
				this.externalOrderIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="externalOrderId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool externalOrderIdSpecified {
			get {
				return this.externalOrderIdFieldSpecified;
			}
			set {
				this.externalOrderIdFieldSpecified = value;
			}
		}

		/// <summary>The purchase order number for the <code>Order</code>. This value is optional and
		/// has a maximum length of 63 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public string poNumber {
			get {
				return this.poNumberField;
			}
			set {
				this.poNumberField = value;
			}
		}

		/// <summary>The ISO currency code for the currency used by the <code>Order</code>. This
		/// value is read-only and is the network's currency code.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public string currencyCode {
			get {
				return this.currencyCodeField;
			}
			set {
				this.currencyCodeField = value;
			}
		}

		/// <summary>The unique ID of the <a href='Company'>Company</a>, which is of type <a
		/// href='Company.Type#ADVERTISER'>Company.Type#ADVERTISER</a>, to which this order
		/// belongs. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 11)]
		public long advertiserId {
			get {
				return this.advertiserIdField;
			}
			set {
				this.advertiserIdField = value;
				this.advertiserIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="advertiserId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool advertiserIdSpecified {
			get {
				return this.advertiserIdFieldSpecified;
			}
			set {
				this.advertiserIdFieldSpecified = value;
			}
		}

		/// <summary>List of IDs for advertiser contacts of the order.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("advertiserContactIds", Order = 12)]
		public long[] advertiserContactIds {
			get {
				return this.advertiserContactIdsField;
			}
			set {
				this.advertiserContactIdsField = value;
			}
		}

		/// <summary>The unique ID of the <a href='Company'>Company</a>, which is of type <a
		/// href='Company.Type#AGENCY'>Company.Type#AGENCY</a>, with which this order is
		/// associated. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 13)]
		public long agencyId {
			get {
				return this.agencyIdField;
			}
			set {
				this.agencyIdField = value;
				this.agencyIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="agencyId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool agencyIdSpecified {
			get {
				return this.agencyIdFieldSpecified;
			}
			set {
				this.agencyIdFieldSpecified = value;
			}
		}

		/// <summary>List of IDs for agency contacts of the order.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("agencyContactIds", Order = 14)]
		public long[] agencyContactIds {
			get {
				return this.agencyContactIdsField;
			}
			set {
				this.agencyContactIdsField = value;
			}
		}

		/// <summary>The unique ID of the <a href='User'>User</a> who created the <code></code> on
		/// behalf of the advertiser. This value is readonly and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 15)]
		public long creatorId {
			get {
				return this.creatorIdField;
			}
			set {
				this.creatorIdField = value;
				this.creatorIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="creatorId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool creatorIdSpecified {
			get {
				return this.creatorIdFieldSpecified;
			}
			set {
				this.creatorIdFieldSpecified = value;
			}
		}

		/// <summary>The unique ID of the <a href='User'>User</a> responsible for trafficking the
		/// <code>Order</code>. This value is required for creating an order.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 16)]
		public long traffickerId {
			get {
				return this.traffickerIdField;
			}
			set {
				this.traffickerIdField = value;
				this.traffickerIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="traffickerId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool traffickerIdSpecified {
			get {
				return this.traffickerIdFieldSpecified;
			}
			set {
				this.traffickerIdFieldSpecified = value;
			}
		}

		/// <summary>The IDs of the secondary traffickers associated with the order. This value is
		/// optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("secondaryTraffickerIds", Order = 17)]
		public long[] secondaryTraffickerIds {
			get {
				return this.secondaryTraffickerIdsField;
			}
			set {
				this.secondaryTraffickerIdsField = value;
			}
		}

		/// <summary>The unique ID of the <a href='User'>User</a> responsible for the sales of the
		/// <code>Order</code>. This value is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 18)]
		public long salespersonId {
			get {
				return this.salespersonIdField;
			}
			set {
				this.salespersonIdField = value;
				this.salespersonIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="salespersonId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool salespersonIdSpecified {
			get {
				return this.salespersonIdFieldSpecified;
			}
			set {
				this.salespersonIdFieldSpecified = value;
			}
		}

		/// <summary>The IDs of the secondary salespeople associated with the order. This value is
		/// optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("secondarySalespersonIds", Order = 19)]
		public long[] secondarySalespersonIds {
			get {
				return this.secondarySalespersonIdsField;
			}
			set {
				this.secondarySalespersonIdsField = value;
			}
		}

		/// <summary>Total impressions delivered for all line items of this <code></code>. This value
		/// is read-only and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 20)]
		public long totalImpressionsDelivered {
			get {
				return this.totalImpressionsDeliveredField;
			}
			set {
				this.totalImpressionsDeliveredField = value;
				this.totalImpressionsDeliveredSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalImpressionsDelivered" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalImpressionsDeliveredSpecified {
			get {
				return this.totalImpressionsDeliveredFieldSpecified;
			}
			set {
				this.totalImpressionsDeliveredFieldSpecified = value;
			}
		}

		/// <summary>Total clicks delivered for all line items of this <code>Order</code>. This value
		/// is read-only and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 21)]
		public long totalClicksDelivered {
			get {
				return this.totalClicksDeliveredField;
			}
			set {
				this.totalClicksDeliveredField = value;
				this.totalClicksDeliveredSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalClicksDelivered" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalClicksDeliveredSpecified {
			get {
				return this.totalClicksDeliveredFieldSpecified;
			}
			set {
				this.totalClicksDeliveredFieldSpecified = value;
			}
		}

		/// <summary>Total viewable impressions delivered for all line items of this
		/// <code>Order</code>. This value is read-only and is assigned by Google. Starting
		/// in v201705, this will be <code>null</code> when the order does not have line
		/// items trafficked against a viewable impressions goal.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 22)]
		public long totalViewableImpressionsDelivered {
			get {
				return this.totalViewableImpressionsDeliveredField;
			}
			set {
				this.totalViewableImpressionsDeliveredField = value;
				this.totalViewableImpressionsDeliveredSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalViewableImpressionsDelivered" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalViewableImpressionsDeliveredSpecified {
			get {
				return this.totalViewableImpressionsDeliveredFieldSpecified;
			}
			set {
				this.totalViewableImpressionsDeliveredFieldSpecified = value;
			}
		}

		/// <summary>Total budget for all line items of this <code>Order</code>. This value is a
		/// readonly field assigned by Google and is calculated from the associated <a
		/// href='LineItem#costPerUnit'>LineItem#costPerUnit</a> values.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 23)]
		public Money totalBudget {
			get {
				return this.totalBudgetField;
			}
			set {
				this.totalBudgetField = value;
			}
		}

		/// <summary>The set of labels applied directly to this order.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("appliedLabels", Order = 24)]
		public AppliedLabel[] appliedLabels {
			get {
				return this.appliedLabelsField;
			}
			set {
				this.appliedLabelsField = value;
			}
		}

		/// <summary>Contains the set of labels applied directly to the order as well as those
		/// inherited from the company that owns the order. If a label has been negated,
		/// only the negated label is returned. This field is readonly and is assigned by
		/// Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("effectiveAppliedLabels", Order = 25)]
		public AppliedLabel[] effectiveAppliedLabels {
			get {
				return this.effectiveAppliedLabelsField;
			}
			set {
				this.effectiveAppliedLabelsField = value;
			}
		}

		/// <summary>The application which modified this order. This attribute is read only and is
		/// assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 26)]
		public string lastModifiedByApp {
			get {
				return this.lastModifiedByAppField;
			}
			set {
				this.lastModifiedByAppField = value;
			}
		}

		/// <summary>Specifies whether or not the <code>Order</code> is a programmatic order. This
		/// value is optional and defaults to false.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 27)]
		public bool isProgrammatic {
			get {
				return this.isProgrammaticField;
			}
			set {
				this.isProgrammaticField = value;
				this.isProgrammaticSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isProgrammatic" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isProgrammaticSpecified {
			get {
				return this.isProgrammaticFieldSpecified;
			}
			set {
				this.isProgrammaticFieldSpecified = value;
			}
		}

		/// <summary>The IDs of all teams that this order is on directly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("appliedTeamIds", Order = 28)]
		public long[] appliedTeamIds {
			get {
				return this.appliedTeamIdsField;
			}
			set {
				this.appliedTeamIdsField = value;
			}
		}

		/// <summary>The date and time this order was last modified.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 29)]
		public DateTime lastModifiedDateTime {
			get {
				return this.lastModifiedDateTimeField;
			}
			set {
				this.lastModifiedDateTimeField = value;
			}
		}

		/// <summary>The values of the custom fields associated with this order.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("customFieldValues", Order = 30)]
		public BaseCustomFieldValue[] customFieldValues {
			get {
				return this.customFieldValuesField;
			}
			set {
				this.customFieldValuesField = value;
			}
		}
	}


	/// <summary>Describes the order statuses.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum OrderStatus {
		/// <summary>Indicates that the <a href='Order'>Order</a> has just been created but no
		/// approval has been requested yet.
		/// </summary>
		DRAFT = 0,
		/// <summary>Indicates that a request for approval for the <a href='Order'>Order</a> has been
		/// made.
		/// </summary>
		PENDING_APPROVAL = 1,
		/// <summary>Indicates that the <a href='Order'>Order</a> has been approved and is ready to
		/// serve.
		/// </summary>
		APPROVED = 2,
		/// <summary>Indicates that the <a href='Order'>Order</a> has been disapproved and is not
		/// eligible to serve.
		/// </summary>
		DISAPPROVED = 3,
		/// <summary>This is a legacy state. Paused status should be checked on <a
		/// href='LineItems'>LineItems</a>s within the order.
		/// </summary>
		PAUSED = 4,
		/// <summary>Indicates that the <a href='Order'>Order</a> has been canceled and cannot serve.
		/// </summary>
		CANCELED = 5,
		/// <summary>Indicates that the <a href='Order'>Order</a> has been deleted by DSM.
		/// </summary>
		DELETED = 6,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 7,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.OrderServiceInterface")]
	public interface OrderServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.OrderService.createOrdersResponse createOrders(Wrappers.OrderService.createOrdersRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.OrderService.createOrdersResponse> createOrdersAsync(Wrappers.OrderService.createOrdersRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.OrderPage getOrdersByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.OrderPage> getOrdersByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performOrderAction(Google.Api.Ads.AdManager.v201802.OrderAction orderAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performOrderActionAsync(Google.Api.Ads.AdManager.v201802.OrderAction orderAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.OrderService.updateOrdersResponse updateOrders(Wrappers.OrderService.updateOrdersRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.OrderService.updateOrdersResponse> updateOrdersAsync(Wrappers.OrderService.updateOrdersRequest request);
	}


	/// <summary>Captures a page of <a href='Order'>Order</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class OrderPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private Order[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of orders contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public Order[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a href='Order'>Order</a>
	/// objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UnarchiveOrders))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SubmitOrdersForApprovalWithoutReservationChanges))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SubmitOrdersForApproval))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SubmitOrdersForApprovalAndOverbook))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RetractOrdersWithoutReservationChanges))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RetractOrders))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ResumeOrders))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ResumeAndOverbookOrders))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(PauseOrders))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DisapproveOrdersWithoutReservationChanges))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DisapproveOrders))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeleteOrders))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ArchiveOrders))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ApproveOrdersWithoutReservationChanges))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ApproveOrders))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ApproveAndOverbookOrders))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class OrderAction {
	}


	/// <summary>The action used for unarchiving <a href='Order'>Order</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UnarchiveOrders : OrderAction {
	}


	/// <summary>The action used for submitting <a href='Order'>Order</a> objects for approval.
	/// This action does not make any changes to the <a
	/// href='LineItem#reservationStatus'>LineItem#reservationStatus</a> of the line
	/// items within the order.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SubmitOrdersForApprovalWithoutReservationChanges : OrderAction {
	}


	/// <summary>The action used for submitting <a href='Order'>Order</a> objects for approval.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SubmitOrdersForApprovalAndOverbook))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SubmitOrdersForApproval : OrderAction {
		private bool skipInventoryCheckField;

		private bool skipInventoryCheckFieldSpecified;

		/// <summary>Indicates whether the inventory check should be skipped when performing this
		/// action. The default value is false.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool skipInventoryCheck {
			get {
				return this.skipInventoryCheckField;
			}
			set {
				this.skipInventoryCheckField = value;
				this.skipInventoryCheckSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="skipInventoryCheck" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool skipInventoryCheckSpecified {
			get {
				return this.skipInventoryCheckFieldSpecified;
			}
			set {
				this.skipInventoryCheckFieldSpecified = value;
			}
		}
	}


	/// <summary>The action used for submitting and overbooking <a href='Order'>Order</a> objects
	/// for approval.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SubmitOrdersForApprovalAndOverbook : SubmitOrdersForApproval {
	}


	/// <summary>The action used for retracting <a href='Order'>Order</a> objects. This action
	/// does not make any changes to the <a
	/// href='LineItem#reservationStatus'>LineItem#reservationStatus</a> of the line
	/// items within the order.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RetractOrdersWithoutReservationChanges : OrderAction {
	}


	/// <summary>The action used for retracting <a href='Order'>Order</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RetractOrders : OrderAction {
	}


	/// <summary>The action used for resuming <a href='Order'>Order</a> objects. <a
	/// href='LineItem'>LineItem</a> objects within the order that are eligble to resume
	/// will resume as well.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ResumeAndOverbookOrders))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ResumeOrders : OrderAction {
		private bool skipInventoryCheckField;

		private bool skipInventoryCheckFieldSpecified;

		/// <summary>Indicates whether the inventory check should be skipped when performing this
		/// action. The default value is false.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool skipInventoryCheck {
			get {
				return this.skipInventoryCheckField;
			}
			set {
				this.skipInventoryCheckField = value;
				this.skipInventoryCheckSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="skipInventoryCheck" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool skipInventoryCheckSpecified {
			get {
				return this.skipInventoryCheckFieldSpecified;
			}
			set {
				this.skipInventoryCheckFieldSpecified = value;
			}
		}
	}


	/// <summary>The action used for resuming and overbooking <a href='Order'>Order</a> objects.
	/// All <a href='LineItem'>LineItem</a> objects within the order will resume as
	/// well.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ResumeAndOverbookOrders : ResumeOrders {
	}


	/// <summary>The action used for pausing all <a href='LineItem'>LineItem</a> objects within
	/// an order.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PauseOrders : OrderAction {
	}


	/// <summary>The action used for disapproving <a href='Order'>Order</a> objects. All <a
	/// href='LineItem'>LineItem</a> objects within the order will be disapproved as
	/// well. This action does not make any changes to the <a
	/// href='LineItem#reservationStatus'>LineItem#reservationStatus</a> of the line
	/// items within the order.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DisapproveOrdersWithoutReservationChanges : OrderAction {
	}


	/// <summary>The action used for disapproving <a href='Order'>Order</a> objects. All <a
	/// href='LineItem'>LineItem</a> objects within the order will be disapproved as
	/// well.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DisapproveOrders : OrderAction {
	}


	/// <summary>The action used for deleting <a href='Order'>Order</a> objects. All line items
	/// within that order are also deleted. Orders can only be deleted if none of its
	/// line items have been eligible to serve. This action can be used to delete
	/// proposed orders and line items if they are no longer valid.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeleteOrders : OrderAction {
	}


	/// <summary>The action used for archiving <a href='Order'>Order</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ArchiveOrders : OrderAction {
	}


	/// <summary>The action used for approving <a href='Order'>Order</a> objects. All <a
	/// href='LineItem'>LineItem</a> objects within the order will be approved as well.
	/// This action does not make any changes to the <a
	/// href='LineItem#reservationStatus'>LineItem#reservationStatus</a> of the line
	/// items within the order. If there are reservable line items that have not been
	/// reserved the operation will not succeed.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ApproveOrdersWithoutReservationChanges : OrderAction {
	}


	/// <summary>The action used for approving <a href='Order'>Order</a> objects. All <a
	/// href='LineItem'>LineItem</a> objects within the order will be approved as well.
	/// For more information on what happens to an order and its line items when it is
	/// approved, see the <a
	/// href="https://support.google.com/dfp_premium/answer/177334">Ad Manager Help
	/// Center</a>. <br /> <br />
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ApproveAndOverbookOrders))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ApproveOrders : OrderAction {
		private bool skipInventoryCheckField;

		private bool skipInventoryCheckFieldSpecified;

		/// <summary>Indicates whether the inventory check should be skipped when performing this
		/// action. The default value is false.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool skipInventoryCheck {
			get {
				return this.skipInventoryCheckField;
			}
			set {
				this.skipInventoryCheckField = value;
				this.skipInventoryCheckSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="skipInventoryCheck" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool skipInventoryCheckSpecified {
			get {
				return this.skipInventoryCheckFieldSpecified;
			}
			set {
				this.skipInventoryCheckFieldSpecified = value;
			}
		}
	}


	/// <summary>The action used for approving and overbooking <a href='Order'>Order</a> objects.
	/// All <a href='LineItem'>LineItem</a> objects within the order will be approved as
	/// well. For more information on what happens to an order and its line items when
	/// it is approved and overbooked, see the <a
	/// href="https://support.google.com/dfp_premium/answer/177334">Ad Manager Help
	/// Center</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ApproveAndOverbookOrders : ApproveOrders {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface OrderServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.OrderServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating, updating and retrieving <a href='Order'>Order</a>
	/// objects. <p>An order is a grouping of <a href='LineItem'>LineItem</a> objects.
	/// Line items have a many-to-one relationship with orders, meaning each line item
	/// can belong to only one order, but orders can have multiple line items. An order
	/// can be used to manage the line items it contains.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class OrderService : AdManagerSoapClient<IOrderService>, IOrderService {
		/// <summary> Creates a new instance of the <see cref="OrderService"/> class.
		/// </summary>
		public OrderService() {
		}

		/// <summary> Creates a new instance of the <see cref="OrderService"/> class.
		/// </summary>
		public OrderService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="OrderService"/> class.
		/// </summary>
		public OrderService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="OrderService"/> class.
		/// </summary>
		public OrderService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="OrderService"/> class.
		/// </summary>
		public OrderService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.OrderService.createOrdersResponse Google.Api.Ads.AdManager.v201802.OrderServiceInterface.createOrders(Wrappers.OrderService.createOrdersRequest request) {
			return base.Channel.createOrders(request);
		}

		/// <summary>Creates new <a href='Order'>Order</a> objects.
		/// </summary><param name='orders'>the orders to create</param>
		/// <returns>the created orders with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Order[] createOrders(Google.Api.Ads.AdManager.v201802.Order[] orders) {
			Wrappers.OrderService.createOrdersRequest inValue = new Wrappers.OrderService.createOrdersRequest();
			inValue.orders = orders;
			Wrappers.OrderService.createOrdersResponse retVal = ((Google.Api.Ads.AdManager.v201802.OrderServiceInterface)(this)).createOrders(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.OrderService.createOrdersResponse> Google.Api.Ads.AdManager.v201802.OrderServiceInterface.createOrdersAsync(Wrappers.OrderService.createOrdersRequest request) {
			return base.Channel.createOrdersAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Order[]> createOrdersAsync(Google.Api.Ads.AdManager.v201802.Order[] orders) {
			Wrappers.OrderService.createOrdersRequest inValue = new Wrappers.OrderService.createOrdersRequest();
			inValue.orders = orders;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Order[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.OrderServiceInterface)(this)).createOrdersAsync(inValue)).Result.rval);
		}

		/// <summary>Gets an <a href='OrderPage'>OrderPage</a> of <a href='Order'>Order</a> objects
		/// that satisfy the given <a href='Statement#query'>Statement#query</a>. The
		/// following fields are supported for filtering: <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>advertiserId</code></td> <td><a
		/// href='Order#advertiserId'>Order#advertiserId</a></td> </tr> <tr>
		/// <td><code>endDateTime</code></td> <td><a
		/// href='Order#endDateTime'>Order#endDateTime</a></td> </tr> <tr>
		/// <td><code>id</code></td> <td><a href='Order#id'>Order#id</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a href='Order#name'>Order#name</a></td> </tr>
		/// <tr> <td><code>salespersonId</code></td> <td><a
		/// href='Order#salespersonId'>Order#salespersonId</a></td> </tr> <tr>
		/// <td><code>startDateTime</code></td> <td><a
		/// href='Order#startDateTime'>Order#startDateTime</a></td> </tr> <tr>
		/// <td><code>status</code></td> <td><a href='Order#status'>Order#status</a></td>
		/// </tr> <tr> <td><code>traffickerId</code></td> <td><a
		/// href='Order#traffickerId'>Order#traffickerId</a></td> </tr> <tr>
		/// <td><code>lastModifiedDateTime</code></td> <td><a
		/// href='Order#lastModifiedDateTime'>Order#lastModifiedDateTime</a></td> </tr>
		/// </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of orders</param>
		/// <returns>the orders that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.OrderPage getOrdersByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getOrdersByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.OrderPage> getOrdersByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getOrdersByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='Order'>Order</a> objects that match the given <a
		/// href='Statement#query'>Statement#query</a>.
		/// </summary><param name='orderAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of orders</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performOrderAction(Google.Api.Ads.AdManager.v201802.OrderAction orderAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performOrderAction(orderAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performOrderActionAsync(Google.Api.Ads.AdManager.v201802.OrderAction orderAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performOrderActionAsync(orderAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.OrderService.updateOrdersResponse Google.Api.Ads.AdManager.v201802.OrderServiceInterface.updateOrders(Wrappers.OrderService.updateOrdersRequest request) {
			return base.Channel.updateOrders(request);
		}

		/// <summary>Updates the specified <a href='Order'>Order</a> objects.
		/// </summary><param name='orders'>the orders to update</param>
		/// <returns>the updated orders</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Order[] updateOrders(Google.Api.Ads.AdManager.v201802.Order[] orders) {
			Wrappers.OrderService.updateOrdersRequest inValue = new Wrappers.OrderService.updateOrdersRequest();
			inValue.orders = orders;
			Wrappers.OrderService.updateOrdersResponse retVal = ((Google.Api.Ads.AdManager.v201802.OrderServiceInterface)(this)).updateOrders(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.OrderService.updateOrdersResponse> Google.Api.Ads.AdManager.v201802.OrderServiceInterface.updateOrdersAsync(Wrappers.OrderService.updateOrdersRequest request) {
			return base.Channel.updateOrdersAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Order[]> updateOrdersAsync(Google.Api.Ads.AdManager.v201802.Order[] orders) {
			Wrappers.OrderService.updateOrdersRequest inValue = new Wrappers.OrderService.updateOrdersRequest();
			inValue.orders = orders;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Order[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.OrderServiceInterface)(this)).updateOrdersAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.PlacementService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createPlacements", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createPlacementsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("placements")]
			public Google.Api.Ads.AdManager.v201802.Placement[] placements;

			/// <summary> Creates a new instance of the <see cref="createPlacementsRequest"/>
			/// class. </summary>
			public createPlacementsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createPlacementsRequest"/>
			/// class. </summary>
			public createPlacementsRequest(Google.Api.Ads.AdManager.v201802.Placement[] placements) {
				this.placements = placements;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createPlacementsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createPlacementsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Placement[] rval;

			/// <summary> Creates a new instance of the <see cref="createPlacementsResponse"/>
			/// class. </summary>
			public createPlacementsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createPlacementsResponse"/>
			/// class. </summary>
			public createPlacementsResponse(Google.Api.Ads.AdManager.v201802.Placement[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updatePlacements", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updatePlacementsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("placements")]
			public Google.Api.Ads.AdManager.v201802.Placement[] placements;

			/// <summary> Creates a new instance of the <see cref="updatePlacementsRequest"/>
			/// class. </summary>
			public updatePlacementsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updatePlacementsRequest"/>
			/// class. </summary>
			public updatePlacementsRequest(Google.Api.Ads.AdManager.v201802.Placement[] placements) {
				this.placements = placements;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updatePlacementsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updatePlacementsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Placement[] rval;

			/// <summary> Creates a new instance of the <see cref="updatePlacementsResponse"/>
			/// class. </summary>
			public updatePlacementsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updatePlacementsResponse"/>
			/// class. </summary>
			public updatePlacementsResponse(Google.Api.Ads.AdManager.v201802.Placement[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>Contains information required for AdWords advertisers to place their ads.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(Placement))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SiteTargetingInfo {
	}


	/// <summary>A <code>Placement</code> groups related <code>AdUnit</code> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Placement : SiteTargetingInfo {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private string descriptionField;

		private string placementCodeField;

		private InventoryStatus statusField;

		private bool statusFieldSpecified;

		private string[] targetedAdUnitIdsField;

		private DateTime lastModifiedDateTimeField;

		/// <summary>Uniquely identifies the <code>Placement</code>. This attribute is read-only and
		/// is assigned by Google when a placement is created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the <code>Placement</code>. This value is required and has a maximum
		/// length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>A description of the <code>Placement</code>. This value is optional and its
		/// maximum length is 65,535 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string description {
			get {
				return this.descriptionField;
			}
			set {
				this.descriptionField = value;
			}
		}

		/// <summary>A string used to uniquely identify the <code>Placement</code> for purposes of
		/// serving the ad. This attribute is read-only and is assigned by Google when a
		/// placement is created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string placementCode {
			get {
				return this.placementCodeField;
			}
			set {
				this.placementCodeField = value;
			}
		}

		/// <summary>The status of the <code>Placement</code>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public InventoryStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>The collection of <code>AdUnit</code> object IDs that constitute the
		/// <code>Placement</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("targetedAdUnitIds", Order = 5)]
		public string[] targetedAdUnitIds {
			get {
				return this.targetedAdUnitIdsField;
			}
			set {
				this.targetedAdUnitIdsField = value;
			}
		}

		/// <summary>The date and time this placement was last modified.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public DateTime lastModifiedDateTime {
			get {
				return this.lastModifiedDateTimeField;
			}
			set {
				this.lastModifiedDateTimeField = value;
			}
		}
	}


	/// <summary>Class defining all validation errors for a placement.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PlacementError : ApiError {
		private PlacementErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public PlacementErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Possible reasons for the error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "PlacementError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum PlacementErrorReason {
		/// <summary>Entity type is something other than inventory or content.
		/// </summary>
		INVALID_ENTITY_TYPE = 0,
		/// <summary>Shared inventory cannot be assigned to a placement.
		/// </summary>
		SHARED_INVENTORY_ASSIGNED = 1,
		/// <summary>Shared inventory from one distributor network cannot be in the same placement
		/// with inventory from another distributor.
		/// </summary>
		PLACEMENTS_CANNOT_INCLUDE_INVENTORY_FROM_MULTIPLE_DISTRIBUTOR_NETWORKS = 2,
		/// <summary>Shared inventory and local inventory cannot be in the same placement.
		/// </summary>
		PLACEMENTS_CANNOT_INCLUDE_BOTH_LOCAL_AND_SHARED_INVENTORY = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.PlacementServiceInterface")]
	public interface PlacementServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(SiteTargetingInfo))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.PlacementService.createPlacementsResponse createPlacements(Wrappers.PlacementService.createPlacementsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.PlacementService.createPlacementsResponse> createPlacementsAsync(Wrappers.PlacementService.createPlacementsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(SiteTargetingInfo))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.PlacementPage getPlacementsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.PlacementPage> getPlacementsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(SiteTargetingInfo))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performPlacementAction(Google.Api.Ads.AdManager.v201802.PlacementAction placementAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performPlacementActionAsync(Google.Api.Ads.AdManager.v201802.PlacementAction placementAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(SiteTargetingInfo))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.PlacementService.updatePlacementsResponse updatePlacements(Wrappers.PlacementService.updatePlacementsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.PlacementService.updatePlacementsResponse> updatePlacementsAsync(Wrappers.PlacementService.updatePlacementsRequest request);
	}


	/// <summary>Captures a page of <a href='Placement'>Placement</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PlacementPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private Placement[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of placements contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public Placement[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a
	/// href='Placement'>Placement</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeactivatePlacements))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ArchivePlacements))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivatePlacements))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class PlacementAction {
	}


	/// <summary>The action used for deactivating <a href='Placement'>Placement</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeactivatePlacements : PlacementAction {
	}


	/// <summary>The action used for archiving <a href='Placement'>Placement</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ArchivePlacements : PlacementAction {
	}


	/// <summary>The action used for activating <a href='Placement'>Placement</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivatePlacements : PlacementAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface PlacementServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.PlacementServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='Placement'>Placement</a> objects. <p>You can use a placement to group ad
	/// units. For example, you might have a placement that focuses on sports sites,
	/// which may be spread across different branches of your inventory. You might also
	/// have a "fire sale" placement that includes ad units that have not been selling
	/// and are consequently priced very attractively.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class PlacementService : AdManagerSoapClient<IPlacementService>, IPlacementService {
		/// <summary> Creates a new instance of the <see cref="PlacementService"/> class.
		/// </summary>
		public PlacementService() {
		}

		/// <summary> Creates a new instance of the <see cref="PlacementService"/> class.
		/// </summary>
		public PlacementService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="PlacementService"/> class.
		/// </summary>
		public PlacementService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="PlacementService"/> class.
		/// </summary>
		public PlacementService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="PlacementService"/> class.
		/// </summary>
		public PlacementService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.PlacementService.createPlacementsResponse Google.Api.Ads.AdManager.v201802.PlacementServiceInterface.createPlacements(Wrappers.PlacementService.createPlacementsRequest request) {
			return base.Channel.createPlacements(request);
		}

		/// <summary>Creates new <a href='Placement'>Placement</a> objects.
		/// </summary><param name='placements'>the placements to create</param>
		/// <returns>the new placements, with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Placement[] createPlacements(Google.Api.Ads.AdManager.v201802.Placement[] placements) {
			Wrappers.PlacementService.createPlacementsRequest inValue = new Wrappers.PlacementService.createPlacementsRequest();
			inValue.placements = placements;
			Wrappers.PlacementService.createPlacementsResponse retVal = ((Google.Api.Ads.AdManager.v201802.PlacementServiceInterface)(this)).createPlacements(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.PlacementService.createPlacementsResponse> Google.Api.Ads.AdManager.v201802.PlacementServiceInterface.createPlacementsAsync(Wrappers.PlacementService.createPlacementsRequest request) {
			return base.Channel.createPlacementsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Placement[]> createPlacementsAsync(Google.Api.Ads.AdManager.v201802.Placement[] placements) {
			Wrappers.PlacementService.createPlacementsRequest inValue = new Wrappers.PlacementService.createPlacementsRequest();
			inValue.placements = placements;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Placement[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.PlacementServiceInterface)(this)).createPlacementsAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='PlacementPage'>PlacementPage</a> of <a
		/// href='Placement'>Placement</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>description</code></td>
		/// <td><a href='Placement#description'>Placement#description</a></td> </tr> <tr>
		/// <td><code>id</code></td> <td><a href='Placement#id'>Placement#id</a></td> </tr>
		/// <tr> <td><code>isAdSenseTargetingEnabled</code></td> <td><a
		/// href='Placement#isAdSenseTargetingEnabled'>Placement#isAdSenseTargetingEnabled</a></td>
		/// </tr> <tr> <td><code>name</code></td> <td><a
		/// href='Placement#name'>Placement#name</a></td> </tr> <tr>
		/// <td><code>placementCode</code></td> <td><a
		/// href='Placement#placementCode'>Placement#placementCode</a></td> </tr> <tr>
		/// <td><code>status</code></td> <td><a
		/// href='Placement#status'>Placement#status</a></td> </tr> <tr>
		/// <td><code>lastModifiedDateTime</code></td> <td><a
		/// href='Placement#lastModifiedDateTime'>Placement#lastModifiedDateTime</a></td>
		/// </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of placements</param>
		/// <returns>the placements that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.PlacementPage getPlacementsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getPlacementsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.PlacementPage> getPlacementsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getPlacementsByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='Placement'>Placement</a> objects that match the
		/// given <a href='Statement#query'>Statement#query</a>.
		/// </summary><param name='placementAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of placements</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performPlacementAction(Google.Api.Ads.AdManager.v201802.PlacementAction placementAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performPlacementAction(placementAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performPlacementActionAsync(Google.Api.Ads.AdManager.v201802.PlacementAction placementAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performPlacementActionAsync(placementAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.PlacementService.updatePlacementsResponse Google.Api.Ads.AdManager.v201802.PlacementServiceInterface.updatePlacements(Wrappers.PlacementService.updatePlacementsRequest request) {
			return base.Channel.updatePlacements(request);
		}

		/// <summary>Updates the specified <a href='Placement'>Placement</a> objects.
		/// </summary><param name='placements'>the placements to update</param>
		/// <returns>the updated placements</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Placement[] updatePlacements(Google.Api.Ads.AdManager.v201802.Placement[] placements) {
			Wrappers.PlacementService.updatePlacementsRequest inValue = new Wrappers.PlacementService.updatePlacementsRequest();
			inValue.placements = placements;
			Wrappers.PlacementService.updatePlacementsResponse retVal = ((Google.Api.Ads.AdManager.v201802.PlacementServiceInterface)(this)).updatePlacements(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.PlacementService.updatePlacementsResponse> Google.Api.Ads.AdManager.v201802.PlacementServiceInterface.updatePlacementsAsync(Wrappers.PlacementService.updatePlacementsRequest request) {
			return base.Channel.updatePlacementsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Placement[]> updatePlacementsAsync(Google.Api.Ads.AdManager.v201802.Placement[] placements) {
			Wrappers.PlacementService.updatePlacementsRequest inValue = new Wrappers.PlacementService.updatePlacementsRequest();
			inValue.placements = placements;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Placement[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.PlacementServiceInterface)(this)).updatePlacementsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.AdExclusionRuleService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createAdExclusionRules", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createAdExclusionRulesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("adExclusionRules")]
			public Google.Api.Ads.AdManager.v201802.AdExclusionRule[] adExclusionRules;

			/// <summary> Creates a new instance of the <see
			/// cref="createAdExclusionRulesRequest"/> class. </summary>
			public createAdExclusionRulesRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createAdExclusionRulesRequest"/> class. </summary>
			public createAdExclusionRulesRequest(Google.Api.Ads.AdManager.v201802.AdExclusionRule[] adExclusionRules) {
				this.adExclusionRules = adExclusionRules;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createAdExclusionRulesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createAdExclusionRulesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.AdExclusionRule[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createAdExclusionRulesResponse"/> class. </summary>
			public createAdExclusionRulesResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createAdExclusionRulesResponse"/> class. </summary>
			public createAdExclusionRulesResponse(Google.Api.Ads.AdManager.v201802.AdExclusionRule[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateAdExclusionRules", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateAdExclusionRulesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("adExclusionRules")]
			public Google.Api.Ads.AdManager.v201802.AdExclusionRule[] adExclusionRules;

			/// <summary> Creates a new instance of the <see
			/// cref="updateAdExclusionRulesRequest"/> class. </summary>
			public updateAdExclusionRulesRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateAdExclusionRulesRequest"/> class. </summary>
			public updateAdExclusionRulesRequest(Google.Api.Ads.AdManager.v201802.AdExclusionRule[] adExclusionRules) {
				this.adExclusionRules = adExclusionRules;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateAdExclusionRulesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateAdExclusionRulesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.AdExclusionRule[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateAdExclusionRulesResponse"/> class. </summary>
			public updateAdExclusionRulesResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateAdExclusionRulesResponse"/> class. </summary>
			public updateAdExclusionRulesResponse(Google.Api.Ads.AdManager.v201802.AdExclusionRule[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>Represents an inventory blocking rule, which prevents certain ads from being
	/// served to specified ad units.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdExclusionRule {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private bool isActiveField;

		private bool isActiveFieldSpecified;

		private InventoryTargeting inventoryTargetingField;

		private bool isBlockAllField;

		private bool isBlockAllFieldSpecified;

		private long[] blockedLabelIdsField;

		private long[] allowedLabelIdsField;

		private AdExclusionRuleType typeField;

		private bool typeFieldSpecified;

		/// <summary>The unique ID of the <code>AdExclusionRule</code>. This attribute is readonly
		/// and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the <code>AdExclusionRule</code>. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>Whether or not the <code>AdExclusionRule</code> is active. An inactive rule will
		/// have no effect on adserving. This attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public bool isActive {
			get {
				return this.isActiveField;
			}
			set {
				this.isActiveField = value;
				this.isActiveSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isActive"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isActiveSpecified {
			get {
				return this.isActiveFieldSpecified;
			}
			set {
				this.isActiveFieldSpecified = value;
			}
		}

		/// <summary>The targeting information about which <a
		/// href='AdUnitTargeting'>AdUnitTargeting</a> objects this rule is in effect for.
		/// Any <a href='AdUnitTargeting'>AdUnitTargeting</a> objects included here will
		/// have their children included implicitly. Children of a targeted ad unit can be
		/// excluded. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public InventoryTargeting inventoryTargeting {
			get {
				return this.inventoryTargetingField;
			}
			set {
				this.inventoryTargetingField = value;
			}
		}

		/// <summary>Whether or not this rule blocks all ads from serving other than the labels or
		/// advertisers specified. This attribute is optional and defaults to false.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public bool isBlockAll {
			get {
				return this.isBlockAllField;
			}
			set {
				this.isBlockAllField = value;
				this.isBlockAllSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isBlockAll"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isBlockAllSpecified {
			get {
				return this.isBlockAllFieldSpecified;
			}
			set {
				this.isBlockAllFieldSpecified = value;
			}
		}

		/// <summary>The labels that will be blocked from serving. Any advertiser, order or line item
		/// with one of these labels will not serve on the relevant ad units and their
		/// children.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("blockedLabelIds", Order = 5)]
		public long[] blockedLabelIds {
			get {
				return this.blockedLabelIdsField;
			}
			set {
				this.blockedLabelIdsField = value;
			}
		}

		/// <summary>The allowed list of labels that will not be blocked by this rule. This trumps
		/// the values of <a href='#isBlockAllLabels'>#isBlockAllLabels</a> and <a
		/// href='#blockedLabelIds'>#blockedLabelIds</a>. For example, if a rule specifies a
		/// blocked label "Cars", and an allowed label "Sports", any ad that is labeled both
		/// "Sports" and "Cars" will not be blocked by this rule.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("allowedLabelIds", Order = 6)]
		public long[] allowedLabelIds {
			get {
				return this.allowedLabelIdsField;
			}
			set {
				this.allowedLabelIdsField = value;
			}
		}

		/// <summary>The derived type of this rule: whether it is associated with labels, unified
		/// entities, or competitive groups. Because it is derived, it is also read-only, so
		/// changes made to this field will not be persisted.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public AdExclusionRuleType type {
			get {
				return this.typeField;
			}
			set {
				this.typeField = value;
				this.typeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="type" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool typeSpecified {
			get {
				return this.typeFieldSpecified;
			}
			set {
				this.typeFieldSpecified = value;
			}
		}
	}


	/// <summary>The derived type of this rule: whether it is associated with labels, unified
	/// entities, or competitive groups.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdExclusionRuleType {
		/// <summary>Rule is associated with labels and is relevant only for direct reservations.
		/// </summary>
		LABEL = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>Ad exclusion rule specific errors.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdExclusionRuleError : ApiError {
		private AdExclusionRuleErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AdExclusionRuleErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the ad exclusion rule error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AdExclusionRuleError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdExclusionRuleErrorReason {
		/// <summary>The <a
		/// href='AdExclusionRule#inventoryTargeting'>AdExclusionRule#inventoryTargeting</a>
		/// cannot target the root ad unit if <a
		/// href='AdExclusionRule#isBlockAll'>AdExclusionRule#isBlockAll</a> is true.
		/// </summary>
		BLOCK_ALL_RULE_CANNOT_INCLUDE_ROOT_AD_UNIT = 0,
		/// <summary>The <a
		/// href='AdExclusionRule#blockedLabelIds'>AdExclusionRule#blockedLabelIds</a> must
		/// be empty if <a href='AdExclusionRule#isBlockAll'>AdExclusionRule#isBlockAll</a>
		/// is true.
		/// </summary>
		BLOCK_ALL_RULE_CANNOT_HAVE_BLOCKED_LABELS = 1,
		/// <summary>The <a
		/// href='AdExclusionRule#allowedLabelIds'>AdExclusionRule#allowedLabelIds</a> must
		/// contain allowed labels if <a
		/// href='AdExclusionRule#isBlockAll'>AdExclusionRule#isBlockAll</a> is true.
		/// </summary>
		BLOCK_ALL_RULE_MUST_CONTAIN_ALLOWED_LABELS = 2,
		/// <summary>The <a href='AdExclusionRule'>AdExclusionRule</a> must contain blocking
		/// information.
		/// </summary>
		RULE_MUST_CONTAIN_BLOCKING = 3,
		/// <summary>The same label ID cannot be contained in both <a
		/// href='AdExclusionRule#allowedLabelIds'>AdExclusionRule#allowedLabelIds</a> and
		/// <a href='AdExclusionRule#blockedLabelIds'>AdExclusionRule#blockedLabelIds</a>.
		/// </summary>
		BLOCKED_LABEL_ALSO_ALLOWED = 4,
		/// <summary>Label IDs included in <a
		/// href='AdExclusionRule#allowedLabelIds'>AdExclusionRule#allowedLabelIds</a> and
		/// <a href='AdExclusionRule#blockedLabelIds'>AdExclusionRule#blockedLabelIds</a>
		/// must correspond to <a href='Label'>Label</a> objects with type <a
		/// href='Label#AD_EXCLUSION'>Label#AD_EXCLUSION</a>.
		/// </summary>
		LABELS_MUST_BE_AD_EXCLUSION_TYPE = 5,
		/// <summary>The same ad unit cannot be included in both <a
		/// href='InventoryTargeting#targetedAdUnits'>InventoryTargeting#targetedAdUnits</a>
		/// and <a
		/// href='InventoryTargeting#excludedAdUnits'>InventoryTargeting#excludedAdUnits</a>
		/// in <a
		/// href='AdExclusionRule#inventoryTargeting'>AdExclusionRule#inventoryTargeting</a>.
		/// </summary>
		EXCLUDED_AD_UNIT_ALSO_INCLUDED = 6,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 7,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.AdExclusionRuleServiceInterface")]
	public interface AdExclusionRuleServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.AdExclusionRuleService.createAdExclusionRulesResponse createAdExclusionRules(Wrappers.AdExclusionRuleService.createAdExclusionRulesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.AdExclusionRuleService.createAdExclusionRulesResponse> createAdExclusionRulesAsync(Wrappers.AdExclusionRuleService.createAdExclusionRulesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.AdExclusionRulePage getAdExclusionRulesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdExclusionRulePage> getAdExclusionRulesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performAdExclusionRuleAction(Google.Api.Ads.AdManager.v201802.AdExclusionRuleAction adExclusionRuleAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performAdExclusionRuleActionAsync(Google.Api.Ads.AdManager.v201802.AdExclusionRuleAction adExclusionRuleAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.AdExclusionRuleService.updateAdExclusionRulesResponse updateAdExclusionRules(Wrappers.AdExclusionRuleService.updateAdExclusionRulesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.AdExclusionRuleService.updateAdExclusionRulesResponse> updateAdExclusionRulesAsync(Wrappers.AdExclusionRuleService.updateAdExclusionRulesRequest request);
	}


	/// <summary>Represents a page of <a href='AdExclusionRule'>AdExclusionRule</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdExclusionRulePage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private AdExclusionRule[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of audience segments contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public AdExclusionRule[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a
	/// href='AdExclusionRule'>AdExclusionRule</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeactivateAdExclusionRules))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateAdExclusionRules))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class AdExclusionRuleAction {
	}


	/// <summary>Deactivate action.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeactivateAdExclusionRules : AdExclusionRuleAction {
	}


	/// <summary>Activate action.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateAdExclusionRules : AdExclusionRuleAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface AdExclusionRuleServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.AdExclusionRuleServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='AdExclusionRule'>AdExclusionRule</a> objects. <p>An <a
	/// href='AdExclusionRule'>AdExclusionRule</a> provides a way to block specified ads
	/// from showing on portions of your site. Each rule specifies the inventory on
	/// which the rule is in effect, and the labels to block on that inventory.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class AdExclusionRuleService : AdManagerSoapClient<IAdExclusionRuleService>, IAdExclusionRuleService {
		/// <summary> Creates a new instance of the <see cref="AdExclusionRuleService"/>
		/// class. </summary>
		public AdExclusionRuleService() {
		}

		/// <summary> Creates a new instance of the <see cref="AdExclusionRuleService"/>
		/// class. </summary>
		public AdExclusionRuleService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="AdExclusionRuleService"/>
		/// class. </summary>
		public AdExclusionRuleService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="AdExclusionRuleService"/>
		/// class. </summary>
		public AdExclusionRuleService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="AdExclusionRuleService"/>
		/// class. </summary>
		public AdExclusionRuleService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.AdExclusionRuleService.createAdExclusionRulesResponse Google.Api.Ads.AdManager.v201802.AdExclusionRuleServiceInterface.createAdExclusionRules(Wrappers.AdExclusionRuleService.createAdExclusionRulesRequest request) {
			return base.Channel.createAdExclusionRules(request);
		}

		/// <summary>Creates new <a href='AdExclusionRule'>AdExclusionRule</a> objects.
		/// </summary><param name='adExclusionRules'>the ad exclusion rules to create</param>
		/// <returns>the created rules with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.AdExclusionRule[] createAdExclusionRules(Google.Api.Ads.AdManager.v201802.AdExclusionRule[] adExclusionRules) {
			Wrappers.AdExclusionRuleService.createAdExclusionRulesRequest inValue = new Wrappers.AdExclusionRuleService.createAdExclusionRulesRequest();
			inValue.adExclusionRules = adExclusionRules;
			Wrappers.AdExclusionRuleService.createAdExclusionRulesResponse retVal = ((Google.Api.Ads.AdManager.v201802.AdExclusionRuleServiceInterface)(this)).createAdExclusionRules(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.AdExclusionRuleService.createAdExclusionRulesResponse> Google.Api.Ads.AdManager.v201802.AdExclusionRuleServiceInterface.createAdExclusionRulesAsync(Wrappers.AdExclusionRuleService.createAdExclusionRulesRequest request) {
			return base.Channel.createAdExclusionRulesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdExclusionRule[]> createAdExclusionRulesAsync(Google.Api.Ads.AdManager.v201802.AdExclusionRule[] adExclusionRules) {
			Wrappers.AdExclusionRuleService.createAdExclusionRulesRequest inValue = new Wrappers.AdExclusionRuleService.createAdExclusionRulesRequest();
			inValue.adExclusionRules = adExclusionRules;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdExclusionRule[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.AdExclusionRuleServiceInterface)(this)).createAdExclusionRulesAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='AdExclusionRulePage'>AdExclusionRulePage</a> of <a
		/// href='AdExclusionRule'>AdExclusionRule</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='AdExclusionRule#id'>AdExclusionRule#id</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a
		/// href='AdExclusionRule#name'>AdExclusionRule#name</a></td> </tr> <tr>
		/// <td><code>status</code></td> <td><a
		/// href='AdExclusionRule#status'>AdExclusionRule#status</a></td> </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of rules</param>
		/// <returns>the rules that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.AdExclusionRulePage getAdExclusionRulesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getAdExclusionRulesByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdExclusionRulePage> getAdExclusionRulesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getAdExclusionRulesByStatementAsync(filterStatement);
		}

		/// <summary>Performs action on <a href='AdExclusionRule'>AdExclusionRule</a> objects that
		/// satisfy the given <a href='Statement#query'>Statement#query</a>.
		/// </summary><param name='adExclusionRuleAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of ad exclusion rules</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performAdExclusionRuleAction(Google.Api.Ads.AdManager.v201802.AdExclusionRuleAction adExclusionRuleAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performAdExclusionRuleAction(adExclusionRuleAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performAdExclusionRuleActionAsync(Google.Api.Ads.AdManager.v201802.AdExclusionRuleAction adExclusionRuleAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performAdExclusionRuleActionAsync(adExclusionRuleAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.AdExclusionRuleService.updateAdExclusionRulesResponse Google.Api.Ads.AdManager.v201802.AdExclusionRuleServiceInterface.updateAdExclusionRules(Wrappers.AdExclusionRuleService.updateAdExclusionRulesRequest request) {
			return base.Channel.updateAdExclusionRules(request);
		}

		/// <summary>Updates the specified <a href='AdExclusionRule'>AdExclusionRule</a> objects.
		/// </summary><param name='adExclusionRules'>the ad exclusion rules to update</param>
		/// <returns>the updated rules</returns>
		public virtual Google.Api.Ads.AdManager.v201802.AdExclusionRule[] updateAdExclusionRules(Google.Api.Ads.AdManager.v201802.AdExclusionRule[] adExclusionRules) {
			Wrappers.AdExclusionRuleService.updateAdExclusionRulesRequest inValue = new Wrappers.AdExclusionRuleService.updateAdExclusionRulesRequest();
			inValue.adExclusionRules = adExclusionRules;
			Wrappers.AdExclusionRuleService.updateAdExclusionRulesResponse retVal = ((Google.Api.Ads.AdManager.v201802.AdExclusionRuleServiceInterface)(this)).updateAdExclusionRules(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.AdExclusionRuleService.updateAdExclusionRulesResponse> Google.Api.Ads.AdManager.v201802.AdExclusionRuleServiceInterface.updateAdExclusionRulesAsync(Wrappers.AdExclusionRuleService.updateAdExclusionRulesRequest request) {
			return base.Channel.updateAdExclusionRulesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdExclusionRule[]> updateAdExclusionRulesAsync(Google.Api.Ads.AdManager.v201802.AdExclusionRule[] adExclusionRules) {
			Wrappers.AdExclusionRuleService.updateAdExclusionRulesRequest inValue = new Wrappers.AdExclusionRuleService.updateAdExclusionRulesRequest();
			inValue.adExclusionRules = adExclusionRules;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdExclusionRule[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.AdExclusionRuleServiceInterface)(this)).updateAdExclusionRulesAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.PremiumRateService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createPremiumRates", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createPremiumRatesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("premiumRates")]
			public Google.Api.Ads.AdManager.v201802.PremiumRate[] premiumRates;

			/// <summary> Creates a new instance of the <see cref="createPremiumRatesRequest"/>
			/// class. </summary>
			public createPremiumRatesRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createPremiumRatesRequest"/>
			/// class. </summary>
			public createPremiumRatesRequest(Google.Api.Ads.AdManager.v201802.PremiumRate[] premiumRates) {
				this.premiumRates = premiumRates;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createPremiumRatesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createPremiumRatesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.PremiumRate[] rval;

			/// <summary> Creates a new instance of the <see cref="createPremiumRatesResponse"/>
			/// class. </summary>
			public createPremiumRatesResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createPremiumRatesResponse"/>
			/// class. </summary>
			public createPremiumRatesResponse(Google.Api.Ads.AdManager.v201802.PremiumRate[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updatePremiumRates", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updatePremiumRatesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("premiumRates")]
			public Google.Api.Ads.AdManager.v201802.PremiumRate[] premiumRates;

			/// <summary> Creates a new instance of the <see cref="updatePremiumRatesRequest"/>
			/// class. </summary>
			public updatePremiumRatesRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updatePremiumRatesRequest"/>
			/// class. </summary>
			public updatePremiumRatesRequest(Google.Api.Ads.AdManager.v201802.PremiumRate[] premiumRates) {
				this.premiumRates = premiumRates;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updatePremiumRatesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updatePremiumRatesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.PremiumRate[] rval;

			/// <summary> Creates a new instance of the <see cref="updatePremiumRatesResponse"/>
			/// class. </summary>
			public updatePremiumRatesResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updatePremiumRatesResponse"/>
			/// class. </summary>
			public updatePremiumRatesResponse(Google.Api.Ads.AdManager.v201802.PremiumRate[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>A premium of a <a href='RateCard'>RateCard</a> which could be applied to the
	/// line item and charges extra.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PremiumRateValue {
		private long premiumRateIdField;

		private bool premiumRateIdFieldSpecified;

		private PremiumFeature premiumFeatureField;

		private RateType rateTypeField;

		private bool rateTypeFieldSpecified;

		private PremiumAdjustmentType adjustmentTypeField;

		private bool adjustmentTypeFieldSpecified;

		private long adjustmentSizeField;

		private bool adjustmentSizeFieldSpecified;

		/// <summary>The ID of the <a href='PremiumRate'>PremiumRate</a> object to which this premium
		/// rate value belongs. This attribute is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long premiumRateId {
			get {
				return this.premiumRateIdField;
			}
			set {
				this.premiumRateIdField = value;
				this.premiumRateIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="premiumRateId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool premiumRateIdSpecified {
			get {
				return this.premiumRateIdFieldSpecified;
			}
			set {
				this.premiumRateIdFieldSpecified = value;
			}
		}

		/// <summary>The feature type of this premium rate value. <p>This attribute is required and
		/// cannot be changed after creation.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public PremiumFeature premiumFeature {
			get {
				return this.premiumFeatureField;
			}
			set {
				this.premiumFeatureField = value;
			}
		}

		/// <summary>The rate type this premium rate value would be applied to. This attribute is
		/// required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public RateType rateType {
			get {
				return this.rateTypeField;
			}
			set {
				this.rateTypeField = value;
				this.rateTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="rateType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool rateTypeSpecified {
			get {
				return this.rateTypeFieldSpecified;
			}
			set {
				this.rateTypeFieldSpecified = value;
			}
		}

		/// <summary>Whether the premium rate value is a percentage or absolute value to the product
		/// rate. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public PremiumAdjustmentType adjustmentType {
			get {
				return this.adjustmentTypeField;
			}
			set {
				this.adjustmentTypeField = value;
				this.adjustmentTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="adjustmentType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool adjustmentTypeSpecified {
			get {
				return this.adjustmentTypeFieldSpecified;
			}
			set {
				this.adjustmentTypeFieldSpecified = value;
			}
		}

		/// <summary>If <a href='#adjustmentType'>#adjustmentType</a> is <a
		/// href='PremiumAdjustmentType#ABSOLUTE_VALUE'>PremiumAdjustmentType#ABSOLUTE_VALUE</a>,
		/// this value is in micros. If <a href='#adjustmentType'>#adjustmentType</a> is <a
		/// href='PremiumAdjustmentType#PERCENTAGE'>PremiumAdjustmentType#PERCENTAGE</a>,
		/// this value is in millipercent. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public long adjustmentSize {
			get {
				return this.adjustmentSizeField;
			}
			set {
				this.adjustmentSizeField = value;
				this.adjustmentSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="adjustmentSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool adjustmentSizeSpecified {
			get {
				return this.adjustmentSizeFieldSpecified;
			}
			set {
				this.adjustmentSizeFieldSpecified = value;
			}
		}
	}


	/// <summary>A <code>PremiumFeature</code> represents the feature type to be applied as a
	/// premium on a <a href='RateCard'>RateCard</a>.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(VideoPositionPremiumFeature))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UserDomainPremiumFeature))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UnknownPremiumFeature))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(PlacementPremiumFeature))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(OperatingSystemPremiumFeature))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(MobileCarrierPremiumFeature))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(GeographyPremiumFeature))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(FrequencyCapPremiumFeature))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeviceManufacturerPremiumFeature))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeviceCategoryPremiumFeature))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeviceCapabilityPremiumFeature))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DaypartPremiumFeature))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CustomTargetingPremiumFeature))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ContentBundlePremiumFeature))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BrowserLanguagePremiumFeature))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BrowserPremiumFeature))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BandwidthPremiumFeature))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AudienceSegmentPremiumFeature))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(AdUnitPremiumFeature))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class PremiumFeature {
	}


	/// <summary>A premium feature applied to video position targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class VideoPositionPremiumFeature : PremiumFeature {
	}


	/// <summary>A premium feature applied to user domain targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UserDomainPremiumFeature : PremiumFeature {
	}


	/// <summary>The <a href='PremiumFeature'>PremiumFeature</a> returned if the actual feature
	/// is not exposed by the requested API version.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UnknownPremiumFeature : PremiumFeature {
	}


	/// <summary>A premium feature applied to placement targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PlacementPremiumFeature : PremiumFeature {
	}


	/// <summary>A premium feature applied to operating system targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class OperatingSystemPremiumFeature : PremiumFeature {
	}


	/// <summary>A premium feature applied to mobile carrier targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class MobileCarrierPremiumFeature : PremiumFeature {
	}


	/// <summary>A premium feature applied to geography targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class GeographyPremiumFeature : PremiumFeature {
	}


	/// <summary>A premium feature applied to frequency caps.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class FrequencyCapPremiumFeature : PremiumFeature {
	}


	/// <summary>A premium feature applied to device manufacturer targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeviceManufacturerPremiumFeature : PremiumFeature {
	}


	/// <summary>A premium feature applied to device category targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeviceCategoryPremiumFeature : PremiumFeature {
	}


	/// <summary>A premium feature applied to device capability targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeviceCapabilityPremiumFeature : PremiumFeature {
	}


	/// <summary>A premium feature applied to daypart targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DaypartPremiumFeature : PremiumFeature {
	}


	/// <summary>A premium feature applied to custom criteria targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomTargetingPremiumFeature : PremiumFeature {
		private long customTargetingKeyIdField;

		private bool customTargetingKeyIdFieldSpecified;

		private long customTargetingValueIdField;

		private bool customTargetingValueIdFieldSpecified;

		/// <summary>The ID of the <a href='CustomTargetingKey'>CustomTargetingKey</a>. <p>This
		/// attribute is required and cannot be changed after creation.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long customTargetingKeyId {
			get {
				return this.customTargetingKeyIdField;
			}
			set {
				this.customTargetingKeyIdField = value;
				this.customTargetingKeyIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="customTargetingKeyId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool customTargetingKeyIdSpecified {
			get {
				return this.customTargetingKeyIdFieldSpecified;
			}
			set {
				this.customTargetingKeyIdFieldSpecified = value;
			}
		}

		/// <summary>The ID of the <a href='CustomTargetingValue'>CustomTargetingValue</a>.
		/// <code>null</code> if all custom targeting values of the <a
		/// href='#customTargetingKeyId'>#customTargetingKeyId</a> should be matched.
		/// <p>This attribute cannot be changed after creation.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long customTargetingValueId {
			get {
				return this.customTargetingValueIdField;
			}
			set {
				this.customTargetingValueIdField = value;
				this.customTargetingValueIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="customTargetingValueId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool customTargetingValueIdSpecified {
			get {
				return this.customTargetingValueIdFieldSpecified;
			}
			set {
				this.customTargetingValueIdFieldSpecified = value;
			}
		}
	}


	/// <summary>A premium feature applied to content bundle targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ContentBundlePremiumFeature : PremiumFeature {
	}


	/// <summary>A premium feature applied to browser language targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class BrowserLanguagePremiumFeature : PremiumFeature {
	}


	/// <summary>A premium feature applied to browser targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class BrowserPremiumFeature : PremiumFeature {
	}


	/// <summary>A premium feature applied to bandwidth targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class BandwidthPremiumFeature : PremiumFeature {
	}


	/// <summary>A premium feature applied to audience segment targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AudienceSegmentPremiumFeature : PremiumFeature {
		private long audienceSegmentIdField;

		private bool audienceSegmentIdFieldSpecified;

		/// <summary>The ID of the <a href='AudienceSegment#id'>AudienceSegment#id</a>. <p>This
		/// attribute is required and cannot be changed after creation.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long audienceSegmentId {
			get {
				return this.audienceSegmentIdField;
			}
			set {
				this.audienceSegmentIdField = value;
				this.audienceSegmentIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="audienceSegmentId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool audienceSegmentIdSpecified {
			get {
				return this.audienceSegmentIdFieldSpecified;
			}
			set {
				this.audienceSegmentIdFieldSpecified = value;
			}
		}
	}


	/// <summary>A premium feature applied to ad unit targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdUnitPremiumFeature : PremiumFeature {
	}


	/// <summary>Describes the type of event the advertiser is paying for. The values here
	/// correspond to the values for the <a
	/// href='LineItem#costType'>LineItem#costType</a> field.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RateType {
		/// <summary>The rate applies to cost per mille (CPM) revenue.
		/// </summary>
		CPM = 0,
		/// <summary>The rate applies to cost per click (CPC) revenue.
		/// </summary>
		CPC = 1,
		/// <summary>The rate applies to cost per day (CPD) revenue.
		/// </summary>
		CPD = 2,
		/// <summary>The rate applies to cost per unit (CPU) revenue.
		/// </summary>
		CPU = 3,
		/// <summary>The rate applies to flat fee revenue.
		/// </summary>
		FLAT_FEE = 4,
		/// <summary>The rate applies to Active View viewable cost per mille (vCPM) revenue.
		/// </summary>
		VCPM = 6,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 5,
	}


	/// <summary>Describes how to apply the adjustment to the base rate.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum PremiumAdjustmentType {
		/// <summary>The adjustment size to the base rate is a percentage.
		/// </summary>
		PERCENTAGE = 0,
		/// <summary>The adjustment size to the base rate is an absolute value.
		/// </summary>
		ABSOLUTE_VALUE = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>A premium rate holding a set of <a href='PremiumRateValue'>PremiumRateValue</a>
	/// objects with the same <a href=''>PremiumFeature</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PremiumRate {
		private long idField;

		private bool idFieldSpecified;

		private long rateCardIdField;

		private bool rateCardIdFieldSpecified;

		private PricingMethod pricingMethodField;

		private bool pricingMethodFieldSpecified;

		private PremiumFeature premiumFeatureField;

		private PremiumRateValue[] premiumRateValuesField;

		/// <summary>Uniquely identifies the <code>PremiumRate</code> object. This attribute is
		/// read-only and is assigned by Google when a premium rate is created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The ID of the <a href='RateCard'>RateCard</a> object to which this premium rate
		/// belongs. This attribute is required and cannot be changed after creation.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long rateCardId {
			get {
				return this.rateCardIdField;
			}
			set {
				this.rateCardIdField = value;
				this.rateCardIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="rateCardId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool rateCardIdSpecified {
			get {
				return this.rateCardIdFieldSpecified;
			}
			set {
				this.rateCardIdFieldSpecified = value;
			}
		}

		/// <summary>The method of deciding which <a href='PremiumRateValue'>PremiumRateValue</a>
		/// objects from this <code></code> to apply to a <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public PricingMethod pricingMethod {
			get {
				return this.pricingMethodField;
			}
			set {
				this.pricingMethodField = value;
				this.pricingMethodSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="pricingMethod" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool pricingMethodSpecified {
			get {
				return this.pricingMethodFieldSpecified;
			}
			set {
				this.pricingMethodFieldSpecified = value;
			}
		}

		/// <summary>The feature type of this premium rate. This attribute is required and cannot be
		/// changed after creation.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public PremiumFeature premiumFeature {
			get {
				return this.premiumFeatureField;
			}
			set {
				this.premiumFeatureField = value;
			}
		}

		/// <summary>The premiums rate values in this rate.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("premiumRateValues", Order = 4)]
		public PremiumRateValue[] premiumRateValues {
			get {
				return this.premiumRateValuesField;
			}
			set {
				this.premiumRateValuesField = value;
			}
		}
	}


	/// <summary>Describes which <a href='PremiumRateValue'>PremiumRateValue</a> objects from the
	/// <a href='PremiumRate'>PremiumRate</a> to apply to a <a
	/// href='ProposalLineItem'>ProposalLineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum PricingMethod {
		/// <summary>Applies sum of all matched <a href='PremiumRateValue'>PremiumRateValue</a>
		/// objects in the <a href='PremiumRate'>PremiumRate</a>.
		/// </summary>
		SUM = 0,
		/// <summary>Applies the matched <a href='PremiumRateValue'>PremiumRateValue</a> with highest
		/// adjustment size.
		/// </summary>
		HIGHEST = 1,
		/// <summary>Only <a href='PremiumRateValue'>PremiumRateValue</a> objects with 'Any' matching
		/// value are allowed to be added to this <a href='PremiumRate'>PremiumRate</a>.
		/// </summary>
		ANY_VALUE = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>An error having to do with <a href='PremiumRate'>PremiumRate</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PremiumRateError : ApiError {
		private PremiumRateErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public PremiumRateErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "PremiumRateError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum PremiumRateErrorReason {
		/// <summary>The rate type of the <a href='PremiumRateValue'>PremiumRateValue</a> is invalid.
		/// </summary>
		INVALID_RATE_TYPE = 0,
		/// <summary>The pricing method of the <a href='PremiumRate'>PremiumRate</a> is invalid.
		/// </summary>
		INVALID_PRICING_METHOD = 1,
		/// <summary>The premium feature of the <a href='PremiumRate'>PremiumRate</a> is invalid.
		/// </summary>
		INVALID_PREMIUM_FEATURE = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.PremiumRateServiceInterface")]
	public interface PremiumRateServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.PremiumRateService.createPremiumRatesResponse createPremiumRates(Wrappers.PremiumRateService.createPremiumRatesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.PremiumRateService.createPremiumRatesResponse> createPremiumRatesAsync(Wrappers.PremiumRateService.createPremiumRatesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.PremiumRatePage getPremiumRatesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.PremiumRatePage> getPremiumRatesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.PremiumRateService.updatePremiumRatesResponse updatePremiumRates(Wrappers.PremiumRateService.updatePremiumRatesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.PremiumRateService.updatePremiumRatesResponse> updatePremiumRatesAsync(Wrappers.PremiumRateService.updatePremiumRatesRequest request);
	}


	/// <summary>Captures a page of <a href='PremiumRate'>PremiumRate</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PremiumRatePage {
		private PremiumRate[] resultsField;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		/// <summary>The collection of premium rates contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 0)]
		public PremiumRate[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface PremiumRateServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.PremiumRateServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for managing <a href='PremiumRate'>PremiumRate</a> objects.
	/// <p>To use this service, you need to have the new sales management solution
	/// enabled on your network. If you do not see a "Sales" tab in <a
	/// href="https://www.google.com/dfp">DoubleClick for Publishers (DFP)</a>, you will
	/// not be able to use this service.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class PremiumRateService : AdManagerSoapClient<IPremiumRateService>, IPremiumRateService {
		/// <summary> Creates a new instance of the <see cref="PremiumRateService"/> class.
		/// </summary>
		public PremiumRateService() {
		}

		/// <summary> Creates a new instance of the <see cref="PremiumRateService"/> class.
		/// </summary>
		public PremiumRateService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="PremiumRateService"/> class.
		/// </summary>
		public PremiumRateService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="PremiumRateService"/> class.
		/// </summary>
		public PremiumRateService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="PremiumRateService"/> class.
		/// </summary>
		public PremiumRateService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.PremiumRateService.createPremiumRatesResponse Google.Api.Ads.AdManager.v201802.PremiumRateServiceInterface.createPremiumRates(Wrappers.PremiumRateService.createPremiumRatesRequest request) {
			return base.Channel.createPremiumRates(request);
		}

		/// <summary>Creates a list of new <a href='PremiumRate'>PremiumRate</a> objects.
		/// </summary><param name='premiumRates'>the premium rates to be created</param>
		/// <returns>the premium rates with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.PremiumRate[] createPremiumRates(Google.Api.Ads.AdManager.v201802.PremiumRate[] premiumRates) {
			Wrappers.PremiumRateService.createPremiumRatesRequest inValue = new Wrappers.PremiumRateService.createPremiumRatesRequest();
			inValue.premiumRates = premiumRates;
			Wrappers.PremiumRateService.createPremiumRatesResponse retVal = ((Google.Api.Ads.AdManager.v201802.PremiumRateServiceInterface)(this)).createPremiumRates(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.PremiumRateService.createPremiumRatesResponse> Google.Api.Ads.AdManager.v201802.PremiumRateServiceInterface.createPremiumRatesAsync(Wrappers.PremiumRateService.createPremiumRatesRequest request) {
			return base.Channel.createPremiumRatesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.PremiumRate[]> createPremiumRatesAsync(Google.Api.Ads.AdManager.v201802.PremiumRate[] premiumRates) {
			Wrappers.PremiumRateService.createPremiumRatesRequest inValue = new Wrappers.PremiumRateService.createPremiumRatesRequest();
			inValue.premiumRates = premiumRates;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.PremiumRate[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.PremiumRateServiceInterface)(this)).createPremiumRatesAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='PremiumRatePage'>PremiumRatePage</a> of <a
		/// href='PremiumRate'>PremiumRate</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='PremiumRate#id'>PremiumRate#id</a></td> </tr> <tr>
		/// <td><code>rateCardId</code></td> <td><a
		/// href='PremiumRate#rateCardId'>PremiumRate#rateCardId</a></td> </tr> <tr>
		/// <td><code>pricingMethod</code></td> <td><a
		/// href='PremiumRate#pricingMethod'>PremiumRate#pricingMethod</a></td> </tr>
		/// </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement to filter a
		/// list of premium rates.</param>
		/// <returns>the premium rates that match the filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.PremiumRatePage getPremiumRatesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getPremiumRatesByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.PremiumRatePage> getPremiumRatesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getPremiumRatesByStatementAsync(filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.PremiumRateService.updatePremiumRatesResponse Google.Api.Ads.AdManager.v201802.PremiumRateServiceInterface.updatePremiumRates(Wrappers.PremiumRateService.updatePremiumRatesRequest request) {
			return base.Channel.updatePremiumRates(request);
		}

		/// <summary>Updates the specified <a href='PremiumRate'>PremiumRate</a> objects.
		/// </summary><param name='premiumRates'>the premium rates to be updated</param>
		/// <returns>the updated premium rates</returns>
		public virtual Google.Api.Ads.AdManager.v201802.PremiumRate[] updatePremiumRates(Google.Api.Ads.AdManager.v201802.PremiumRate[] premiumRates) {
			Wrappers.PremiumRateService.updatePremiumRatesRequest inValue = new Wrappers.PremiumRateService.updatePremiumRatesRequest();
			inValue.premiumRates = premiumRates;
			Wrappers.PremiumRateService.updatePremiumRatesResponse retVal = ((Google.Api.Ads.AdManager.v201802.PremiumRateServiceInterface)(this)).updatePremiumRates(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.PremiumRateService.updatePremiumRatesResponse> Google.Api.Ads.AdManager.v201802.PremiumRateServiceInterface.updatePremiumRatesAsync(Wrappers.PremiumRateService.updatePremiumRatesRequest request) {
			return base.Channel.updatePremiumRatesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.PremiumRate[]> updatePremiumRatesAsync(Google.Api.Ads.AdManager.v201802.PremiumRate[] premiumRates) {
			Wrappers.PremiumRateService.updatePremiumRatesRequest inValue = new Wrappers.PremiumRateService.updatePremiumRatesRequest();
			inValue.premiumRates = premiumRates;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.PremiumRate[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.PremiumRateServiceInterface)(this)).updatePremiumRatesAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.ProductService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createProducts", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createProductsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("products")]
			public Google.Api.Ads.AdManager.v201802.Product[] products;

			/// <summary> Creates a new instance of the <see cref="createProductsRequest"/>
			/// class. </summary>
			public createProductsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createProductsRequest"/>
			/// class. </summary>
			public createProductsRequest(Google.Api.Ads.AdManager.v201802.Product[] products) {
				this.products = products;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createProductsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createProductsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Product[] rval;

			/// <summary> Creates a new instance of the <see cref="createProductsResponse"/>
			/// class. </summary>
			public createProductsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createProductsResponse"/>
			/// class. </summary>
			public createProductsResponse(Google.Api.Ads.AdManager.v201802.Product[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateProducts", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateProductsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("products")]
			public Google.Api.Ads.AdManager.v201802.Product[] products;

			/// <summary> Creates a new instance of the <see cref="updateProductsRequest"/>
			/// class. </summary>
			public updateProductsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updateProductsRequest"/>
			/// class. </summary>
			public updateProductsRequest(Google.Api.Ads.AdManager.v201802.Product[] products) {
				this.products = products;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateProductsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateProductsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Product[] rval;

			/// <summary> Creates a new instance of the <see cref="updateProductsResponse"/>
			/// class. </summary>
			public updateProductsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updateProductsResponse"/>
			/// class. </summary>
			public updateProductsResponse(Google.Api.Ads.AdManager.v201802.Product[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>Marketplace information for a programmatic <a href='Product'>Product</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductMarketplaceInfo {
		private AdExchangeEnvironment adExchangeEnvironmentField;

		private bool adExchangeEnvironmentFieldSpecified;

		private string additionalTermsField;

		private ValueSourceType additionalTermsSourceField;

		private bool additionalTermsSourceFieldSpecified;

		/// <summary>The <a href='AdExchangeEnvironment'>AdExchangeEnvironment</a> of the AdX Web
		/// Property this product will serve to. <span class="constraint ReadOnly">This
		/// attribute is read-only when:</span> <ul> <li>using programmatic guaranteed,
		/// using sales management.</li> </ul> <span class="constraint Required">This
		/// attribute is required when:</span> <ul> <li>using programmatic guaranteed, not
		/// using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AdExchangeEnvironment adExchangeEnvironment {
			get {
				return this.adExchangeEnvironmentField;
			}
			set {
				this.adExchangeEnvironmentField = value;
				this.adExchangeEnvironmentSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="adExchangeEnvironment" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool adExchangeEnvironmentSpecified {
			get {
				return this.adExchangeEnvironmentFieldSpecified;
			}
			set {
				this.adExchangeEnvironmentFieldSpecified = value;
			}
		}

		/// <summary>Additional terms shown to the buyer in Marketplace. When using sales management,
		/// this attribute is populated with the <a
		/// href='ProductTemplateMarketplaceInfo#additionalTerms'>additional terms</a> value
		/// from the product template this product is created from. To overwrite this, set
		/// the <a href='#additionalTermsSource'>#additionalTermsSource</a> to <a
		/// href='ValueSourceType#DIRECTLY_SPECIFIED'>ValueSourceType#DIRECTLY_SPECIFIED</a>
		/// when setting the value of this field.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string additionalTerms {
			get {
				return this.additionalTermsField;
			}
			set {
				this.additionalTermsField = value;
			}
		}

		/// <summary>Specifies the source of the <a href='#additionalTerms'>#additionalTerms</a>
		/// value. To revert an overridden value to its default, set this field to <a
		/// href='ValueSourceType#PARENT'>ValueSourceType#PARENT</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public ValueSourceType additionalTermsSource {
			get {
				return this.additionalTermsSourceField;
			}
			set {
				this.additionalTermsSourceField = value;
				this.additionalTermsSourceSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="additionalTermsSource" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool additionalTermsSourceSpecified {
			get {
				return this.additionalTermsSourceFieldSpecified;
			}
			set {
				this.additionalTermsSourceFieldSpecified = value;
			}
		}
	}


	/// <summary>Identifies the format of inventory or "channel" in which ads serve.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdExchangeEnvironment {
		/// <summary>Ads serve in a browser.
		/// </summary>
		DISPLAY = 0,
		/// <summary>In-stream video ads serve in a video.
		/// </summary>
		VIDEO = 1,
		/// <summary>In-stream video ads serve in a game.
		/// </summary>
		GAMES = 2,
		/// <summary>Ads serve in a mobile app.
		/// </summary>
		MOBILE = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>Specifies what targeting or attributes are customizable on a <a
	/// href='ProductTemplate'>ProductTemplate</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CustomizableAttributes {
		private bool allowGeoTargetingCustomizationField;

		private bool allowGeoTargetingCustomizationFieldSpecified;

		private bool allowAdUnitTargetingCustomizationField;

		private bool allowAdUnitTargetingCustomizationFieldSpecified;

		private bool allowPlacementTargetingCustomizationField;

		private bool allowPlacementTargetingCustomizationFieldSpecified;

		private bool allowUserDomainTargetingCustomizationField;

		private bool allowUserDomainTargetingCustomizationFieldSpecified;

		private bool allowBandwidthGroupTargetingCustomizationField;

		private bool allowBandwidthGroupTargetingCustomizationFieldSpecified;

		private bool allowBrowserTargetingCustomizationField;

		private bool allowBrowserTargetingCustomizationFieldSpecified;

		private bool allowBrowserLanguageTargetingCustomizationField;

		private bool allowBrowserLanguageTargetingCustomizationFieldSpecified;

		private bool allowOperatingSystemTargetingCustomizationField;

		private bool allowOperatingSystemTargetingCustomizationFieldSpecified;

		private bool allowDeviceCapabilityTargetingCustomizationField;

		private bool allowDeviceCapabilityTargetingCustomizationFieldSpecified;

		private bool allowDeviceCategoryTargetingCustomizationField;

		private bool allowDeviceCategoryTargetingCustomizationFieldSpecified;

		private bool allowMobileApplicationTargetingCustomizationField;

		private bool allowMobileApplicationTargetingCustomizationFieldSpecified;

		private bool allowMobileCarrierTargetingCustomizationField;

		private bool allowMobileCarrierTargetingCustomizationFieldSpecified;

		private bool allowMobileDeviceAndManufacturerTargetingCustomizationField;

		private bool allowMobileDeviceAndManufacturerTargetingCustomizationFieldSpecified;

		private bool allowAudienceSegmentTargetingCustomizationField;

		private bool allowAudienceSegmentTargetingCustomizationFieldSpecified;

		private bool isAllCustomTargetingKeysCustomizableField;

		private bool isAllCustomTargetingKeysCustomizableFieldSpecified;

		private long[] customizableCustomTargetingKeyIdsField;

		private bool allowDaypartTargetingCustomizationField;

		private bool allowDaypartTargetingCustomizationFieldSpecified;

		private bool allowFrequencyCapsCustomizationField;

		private bool allowFrequencyCapsCustomizationFieldSpecified;

		private bool allowDeliverySettingsCustomizationField;

		private bool allowDeliverySettingsCustomizationFieldSpecified;

		private bool allowCreativePlaceholdersCustomizationField;

		private bool allowCreativePlaceholdersCustomizationFieldSpecified;

		/// <summary>Allows customization by salespeople of geographical targeting when creating
		/// proposal line items. <p>This attribute is optional and defaults to false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool allowGeoTargetingCustomization {
			get {
				return this.allowGeoTargetingCustomizationField;
			}
			set {
				this.allowGeoTargetingCustomizationField = value;
				this.allowGeoTargetingCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowGeoTargetingCustomization" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowGeoTargetingCustomizationSpecified {
			get {
				return this.allowGeoTargetingCustomizationFieldSpecified;
			}
			set {
				this.allowGeoTargetingCustomizationFieldSpecified = value;
			}
		}

		/// <summary>Allows customization by salespeople of ad unit targeting in <a
		/// href='Targeting#inventoryTargeting'>Targeting#inventoryTargeting</a> when
		/// creating proposal line items. <p>This attribute is optional and defaults to
		/// false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public bool allowAdUnitTargetingCustomization {
			get {
				return this.allowAdUnitTargetingCustomizationField;
			}
			set {
				this.allowAdUnitTargetingCustomizationField = value;
				this.allowAdUnitTargetingCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowAdUnitTargetingCustomization" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowAdUnitTargetingCustomizationSpecified {
			get {
				return this.allowAdUnitTargetingCustomizationFieldSpecified;
			}
			set {
				this.allowAdUnitTargetingCustomizationFieldSpecified = value;
			}
		}

		/// <summary>Allows customization by salespeople of placement targeting in <a
		/// href='Targeting#inventoryTargeting'>Targeting#inventoryTargeting</a> when
		/// creating proposal line items. <p>This attribute is optional and defaults to
		/// false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public bool allowPlacementTargetingCustomization {
			get {
				return this.allowPlacementTargetingCustomizationField;
			}
			set {
				this.allowPlacementTargetingCustomizationField = value;
				this.allowPlacementTargetingCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowPlacementTargetingCustomization" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowPlacementTargetingCustomizationSpecified {
			get {
				return this.allowPlacementTargetingCustomizationFieldSpecified;
			}
			set {
				this.allowPlacementTargetingCustomizationFieldSpecified = value;
			}
		}

		/// <summary>Allows customization by salespeople of user domain targeting when creating
		/// proposal line items. <p>This attribute is optional and defaults to false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public bool allowUserDomainTargetingCustomization {
			get {
				return this.allowUserDomainTargetingCustomizationField;
			}
			set {
				this.allowUserDomainTargetingCustomizationField = value;
				this.allowUserDomainTargetingCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowUserDomainTargetingCustomization" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowUserDomainTargetingCustomizationSpecified {
			get {
				return this.allowUserDomainTargetingCustomizationFieldSpecified;
			}
			set {
				this.allowUserDomainTargetingCustomizationFieldSpecified = value;
			}
		}

		/// <summary>Allows customization by salespeople of bandwidth group targeting when creating
		/// proposal line items. <p>This attribute is optional and defaults to false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public bool allowBandwidthGroupTargetingCustomization {
			get {
				return this.allowBandwidthGroupTargetingCustomizationField;
			}
			set {
				this.allowBandwidthGroupTargetingCustomizationField = value;
				this.allowBandwidthGroupTargetingCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowBandwidthGroupTargetingCustomization" />, <code>false</code>
		/// otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowBandwidthGroupTargetingCustomizationSpecified {
			get {
				return this.allowBandwidthGroupTargetingCustomizationFieldSpecified;
			}
			set {
				this.allowBandwidthGroupTargetingCustomizationFieldSpecified = value;
			}
		}

		/// <summary>Allows customization by salespeople of browser targeting when creating proposal
		/// line items. <p>This attribute is optional and defaults to false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public bool allowBrowserTargetingCustomization {
			get {
				return this.allowBrowserTargetingCustomizationField;
			}
			set {
				this.allowBrowserTargetingCustomizationField = value;
				this.allowBrowserTargetingCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowBrowserTargetingCustomization" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowBrowserTargetingCustomizationSpecified {
			get {
				return this.allowBrowserTargetingCustomizationFieldSpecified;
			}
			set {
				this.allowBrowserTargetingCustomizationFieldSpecified = value;
			}
		}

		/// <summary>Allows customization by salespeople of browser language targeting when creating
		/// proposal line items. <p>This attribute is optional and defaults to false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public bool allowBrowserLanguageTargetingCustomization {
			get {
				return this.allowBrowserLanguageTargetingCustomizationField;
			}
			set {
				this.allowBrowserLanguageTargetingCustomizationField = value;
				this.allowBrowserLanguageTargetingCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowBrowserLanguageTargetingCustomization" />, <code>false</code>
		/// otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowBrowserLanguageTargetingCustomizationSpecified {
			get {
				return this.allowBrowserLanguageTargetingCustomizationFieldSpecified;
			}
			set {
				this.allowBrowserLanguageTargetingCustomizationFieldSpecified = value;
			}
		}

		/// <summary>Allows customization by salespeople of operating system targeting when creating
		/// proposal line items. <p>This attribute is optional and defaults to false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public bool allowOperatingSystemTargetingCustomization {
			get {
				return this.allowOperatingSystemTargetingCustomizationField;
			}
			set {
				this.allowOperatingSystemTargetingCustomizationField = value;
				this.allowOperatingSystemTargetingCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowOperatingSystemTargetingCustomization" />, <code>false</code>
		/// otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowOperatingSystemTargetingCustomizationSpecified {
			get {
				return this.allowOperatingSystemTargetingCustomizationFieldSpecified;
			}
			set {
				this.allowOperatingSystemTargetingCustomizationFieldSpecified = value;
			}
		}

		/// <summary>Allows customization by salespeople of device capability targeting when creating
		/// proposal line items. <p>This attribute is optional and defaults to false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public bool allowDeviceCapabilityTargetingCustomization {
			get {
				return this.allowDeviceCapabilityTargetingCustomizationField;
			}
			set {
				this.allowDeviceCapabilityTargetingCustomizationField = value;
				this.allowDeviceCapabilityTargetingCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowDeviceCapabilityTargetingCustomization" />, <code>false</code>
		/// otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowDeviceCapabilityTargetingCustomizationSpecified {
			get {
				return this.allowDeviceCapabilityTargetingCustomizationFieldSpecified;
			}
			set {
				this.allowDeviceCapabilityTargetingCustomizationFieldSpecified = value;
			}
		}

		/// <summary>Allows customization by salespeople of device category targeting when creating
		/// proposal line items. <p>This attribute is optional and defaults to false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public bool allowDeviceCategoryTargetingCustomization {
			get {
				return this.allowDeviceCategoryTargetingCustomizationField;
			}
			set {
				this.allowDeviceCategoryTargetingCustomizationField = value;
				this.allowDeviceCategoryTargetingCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowDeviceCategoryTargetingCustomization" />, <code>false</code>
		/// otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowDeviceCategoryTargetingCustomizationSpecified {
			get {
				return this.allowDeviceCategoryTargetingCustomizationFieldSpecified;
			}
			set {
				this.allowDeviceCategoryTargetingCustomizationFieldSpecified = value;
			}
		}

		/// <summary>Allows customization by salespeople of mobile application targeting when
		/// creating proposal line items. <p>This attribute is optional and defaults to
		/// false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public bool allowMobileApplicationTargetingCustomization {
			get {
				return this.allowMobileApplicationTargetingCustomizationField;
			}
			set {
				this.allowMobileApplicationTargetingCustomizationField = value;
				this.allowMobileApplicationTargetingCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowMobileApplicationTargetingCustomization" />, <code>false</code>
		/// otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowMobileApplicationTargetingCustomizationSpecified {
			get {
				return this.allowMobileApplicationTargetingCustomizationFieldSpecified;
			}
			set {
				this.allowMobileApplicationTargetingCustomizationFieldSpecified = value;
			}
		}

		/// <summary>Allows customization by salespeople of mobile carrier targeting when creating
		/// proposal line items. <p>This attribute is optional and defaults to false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 11)]
		public bool allowMobileCarrierTargetingCustomization {
			get {
				return this.allowMobileCarrierTargetingCustomizationField;
			}
			set {
				this.allowMobileCarrierTargetingCustomizationField = value;
				this.allowMobileCarrierTargetingCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowMobileCarrierTargetingCustomization" />, <code>false</code>
		/// otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowMobileCarrierTargetingCustomizationSpecified {
			get {
				return this.allowMobileCarrierTargetingCustomizationFieldSpecified;
			}
			set {
				this.allowMobileCarrierTargetingCustomizationFieldSpecified = value;
			}
		}

		/// <summary>Allows customization by salespeople of device manufacturer, mobile device, and
		/// mobile device sub-model targeting when creating proposal line items. <p>This
		/// attribute is optional and defaults to false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 12)]
		public bool allowMobileDeviceAndManufacturerTargetingCustomization {
			get {
				return this.allowMobileDeviceAndManufacturerTargetingCustomizationField;
			}
			set {
				this.allowMobileDeviceAndManufacturerTargetingCustomizationField = value;
				this.allowMobileDeviceAndManufacturerTargetingCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowMobileDeviceAndManufacturerTargetingCustomization" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowMobileDeviceAndManufacturerTargetingCustomizationSpecified {
			get {
				return this.allowMobileDeviceAndManufacturerTargetingCustomizationFieldSpecified;
			}
			set {
				this.allowMobileDeviceAndManufacturerTargetingCustomizationFieldSpecified = value;
			}
		}

		/// <summary>Allows customization by salespeople of audience segment targeting when creating
		/// proposal line items. <p>This attribute is optional and defaults to false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 13)]
		public bool allowAudienceSegmentTargetingCustomization {
			get {
				return this.allowAudienceSegmentTargetingCustomizationField;
			}
			set {
				this.allowAudienceSegmentTargetingCustomizationField = value;
				this.allowAudienceSegmentTargetingCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowAudienceSegmentTargetingCustomization" />, <code>false</code>
		/// otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowAudienceSegmentTargetingCustomizationSpecified {
			get {
				return this.allowAudienceSegmentTargetingCustomizationFieldSpecified;
			}
			set {
				this.allowAudienceSegmentTargetingCustomizationFieldSpecified = value;
			}
		}

		/// <summary>Specifies whether all custom targeting keys (except those used in <a
		/// href='ProductSegmentation#customTargetingSegment'>ProductSegmentation#customTargetingSegment</a>)
		/// are allowed to be customized by salespeople. <p>If it's true, then <a
		/// href='#customizableCustomTargetingKeyIds'>#customizableCustomTargetingKeyIds</a>
		/// is ignored.</p> <p>This attribute is optional and defaults to false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 14)]
		public bool isAllCustomTargetingKeysCustomizable {
			get {
				return this.isAllCustomTargetingKeysCustomizableField;
			}
			set {
				this.isAllCustomTargetingKeysCustomizableField = value;
				this.isAllCustomTargetingKeysCustomizableSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isAllCustomTargetingKeysCustomizable" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isAllCustomTargetingKeysCustomizableSpecified {
			get {
				return this.isAllCustomTargetingKeysCustomizableFieldSpecified;
			}
			set {
				this.isAllCustomTargetingKeysCustomizableFieldSpecified = value;
			}
		}

		/// <summary>Specifies what custom criteria salespeople are allow to customize. It refers the
		/// key id of customizable custom criteria here. <p>If <a
		/// href='#isAllCustomTargetingKeysCustomizable'>#isAllCustomTargetingKeysCustomizable</a>
		/// is <code>true</code>, then this attribute is ignored.</p> <p>This attribute is
		/// optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("customizableCustomTargetingKeyIds", Order = 15)]
		public long[] customizableCustomTargetingKeyIds {
			get {
				return this.customizableCustomTargetingKeyIdsField;
			}
			set {
				this.customizableCustomTargetingKeyIdsField = value;
			}
		}

		/// <summary>Allows customization by salespeople of daypart targeting when creating proposal
		/// line items. <p>This attribute is optional and defaults to false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 16)]
		public bool allowDaypartTargetingCustomization {
			get {
				return this.allowDaypartTargetingCustomizationField;
			}
			set {
				this.allowDaypartTargetingCustomizationField = value;
				this.allowDaypartTargetingCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowDaypartTargetingCustomization" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowDaypartTargetingCustomizationSpecified {
			get {
				return this.allowDaypartTargetingCustomizationFieldSpecified;
			}
			set {
				this.allowDaypartTargetingCustomizationFieldSpecified = value;
			}
		}

		/// <summary>Allows customization by salespeople of frequency caps when creating proposal
		/// line items. <p>This attribute is optional and defaults to false when <a
		/// href='ProductTemplate#productType'>ProductTemplate#productType</a> is <a
		/// href='ProductType#DFP'>ProductType#DFP</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 17)]
		public bool allowFrequencyCapsCustomization {
			get {
				return this.allowFrequencyCapsCustomizationField;
			}
			set {
				this.allowFrequencyCapsCustomizationField = value;
				this.allowFrequencyCapsCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowFrequencyCapsCustomization" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowFrequencyCapsCustomizationSpecified {
			get {
				return this.allowFrequencyCapsCustomizationFieldSpecified;
			}
			set {
				this.allowFrequencyCapsCustomizationFieldSpecified = value;
			}
		}

		/// <summary>Allows customization by salespeople of delivery settings when creating proposal
		/// line items. <p>The delivery settings of a <a
		/// href='ProductTemplate'>ProductTemplate</a> include <a
		/// href='ProductTemplate#roadblockingType'>ProductTemplate#roadblockingType</a>, <a
		/// href='ProductTemplate#deliveryRateType'>ProductTemplate#deliveryRateType</a>, <a
		/// href='ProductTemplate#creativeRotationType'>ProductTemplate#creativeRotationType</a>
		/// and <a
		/// href='ProductTemplate#companionDeliveryOption'>ProductTemplate#companionDeliveryOption</a>.</p>
		/// <p>This attribute is optional and defaults to false when <a
		/// href='ProductTemplate#productType'>ProductTemplate#productType</a> is <a
		/// href='ProductType#DFP'>ProductType#DFP</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 18)]
		public bool allowDeliverySettingsCustomization {
			get {
				return this.allowDeliverySettingsCustomizationField;
			}
			set {
				this.allowDeliverySettingsCustomizationField = value;
				this.allowDeliverySettingsCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowDeliverySettingsCustomization" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowDeliverySettingsCustomizationSpecified {
			get {
				return this.allowDeliverySettingsCustomizationFieldSpecified;
			}
			set {
				this.allowDeliverySettingsCustomizationFieldSpecified = value;
			}
		}

		/// <summary>Allows customization of <a href='CreativePlaceholder'>creative placeholders</a>
		/// when creating <a href='ProposalLineItem'>proposal line items</a>. <p>This
		/// attribute is optional and defaults to false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 19)]
		public bool allowCreativePlaceholdersCustomization {
			get {
				return this.allowCreativePlaceholdersCustomizationField;
			}
			set {
				this.allowCreativePlaceholdersCustomizationField = value;
				this.allowCreativePlaceholdersCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowCreativePlaceholdersCustomization" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowCreativePlaceholdersCustomizationSpecified {
			get {
				return this.allowCreativePlaceholdersCustomizationFieldSpecified;
			}
			set {
				this.allowCreativePlaceholdersCustomizationFieldSpecified = value;
			}
		}
	}


	/// <summary><a href='ProposalLineItem'>Proposal line items</a> are created from products,
	/// from which their properties are copied.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Product {
		private string nameField;

		private ValueSourceType nameSourceField;

		private bool nameSourceFieldSpecified;

		private ProductStatus statusField;

		private bool statusFieldSpecified;

		private ProductType productTypeField;

		private bool productTypeFieldSpecified;

		private long productTemplateIdField;

		private bool productTemplateIdFieldSpecified;

		private long idField;

		private bool idFieldSpecified;

		private string notesField;

		private string productTemplateDescriptionField;

		private DateTime lastModifiedDateTimeField;

		private RateType rateTypeField;

		private bool rateTypeFieldSpecified;

		private RoadblockingType roadblockingTypeField;

		private bool roadblockingTypeFieldSpecified;

		private DeliveryRateType deliveryRateTypeField;

		private bool deliveryRateTypeFieldSpecified;

		private CreativeRotationType creativeRotationTypeField;

		private bool creativeRotationTypeFieldSpecified;

		private CompanionDeliveryOption companionDeliveryOptionField;

		private bool companionDeliveryOptionFieldSpecified;

		private CreativePlaceholder[] creativePlaceholdersField;

		private LineItemType lineItemTypeField;

		private bool lineItemTypeFieldSpecified;

		private int priorityField;

		private bool priorityFieldSpecified;

		private FrequencyCap[] frequencyCapsField;

		private Targeting builtInTargetingField;

		private CustomizableAttributes customizableAttributesField;

		private BaseCustomFieldValue[] customFieldValuesField;

		private EnvironmentType environmentTypeField;

		private bool environmentTypeFieldSpecified;

		private Money rateField;

		private ProductMarketplaceInfo productMarketplaceInfoField;

		private long videoMaxDurationField;

		private bool videoMaxDurationFieldSpecified;

		/// <summary>The name of the <code>Product</code>. This attribute is populated by Google, but
		/// can be updated. To overwrite this, set the <a href='#nameSource'>#nameSource</a>
		/// to <a
		/// href='ValueSourceType#DIRECTLY_SPECIFIED'>ValueSourceType#DIRECTLY_SPECIFIED</a>
		/// when setting the value of this field. It has maximum length of 255 characters if
		/// overridden via update. <span class="constraint Required">This attribute is
		/// required.</span>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>Specifies the source of the <a href='Product#name'>Product#name</a> value. To
		/// revert an overridden value to its default, set this field to <a
		/// href='ValueSourceType#PARENT'>ValueSourceType#PARENT</a>. <span
		/// class="constraint Applicable">This attribute is applicable when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public ValueSourceType nameSource {
			get {
				return this.nameSourceField;
			}
			set {
				this.nameSourceField = value;
				this.nameSourceSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="nameSource"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool nameSourceSpecified {
			get {
				return this.nameSourceFieldSpecified;
			}
			set {
				this.nameSourceFieldSpecified = value;
			}
		}

		/// <summary>The status of the <code>Product</code>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public ProductStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>The type of <code>Product</code>. This will always be <a
		/// href='ProductType#DFP'>ProductType#DFP</a> for programmatic guaranteed products.
		/// <span class="constraint ReadOnly">This attribute is read-only when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public ProductType productType {
			get {
				return this.productTypeField;
			}
			set {
				this.productTypeField = value;
				this.productTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="productType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool productTypeSpecified {
			get {
				return this.productTypeFieldSpecified;
			}
			set {
				this.productTypeFieldSpecified = value;
			}
		}

		/// <summary>The ID of the <code>ProductTemplate</code> from which this product is generated.
		/// <span class="constraint Applicable">This attribute is applicable when:</span>
		/// <ul> <li>using programmatic guaranteed, using sales management.</li> <li>not
		/// using programmatic, using sales management.</li> </ul> <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public long productTemplateId {
			get {
				return this.productTemplateIdField;
			}
			set {
				this.productTemplateIdField = value;
				this.productTemplateIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="productTemplateId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool productTemplateIdSpecified {
			get {
				return this.productTemplateIdFieldSpecified;
			}
			set {
				this.productTemplateIdFieldSpecified = value;
			}
		}

		/// <summary>Unique identifier of the <code>Product</code>. This attribute is read-only and
		/// is assigned by Google when a <code>Product</code> is created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The notes of this product. This attribute is optional, with a maximum length of
		/// 511 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public string notes {
			get {
				return this.notesField;
			}
			set {
				this.notesField = value;
			}
		}

		/// <summary>The description of the <code>ProductTemplate</code> from which this product is
		/// generated. <span class="constraint Applicable">This attribute is applicable
		/// when:</span> <ul> <li>using programmatic guaranteed, using sales
		/// management.</li> <li>not using programmatic, using sales management.</li> </ul>
		/// <span class="constraint ReadOnly">This attribute is read-only when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public string productTemplateDescription {
			get {
				return this.productTemplateDescriptionField;
			}
			set {
				this.productTemplateDescriptionField = value;
			}
		}

		/// <summary>The date and time this product was last modified. This attribute is read-only
		/// and is assigned by Google when a product is updated.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public DateTime lastModifiedDateTime {
			get {
				return this.lastModifiedDateTimeField;
			}
			set {
				this.lastModifiedDateTimeField = value;
			}
		}

		/// <summary>The method used for billing the created <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public RateType rateType {
			get {
				return this.rateTypeField;
			}
			set {
				this.rateTypeField = value;
				this.rateTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="rateType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool rateTypeSpecified {
			get {
				return this.rateTypeFieldSpecified;
			}
			set {
				this.rateTypeFieldSpecified = value;
			}
		}

		/// <summary>The strategy for serving roadblocked creatives, i.e. instances where multiple
		/// creatives must be served together on a single web page. <span class="constraint
		/// Applicable">This attribute is applicable when:</span> <ul> <li>using
		/// programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul> <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public RoadblockingType roadblockingType {
			get {
				return this.roadblockingTypeField;
			}
			set {
				this.roadblockingTypeField = value;
				this.roadblockingTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="roadblockingType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool roadblockingTypeSpecified {
			get {
				return this.roadblockingTypeFieldSpecified;
			}
			set {
				this.roadblockingTypeFieldSpecified = value;
			}
		}

		/// <summary>The strategy for delivering ads over the course of the line item's duration.
		/// <span class="constraint Applicable">This attribute is applicable when:</span>
		/// <ul> <li>using programmatic guaranteed, using sales management.</li> <li>not
		/// using programmatic, using sales management.</li> </ul> <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 11)]
		public DeliveryRateType deliveryRateType {
			get {
				return this.deliveryRateTypeField;
			}
			set {
				this.deliveryRateTypeField = value;
				this.deliveryRateTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="deliveryRateType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool deliveryRateTypeSpecified {
			get {
				return this.deliveryRateTypeFieldSpecified;
			}
			set {
				this.deliveryRateTypeFieldSpecified = value;
			}
		}

		/// <summary>The strategy used for displaying multiple <a href='Creative'>Creative</a>
		/// objects that are associated with the created <code>ProposalLineItem</code>.
		/// <span class="constraint Applicable">This attribute is applicable when:</span>
		/// <ul> <li>using programmatic guaranteed, using sales management.</li> <li>not
		/// using programmatic, using sales management.</li> </ul> <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 12)]
		public CreativeRotationType creativeRotationType {
			get {
				return this.creativeRotationTypeField;
			}
			set {
				this.creativeRotationTypeField = value;
				this.creativeRotationTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="creativeRotationType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool creativeRotationTypeSpecified {
			get {
				return this.creativeRotationTypeFieldSpecified;
			}
			set {
				this.creativeRotationTypeFieldSpecified = value;
			}
		}

		/// <summary>The delivery option for companions. <span class="constraint Applicable">This
		/// attribute is applicable when:</span> <ul> <li>using programmatic guaranteed,
		/// using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul> <span class="constraint ReadOnly">This attribute is
		/// read-only when:</span> <ul> <li>using programmatic guaranteed, using sales
		/// management.</li> <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 13)]
		public CompanionDeliveryOption companionDeliveryOption {
			get {
				return this.companionDeliveryOptionField;
			}
			set {
				this.companionDeliveryOptionField = value;
				this.companionDeliveryOptionSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="companionDeliveryOption" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool companionDeliveryOptionSpecified {
			get {
				return this.companionDeliveryOptionFieldSpecified;
			}
			set {
				this.companionDeliveryOptionFieldSpecified = value;
			}
		}

		/// <summary>Details about the creatives that are expected to serve for the created <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. <p>For a <a
		/// href='#roadblockingType'>#roadblockingType</a> of <a
		/// href='RoadblockingType#CREATIVE_SET'>RoadblockingType#CREATIVE_SET</a>, all
		/// creative placeholders must have a master and at least one companion size. <span
		/// class="constraint ReadOnly">This attribute is read-only when:</span></p> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("creativePlaceholders", Order = 14)]
		public CreativePlaceholder[] creativePlaceholders {
			get {
				return this.creativePlaceholdersField;
			}
			set {
				this.creativePlaceholdersField = value;
			}
		}

		/// <summary>Indicates the line item type for the created <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 15)]
		public LineItemType lineItemType {
			get {
				return this.lineItemTypeField;
			}
			set {
				this.lineItemTypeField = value;
				this.lineItemTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lineItemType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lineItemTypeSpecified {
			get {
				return this.lineItemTypeFieldSpecified;
			}
			set {
				this.lineItemTypeFieldSpecified = value;
			}
		}

		/// <summary>The priority for the created <a href='ProposalLineItem'>ProposalLineItem</a>.
		/// The priority is a value between 1 and 16. <span class="constraint ReadOnly">This
		/// attribute is read-only when:</span> <ul> <li>using programmatic guaranteed,
		/// using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 16)]
		public int priority {
			get {
				return this.priorityField;
			}
			set {
				this.priorityField = value;
				this.prioritySpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="priority"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool prioritySpecified {
			get {
				return this.priorityFieldSpecified;
			}
			set {
				this.priorityFieldSpecified = value;
			}
		}

		/// <summary>The set of frequency capping units for the created <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. Each frequency cap in the list
		/// must have unique <a href='TimeUnit'>TimeUnit</a>. <span class="constraint
		/// Applicable">This attribute is applicable when:</span> <ul> <li>using
		/// programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul> <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("frequencyCaps", Order = 17)]
		public FrequencyCap[] frequencyCaps {
			get {
				return this.frequencyCapsField;
			}
			set {
				this.frequencyCapsField = value;
			}
		}

		/// <summary>The targeting for the created <a href='ProposalLineItem'>ProposalLineItem</a>.
		/// For those scenarios using sales management, it's a combination of <a
		/// href='ProductTemplate#productSegmentation'>ProductTemplate#productSegmentation</a>
		/// and <a
		/// href='ProductTemplate#builtInTargeting'>ProductTemplate#builtInTargeting</a>.
		/// See details in <a href='ProductTemplate'>ProductTemplate</a>. <span
		/// class="constraint ReadOnly">This attribute is read-only when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 18)]
		public Targeting builtInTargeting {
			get {
				return this.builtInTargetingField;
			}
			set {
				this.builtInTargetingField = value;
			}
		}

		/// <summary>Specifies what targeting or attributes for the created <a
		/// href='ProposalLineItem'>ProposalLineItem</a> are customizable. <span
		/// class="constraint Applicable">This attribute is applicable when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul> <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 19)]
		public CustomizableAttributes customizableAttributes {
			get {
				return this.customizableAttributesField;
			}
			set {
				this.customizableAttributesField = value;
			}
		}

		/// <summary>The values of the custom fields associated with this <code></code>. This
		/// attribute is optional. <span class="constraint Applicable">This attribute is
		/// applicable when:</span> <ul> <li>using programmatic guaranteed, using sales
		/// management.</li> <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("customFieldValues", Order = 20)]
		public BaseCustomFieldValue[] customFieldValues {
			get {
				return this.customFieldValuesField;
			}
			set {
				this.customFieldValuesField = value;
			}
		}

		/// <summary>The environment that the created <a href='ProposalLineItem'>ProposalLineItem</a>
		/// will target. The default value is <a
		/// href='EnvironmentType#BROWSER'>EnvironmentType#BROWSER</a>. If this value is <a
		/// href='EnvironmentType#VIDEO_PLAYER'>EnvironmentType#VIDEO_PLAYER</a>, then the
		/// <a href='ProposalLineItem'>ProposalLineItem</a> can only target <a
		/// href='AdUnit'>ad units</a> that have <a href='AdUnitSize'>sizes</a> whose <a
		/// href='AdUnitSize#environmentType'>AdUnitSize#environmentType</a> is also <a
		/// href='EnvironmentType#VIDEO_PLAYER'>EnvironmentType#VIDEO_PLAYER</a>. <span
		/// class="constraint ReadOnly">This attribute is read-only when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 21)]
		public EnvironmentType environmentType {
			get {
				return this.environmentTypeField;
			}
			set {
				this.environmentTypeField = value;
				this.environmentTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="environmentType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool environmentTypeSpecified {
			get {
				return this.environmentTypeFieldSpecified;
			}
			set {
				this.environmentTypeFieldSpecified = value;
			}
		}

		/// <summary>The rate of this <code>Product</code>. <span class="constraint Applicable">This
		/// attribute is applicable when:</span> <ul> <li>using programmatic guaranteed, not
		/// using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 22)]
		public Money rate {
			get {
				return this.rateField;
			}
			set {
				this.rateField = value;
			}
		}

		/// <summary>Marketplace information of this <code>Product</code>. <span class="constraint
		/// Applicable">This attribute is applicable when:</span> <ul> <li>using
		/// programmatic guaranteed, using sales management.</li> </ul> <span
		/// class="constraint Required">This attribute is required when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 23)]
		public ProductMarketplaceInfo productMarketplaceInfo {
			get {
				return this.productMarketplaceInfoField;
			}
			set {
				this.productMarketplaceInfoField = value;
			}
		}

		/// <summary>The max duration of a video creative associated with this <code></code> in
		/// milliseconds. This value is only meaningful if this is a video product. <span
		/// class="constraint Applicable">This attribute is applicable when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul> <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 24)]
		public long videoMaxDuration {
			get {
				return this.videoMaxDurationField;
			}
			set {
				this.videoMaxDurationField = value;
				this.videoMaxDurationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="videoMaxDuration" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool videoMaxDurationSpecified {
			get {
				return this.videoMaxDurationFieldSpecified;
			}
			set {
				this.videoMaxDurationFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes the different statuses for <a href='Product'>Product</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProductStatus {
		/// <summary>Accessible to sales person.
		/// </summary>
		ACTIVE = 0,
		/// <summary>Not accessible to sales person.
		/// </summary>
		INACTIVE = 1,
		/// <summary>Products can no longer be used.
		/// </summary>
		ARCHIVED = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Describes the type of <a href='Product'>Product</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProductType {
		/// <summary>For line items that are booked and managed in DFP.
		/// </summary>
		DFP = 0,
		/// <summary>Offline charges indicate services you render for a client which are also outside
		/// of the DFP system, such as consulting or creative services.
		/// </summary>
		OFFLINE = 1,
		/// <summary>For campaigns that are booked and managed by a third party outside of DFP.
		/// </summary>
		NON_DFP = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Lists all programmatic errors associated with products which can be used in
	/// Marketplace.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProgrammaticProductError : ApiError {
		private ProgrammaticProductErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ProgrammaticProductErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ProgrammaticProductError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProgrammaticProductErrorReason {
		/// <summary><a href='ProductMarketplaceInfo'>Product Marketplace info</a> cannot be
		/// <code>null</code>.
		/// </summary>
		PRODUCT_MARKETPLACE_INFO_IS_NULL = 0,
		/// <summary><a href='AdExchangeEnvironment'>AdExchange environment</a> cannot be
		/// <code>null</code>.
		/// </summary>
		ENVIRONMENT_IS_NULL = 1,
		/// <summary><a href='AdExchangeEnvironment'>AdExchange environment</a> is invalid.
		/// </summary>
		INVALID_AD_EXCHANGE_ENVIRONMENT = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Lists all programmatic errors associated with entities which can be used in
	/// Marketplace.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProgrammaticEntitiesError : ApiError {
		private ProgrammaticEntitiesErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ProgrammaticEntitiesErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ProgrammaticEntitiesError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProgrammaticEntitiesErrorReason {
		/// <summary><a href='RateType'>RateType</a> is not supported.
		/// </summary>
		INVALID_RATE_TYPE = 0,
		/// <summary><a href='EnvironmentType'>EnvironmentType</a> must match <a
		/// href='AdExchangeEnvironment'>AdExchange environment</a>.
		/// </summary>
		INVALID_ENVIRONMENT_TYPE = 1,
		/// <summary><a href='ProductType'>ProductType</a> is not supported.
		/// </summary>
		INVALID_PRODUCT_TYPE = 2,
		/// <summary><a href='LineItemType'>LineItemType</a> is not supported.
		/// </summary>
		INVALID_LINE_ITEM_TYPE = 3,
		/// <summary><a href='RoadblockingType'>RoadblockingType</a> is not supported.
		/// </summary>
		INVALID_ROADBLOCKING_TYPE = 4,
		/// <summary><a href='DeliveryRateType'>DeliveryRateType</a> is not supported.
		/// </summary>
		INVALID_DELIVERY_RATE_TYPE = 5,
		/// <summary><a href='CompanionDeliveryOption'>CompanionDeliveryOption</a> is not supported.
		/// </summary>
		INVALID_COMPANION_DELIVERY_OPTION = 6,
		/// <summary><a href='CreativeRotationType'>CreativeRotationType</a> is not supported.
		/// </summary>
		INVALID_CREATIVE_ROTATION_TYPE = 7,
		/// <summary><a href='CreativePlaceholder'>CreativePlaceholder</a> should not have
		/// companions.
		/// </summary>
		INVALID_COMPANION_CREATIVE_PLACEHOLDER = 8,
		/// <summary><a href='CreativePlaceholder'>Creative placeholders</a> cannot be
		/// <code>null</code> or empty.
		/// </summary>
		EMPTY_CREATIVE_PLACEHOLDER = 9,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 10,
	}


	/// <summary>Lists all error reasons associated with <a href='Product'>products</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductError : ApiError {
		private ProductErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ProductErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ProductError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProductErrorReason {
		/// <summary>The specified template is not found.
		/// </summary>
		TEMPLATE_NOT_FOUND = 0,
		/// <summary>The product ID is not correctly formed.
		/// </summary>
		MALFORMED_PRODUCT_ID = 1,
		/// <summary>The product ID does not match the expanded features configured in its product
		/// template.
		/// </summary>
		BAD_PRODUCT_ID_FEATURE = 2,
		/// <summary>The product template ID specified in the parameters does not match the product
		/// template ID implied in the product ID.
		/// </summary>
		BAD_PRODUCT_TEMPLATE_ID = 3,
		/// <summary>Cannot update an archived product.
		/// </summary>
		CANNOT_UPDATE_ARCHIVED_PRODUCT = 4,
		/// <summary>The query is too large to be processed.
		/// </summary>
		QUERY_TOO_LARGE = 5,
		/// <summary>When not using sales management, <a href='Product'>products</a> should not have
		/// <a href='ProductTemplate'>product templates</a>.
		/// </summary>
		PRODUCT_TEMPLATE_ID_IS_NOT_ZERO = 7,
		/// <summary>When not using sales management, <a href='Product'>products</a> cannot have
		/// zero-value rates.
		/// </summary>
		INVALID_RATE = 8,
		/// <summary>When not using sales management, the currency code for <a
		/// href='Product'>products</a> must be the same as the network default currency
		/// code.
		/// </summary>
		INVALID_CURRENCY = 9,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 6,
	}


	/// <summary>Lists all error reasons associated with performing actions on <a
	/// href='Product'>products</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductActionError : ApiError {
		private ProductActionErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ProductActionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ProductActionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProductActionErrorReason {
		/// <summary>The operation is not applicable for a {@like Product product's} current status.
		/// </summary>
		NOT_APPLICABLE = 0,
		/// <summary>You must agree to share contact information, brand features and product data
		/// before publishing products to the Marketplace.
		/// </summary>
		DEALS_LEGAL_AGREEMENT_NOT_ACCEPTED = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>Errors associated with preferred deal <a href='ProposalLineItem'>proposal line
	/// items</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PreferredDealError : ApiError {
		private PreferredDealErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public PreferredDealErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "PreferredDealError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum PreferredDealErrorReason {
		INVALID_PRIORITY = 0,
		/// <summary>Preferred deal <a href='ProposalLineItem'>proposal line items</a> only support
		/// <a href='RateType#CPM'>RateType#CPM</a>.
		/// </summary>
		INVALID_RATE_TYPE = 1,
		/// <summary>Preferred deal <a href='ProposalLineItem'>proposal line items</a> do not support
		/// frequency caps.
		/// </summary>
		INVALID_FREQUENCY_CAPS = 2,
		/// <summary>Preferred deal <a href='ProposalLineItem'>proposal line items</a> only support
		/// <a href='RoadblockingType#ONE_OR_MORE'>RoadblockingType#ONE_OR_MORE</a>.
		/// </summary>
		INVALID_ROADBLOCKING_TYPE = 3,
		/// <summary>Preferred deal <a href='ProposalLineItem'>proposal line items</a> only support
		/// <a href='DeliveryRateType#FRONTLOADED'>DeliveryRateType#FRONTLOADED</a>.
		/// </summary>
		INVALID_DELIVERY_RATE_TYPE = 4,
		UNKNOWN = 5,
	}


	/// <summary>Lists all non-programmatic errors associated with products which can't be used
	/// in Marketplace.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class NonProgrammaticProductError : ApiError {
		private NonProgrammaticProductErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public NonProgrammaticProductErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "NonProgrammaticProductError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum NonProgrammaticProductErrorReason {
		/// <summary><a href='ProductMarketplaceInfo'>Product Marketplace info</a> should be
		/// <code>null</code> for non-programmatic <a href='Product'>products</a>.
		/// </summary>
		PRODUCT_MARKETPLACE_INFO_IS_NOT_NULL = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>An error having to do with <a href='BaseRate'>BaseRate</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class BaseRateError : ApiError {
		private BaseRateErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public BaseRateErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "BaseRateError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum BaseRateErrorReason {
		/// <summary>The currency code is invalid.
		/// </summary>
		INVALID_CURRENCY_CODE = 1,
		/// <summary>Cannot create or activate a base rate if the product template is archived.
		/// </summary>
		PRODUCT_TEMPLATE_ARCHIVED = 2,
		/// <summary>Cannot create or activate a product package item base rate if the product
		/// package item is archived.
		/// </summary>
		PRODUCT_PACKAGE_ITEM_ARCHIVED = 9,
		/// <summary>The PQL statement can only contain one of <code></code>, <code>productId</code>
		/// or <code></code>.
		/// </summary>
		CANNOT_QUERY_ON_MULTIPLE_TYPES = 10,
		/// <summary>Product package must be associated with the rate card of the product package
		/// item base rate. <p>See <a
		/// href='ProductPackage#rateCardIds'>ProductPackage#rateCardIds</a>.</p>
		/// </summary>
		PRODUCT_PACKAGE_RATE_CARD_ASSOCIATION_MISSING = 11,
		/// <summary>Indicates that the requested operation is not supported.
		/// </summary>
		UNSUPPORTED_OPERATION = 3,
		/// <summary>Cannot delete a product package item base rate when its product package is
		/// active.
		/// </summary>
		PRODUCT_PACKAGE_ACTIVE = 12,
		/// <summary>Cannot create a base rate to a product if its product template does not have a
		/// base rate on this rate card.
		/// </summary>
		PRODUCT_TEMPLATE_BASE_RATE_NOT_FOUND = 4,
		/// <summary>Cannot delete a base rate on a product template if its products still have base
		/// rates on this rate card.
		/// </summary>
		PRODUCT_BASE_RATE_EXISTS = 5,
		/// <summary>Marketplace <a href='RateCard'>rate cards</a> should only have Marketplace <a
		/// href='Product'>Product</a>/<a href='ProductTemplate'>ProductTemplate</a> <a
		/// href='BaseRate'>base rates</a>. Non-Marketplace <a href='RateCard'>rate
		/// cards</a> should use traditional base rates.
		/// </summary>
		INVALID_RATE_CARD_CHANNEL = 7,
		/// <summary>Marketplace does not support <a href='BaseRate'>base rates</a> with zero-value
		/// rates.
		/// </summary>
		ZERO_MARKETPLACE_RATE_NOT_SUPPORTED = 8,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 6,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ProductServiceInterface")]
	public interface ProductServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ProductService.createProductsResponse createProducts(Wrappers.ProductService.createProductsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ProductService.createProductsResponse> createProductsAsync(Wrappers.ProductService.createProductsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ProductPage getProductsByStatement(Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductPage> getProductsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performProductAction(Google.Api.Ads.AdManager.v201802.ProductAction productAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performProductActionAsync(Google.Api.Ads.AdManager.v201802.ProductAction productAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ProductService.updateProductsResponse updateProducts(Wrappers.ProductService.updateProductsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ProductService.updateProductsResponse> updateProductsAsync(Wrappers.ProductService.updateProductsRequest request);
	}


	/// <summary>Captures a page of <a href='ProductDto'>ProductDto</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private Product[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of products contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public Product[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on products.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(WithdrawProducts))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(PublishProducts))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeactivateProducts))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateProducts))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class ProductAction {
	}


	/// <summary>The action used to withdraw products from Marketplace.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class WithdrawProducts : ProductAction {
	}


	/// <summary>The action used to publish products to Marketplace.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PublishProducts : ProductAction {
	}


	/// <summary>The action used to deactivate products.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeactivateProducts : ProductAction {
	}


	/// <summary>The action used to activate products.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateProducts : ProductAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ProductServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ProductServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for updating and retrieving <a href='Product'>Product</a>
	/// objects. <p>A <code>Product</code> represents a line item proposal. Products are
	/// generated from <a href=''>ProductTemplate product templates</a> on a periodic
	/// basis using the product template's attributes. Products are typically used by
	/// inventory managers to restrict what salespeople can sell.</p> <p>To use this
	/// service, you need to have the new sales management solution enabled on your
	/// network. If you do not see a "Sales" tab in <a
	/// href="https://www.google.com/dfp">DoubleClick for Publishers (DFP)</a>, you will
	/// not be able to use this service.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ProductService : AdManagerSoapClient<IProductService>, IProductService {
		/// <summary> Creates a new instance of the <see cref="ProductService"/> class.
		/// </summary>
		public ProductService() {
		}

		/// <summary> Creates a new instance of the <see cref="ProductService"/> class.
		/// </summary>
		public ProductService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="ProductService"/> class.
		/// </summary>
		public ProductService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ProductService"/> class.
		/// </summary>
		public ProductService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ProductService"/> class.
		/// </summary>
		public ProductService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ProductService.createProductsResponse Google.Api.Ads.AdManager.v201802.ProductServiceInterface.createProducts(Wrappers.ProductService.createProductsRequest request) {
			return base.Channel.createProducts(request);
		}

		/// <summary>Creates new <a href='Product'>Product</a> objects. This method is only available
		/// when creating programmatic guaranteed products when not using sales management.
		/// </summary><param name='products'>the products to create</param>
		/// <returns>the created products with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Product[] createProducts(Google.Api.Ads.AdManager.v201802.Product[] products) {
			Wrappers.ProductService.createProductsRequest inValue = new Wrappers.ProductService.createProductsRequest();
			inValue.products = products;
			Wrappers.ProductService.createProductsResponse retVal = ((Google.Api.Ads.AdManager.v201802.ProductServiceInterface)(this)).createProducts(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ProductService.createProductsResponse> Google.Api.Ads.AdManager.v201802.ProductServiceInterface.createProductsAsync(Wrappers.ProductService.createProductsRequest request) {
			return base.Channel.createProductsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Product[]> createProductsAsync(Google.Api.Ads.AdManager.v201802.Product[] products) {
			Wrappers.ProductService.createProductsRequest inValue = new Wrappers.ProductService.createProductsRequest();
			inValue.products = products;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Product[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ProductServiceInterface)(this)).createProductsAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='ProductPage'>ProductPage</a> of <a href='Product'>Product</a>
		/// objects that satisfy the criteria specified by given <a
		/// href='Statement#query'>Statement#query</a>. <p>When using sales management, the
		/// following fields are supported for filtering and/or sorting.</p> <table> <tr>
		/// <th scope="col">PQL Property</th> <th scope="col">Object Property</th> <th
		/// scope="col">Filterable</th> <th scope="col">Sortable</th> </tr> <tr>
		/// <td><code>rateCardId</code></td> <td>Rate card ID which the product is
		/// associated with</td> <td>Yes</td> <td>No</td> </tr> <tr>
		/// <td><code>status</code></td> <td><a
		/// href='Product#status'>Product#status</a></td> <td>Yes</td> <td>Yes</td> </tr>
		/// <tr> <td><code>lineItemType</code></td> <td><a
		/// href='Product#lineItemType'>Product#lineItemType</a></td> <td>Yes</td>
		/// <td>Yes</td> </tr> <tr> <td><code>productType</code></td> <td><a
		/// href='Product#productType'>Product#productType</a></td> <td>Yes</td>
		/// <td>Yes</td> </tr> <tr> <td><code>rateType</code></td> <td><a
		/// href='Product#rateType'>Product#rateType</a></td> <td>Yes</td> <td>Yes</td>
		/// </tr> <tr> <td><code>productTemplateId</code></td> <td><a
		/// href='Product#productTemplateId'>Product#productTemplateId</a></td> <td>Yes</td>
		/// <td>No</td> </tr> <tr> <td><code>name</code></td> <td><a
		/// href='Product#name'>Product#name</a></td> <td>Yes</td> <td>Yes</td> </tr> <tr>
		/// <td><code>description</code></td> <td><a
		/// href='Product#description'>Product#description</a></td> <td>Yes</td> <td>No</td>
		/// </tr> <tr> <td><code>id</code></td> <td><a href='Product#id'>Product#id</a></td>
		/// <td>Yes</td> <td>Yes</td> </tr> <tr> <td><code>lastModifiedDateTime</code></td>
		/// <td><a href='Product#lastModifiedDateTime'>Product#lastModifiedDateTime</a></td>
		/// <td>Yes</td> <td>Yes</td> </tr> </table>
		/// </summary><param name='statement'>a Publisher Query Language statement which specifies the
		/// filtering criteria over products</param>
		/// <returns>the products that match the given statement</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ProductPage getProductsByStatement(Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.getProductsByStatement(statement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductPage> getProductsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.getProductsByStatementAsync(statement);
		}

		/// <summary>Performs action on <a href='Product'>Product</a> objects that satisfy the given
		/// <a href='Statement'>Statement</a>.
		/// </summary><param name='productAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of products.</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performProductAction(Google.Api.Ads.AdManager.v201802.ProductAction productAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performProductAction(productAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performProductActionAsync(Google.Api.Ads.AdManager.v201802.ProductAction productAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performProductActionAsync(productAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ProductService.updateProductsResponse Google.Api.Ads.AdManager.v201802.ProductServiceInterface.updateProducts(Wrappers.ProductService.updateProductsRequest request) {
			return base.Channel.updateProducts(request);
		}

		/// <summary>Updates the specified <a href='Product'>Product</a> objects. Note non-updatable
		/// fields will not be backfilled.
		/// </summary><param name='products'>the products to update</param>
		/// <returns>the updated products</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Product[] updateProducts(Google.Api.Ads.AdManager.v201802.Product[] products) {
			Wrappers.ProductService.updateProductsRequest inValue = new Wrappers.ProductService.updateProductsRequest();
			inValue.products = products;
			Wrappers.ProductService.updateProductsResponse retVal = ((Google.Api.Ads.AdManager.v201802.ProductServiceInterface)(this)).updateProducts(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ProductService.updateProductsResponse> Google.Api.Ads.AdManager.v201802.ProductServiceInterface.updateProductsAsync(Wrappers.ProductService.updateProductsRequest request) {
			return base.Channel.updateProductsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Product[]> updateProductsAsync(Google.Api.Ads.AdManager.v201802.Product[] products) {
			Wrappers.ProductService.updateProductsRequest inValue = new Wrappers.ProductService.updateProductsRequest();
			inValue.products = products;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Product[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ProductServiceInterface)(this)).updateProductsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.ProductTemplateService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createProductTemplates", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createProductTemplatesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("productTemplates")]
			public Google.Api.Ads.AdManager.v201802.ProductTemplate[] productTemplates;

			/// <summary> Creates a new instance of the <see
			/// cref="createProductTemplatesRequest"/> class. </summary>
			public createProductTemplatesRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createProductTemplatesRequest"/> class. </summary>
			public createProductTemplatesRequest(Google.Api.Ads.AdManager.v201802.ProductTemplate[] productTemplates) {
				this.productTemplates = productTemplates;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createProductTemplatesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createProductTemplatesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ProductTemplate[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createProductTemplatesResponse"/> class. </summary>
			public createProductTemplatesResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createProductTemplatesResponse"/> class. </summary>
			public createProductTemplatesResponse(Google.Api.Ads.AdManager.v201802.ProductTemplate[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateProductTemplates", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateProductTemplatesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("productTemplates")]
			public Google.Api.Ads.AdManager.v201802.ProductTemplate[] productTemplates;

			/// <summary> Creates a new instance of the <see
			/// cref="updateProductTemplatesRequest"/> class. </summary>
			public updateProductTemplatesRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateProductTemplatesRequest"/> class. </summary>
			public updateProductTemplatesRequest(Google.Api.Ads.AdManager.v201802.ProductTemplate[] productTemplates) {
				this.productTemplates = productTemplates;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateProductTemplatesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateProductTemplatesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ProductTemplate[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateProductTemplatesResponse"/> class. </summary>
			public updateProductTemplatesResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateProductTemplatesResponse"/> class. </summary>
			public updateProductTemplatesResponse(Google.Api.Ads.AdManager.v201802.ProductTemplate[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>Marketplace information for a programmatic <a
	/// href='ProductTemplate'>ProductTemplate</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductTemplateMarketplaceInfo {
		private AdExchangeEnvironment adExchangeEnvironmentField;

		private bool adExchangeEnvironmentFieldSpecified;

		private string additionalTermsField;

		/// <summary>The <a href='AdExchangeEnvironment'>AdExchangeEnvironment</a> of the AdX Web
		/// Property this product will serve to. <p>This field is required.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AdExchangeEnvironment adExchangeEnvironment {
			get {
				return this.adExchangeEnvironmentField;
			}
			set {
				this.adExchangeEnvironmentField = value;
				this.adExchangeEnvironmentSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="adExchangeEnvironment" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool adExchangeEnvironmentSpecified {
			get {
				return this.adExchangeEnvironmentFieldSpecified;
			}
			set {
				this.adExchangeEnvironmentFieldSpecified = value;
			}
		}

		/// <summary>Additional terms shown to the buyer in Marketplace. <p>This field is
		/// optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string additionalTerms {
			get {
				return this.additionalTermsField;
			}
			set {
				this.additionalTermsField = value;
			}
		}
	}


	/// <summary>Segmentations used to create products. Within a product template, for each
	/// segmentation, a product will be created for the combination of all other
	/// segments within other segmentations. <p>For example, a product with 3
	/// segmentations with only 1 segment for each will produce <code>1 x 1 x 1 =
	/// 1</code> product. A product with 3 segmentations with 2 segments for each will
	/// produce <code>2 x 2 x 2 = 8</code> products.</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductSegmentation {
		private GeoTargeting geoSegmentField;

		private AdUnitTargeting[] adUnitSegmentsField;

		private long[] placementSegmentField;

		private CustomCriteria[] customTargetingSegmentField;

		private UserDomainTargeting userDomainSegmentField;

		private BandwidthGroupTargeting bandwidthSegmentField;

		private BrowserTargeting browserSegmentField;

		private BrowserLanguageTargeting browserLanguageSegmentField;

		private OperatingSystemTargeting operatingSystemSegmentField;

		private OperatingSystemVersionTargeting operatingSystemVersionSegmentField;

		private MobileCarrierTargeting mobileCarrierSegmentField;

		private DeviceCapabilityTargeting deviceCapabilitySegmentField;

		private DeviceCategoryTargeting deviceCategorySegmentField;

		private DeviceManufacturerTargeting deviceManufacturerSegmentField;

		private MobileDeviceTargeting mobileDeviceSegmentField;

		private MobileDeviceSubmodelTargeting mobileDeviceSubmodelSegmentField;

		private CreativePlaceholder[] sizeSegmentField;

		private MobileApplicationTargeting mobileApplicationSegmentField;

		private VideoPositionTarget[] videoPositionSegmentField;

		/// <summary>The geographic segmentation. Segments should be set on the <a
		/// href='GeoTargeting#targetedLocations'>GeoTargeting#targetedLocations</a> field.
		/// <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public GeoTargeting geoSegment {
			get {
				return this.geoSegmentField;
			}
			set {
				this.geoSegmentField = value;
			}
		}

		/// <summary>The ad unit targeting segmentation. For each ad unit segment, <a
		/// href='AdUnitTargeting#includeDescendants'>AdUnitTargeting#includeDescendants</a>
		/// must be true. <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("adUnitSegments", Order = 1)]
		public AdUnitTargeting[] adUnitSegments {
			get {
				return this.adUnitSegmentsField;
			}
			set {
				this.adUnitSegmentsField = value;
			}
		}

		/// <summary>The placement targeting segmentation. <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlArrayAttribute(Order = 2)]
		[System.Xml.Serialization.XmlArrayItemAttribute("targetedPlacementIds", IsNullable = false)]
		public long[] placementSegment {
			get {
				return this.placementSegmentField;
			}
			set {
				this.placementSegmentField = value;
			}
		}

		/// <summary>The custom targeting segmentation. <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("customTargetingSegment", Order = 3)]
		public CustomCriteria[] customTargetingSegment {
			get {
				return this.customTargetingSegmentField;
			}
			set {
				this.customTargetingSegmentField = value;
			}
		}

		/// <summary>The user domain segmentation. <a
		/// href='UserDomainTargeting#isTargeted'>UserDomainTargeting#isTargeted</a> must be
		/// <code>true</code>. <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public UserDomainTargeting userDomainSegment {
			get {
				return this.userDomainSegmentField;
			}
			set {
				this.userDomainSegmentField = value;
			}
		}

		/// <summary>The bandwidth segmentation. <a
		/// href='BandwidthGroupTargeting#isTargeted'>BandwidthGroupTargeting#isTargeted</a>
		/// must be <code>true</code>. <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public BandwidthGroupTargeting bandwidthSegment {
			get {
				return this.bandwidthSegmentField;
			}
			set {
				this.bandwidthSegmentField = value;
			}
		}

		/// <summary>The browser segmentation. <a
		/// href='BrowserTargeting#isTargeted'>BrowserTargeting#isTargeted</a> must be
		/// <code>true</code>. <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public BrowserTargeting browserSegment {
			get {
				return this.browserSegmentField;
			}
			set {
				this.browserSegmentField = value;
			}
		}

		/// <summary>The browser language segmentation. <a
		/// href='BrowserLanguageTargeting#isTargeted'>BrowserLanguageTargeting#isTargeted</a>
		/// must be <code>true</code>. <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public BrowserLanguageTargeting browserLanguageSegment {
			get {
				return this.browserLanguageSegmentField;
			}
			set {
				this.browserLanguageSegmentField = value;
			}
		}

		/// <summary>The operating system segmentation. <a
		/// href='OperatingSystemTargeting#isTargeted'>OperatingSystemTargeting#isTargeted</a>
		/// must be <code>true</code>. We only allow segment by Operating_System, not
		/// Operating_System_Version (will be ignored). <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public OperatingSystemTargeting operatingSystemSegment {
			get {
				return this.operatingSystemSegmentField;
			}
			set {
				this.operatingSystemSegmentField = value;
			}
		}

		/// <summary>The operating system version segmentation. <a
		/// href='OperatingSystemVersionTargeting#isTargeted'>OperatingSystemVersionTargeting#isTargeted</a>
		/// must be <code>true</code>. <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public OperatingSystemVersionTargeting operatingSystemVersionSegment {
			get {
				return this.operatingSystemVersionSegmentField;
			}
			set {
				this.operatingSystemVersionSegmentField = value;
			}
		}

		/// <summary>The mobile carrier segmentation. <a
		/// href='MobileCarrierTargeting#isTargeted'>MobileCarrierTargeting#isTargeted</a>
		/// must be <code>true</code>. <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public MobileCarrierTargeting mobileCarrierSegment {
			get {
				return this.mobileCarrierSegmentField;
			}
			set {
				this.mobileCarrierSegmentField = value;
			}
		}

		/// <summary>The device capability segmentation. <a
		/// href=''>DeviceCapabilityTargeting#excludedDeviceCapabilities</a> must be empty
		/// or null. <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 11)]
		public DeviceCapabilityTargeting deviceCapabilitySegment {
			get {
				return this.deviceCapabilitySegmentField;
			}
			set {
				this.deviceCapabilitySegmentField = value;
			}
		}

		/// <summary>The device category segmentation. <a
		/// href='DeviceCategoryTargeting#excludedDeviceCategories'>DeviceCategoryTargeting#excludedDeviceCategories</a>
		/// must be empty or null. <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 12)]
		public DeviceCategoryTargeting deviceCategorySegment {
			get {
				return this.deviceCategorySegmentField;
			}
			set {
				this.deviceCategorySegmentField = value;
			}
		}

		/// <summary>The device manufacturer segmentation. <a
		/// href='DeviceFamilyTargeting#isTargeted'>DeviceFamilyTargeting#isTargeted</a>
		/// must be <code>true</code>. <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 13)]
		public DeviceManufacturerTargeting deviceManufacturerSegment {
			get {
				return this.deviceManufacturerSegmentField;
			}
			set {
				this.deviceManufacturerSegmentField = value;
			}
		}

		/// <summary>The mobile device segmentation. <a
		/// href='MobileDeviceTargeting#excludedMobileDevices'>MobileDeviceTargeting#excludedMobileDevices</a>
		/// must be empty or null. <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 14)]
		public MobileDeviceTargeting mobileDeviceSegment {
			get {
				return this.mobileDeviceSegmentField;
			}
			set {
				this.mobileDeviceSegmentField = value;
			}
		}

		/// <summary>The mobile device submodel segmentation. <a
		/// href=''>MobileDeviceSubmodelTargeting#excludedMobileDeviceSubmodels</a> must be
		/// empty or null.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 15)]
		public MobileDeviceSubmodelTargeting mobileDeviceSubmodelSegment {
			get {
				return this.mobileDeviceSubmodelSegmentField;
			}
			set {
				this.mobileDeviceSubmodelSegmentField = value;
			}
		}

		/// <summary>The creative size segmentation. <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("sizeSegment", Order = 16)]
		public CreativePlaceholder[] sizeSegment {
			get {
				return this.sizeSegmentField;
			}
			set {
				this.sizeSegmentField = value;
			}
		}

		/// <summary>The mobile application segmentation. <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 17)]
		public MobileApplicationTargeting mobileApplicationSegment {
			get {
				return this.mobileApplicationSegmentField;
			}
			set {
				this.mobileApplicationSegmentField = value;
			}
		}

		/// <summary>The video position segmentation. <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlArrayAttribute(Order = 18)]
		[System.Xml.Serialization.XmlArrayItemAttribute("targetedPositions", IsNullable = false)]
		public VideoPositionTarget[] videoPositionSegment {
			get {
				return this.videoPositionSegmentField;
			}
			set {
				this.videoPositionSegmentField = value;
			}
		}
	}


	/// <summary><code>ProductTemplate</code> is used to generate products. All generated
	/// products will inherit all attributes from their <code></code>, except for
	/// segmentation, which will be included in the <a
	/// href='Product#targeting'>Product#targeting</a>. The generated products in turn
	/// will be used to create <a href='ProposalLineItem'>proposal line items</a> so
	/// that almost all attributes in the product template are properties of the
	/// proposal line item.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductTemplate {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private DateTime creationDateTimeField;

		private DateTime lastModifiedDateTimeField;

		private string descriptionField;

		private string nameMacroField;

		private ProductTemplateStatus statusField;

		private bool statusFieldSpecified;

		private ProductType productTypeField;

		private bool productTypeFieldSpecified;

		private long creatorIdField;

		private bool creatorIdFieldSpecified;

		private RateType rateTypeField;

		private bool rateTypeFieldSpecified;

		private RoadblockingType roadblockingTypeField;

		private bool roadblockingTypeFieldSpecified;

		private DeliveryRateType deliveryRateTypeField;

		private bool deliveryRateTypeFieldSpecified;

		private CreativeRotationType creativeRotationTypeField;

		private bool creativeRotationTypeFieldSpecified;

		private CompanionDeliveryOption companionDeliveryOptionField;

		private bool companionDeliveryOptionFieldSpecified;

		private CreativePlaceholder[] creativePlaceholdersField;

		private LineItemType lineItemTypeField;

		private bool lineItemTypeFieldSpecified;

		private int priorityField;

		private bool priorityFieldSpecified;

		private FrequencyCap[] frequencyCapsField;

		private ProductSegmentation productSegmentationField;

		private Targeting builtInTargetingField;

		private CustomizableAttributes customizableAttributesField;

		private BaseCustomFieldValue[] customFieldValuesField;

		private EnvironmentType environmentTypeField;

		private bool environmentTypeFieldSpecified;

		private long videoMaxDurationField;

		private bool videoMaxDurationFieldSpecified;

		private ProductTemplateMarketplaceInfo productTemplateMarketplaceInfoField;

		/// <summary>Uniquely identifies the <code>ProductTemplate</code>. This attribute is
		/// read-only and is assigned by Google when a <code>ProductTemplate</code> is
		/// created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the <code>ProductTemplate</code>. This attribute has maximum length
		/// of 255 characters. <span class="constraint Required">This attribute is
		/// required.</span>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The creation time of the <code>ProductTemplate</code>. This attribute is
		/// read-only and is assigned by Google when a <code>ProductTemplate</code> is
		/// created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public DateTime creationDateTime {
			get {
				return this.creationDateTimeField;
			}
			set {
				this.creationDateTimeField = value;
			}
		}

		/// <summary>The date and time this <code>ProductTemplate</code> was last modified. This
		/// attribute is read-only and is assigned by Google when a <code></code> is
		/// updated.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public DateTime lastModifiedDateTime {
			get {
				return this.lastModifiedDateTimeField;
			}
			set {
				this.lastModifiedDateTimeField = value;
			}
		}

		/// <summary>The description of the <code>ProductTemplate</code>. This attribute has maximum
		/// length of 511 characters. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string description {
			get {
				return this.descriptionField;
			}
			set {
				this.descriptionField = value;
			}
		}

		/// <summary>The name macro of the <code>ProductTemplate</code>. The name macro is used to
		/// generate the <a href=''>Product#name</a>. This attribute is required and has
		/// maximum length of 1023 characters. The name macro can contain plain text and
		/// several placeholders that will be replaced with values specified in the
		/// <code>ProductTemplate</code> when generating product names. Allowed placeholders
		/// are: <table> <tr> <th>Placeholder</th> <th>Segmentation</th> </tr> <tr>
		/// <td><code>&lt;ad-unit&gt;</code></td> <td><a
		/// href='ProductSegmentation#adUnitSegments'>ProductSegmentation#adUnitSegments</a></td>
		/// </tr> <tr> <td><code>&lt;placement&gt;</code></td> <td><a
		/// href='ProductSegmentation#placementSegment'>ProductSegmentation#placementSegment</a></td>
		/// </tr> <tr> <td><code>&lt;location&gt;</code></td> <td><a
		/// href='ProductSegmentation#geoSegment'>ProductSegmentation#geoSegment</a></td>
		/// </tr> <tr> <td><code>&lt;user-domain&gt;</code></td> <td><a
		/// href='ProductSegmentation#userDomainSegment'>ProductSegmentation#userDomainSegment</a></td>
		/// </tr> <tr> <td><code>&lt;bandwidth-group&gt;</code></td> <td><a
		/// href='ProductSegmentation#bandwidthSegment'>ProductSegmentation#bandwidthSegment</a></td>
		/// </tr> <tr> <td><code>&lt;browser&gt;</code></td> <td><a
		/// href='ProductSegmentation#browserSegment'>ProductSegmentation#browserSegment</a></td>
		/// </tr> <tr> <td><code>&lt;browser-language&gt;</code></td> <td><a
		/// href='ProductSegmentation#browserLanguageSegment'>ProductSegmentation#browserLanguageSegment</a></td>
		/// </tr> <tr> <td><code>&lt;operating-system&gt;</code></td> <td><a
		/// href='ProductSegmentation#operatingSystemSegment'>ProductSegmentation#operatingSystemSegment</a></td>
		/// </tr> <tr> <td><code>&lt;frequency-cap&gt;</code></td> <td><a
		/// href='#frequencyCaps'>#frequencyCaps</a></td> </tr> <tr>
		/// <td><code>&lt;rate-type&gt;</code></td> <td><a
		/// href='#rateType'>#rateType</a></td> </tr> <tr>
		/// <td><code>&lt;creative-placeholder-size&gt;</code></td> <td><a
		/// href='#creativePlaceholders'>#creativePlaceholders</a></td> </tr> <tr>
		/// <td><code>&lt;line-item-type&gt;</code></td> <td><a
		/// href='#lineItemType'>#lineItemType</a></td> </tr> <tr>
		/// <td><code>&lt;line-item-priority&gt;</code></td> <td><a
		/// href='#priority'>#priority</a></td> </tr> <tr>
		/// <td><code>&lt;template-name&gt;</code></td> <td><a href='#name'>#name</a></td>
		/// </tr> </table> Each placeholder should appear no more than once and all expanded
		/// features must have their corresponding placeholders in the name macro. This
		/// attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public string nameMacro {
			get {
				return this.nameMacroField;
			}
			set {
				this.nameMacroField = value;
			}
		}

		/// <summary>The status of the <code>ProductTemplate</code>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public ProductTemplateStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>The type of generated <code>Product</code>. <b>Note: if the type is <a
		/// href='ProductType#OFFLINE'>ProductType#OFFLINE</a>, then the following fields
		/// must be null or empty: <a href='#roadblockingType'>#roadblockingType</a>, <a
		/// href='#lineItemType'>#lineItemType</a>, <a
		/// href='#frequencyCaps'>#frequencyCaps</a>, <a
		/// href='#productSegmentation'>#productSegmentation</a> and <a
		/// href='#targeting'>#targeting</a>.</b> <span class="constraint Required">This
		/// attribute is required.</span>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public ProductType productType {
			get {
				return this.productTypeField;
			}
			set {
				this.productTypeField = value;
				this.productTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="productType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool productTypeSpecified {
			get {
				return this.productTypeFieldSpecified;
			}
			set {
				this.productTypeFieldSpecified = value;
			}
		}

		/// <summary>The <a href='User#ID'>id</a> of the user who created the <code></code>. This
		/// attribute is read-only and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public long creatorId {
			get {
				return this.creatorIdField;
			}
			set {
				this.creatorIdField = value;
				this.creatorIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="creatorId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool creatorIdSpecified {
			get {
				return this.creatorIdFieldSpecified;
			}
			set {
				this.creatorIdFieldSpecified = value;
			}
		}

		/// <summary>The method used for billing the created <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. <span class="constraint
		/// Required">This attribute is required.</span>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public RateType rateType {
			get {
				return this.rateTypeField;
			}
			set {
				this.rateTypeField = value;
				this.rateTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="rateType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool rateTypeSpecified {
			get {
				return this.rateTypeFieldSpecified;
			}
			set {
				this.rateTypeFieldSpecified = value;
			}
		}

		/// <summary>The strategy for serving roadblocked creatives, i.e. instances where multiple
		/// creatives must be served together on a single web page. This attribute is
		/// optional and defaults to <a
		/// href='RoadblockingType#ONE_OR_MORE'>RoadblockingType#ONE_OR_MORE</a> if <a
		/// href='#productType'>#productType</a> is <a
		/// href='ProductType#DFP'>ProductType#DFP</a>, or <a
		/// href='RoadblockingType#CREATIVE_SET'>RoadblockingType#CREATIVE_SET</a> if there
		/// are companion sizes in <a
		/// href='#creativePlaceholders'>#creativePlaceholders</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public RoadblockingType roadblockingType {
			get {
				return this.roadblockingTypeField;
			}
			set {
				this.roadblockingTypeField = value;
				this.roadblockingTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="roadblockingType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool roadblockingTypeSpecified {
			get {
				return this.roadblockingTypeFieldSpecified;
			}
			set {
				this.roadblockingTypeFieldSpecified = value;
			}
		}

		/// <summary>The strategy for delivering ads over the course of the line item's duration.
		/// This attribute is optional and defaults to <a
		/// href='DeliveryRateType#EVENLY'>DeliveryRateType#EVENLY</a> if <a
		/// href='#productType'>#productType</a> is <a
		/// href='ProductType#DFP'>ProductType#DFP</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 11)]
		public DeliveryRateType deliveryRateType {
			get {
				return this.deliveryRateTypeField;
			}
			set {
				this.deliveryRateTypeField = value;
				this.deliveryRateTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="deliveryRateType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool deliveryRateTypeSpecified {
			get {
				return this.deliveryRateTypeFieldSpecified;
			}
			set {
				this.deliveryRateTypeFieldSpecified = value;
			}
		}

		/// <summary>The strategy used for displaying multiple <a href='Creative'>Creative</a>
		/// objects that are associated with the created <code>ProposalLineItem</code>. This
		/// attribute is optional and defaults to <a
		/// href='CreativeRotationType#OPTIMIZED'>CreativeRotationType#OPTIMIZED</a> if <a
		/// href='#productType'>#productType</a> is <a
		/// href='ProductType#DFP'>ProductType#DFP</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 12)]
		public CreativeRotationType creativeRotationType {
			get {
				return this.creativeRotationTypeField;
			}
			set {
				this.creativeRotationTypeField = value;
				this.creativeRotationTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="creativeRotationType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool creativeRotationTypeSpecified {
			get {
				return this.creativeRotationTypeFieldSpecified;
			}
			set {
				this.creativeRotationTypeFieldSpecified = value;
			}
		}

		/// <summary>The delivery option for companions. Setting this field is only meaningful if the
		/// following conditions are met: <ol> <li>The <b>Guaranteed roadblocks</b> feature
		/// is enabled on your network.</li> <li>One of the following is true. <ul> <li>The
		/// <a href='#environmentType'>#environmentType</a> is <a
		/// href='EnvironmentType#VIDEO_PLAYER'>EnvironmentType#VIDEO_PLAYER</a>.</li>
		/// <li>The <a href='#roadblockingType'>#roadblockingType</a> is <a
		/// href='RoadblockingType#CREATIVE_SET'>RoadblockingType#CREATIVE_SET</a>.</li>
		/// </ul> </li> </ol> <p>This field is optional and defaults to <a
		/// href='CompanionDeliveryOption#OPTIONAL'>CompanionDeliveryOption#OPTIONAL</a> if
		/// the above conditions are met and <a href='#productType'>#productType</a> is <a
		/// href='ProductType#DFP'>ProductType#DFP</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 13)]
		public CompanionDeliveryOption companionDeliveryOption {
			get {
				return this.companionDeliveryOptionField;
			}
			set {
				this.companionDeliveryOptionField = value;
				this.companionDeliveryOptionSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="companionDeliveryOption" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool companionDeliveryOptionSpecified {
			get {
				return this.companionDeliveryOptionFieldSpecified;
			}
			set {
				this.companionDeliveryOptionFieldSpecified = value;
			}
		}

		/// <summary>Details about the creatives that are expected to serve for the created <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. <p>For a <a
		/// href='#roadblockingType'>#roadblockingType</a> of <a
		/// href='RoadblockingType#CREATIVE_SET'>RoadblockingType#CREATIVE_SET</a>, all
		/// creative placeholders must have a master and at least one companion size. This
		/// attribute is required when <a href='#productType'>#productType</a> is <a
		/// href='ProductType#DFP'>ProductType#DFP</a>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("creativePlaceholders", Order = 14)]
		public CreativePlaceholder[] creativePlaceholders {
			get {
				return this.creativePlaceholdersField;
			}
			set {
				this.creativePlaceholdersField = value;
			}
		}

		/// <summary>Indicates the line item type for the created <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. This attribute is required when <a
		/// href='#productType'>#productType</a> is <a
		/// href='ProductType#DFP'>ProductType#DFP</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 15)]
		public LineItemType lineItemType {
			get {
				return this.lineItemTypeField;
			}
			set {
				this.lineItemTypeField = value;
				this.lineItemTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lineItemType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lineItemTypeSpecified {
			get {
				return this.lineItemTypeFieldSpecified;
			}
			set {
				this.lineItemTypeFieldSpecified = value;
			}
		}

		/// <summary>Priority of <a href='ProposalLineItem'>ProposalLineItem</a>. The priority is a
		/// value between 1 and 16. If not specified, the default priority of the <a
		/// href='LineItemType'>LineItemType</a> will be assigned. The following default,
		/// minimum and maximum priority values is allowed for each line item type: <table>
		/// <tr> <th scope="col">LineItemType</th> <th scope="col">Default Priority</th> <th
		/// scope="col">Minimum Priority</th> <th scope="col">Maximum priority</th> </tr>
		/// <tr> <td><a href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a></td>
		/// <td>4</td> <td>2</td> <td>5</td> </tr> <tr> <td><a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a></td> <td>8</td>
		/// <td>6</td> <td>10</td> </tr> <tr> <td><a
		/// href='LineItemType#NETWORK'>LineItemType#NETWORK</a></td> <td>12</td>
		/// <td>11</td> <td>14</td> </tr> <tr> <td><a
		/// href='LineItemType#BULK'>LineItemType#BULK</a></td> <td>12</td> <td>11</td>
		/// <td>14</td> </tr> <tr> <td><a
		/// href='LineItemType#PRICE_PRIORITY'>LineItemType#PRICE_PRIORITY</a></td>
		/// <td>12</td> <td>11</td> <td>14</td> </tr> <tr> <td><a
		/// href='LineItemType#HOUSE'>LineItemType#HOUSE</a></td> <td>16</td> <td>15</td>
		/// <td>16</td> </tr> </table> Note: it's ignored when <a
		/// href='#productType'>#productType</a> is <a
		/// href='ProductType#OFFLINE'>ProductType#OFFLINE</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 16)]
		public int priority {
			get {
				return this.priorityField;
			}
			set {
				this.priorityField = value;
				this.prioritySpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="priority"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool prioritySpecified {
			get {
				return this.priorityFieldSpecified;
			}
			set {
				this.priorityFieldSpecified = value;
			}
		}

		/// <summary>The set of frequency capping units for the created <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. Each frequency cap in the list
		/// must have unique <a href='TimeUnit'>TimeUnit</a>. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("frequencyCaps", Order = 17)]
		public FrequencyCap[] frequencyCaps {
			get {
				return this.frequencyCapsField;
			}
			set {
				this.frequencyCapsField = value;
			}
		}

		/// <summary>The product segmentation. The combination from the segments and the <a
		/// href='#targeting'>#targeting</a> will produce the targeting on the resulting <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. Any type of segmentation cannot
		/// also be used for targeting. This attribute is optional. Note: if you specify <a
		/// href='ProducSegmentation#geoSegment'>ProducSegmentation#geoSegment</a>, then <a
		/// href='ProductTemplateTargeting#geoTargeting'>ProductTemplateTargeting#geoTargeting</a>
		/// must be null or empty, vice versa. This also applies to other targeting and
		/// segmentation.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 18)]
		public ProductSegmentation productSegmentation {
			get {
				return this.productSegmentationField;
			}
			set {
				this.productSegmentationField = value;
			}
		}

		/// <summary>Targeting to be included in the created <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. Any type targeted cannot also be
		/// used for segmentation. <p>This attribute is optional. Note: if <a
		/// href='#productType'>#productType</a> is <a
		/// href='ProductType#DFP'>ProductType#DFP</a> and <a
		/// href='#productSegmentation'>#productSegmentation</a> is not specified, this
		/// attribute is required.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 19)]
		public Targeting builtInTargeting {
			get {
				return this.builtInTargetingField;
			}
			set {
				this.builtInTargetingField = value;
			}
		}

		/// <summary>Specifies what targeting or attributes for the created <a
		/// href='ProposalLineItem'>ProposalLineItem</a> are customizable. <p>This attribute
		/// is optional. If not specified, then no targeting or attributes are
		/// customizable.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 20)]
		public CustomizableAttributes customizableAttributes {
			get {
				return this.customizableAttributesField;
			}
			set {
				this.customizableAttributesField = value;
			}
		}

		/// <summary>The values of the custom fields associated with this <code></code>. This
		/// attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("customFieldValues", Order = 21)]
		public BaseCustomFieldValue[] customFieldValues {
			get {
				return this.customFieldValuesField;
			}
			set {
				this.customFieldValuesField = value;
			}
		}

		/// <summary>The environment that the created <a href='ProposalLineItem'>ProposalLineItem</a>
		/// is targeting. The default value is <a
		/// href='EnvironmentType#BROWSER'>EnvironmentType#BROWSER</a>. If this value is <a
		/// href='EnvironmentType#VIDEO_PLAYER'>EnvironmentType#VIDEO_PLAYER</a>, then the
		/// <a href='ProposalLineItem'>ProposalLineItem</a> can only target
		/// <code>AdUnits</code> that have <code>AdUnitSizes</code> whose <code></code> is
		/// also <code>VIDEO_PLAYER</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 22)]
		public EnvironmentType environmentType {
			get {
				return this.environmentTypeField;
			}
			set {
				this.environmentTypeField = value;
				this.environmentTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="environmentType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool environmentTypeSpecified {
			get {
				return this.environmentTypeFieldSpecified;
			}
			set {
				this.environmentTypeFieldSpecified = value;
			}
		}

		/// <summary>The max duration of a video creative associated with this <code></code> in
		/// milliseconds. This attribute is optional, defaults to 0, and only meaningful if
		/// this is a video product template.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 23)]
		public long videoMaxDuration {
			get {
				return this.videoMaxDurationField;
			}
			set {
				this.videoMaxDurationField = value;
				this.videoMaxDurationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="videoMaxDuration" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool videoMaxDurationSpecified {
			get {
				return this.videoMaxDurationFieldSpecified;
			}
			set {
				this.videoMaxDurationFieldSpecified = value;
			}
		}

		/// <summary>Marketplace information of this <code>ProductTemplate</code>. <span
		/// class="constraint Applicable">This attribute is applicable when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> </ul> <span
		/// class="constraint Required">This attribute is required when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 24)]
		public ProductTemplateMarketplaceInfo productTemplateMarketplaceInfo {
			get {
				return this.productTemplateMarketplaceInfoField;
			}
			set {
				this.productTemplateMarketplaceInfoField = value;
			}
		}
	}


	/// <summary>Describes the different statuses for ProductTemplate.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProductTemplateStatus {
		/// <summary>Product template is active, and all products it generates without status
		/// overridden are available in product catalog.
		/// </summary>
		ACTIVE = 0,
		/// <summary>Not used.
		/// </summary>
		DRAFT = 1,
		/// <summary>Product template is inactive, no product is generated.
		/// </summary>
		CANCELED = 2,
		/// <summary>No unarchived proposal should reference this template and report on it. All
		/// persisted products based on this product template are archived as well.
		/// </summary>
		ARCHIVED = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>A catch-all error that lists all generic errors associated with ProductTemplate.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductTemplateError : ApiError {
		private ProductTemplateErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ProductTemplateErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ProductTemplateError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProductTemplateErrorReason {
		/// <summary>One feature affinity should be expanded or not-expanded exclusively.
		/// </summary>
		INVALID_FEATURE_EXPANDED_EXCLUSIVE = 0,
		/// <summary>Expanded feature should have false default targeting type.
		/// </summary>
		INVALID_EXPANDED_FEATURE_DEFAULT_NOT_TARGETED = 1,
		/// <summary>Expanded feature should be default locked.
		/// </summary>
		INVALID_EXPANDED_FEATURE_DEFAULT_LOCKED = 2,
		/// <summary>Expanded feature value should have true targeting type.
		/// </summary>
		INVALID_EXPANDED_FEATURE_VALUE_TARGETED = 3,
		/// <summary>Expanded feature value should be default locked.
		/// </summary>
		INVALID_EXPANDED_FEATURE_VALUE_LOCKED = 4,
		/// <summary>The feature type is mismatch with feature value's type.
		/// </summary>
		INVALID_FEATURE_TYPE = 5,
		/// <summary>The roadblocking type is invalid.
		/// </summary>
		INVALID_ROADBLOCKING_TYPE = 6,
		/// <summary>The delivery rate type is invalid.
		/// </summary>
		INVALID_DELIVERY_RATE_TYPE = 60,
		/// <summary>The creative rotation type is invalid.
		/// </summary>
		INVALID_CREATIVE_ROTATION_TYPE = 61,
		/// <summary>The companion delivery option is invalid.
		/// </summary>
		INVALID_COMPANION_DELIVERY_OPTION = 62,
		/// <summary>The targeting is invalid.
		/// </summary>
		INVALID_TARGETING = 7,
		/// <summary>The frequency cap is invalid.
		/// </summary>
		INVALID_FREQUENCY_CAPS = 8,
		/// <summary>The technology criteria is included and excluded at same time.
		/// </summary>
		INVALID_TECHNOLOGY_INCLUDE_EXCLUDE = 9,
		INVALID_EXPANDED_PRODUCT_COUNT = 10,
		/// <summary>The target platform should always be WEB.
		/// </summary>
		INVALID_TARGET_PLATFORM = 11,
		/// <summary>The non-targeting feature cannot have default target type TRUE.
		/// </summary>
		INVALID_NON_TARGETING_FEATURE = 12,
		/// <summary>The feature's targeted value number breaks the cardinality request, it should
		/// have at least one value.
		/// </summary>
		INVALID_FEATURE_CARDINALITY_AT_LEAST_ONE = 13,
		/// <summary>The feature's targeted value number breaks the cardinality request, it should
		/// have at most one value.
		/// </summary>
		INVALID_FEATURE_CARDINALITY_AT_MOST_ONE = 14,
		/// <summary>The feature's targeted value number breaks the cardinality request, it should
		/// have exactly one value.
		/// </summary>
		INVALID_FEATURE_CARDINALITY_EXACTLY_ONE = 15,
		/// <summary>The feature is invalid for offline product template.
		/// </summary>
		INVALID_FEATURE_FOR_OFFLINE = 16,
		/// <summary>The rate type is invalid for offline product template.
		/// </summary>
		INVALID_RATE_TYPE_FOR_OFFLINE = 17,
		/// <summary>The rate type should be in the valid set for corresponding line item type of a
		/// dfp product template.
		/// </summary>
		INVALID_RATE_TYPE_FOR_DFP = 18,
		/// <summary>The rate type should be in the valid set for corresponding line item type of a
		/// <a href='ProductType#NON_DFP'>ProductType#NON_DFP</a> product template.
		/// </summary>
		INVALID_RATE_TYPE_FOR_NON_DFP = 19,
		/// <summary>One or more values on the product template are not valid for a <a
		/// href='LineItemType#CLICK_TRACKING'>LineItemType#CLICK_TRACKING</a> line item
		/// type.
		/// </summary>
		INVALID_VALUES_FOR_CLICK_TRACKING_LINE_ITEM_TYPE = 20,
		/// <summary>The segmentation or targeting on the product template is not valid for a <a
		/// href='LineItemType#CLICK_TRACKING'>LineItemType#CLICK_TRACKING</a> line item
		/// type.
		/// </summary>
		INVALID_SEGMENTATION_OR_TARGETING_FOR_CLICK_TRACKING_LINE_ITEM_TYPE = 21,
		/// <summary>The line item priority feature is not match with line item type feature.
		/// </summary>
		INVALID_LINE_ITEM_PRIORITY = 22,
		/// <summary>The line item type value is not supported.
		/// </summary>
		INVALID_LINE_ITEM_TYPE = 23,
		/// <summary>The environment type is not valid.
		/// </summary>
		INVALID_ENVIRONMENT_TYPE = 24,
		/// <summary>Duplication of placeholder for feature type affinity exists in name macro.
		/// </summary>
		DUPLICATED_PLACEHOLDER_IN_NAMEMACRO = 25,
		/// <summary>Expanded features are not allowed in non expandable feature affinity.
		/// </summary>
		INVALID_EXPANDED_FEATURE_IN_NON_EXPANDABLE_AFFINITY = 26,
		/// <summary>The default target type of the feature is not supported.
		/// </summary>
		INVALID_FEATURE_DEFAULT_TARGET_TYPE = 27,
		/// <summary>The target type of the value is invalid.
		/// </summary>
		INVALID_FEATURE_VALUE_TARGET_TYPE = 28,
		/// <summary>The default locked of feature is different with locked of feature values.
		/// </summary>
		INVALID_FEATURE_AND_VALUE_LOCK_EXCLUSIVE = 29,
		/// <summary>The creative placeholder should have at least a master size, or has one master
		/// and multiple companion sizes.
		/// </summary>
		INVALID_CREATIVE_PLACEHOLDER = 30,
		/// <summary>Duplicated features with the same feature type.
		/// </summary>
		DUPLICATED_FEATURE = 31,
		/// <summary>Duplicated custom criteria key.
		/// </summary>
		DUPLICATED_CUSTOM_TARGETING_KEY = 32,
		/// <summary>Duplicated custom criteria value.
		/// </summary>
		DUPLICATED_CUSTOM_TARGETING_VALUE = 33,
		/// <summary>The id of custom criteria key is invalid.
		/// </summary>
		INVALID_CUSTOM_TARGETING_KEY_ID = 34,
		/// <summary>The id of custom criteria value is invalid.
		/// </summary>
		INVALID_CUSTOM_TARGETING_VALUE_ID = 35,
		/// <summary>Missing custom targeting values.
		/// </summary>
		MISSING_CUSTOM_TARGETING_VALUES = 36,
		/// <summary>A child location can not be targeted if any one of its parent locations is also
		/// targeted.
		/// </summary>
		LOCATION_CANNOT_BE_TARGETED_IF_PARENT_IS_TARGETED = 37,
		/// <summary>A child location can not be excluded if any one of its parent locations is also
		/// excluded.
		/// </summary>
		LOCATION_CANNOT_BE_EXCLUDED_IF_PARENT_IS_EXCLUDED = 38,
		/// <summary>An excluded location must have one targeted parent when targeted location is not
		/// empty.
		/// </summary>
		LOCATION_CANNOT_BE_EXCLUDED_DIRECTLY_WHEN_HAVE_TARGETED_LOCATION = 39,
		/// <summary>Customizable key is used in custom targeting segment.
		/// </summary>
		CUSTOMIZABLE_CUSTOM_KEY_CANNOT_BE_SEGMENTED = 40,
		/// <summary>Custom targeting key is already used in custom targeting segment.
		/// </summary>
		CUSTOM_KEY_USED_IN_TARGETING_CANNOT_BE_SEGMENTED = 41,
		/// <summary>A placeholder for an expanded feature type affinity is missing in name macro.
		/// </summary>
		MISSING_EXPANDED_FEATURE_PLACEHOLDER_IN_NAMEMACRO = 43,
		/// <summary>The feature type affinity with placeholder been added is missing corresponding
		/// value.
		/// </summary>
		MISSING_FEATURE_VALUE_OF_NAMEMACRO_PLACEHOLDER = 44,
		/// <summary>The feature type affinity with placeholder been added is not specified.
		/// </summary>
		MISSING_FEATURE_OF_NAMEMACRO_PLACEHOLDER = 45,
		/// <summary>The SubTypeId of custom criteria feature is not specified.
		/// </summary>
		MISSING_SUBTYPE_FOR_CUSTOM_TARGETING = 46,
		/// <summary>A placeholder contains companions but the roadblocking type is not CREATIVE_SET
		/// or the product type is offline.
		/// </summary>
		COMPANION_NOT_ALLOWED = 47,
		/// <summary>A placeholder does not contain companions but the roadblocking type is
		/// CREATIVE_SET.
		/// </summary>
		MISSING_COMPANION = 48,
		/// <summary>A placeholder's master size is the same as another placeholder.
		/// </summary>
		DUPLICATED_MASTER_SIZE = 49,
		/// <summary>Non-native placeholders cannot have creative templates.
		/// </summary>
		CANNOT_HAVE_CREATIVE_TEMPLATE = 63,
		/// <summary>Placeholders can only have native creative templates.
		/// </summary>
		NATIVE_CREATIVE_TEMPLATE_REQUIRED = 64,
		/// <summary>Cannot include native placeholders without native creative templates.
		/// </summary>
		CANNOT_INCLUDE_NATIVE_PLACEHOLDER_WITHOUT_TEMPLATE_ID = 65,
		/// <summary>The feature is readonly.
		/// </summary>
		CANNOT_MODIFY_READONLY_FEATURE = 50,
		/// <summary>The product type can not be modified after creation.
		/// </summary>
		CANNOT_MODIFY_PRODUCT_TYPE = 51,
		/// <summary>Cannot add new segmentations after product template is saved.
		/// </summary>
		CANNOT_ADD_SEGMENTATION = 52,
		/// <summary>Cannot remove segmentations after product template is saved.
		/// </summary>
		CANNOT_REMOVE_SEGMENTATION = 53,
		/// <summary>Cannot remove value from segmentation after product template is saved.
		/// </summary>
		CANNOT_REMOVE_VALUE_FROM_SEGMENTATION = 54,
		/// <summary>Cannot add feature value for custom targeting.
		/// </summary>
		CANNOT_ADD_FEATURE_VALUE_FOR_CUSTOM_TARGETING = 55,
		/// <summary>Cannot modify a builtin targeting feature.
		/// </summary>
		CANNOT_MODIFY_BUILTIN_TARGETING_FEATURE = 56,
		/// <summary>Cannot update an archived product template.
		/// </summary>
		CANNOT_UPDATE_ARCHIVED_PRODUCT_TEMPLATE = 57,
		/// <summary>There are video position values that are invalid for the <a
		/// href='LineItemType'>LineItemType</a>.
		/// </summary>
		INVALID_VIDEO_POSITION_VALUE_FOR_LINE_ITEM_TYPE = 58,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 59,
	}


	/// <summary>An error lists all error reasons associated with performing action on <a
	/// href='ProductTemplate'>ProductTemplate</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductTemplateActionError : ApiError {
		private ProductTemplateActionErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ProductTemplateActionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ProductTemplateActionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProductTemplateActionErrorReason {
		/// <summary>The operation is not applicable to the current status.
		/// </summary>
		NOT_APPLICABLE = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ProductTemplateServiceInterface")]
	public interface ProductTemplateServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ProductTemplateService.createProductTemplatesResponse createProductTemplates(Wrappers.ProductTemplateService.createProductTemplatesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ProductTemplateService.createProductTemplatesResponse> createProductTemplatesAsync(Wrappers.ProductTemplateService.createProductTemplatesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ProductTemplatePage getProductTemplatesByStatement(Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductTemplatePage> getProductTemplatesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performProductTemplateAction(Google.Api.Ads.AdManager.v201802.ProductTemplateAction action, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performProductTemplateActionAsync(Google.Api.Ads.AdManager.v201802.ProductTemplateAction action, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ProductTemplateService.updateProductTemplatesResponse updateProductTemplates(Wrappers.ProductTemplateService.updateProductTemplatesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ProductTemplateService.updateProductTemplatesResponse> updateProductTemplatesAsync(Wrappers.ProductTemplateService.updateProductTemplatesRequest request);
	}


	/// <summary>Captures a page of <a href='ProductTemplate'>ProductTemplate</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductTemplatePage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private ProductTemplate[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of <a href='ProductTemplate'>ProductTemplate</a> contained within
		/// this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public ProductTemplate[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on product templates.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UnarchiveProductTemplates))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeactivateProductTemplates))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ArchiveProductTemplates))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateProductTemplates))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class ProductTemplateAction {
	}


	/// <summary>The action used for unarchiving <a href='ProductTemplate'>ProductTemplate</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UnarchiveProductTemplates : ProductTemplateAction {
	}


	/// <summary>The action used for deactivating product templates.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeactivateProductTemplates : ProductTemplateAction {
	}


	/// <summary>The action used for archiving product template.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ArchiveProductTemplates : ProductTemplateAction {
	}


	/// <summary>The action used for activating product templates.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateProductTemplates : ProductTemplateAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ProductTemplateServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ProductTemplateServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='ProductTemplate'>ProductTemplate</a> objects. <p>A product template is
	/// used to generate a set of products. Products allow inventory managers to control
	/// what salespeople can sell.</p> <p>To use this service, you need to have the new
	/// sales management solution enabled on your network. If you do not see a "Sales"
	/// tab in <a href="https://www.google.com/dfp">DoubleClick for Publishers
	/// (DFP)</a>, you will not be able to use this service.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ProductTemplateService : AdManagerSoapClient<IProductTemplateService>, IProductTemplateService {
		/// <summary> Creates a new instance of the <see cref="ProductTemplateService"/>
		/// class. </summary>
		public ProductTemplateService() {
		}

		/// <summary> Creates a new instance of the <see cref="ProductTemplateService"/>
		/// class. </summary>
		public ProductTemplateService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="ProductTemplateService"/>
		/// class. </summary>
		public ProductTemplateService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ProductTemplateService"/>
		/// class. </summary>
		public ProductTemplateService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ProductTemplateService"/>
		/// class. </summary>
		public ProductTemplateService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ProductTemplateService.createProductTemplatesResponse Google.Api.Ads.AdManager.v201802.ProductTemplateServiceInterface.createProductTemplates(Wrappers.ProductTemplateService.createProductTemplatesRequest request) {
			return base.Channel.createProductTemplates(request);
		}

		/// <summary>Creates new <a href='ProductTemplate'>ProductTemplate</a> objects.
		/// </summary><param name='productTemplates'>the productTemplates to create</param>
		/// <returns>the persisted product templates with their Ids filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ProductTemplate[] createProductTemplates(Google.Api.Ads.AdManager.v201802.ProductTemplate[] productTemplates) {
			Wrappers.ProductTemplateService.createProductTemplatesRequest inValue = new Wrappers.ProductTemplateService.createProductTemplatesRequest();
			inValue.productTemplates = productTemplates;
			Wrappers.ProductTemplateService.createProductTemplatesResponse retVal = ((Google.Api.Ads.AdManager.v201802.ProductTemplateServiceInterface)(this)).createProductTemplates(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ProductTemplateService.createProductTemplatesResponse> Google.Api.Ads.AdManager.v201802.ProductTemplateServiceInterface.createProductTemplatesAsync(Wrappers.ProductTemplateService.createProductTemplatesRequest request) {
			return base.Channel.createProductTemplatesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductTemplate[]> createProductTemplatesAsync(Google.Api.Ads.AdManager.v201802.ProductTemplate[] productTemplates) {
			Wrappers.ProductTemplateService.createProductTemplatesRequest inValue = new Wrappers.ProductTemplateService.createProductTemplatesRequest();
			inValue.productTemplates = productTemplates;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductTemplate[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ProductTemplateServiceInterface)(this)).createProductTemplatesAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='ProductTemplatePage'>ProductTemplatePage</a> of <a
		/// href='ProductTemplate'>ProductTemplate</a> objects that satisfy the filtering
		/// criteria specified by given <a href='Statement#query'>Statement#query</a>. The
		/// following fields are supported for filtering: <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>id</code></td> <td><a
		/// href='ProductTemplate#id'>ProductTemplate#id</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a
		/// href='ProductTemplate#name'>ProductTemplate#name</a></td> </tr> <tr>
		/// <td><code>nameMacro</code></td> <td><a
		/// href='ProductTemplate#nameMacro'>ProductTemplate#nameMacro</a></td> </tr> <tr>
		/// <td><code>description</code></td> <td><a
		/// href='ProductTemplate#description'>ProductTemplate#description</a></td> </tr>
		/// <tr> <td><code>status</code></td> <td><a
		/// href='ProductTemplate#status'>ProductTemplate#status</a></td> </tr> <tr>
		/// <td><code>lastModifiedDateTime</code></td> <td><a
		/// href='ProductTemplate#lastModifiedDateTime'>ProductTemplate#lastModifiedDateTime</a></td>
		/// </tr> <tr> <td><code>lineItemType</code></td> <td><a
		/// href='LineItemType'>LineItemType</a></td> </tr> <tr>
		/// <td><code>productType</code></td> <td><a href='ProductType'>ProductType</a></td>
		/// </tr> <tr> <td><code>rateType</code></td> <td><a
		/// href='RateType'>RateType</a></td> </tr> </table>
		/// </summary><param name='statement'>a Publisher Query Language statement which specifies the
		/// filtering criteria over productTemplates</param>
		/// <returns>the productTemplates that match the given statement</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ProductTemplatePage getProductTemplatesByStatement(Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.getProductTemplatesByStatement(statement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductTemplatePage> getProductTemplatesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.getProductTemplatesByStatementAsync(statement);
		}

		/// <summary>Performs action on <a href='ProductTemplate'>ProductTemplate</a> objects that
		/// satisfy the given <a href='Statement#query'>Statement#query</a>.
		/// </summary><param name='action'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of product templates</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performProductTemplateAction(Google.Api.Ads.AdManager.v201802.ProductTemplateAction action, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performProductTemplateAction(action, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performProductTemplateActionAsync(Google.Api.Ads.AdManager.v201802.ProductTemplateAction action, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performProductTemplateActionAsync(action, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ProductTemplateService.updateProductTemplatesResponse Google.Api.Ads.AdManager.v201802.ProductTemplateServiceInterface.updateProductTemplates(Wrappers.ProductTemplateService.updateProductTemplatesRequest request) {
			return base.Channel.updateProductTemplates(request);
		}

		/// <summary>Updates the specified <a href='ProductTemplate'>ProductTemplate</a> objects.
		/// </summary><param name='productTemplates'>the product templates to update</param>
		/// <returns>the updated product templates</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ProductTemplate[] updateProductTemplates(Google.Api.Ads.AdManager.v201802.ProductTemplate[] productTemplates) {
			Wrappers.ProductTemplateService.updateProductTemplatesRequest inValue = new Wrappers.ProductTemplateService.updateProductTemplatesRequest();
			inValue.productTemplates = productTemplates;
			Wrappers.ProductTemplateService.updateProductTemplatesResponse retVal = ((Google.Api.Ads.AdManager.v201802.ProductTemplateServiceInterface)(this)).updateProductTemplates(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ProductTemplateService.updateProductTemplatesResponse> Google.Api.Ads.AdManager.v201802.ProductTemplateServiceInterface.updateProductTemplatesAsync(Wrappers.ProductTemplateService.updateProductTemplatesRequest request) {
			return base.Channel.updateProductTemplatesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductTemplate[]> updateProductTemplatesAsync(Google.Api.Ads.AdManager.v201802.ProductTemplate[] productTemplates) {
			Wrappers.ProductTemplateService.updateProductTemplatesRequest inValue = new Wrappers.ProductTemplateService.updateProductTemplatesRequest();
			inValue.productTemplates = productTemplates;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductTemplate[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ProductTemplateServiceInterface)(this)).updateProductTemplatesAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.ProposalService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createProposals", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createProposalsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("proposals")]
			public Google.Api.Ads.AdManager.v201802.Proposal[] proposals;

			/// <summary> Creates a new instance of the <see cref="createProposalsRequest"/>
			/// class. </summary>
			public createProposalsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createProposalsRequest"/>
			/// class. </summary>
			public createProposalsRequest(Google.Api.Ads.AdManager.v201802.Proposal[] proposals) {
				this.proposals = proposals;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createProposalsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createProposalsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Proposal[] rval;

			/// <summary> Creates a new instance of the <see cref="createProposalsResponse"/>
			/// class. </summary>
			public createProposalsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createProposalsResponse"/>
			/// class. </summary>
			public createProposalsResponse(Google.Api.Ads.AdManager.v201802.Proposal[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateProposals", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateProposalsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("proposals")]
			public Google.Api.Ads.AdManager.v201802.Proposal[] proposals;

			/// <summary> Creates a new instance of the <see cref="updateProposalsRequest"/>
			/// class. </summary>
			public updateProposalsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updateProposalsRequest"/>
			/// class. </summary>
			public updateProposalsRequest(Google.Api.Ads.AdManager.v201802.Proposal[] proposals) {
				this.proposals = proposals;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateProposalsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateProposalsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Proposal[] rval;

			/// <summary> Creates a new instance of the <see cref="updateProposalsResponse"/>
			/// class. </summary>
			public updateProposalsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updateProposalsResponse"/>
			/// class. </summary>
			public updateProposalsResponse(Google.Api.Ads.AdManager.v201802.Proposal[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>Represents the buyer RFP information associated with a <a
	/// href='Proposal'>Proposal</a> describing the requirements from the buyer.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class BuyerRfp {
		private Money costPerUnitField;

		private long unitsField;

		private bool unitsFieldSpecified;

		private Money budgetField;

		private string currencyCodeField;

		private DateTime startDateTimeField;

		private DateTime endDateTimeField;

		private string descriptionField;

		private CreativePlaceholder[] creativePlaceholdersField;

		private Targeting targetingField;

		private string additionalTermsField;

		private AdExchangeEnvironment adExchangeEnvironmentField;

		private bool adExchangeEnvironmentFieldSpecified;

		private RfpType rfpTypeField;

		private bool rfpTypeFieldSpecified;

		/// <summary>CPM for the <a href='Proposal'>Proposal</a> in question. Given that this field
		/// belongs to a request for proposal (for which initially a <a
		/// href='Proposal'>Proposal</a> does not yet exist), this field should serve as
		/// guidance for publishers to create a <a href='Proposal'>Proposal</a> with <a
		/// href='LineItem'>LineItem</a>s reflecting this CPM. <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, not using sales management.</li> <li>using preferred deals, not
		/// using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public Money costPerUnit {
			get {
				return this.costPerUnitField;
			}
			set {
				this.costPerUnitField = value;
			}
		}

		/// <summary>The number of impressions per day that a buyer wishes to see in the <a
		/// href='Proposal'>Proposal</a> derived from the request for proposal in question.
		/// <span class="constraint ReadOnly">This attribute is read-only when:</span> <ul>
		/// <li>using programmatic guaranteed, not using sales management.</li> <li>using
		/// preferred deals, not using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long units {
			get {
				return this.unitsField;
			}
			set {
				this.unitsField = value;
				this.unitsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="units" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool unitsSpecified {
			get {
				return this.unitsFieldSpecified;
			}
			set {
				this.unitsFieldSpecified = value;
			}
		}

		/// <summary>Total amount of <a href='Money'>Money</a> available to spend on this deal. In
		/// the case of Preferred Deal, the budget is equal to the maximum amount of money a
		/// buyer is willing to spend on a given <a href='Proposal'>Proposal</a>, even
		/// though the budget might not be spent entirely, as impressions are not
		/// guaranteed. <span class="constraint ReadOnly">This attribute is read-only
		/// when:</span> <ul> <li>using programmatic guaranteed, not using sales
		/// management.</li> <li>using preferred deals, not using sales management.</li>
		/// </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public Money budget {
			get {
				return this.budgetField;
			}
			set {
				this.budgetField = value;
			}
		}

		/// <summary>Currency code for this deal's budget and CPM. <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, not using sales management.</li> <li>using preferred deals, not
		/// using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string currencyCode {
			get {
				return this.currencyCodeField;
			}
			set {
				this.currencyCodeField = value;
			}
		}

		/// <summary>The <a href='DateTime'>DateTime</a> in which the proposed deal should start
		/// serving. <span class="constraint ReadOnly">This attribute is read-only
		/// when:</span> <ul> <li>using programmatic guaranteed, not using sales
		/// management.</li> <li>using preferred deals, not using sales management.</li>
		/// </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public DateTime startDateTime {
			get {
				return this.startDateTimeField;
			}
			set {
				this.startDateTimeField = value;
			}
		}

		/// <summary>The <a href='DateTime'>DateTime</a> in which the proposed deal should end
		/// serving. <span class="constraint ReadOnly">This attribute is read-only
		/// when:</span> <ul> <li>using programmatic guaranteed, not using sales
		/// management.</li> <li>using preferred deals, not using sales management.</li>
		/// </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public DateTime endDateTime {
			get {
				return this.endDateTimeField;
			}
			set {
				this.endDateTimeField = value;
			}
		}

		/// <summary>A description of the proposed deal. This can be used for the buyer to tell the
		/// publisher more detailed information about the deal in question. <span
		/// class="constraint ReadOnly">This attribute is read-only when:</span> <ul>
		/// <li>using programmatic guaranteed, not using sales management.</li> <li>using
		/// preferred deals, not using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public string description {
			get {
				return this.descriptionField;
			}
			set {
				this.descriptionField = value;
			}
		}

		/// <summary>A list of inventory sizes in which creatives will be eventually served. <span
		/// class="constraint ReadOnly">This attribute is read-only when:</span> <ul>
		/// <li>using programmatic guaranteed, not using sales management.</li> <li>using
		/// preferred deals, not using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("creativePlaceholders", Order = 7)]
		public CreativePlaceholder[] creativePlaceholders {
			get {
				return this.creativePlaceholdersField;
			}
			set {
				this.creativePlaceholdersField = value;
			}
		}

		/// <summary>Targeting information for the proposal in question. Currently this field only
		/// contains <a href='GeoTargeting'>GeoTargeting</a> information. <span
		/// class="constraint ReadOnly">This attribute is read-only when:</span> <ul>
		/// <li>using programmatic guaranteed, not using sales management.</li> <li>using
		/// preferred deals, not using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public Targeting targeting {
			get {
				return this.targetingField;
			}
			set {
				this.targetingField = value;
			}
		}

		/// <summary>Additional terms of the deal in question. This field can be used to state more
		/// specific targeting information for the deal, as well as any additional
		/// information regarding this deal. Given that this field belongs to a request for
		/// proposal (for which initially a <a href='Proposal'>Proposal</a> does not yet
		/// exist), this field can be populated by buyers to specify additional information
		/// that they wish publishers to incorporate into the <a
		/// href='Proposal'>Proposal</a> derived from this request for proposal. <span
		/// class="constraint ReadOnly">This attribute is read-only when:</span> <ul>
		/// <li>using programmatic guaranteed, not using sales management.</li> <li>using
		/// preferred deals, not using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public string additionalTerms {
			get {
				return this.additionalTermsField;
			}
			set {
				this.additionalTermsField = value;
			}
		}

		/// <summary>Identifies the format of the inventory or "channel" through which the ad serves.
		/// Environments currently supported include <a
		/// href='AdExchangeEnvironment#DISPLAY'>AdExchangeEnvironment#DISPLAY</a>, <a
		/// href='AdExchangeEnvironment#VIDEO'>AdExchangeEnvironment#VIDEO</a>, and <a
		/// href='AdExchangeEnvironment#MOBILE'>AdExchangeEnvironment#MOBILE</a>. <span
		/// class="constraint ReadOnly">This attribute is read-only when:</span> <ul>
		/// <li>using programmatic guaranteed, not using sales management.</li> <li>using
		/// preferred deals, not using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public AdExchangeEnvironment adExchangeEnvironment {
			get {
				return this.adExchangeEnvironmentField;
			}
			set {
				this.adExchangeEnvironmentField = value;
				this.adExchangeEnvironmentSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="adExchangeEnvironment" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool adExchangeEnvironmentSpecified {
			get {
				return this.adExchangeEnvironmentFieldSpecified;
			}
			set {
				this.adExchangeEnvironmentFieldSpecified = value;
			}
		}

		/// <summary>Deal type; either Programmatic Guaranteed or Preferred Deal. This field
		/// corresponds to the type of <a href='Proposal'>Proposal</a> that a buyer wishes
		/// to negotiate with a seller. <span class="constraint ReadOnly">This attribute is
		/// read-only when:</span> <ul> <li>using programmatic guaranteed, not using sales
		/// management.</li> <li>using preferred deals, not using sales management.</li>
		/// </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 11)]
		public RfpType rfpType {
			get {
				return this.rfpTypeField;
			}
			set {
				this.rfpTypeField = value;
				this.rfpTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="rfpType" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool rfpTypeSpecified {
			get {
				return this.rfpTypeFieldSpecified;
			}
			set {
				this.rfpTypeFieldSpecified = value;
			}
		}
	}


	/// <summary>Decribes the type of <a href='BuyerRfp'>BuyerRfp</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RfpType {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		/// <summary>Indicates the <a href='BuyerRfp'>BuyerRfp</a> is a Programmatic Guaranteed RFP.
		/// </summary>
		PROGRAMMATIC_GUARANTEED = 1,
		/// <summary>Indicates the <a href='BuyerRfp'>BuyerRfp</a> is a Preferred Deal RFP.
		/// </summary>
		PREFERRED_DEAL = 2,
	}


	/// <summary>An error that occurs for an internal Ad Manager process that happens in the
	/// background. For example, <a href='Proposal'>Proposal</a> workflows can have
	/// background tasks that may have offline errors.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class OfflineError {
		private string fieldPathField;

		private string triggerField;

		private DateTime errorTimeField;

		private string reasonField;

		/// <summary>The OGNL field path to identify cause of error.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string fieldPath {
			get {
				return this.fieldPathField;
			}
			set {
				this.fieldPathField = value;
			}
		}

		/// <summary>The data that caused the error.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string trigger {
			get {
				return this.triggerField;
			}
			set {
				this.triggerField = value;
			}
		}

		/// <summary>The time when this error occurred.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public DateTime errorTime {
			get {
				return this.errorTimeField;
			}
			set {
				this.errorTimeField = value;
			}
		}

		/// <summary>The error reason represented by a string.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
			}
		}
	}


	/// <summary>Marketplace info for a proposal with a corresponding order in Marketplace.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProposalMarketplaceInfo {
		private bool hasLocalVersionEditsField;

		private bool hasLocalVersionEditsFieldSpecified;

		private NegotiationStatus negotiationStatusField;

		private bool negotiationStatusFieldSpecified;

		private string marketplaceCommentField;

		private bool isNewVersionFromBuyerField;

		private bool isNewVersionFromBuyerFieldSpecified;

		private long buyerAccountIdField;

		private bool buyerAccountIdFieldSpecified;

		/// <summary>Whether the non-free-editable fields of a <a href='Proposal'>Proposal</a> are
		/// opened for edit. A proposal that is open for edit will not receive buyer updates
		/// from Marketplace. If the buyer updates the proposal while this is open for local
		/// editing, Google will set <a
		/// href='#isNewVersionFromBuyer'>#isNewVersionFromBuyer</a> to <code></code>. You
		/// will then need to call <a href='DiscardProposalDrafts'>DiscardProposalDrafts</a>
		/// to revert your edits to get the buyer's latest changes. This attribute is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool hasLocalVersionEdits {
			get {
				return this.hasLocalVersionEditsField;
			}
			set {
				this.hasLocalVersionEditsField = value;
				this.hasLocalVersionEditsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="hasLocalVersionEdits" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool hasLocalVersionEditsSpecified {
			get {
				return this.hasLocalVersionEditsFieldSpecified;
			}
			set {
				this.hasLocalVersionEditsFieldSpecified = value;
			}
		}

		/// <summary>The negotiation status of the <a href='Proposal'>Proposal</a>. This attribute is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public NegotiationStatus negotiationStatus {
			get {
				return this.negotiationStatusField;
			}
			set {
				this.negotiationStatusField = value;
				this.negotiationStatusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="negotiationStatus" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool negotiationStatusSpecified {
			get {
				return this.negotiationStatusFieldSpecified;
			}
			set {
				this.negotiationStatusFieldSpecified = value;
			}
		}

		/// <summary>The comment on the <a href='Proposal'>Proposal</a> to be sent to the buyer.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string marketplaceComment {
			get {
				return this.marketplaceCommentField;
			}
			set {
				this.marketplaceCommentField = value;
			}
		}

		/// <summary>Indicates that the buyer has made updates to the proposal on Marketplace. This
		/// attribute is only meaningful if the proposal is open for edit (i.e., <a
		/// href='#hasLocalVersionEdits'>#hasLocalVersionEdits</a> is <code>true</code>)
		/// This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public bool isNewVersionFromBuyer {
			get {
				return this.isNewVersionFromBuyerField;
			}
			set {
				this.isNewVersionFromBuyerField = value;
				this.isNewVersionFromBuyerSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isNewVersionFromBuyer" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isNewVersionFromBuyerSpecified {
			get {
				return this.isNewVersionFromBuyerFieldSpecified;
			}
			set {
				this.isNewVersionFromBuyerFieldSpecified = value;
			}
		}

		/// <summary>The ID of the buyer that this <code>Proposal</code> is being negotiated with.
		/// <span class="constraint Required">This attribute is required.</span>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public long buyerAccountId {
			get {
				return this.buyerAccountIdField;
			}
			set {
				this.buyerAccountIdField = value;
				this.buyerAccountIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="buyerAccountId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool buyerAccountIdSpecified {
			get {
				return this.buyerAccountIdFieldSpecified;
			}
			set {
				this.buyerAccountIdFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents the <a href='Proposal'>proposal's</a> negotiation status for
	/// Marketplace.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum NegotiationStatus {
		/// <summary>Indicates that a new <a href='Proposal'>Proposal</a> has been created by the
		/// seller and has not been sent to Marketplace yet.
		/// </summary>
		SELLER_INITIATED = 0,
		/// <summary>Indicates that a new <a href='Proposal'>Proposal</a> has been created by the
		/// buyer and is awaiting seller action.
		/// </summary>
		BUYER_INITIATED = 1,
		/// <summary>Indicates that a <a href='Proposal'>Proposal</a> has been updated by the buyer
		/// and is awaiting seller approval.
		/// </summary>
		AWAITING_SELLER_REVIEW = 2,
		/// <summary>Indicates that a <a href='Proposal'>Proposal</a> has been updated by the seller
		/// and is awaiting buyer approval.
		/// </summary>
		AWAITING_BUYER_REVIEW = 3,
		/// <summary>Indicates that the seller has accepted the <a href='Proposal'>Proposal</a> and
		/// is awaiting the buyer's acceptance.
		/// </summary>
		ONLY_SELLER_ACCEPTED = 4,
		/// <summary>Indicates that the <a href='Proposal'>Proposal</a> has been accepted by both the
		/// buyer and the seller.
		/// </summary>
		FINALIZED = 5,
		/// <summary>Indicates that negotiations for the <a href='Proposal'>Proposal</a> have been
		/// cancelled.
		/// </summary>
		CANCELLED = 6,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 7,
	}


	/// <summary>Details describing why a <a href='Proposal'>Proposal</a> was retracted.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RetractionDetails {
		private long retractionReasonIdField;

		private bool retractionReasonIdFieldSpecified;

		private string commentsField;

		/// <summary>The ID of the reason for why the <a href='Proposal'>Proposal</a> was retracted.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long retractionReasonId {
			get {
				return this.retractionReasonIdField;
			}
			set {
				this.retractionReasonIdField = value;
				this.retractionReasonIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="retractionReasonId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool retractionReasonIdSpecified {
			get {
				return this.retractionReasonIdFieldSpecified;
			}
			set {
				this.retractionReasonIdFieldSpecified = value;
			}
		}

		/// <summary>Comments on why the <a href='Proposal'>Proposal</a> was retracted. This field is
		/// optional and has a maximum length of 1023 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string comments {
			get {
				return this.commentsField;
			}
			set {
				this.commentsField = value;
			}
		}
	}


	/// <summary>Represents a terms and conditions that has been added to a <a
	/// href='Proposal'>Proposal</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProposalTermsAndConditions {
		private long termsAndConditionsIdField;

		private bool termsAndConditionsIdFieldSpecified;

		private string nameField;

		private string contentField;

		/// <summary>The ID of the terms and conditions added to the proposal. <span
		/// class="constraint Required">This attribute is required.</span>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long termsAndConditionsId {
			get {
				return this.termsAndConditionsIdField;
			}
			set {
				this.termsAndConditionsIdField = value;
				this.termsAndConditionsIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="termsAndConditionsId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool termsAndConditionsIdSpecified {
			get {
				return this.termsAndConditionsIdFieldSpecified;
			}
			set {
				this.termsAndConditionsIdFieldSpecified = value;
			}
		}

		/// <summary>The name of the terms and conditions at the time it was added to the proposal.
		/// This is a snapshot of the terms and conditions' name. It will not be updated if
		/// the terms and conditions name is updated. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The content of the terms and conditions at the time it was added to the
		/// proposal. This is a snapshot of the terms and conditions' content. It will not
		/// be updated if the terms and conditions content is updated. This attribute is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string content {
			get {
				return this.contentField;
			}
			set {
				this.contentField = value;
			}
		}
	}


	/// <summary>A link that can be added as a resource to a <a href='Proposal'>Proposal</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProposalLink {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private long creatorIdField;

		private bool creatorIdFieldSpecified;

		private string urlField;

		private string descriptionField;

		private DateTime creationDateTimeField;

		/// <summary>The unique ID of the <code>ProposalLink</code>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the <code>ProposalLink</code>. Must be unique under the same <a
		/// href='Proposal'>Proposal</a>. This attribute has a maximum length of 255
		/// characters. <span class="constraint Required">This attribute is required.</span>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The unique ID of the <a href='User'>User</a> who created the <code></code>. This
		/// attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public long creatorId {
			get {
				return this.creatorIdField;
			}
			set {
				this.creatorIdField = value;
				this.creatorIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="creatorId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool creatorIdSpecified {
			get {
				return this.creatorIdFieldSpecified;
			}
			set {
				this.creatorIdFieldSpecified = value;
			}
		}

		/// <summary>The link to the <code>ProposalLink</code> resource. <span class="constraint
		/// Required">This attribute is required.</span>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string url {
			get {
				return this.urlField;
			}
			set {
				this.urlField = value;
			}
		}

		/// <summary>The description for the <code>ProposalLink</code>. This attribute is optional
		/// and has a maximum length of 1023 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string description {
			get {
				return this.descriptionField;
			}
			set {
				this.descriptionField = value;
			}
		}

		/// <summary>The creation time of the <code>ProposalLink</code>. This attribute is assigned
		/// by Google when the <code>ProposalLink</code> is created. This attribute is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public DateTime creationDateTime {
			get {
				return this.creationDateTimeField;
			}
			set {
				this.creationDateTimeField = value;
			}
		}
	}


	/// <summary>An action that is being or was done to progress the workflow.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SendNotificationProgressAction))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ReserveInventoryProgressAction))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RequestApprovalProgressAction))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class ProgressAction {
		private DateTime evaluationTimeField;

		private EvaluationStatus evaluationStatusField;

		private bool evaluationStatusFieldSpecified;

		/// <summary>The <a href='DateTime'>DateTime</a> this action was evaluated.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public DateTime evaluationTime {
			get {
				return this.evaluationTimeField;
			}
			set {
				this.evaluationTimeField = value;
			}
		}

		/// <summary>The status of this action.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public EvaluationStatus evaluationStatus {
			get {
				return this.evaluationStatusField;
			}
			set {
				this.evaluationStatusField = value;
				this.evaluationStatusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="evaluationStatus" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool evaluationStatusSpecified {
			get {
				return this.evaluationStatusFieldSpecified;
			}
			set {
				this.evaluationStatusFieldSpecified = value;
			}
		}
	}


	/// <summary>The status of various entities in a workflow. The entity can be a workflow, a
	/// workflow step, or a workflow action.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum EvaluationStatus {
		/// <summary>When a <a href='Proposal'>Proposal</a> is retracted the associated workflow is
		/// canceled. Including the steps, rules and actions.
		/// </summary>
		CANCELED = 0,
		/// <summary>The entity is in a completed state. If the entity is a workflow, it means that
		/// all steps have been completed. If the entity is a step, it means all actions in
		/// the step have been completed. If the entity is a workflow action, it means it
		/// has been done.
		/// </summary>
		COMPLETED = 1,
		/// <summary>The entity is in a failed state. If the entity is a workflow, it means that some
		/// step has failed. If the entity is a step, it means some actions in the step have
		/// failed. If the entity is a workflow action, it means it has failed.
		/// </summary>
		FAILED = 2,
		/// <summary>The entity is in progress. If the entity is a workflow, it means that some steps
		/// have yet to be started. If the entity is a step, it means some actions in the
		/// step are still in a pending state. If the entity is a workflow action, it means
		/// the action is ongoing.
		/// </summary>
		IN_PROGRESS = 3,
		/// <summary>The entity has not been started. If the entity is a step, it has not been
		/// started by the workflow execution process If the entity is a workflow action, it
		/// means that the step has not been triggered.
		/// </summary>
		INACTIVE = 4,
		/// <summary>The action is skipped because the <a href='Proposal'>Proposal</a> and/or <a
		/// href='ProposalLineItem'>proposal line items</a> do not trigger the conditions
		/// for the step. This value is only for actions.
		/// </summary>
		SKIPPED = 5,
		/// <summary>The action is triggered because the <a href='Proposal'>Proposal</a> and/or <a
		/// href='ProposalLineItem'>proposal line items</a> trigger the conditions for the
		/// step, but the step itself has not started yet.
		/// </summary>
		INACTIVE_BUT_TRIGGERED = 6,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 7,
	}


	/// <summary>Action requiring a notification to be sent before the workflow can continue.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SendNotificationProgressAction : ProgressAction {
	}


	/// <summary>Action requiring inventory to be reserved before the workflow can continue.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReserveInventoryProgressAction : ProgressAction {
	}


	/// <summary>Action requiring approval before the workflow can continue.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RequestApprovalProgressAction : ProgressAction {
		private long approverIdField;

		private bool approverIdFieldSpecified;

		private long[] eligibleApproverUserIdsField;

		private long[] eligibleApproverTeamIdsField;

		private string commentField;

		private WorkflowApprovalRequestStatus approvalStatusField;

		private bool approvalStatusFieldSpecified;

		/// <summary>The <a href='User#ID'>User#ID</a> of the user who performed this action.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long approverId {
			get {
				return this.approverIdField;
			}
			set {
				this.approverIdField = value;
				this.approverIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="approverId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool approverIdSpecified {
			get {
				return this.approverIdFieldSpecified;
			}
			set {
				this.approverIdFieldSpecified = value;
			}
		}

		/// <summary>The <a href='User#id'>IDs</a> of users who are eligible to approve this action.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("eligibleApproverUserIds", Order = 1)]
		public long[] eligibleApproverUserIds {
			get {
				return this.eligibleApproverUserIdsField;
			}
			set {
				this.eligibleApproverUserIdsField = value;
			}
		}

		/// <summary>The <a href='Team#id'>IDs</a> of teams who are eligible to approve this action.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("eligibleApproverTeamIds", Order = 2)]
		public long[] eligibleApproverTeamIds {
			get {
				return this.eligibleApproverTeamIdsField;
			}
			set {
				this.eligibleApproverTeamIdsField = value;
			}
		}

		/// <summary>A comment left by the <a href='#approverId'>approver</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string comment {
			get {
				return this.commentField;
			}
			set {
				this.commentField = value;
			}
		}

		/// <summary>The approval status of this action.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public WorkflowApprovalRequestStatus approvalStatus {
			get {
				return this.approvalStatusField;
			}
			set {
				this.approvalStatusField = value;
				this.approvalStatusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="approvalStatus" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool approvalStatusSpecified {
			get {
				return this.approvalStatusFieldSpecified;
			}
			set {
				this.approvalStatusFieldSpecified = value;
			}
		}
	}


	/// <summary>The status of the workflow approval request.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum WorkflowApprovalRequestStatus {
		/// <summary>The request is pending approval.
		/// </summary>
		PENDING_APPROVAL = 0,
		/// <summary>The workflow approval request has been approved.
		/// </summary>
		APPROVED = 1,
		/// <summary>The workflow approval request has been rejected.
		/// </summary>
		REJECTED = 2,
		/// <summary>The workflow request was retracted because the proposal was retracted.
		/// </summary>
		RETRACTED = 3,
		/// <summary>The entity might have a non-applicable status in several scenarios: <ul
		/// class="noindent"> <li>The <a href='User'>User</a> is not an approver when
		/// querying the <code>ApprovalStatus</code> of an action.</li> <li>The <a
		/// href='User'>User</a> is not an approver of any actions within the <a
		/// href='Proposal#workflowProgress'>Proposal#workflowProgress</a>.</li>
		/// <li>Querying for the <code>ApprovalStatus</code> for a <a
		/// href='ProposalStatus#DRAFT'>ProposalStatus#DRAFT</a> <a
		/// href='Proposal'>Proposal</a>.</li> </ul>
		/// </summary>
		NOT_APPLICABLE = 5,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>Describes a rule in a workflow step.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProgressRule {
		private ProgressAction[] actionsField;

		private string nameField;

		private WorkflowEvaluationStatus evaluationStatusField;

		private bool evaluationStatusFieldSpecified;

		private DateTime evaluationTimeField;

		private bool isExternalField;

		private bool isExternalFieldSpecified;

		/// <summary>Pending or completed actions for this rule.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("actions", Order = 0)]
		public ProgressAction[] actions {
			get {
				return this.actionsField;
			}
			set {
				this.actionsField = value;
			}
		}

		/// <summary>The name of this rule.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The status of this rule.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public WorkflowEvaluationStatus evaluationStatus {
			get {
				return this.evaluationStatusField;
			}
			set {
				this.evaluationStatusField = value;
				this.evaluationStatusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="evaluationStatus" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool evaluationStatusSpecified {
			get {
				return this.evaluationStatusFieldSpecified;
			}
			set {
				this.evaluationStatusFieldSpecified = value;
			}
		}

		/// <summary>The <a href='DateTime'>DateTime</a> this rule was evaluated.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public DateTime evaluationTime {
			get {
				return this.evaluationTimeField;
			}
			set {
				this.evaluationTimeField = value;
			}
		}

		/// <summary>Whether this rule is evaluated by external system.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public bool isExternal {
			get {
				return this.isExternalField;
			}
			set {
				this.isExternalField = value;
				this.isExternalSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isExternal"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isExternalSpecified {
			get {
				return this.isExternalFieldSpecified;
			}
			set {
				this.isExternalFieldSpecified = value;
			}
		}
	}


	/// <summary>The status of a workflow rule during workflow execution.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum WorkflowEvaluationStatus {
		/// <summary>The workflow external condition is pending evaluation.
		/// </summary>
		PENDING = 0,
		/// <summary>The workflow external condition has been triggered.
		/// </summary>
		TRIGGERED = 1,
		/// <summary>The workflow external condition has not been triggered.
		/// </summary>
		NOT_TRIGGERED = 2,
		/// <summary>The associated proposal was retracted, this rule is no longer valid.
		/// </summary>
		CANCELLED = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>Describes a step in a workflow.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProgressStep {
		private ProgressRule[] rulesField;

		private EvaluationStatus evaluationStatusField;

		private bool evaluationStatusFieldSpecified;

		/// <summary>The rules in this step.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("rules", Order = 0)]
		public ProgressRule[] rules {
			get {
				return this.rulesField;
			}
			set {
				this.rulesField = value;
			}
		}

		/// <summary>The status of this step.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public EvaluationStatus evaluationStatus {
			get {
				return this.evaluationStatusField;
			}
			set {
				this.evaluationStatusField = value;
				this.evaluationStatusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="evaluationStatus" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool evaluationStatusSpecified {
			get {
				return this.evaluationStatusFieldSpecified;
			}
			set {
				this.evaluationStatusFieldSpecified = value;
			}
		}
	}


	/// <summary>The progress indicator of a <a href='Proposal'>proposal's</a> workflow.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class WorkflowProgress {
		private ProgressStep[] stepsField;

		private long submitterIdField;

		private bool submitterIdFieldSpecified;

		private EvaluationStatus evaluationStatusField;

		private bool evaluationStatusFieldSpecified;

		private DateTime submissionTimeField;

		private DateTime evaluationTimeField;

		private bool isProcessingField;

		private bool isProcessingFieldSpecified;

		/// <summary>The steps in this workflow.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("steps", Order = 0)]
		public ProgressStep[] steps {
			get {
				return this.stepsField;
			}
			set {
				this.stepsField = value;
			}
		}

		/// <summary>The <a href='User#Id'>ID</a> of the user who submitted the <a
		/// href='Proposal'>Proposal</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long submitterId {
			get {
				return this.submitterIdField;
			}
			set {
				this.submitterIdField = value;
				this.submitterIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="submitterId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool submitterIdSpecified {
			get {
				return this.submitterIdFieldSpecified;
			}
			set {
				this.submitterIdFieldSpecified = value;
			}
		}

		/// <summary>The status of this workflow.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public EvaluationStatus evaluationStatus {
			get {
				return this.evaluationStatusField;
			}
			set {
				this.evaluationStatusField = value;
				this.evaluationStatusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="evaluationStatus" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool evaluationStatusSpecified {
			get {
				return this.evaluationStatusFieldSpecified;
			}
			set {
				this.evaluationStatusFieldSpecified = value;
			}
		}

		/// <summary>The <a href='DateTime'>DateTime</a> the proposal was submitted.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public DateTime submissionTime {
			get {
				return this.submissionTimeField;
			}
			set {
				this.submissionTimeField = value;
			}
		}

		/// <summary>The <a href='DateTime'>DateTime</a> this workflow was evaluated.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public DateTime evaluationTime {
			get {
				return this.evaluationTimeField;
			}
			set {
				this.evaluationTimeField = value;
			}
		}

		/// <summary>Whether any offline processing is occurring.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public bool isProcessing {
			get {
				return this.isProcessingField;
			}
			set {
				this.isProcessingField = value;
				this.isProcessingSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isProcessing" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isProcessingSpecified {
			get {
				return this.isProcessingFieldSpecified;
			}
			set {
				this.isProcessingFieldSpecified = value;
			}
		}
	}


	/// <summary>A <code>SalespersonSplit</code> represents a salesperson and his/her split.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SalespersonSplit {
		private long userIdField;

		private bool userIdFieldSpecified;

		private int splitField;

		private bool splitFieldSpecified;

		/// <summary>The unique ID of the <a href='User'>User</a> responsible for the sales of the <a
		/// href='Proposal'>Proposal</a>. <span class="constraint Required">This attribute
		/// is required.</span>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long userId {
			get {
				return this.userIdField;
			}
			set {
				this.userIdField = value;
				this.userIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="userId" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool userIdSpecified {
			get {
				return this.userIdFieldSpecified;
			}
			set {
				this.userIdFieldSpecified = value;
			}
		}

		/// <summary>The split can be attributed to the salesperson. The percentage value is stored
		/// as millipercents, and must be multiples of 10 with the range from 0 to 100000.
		/// The default value is 0.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int split {
			get {
				return this.splitField;
			}
			set {
				this.splitField = value;
				this.splitSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="split" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool splitSpecified {
			get {
				return this.splitFieldSpecified;
			}
			set {
				this.splitFieldSpecified = value;
			}
		}
	}


	/// <summary>A <code>ProposalCompanyAssociation</code> represents a <a
	/// href='Company'>Company</a> associated with the <a href='Proposal'>Proposal</a>
	/// and a set of <a href='Contact'>Contact</a> objects belonging to the company.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProposalCompanyAssociation {
		private long companyIdField;

		private bool companyIdFieldSpecified;

		private ProposalCompanyAssociationType typeField;

		private bool typeFieldSpecified;

		private long[] contactIdsField;

		/// <summary>The unique ID of the <a href='Company'>Company</a> associated with the <a
		/// href='Proposal'>Proposal</a>. <span class="constraint Required">This attribute
		/// is required.</span>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long companyId {
			get {
				return this.companyIdField;
			}
			set {
				this.companyIdField = value;
				this.companyIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="companyId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool companyIdSpecified {
			get {
				return this.companyIdFieldSpecified;
			}
			set {
				this.companyIdFieldSpecified = value;
			}
		}

		/// <summary>The association type of the <a href='Company'>Company</a> and <a
		/// href='Proposal'>Proposal</a>. <span class="constraint Required">This attribute
		/// is required.</span>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public ProposalCompanyAssociationType type {
			get {
				return this.typeField;
			}
			set {
				this.typeField = value;
				this.typeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="type" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool typeSpecified {
			get {
				return this.typeFieldSpecified;
			}
			set {
				this.typeFieldSpecified = value;
			}
		}

		/// <summary>List of unique IDs for <a href='Contact'>Contact</a> objects of the <a
		/// href='Company'>Company</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("contactIds", Order = 2)]
		public long[] contactIds {
			get {
				return this.contactIdsField;
			}
			set {
				this.contactIdsField = value;
			}
		}
	}


	/// <summary>Describes the type of a <a href='Company'>Company</a> associated with a <a
	/// href='Proposal'>Proposal</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProposalCompanyAssociationType {
		/// <summary>The company is a primary agency.
		/// </summary>
		PRIMARY_AGENCY = 0,
		/// <summary>The company is a billing agency.
		/// </summary>
		BILLING_AGENCY = 1,
		/// <summary>The company is a branding agency.
		/// </summary>
		BRANDING_AGENCY = 2,
		/// <summary>The company is other type of agency.
		/// </summary>
		OTHER_AGENCY = 3,
		/// <summary>The company is advertiser.
		/// </summary>
		ADVERTISER = 4,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 5,
	}


	/// <summary>A <code>Proposal</code> represents an agreement between an interactive
	/// advertising seller and a buyer that specifies the details of an advertising
	/// campaign.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Proposal {
		private long idField;

		private bool idFieldSpecified;

		private bool isProgrammaticField;

		private bool isProgrammaticFieldSpecified;

		private long dfpOrderIdField;

		private bool dfpOrderIdFieldSpecified;

		private string nameField;

		private PricingModel pricingModelField;

		private bool pricingModelFieldSpecified;

		private DateTime startDateTimeField;

		private DateTime endDateTimeField;

		private string timeZoneIdField;

		private ProposalStatus statusField;

		private bool statusFieldSpecified;

		private bool isArchivedField;

		private bool isArchivedFieldSpecified;

		private ProposalCompanyAssociation advertiserField;

		private ProposalCompanyAssociation[] agenciesField;

		private long probabilityOfCloseField;

		private bool probabilityOfCloseFieldSpecified;

		private BillingCap billingCapField;

		private bool billingCapFieldSpecified;

		private BillingSchedule billingScheduleField;

		private bool billingScheduleFieldSpecified;

		private BillingSource billingSourceField;

		private bool billingSourceFieldSpecified;

		private BillingBase billingBaseField;

		private bool billingBaseFieldSpecified;

		private string poNumberField;

		private string internalNotesField;

		private Money budgetField;

		private SalespersonSplit primarySalespersonField;

		private SalespersonSplit[] secondarySalespeopleField;

		private long[] salesPlannerIdsField;

		private long primaryTraffickerIdField;

		private bool primaryTraffickerIdFieldSpecified;

		private long[] secondaryTraffickerIdsField;

		private long[] sellerContactIdsField;

		private long[] appliedTeamIdsField;

		private BaseCustomFieldValue[] customFieldValuesField;

		private AppliedLabel[] appliedLabelsField;

		private AppliedLabel[] effectiveAppliedLabelsField;

		private long advertiserDiscountField;

		private bool advertiserDiscountFieldSpecified;

		private long proposalDiscountField;

		private bool proposalDiscountFieldSpecified;

		private string currencyCodeField;

		private long exchangeRateField;

		private bool exchangeRateFieldSpecified;

		private bool refreshExchangeRateField;

		private bool refreshExchangeRateFieldSpecified;

		private long agencyCommissionField;

		private bool agencyCommissionFieldSpecified;

		private long valueAddedTaxField;

		private bool valueAddedTaxFieldSpecified;

		private bool isSoldField;

		private bool isSoldFieldSpecified;

		private ProposalApprovalStatus approvalStatusField;

		private bool approvalStatusFieldSpecified;

		private WorkflowProgress workflowProgressField;

		private DateTime lastModifiedDateTimeField;

		private ProposalLink[] resourcesField;

		private DateTime actualExpiryTimeField;

		private DateTime expectedExpiryTimeField;

		private int thirdPartyAdServerIdField;

		private bool thirdPartyAdServerIdFieldSpecified;

		private string customThirdPartyAdServerNameField;

		private ProposalTermsAndConditions[] termsAndConditionsField;

		private RetractionDetails lastRetractionDetailsField;

		private ProposalMarketplaceInfo marketplaceInfoField;

		private OfflineError[] offlineErrorsField;

		private bool hasOfflineErrorsField;

		private bool hasOfflineErrorsFieldSpecified;

		private BuyerRfp buyerRfpField;

		private bool hasBuyerRfpField;

		private bool hasBuyerRfpFieldSpecified;

		/// <summary>The unique ID of the <code>Proposal</code>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>Flag that specifies whether this <code>Proposal</code> is for programmatic
		/// deals. This value is default to <code>false</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public bool isProgrammatic {
			get {
				return this.isProgrammaticField;
			}
			set {
				this.isProgrammaticField = value;
				this.isProgrammaticSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isProgrammatic" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isProgrammaticSpecified {
			get {
				return this.isProgrammaticFieldSpecified;
			}
			set {
				this.isProgrammaticFieldSpecified = value;
			}
		}

		/// <summary>The unique ID of corresponding <a href='Order'>Order</a>. This will be
		/// <code>null</code> if the <code>Proposal</code> has not been pushed to Ad
		/// Manager. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public long dfpOrderId {
			get {
				return this.dfpOrderIdField;
			}
			set {
				this.dfpOrderIdField = value;
				this.dfpOrderIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="dfpOrderId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool dfpOrderIdSpecified {
			get {
				return this.dfpOrderIdFieldSpecified;
			}
			set {
				this.dfpOrderIdFieldSpecified = value;
			}
		}

		/// <summary>The name of the <code>Proposal</code>. This value has a maximum length of 255
		/// characters. This value is copied to <a href='Order#name'>Order#name</a> when the
		/// proposal turns into an order. This attribute can be configured as editable after
		/// the proposal has been submitted. Please check with your network administrator
		/// for editable fields configuration. <span class="constraint Required">This
		/// attribute is required.</span>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The option to specify whether the <code>Proposal</code> uses the Net or Gross
		/// pricing model. This field is optional and defaults to <a
		/// href='PricingModel#NET'>PricingModel#NET</a>. <span class="constraint
		/// Applicable">This attribute is applicable when:</span> <ul> <li>not using
		/// programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public PricingModel pricingModel {
			get {
				return this.pricingModelField;
			}
			set {
				this.pricingModelField = value;
				this.pricingModelSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="pricingModel" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool pricingModelSpecified {
			get {
				return this.pricingModelFieldSpecified;
			}
			set {
				this.pricingModelFieldSpecified = value;
			}
		}

		/// <summary>The date and time at which the order and line items associated with the
		/// <code>Proposal</code> are eligible to begin serving. This attribute is derived
		/// from the proposal line item of the proposal which has the earliest <a
		/// href='ProposalLineItem#startDateTime'>ProposalLineItem#startDateTime</a>. This
		/// attribute will be null, if this proposal has no related line items, or none of
		/// its line items have a start time. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public DateTime startDateTime {
			get {
				return this.startDateTimeField;
			}
			set {
				this.startDateTimeField = value;
			}
		}

		/// <summary>The date and time at which the order and line items associated with the
		/// <code>Proposal</code> stop being served. This attribute is derived from the
		/// proposal line item of the proposal which has the latest <a
		/// href='ProposalLineItem#endDateTime'>ProposalLineItem#endDateTime</a>. This
		/// attribute will be null, if this proposal has no related line items, or none of
		/// its line items have an end time. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public DateTime endDateTime {
			get {
				return this.endDateTimeField;
			}
			set {
				this.endDateTimeField = value;
			}
		}

		/// <summary>The time zone ID in tz database format (e.g. "America/Los_Angeles") for this
		/// <code>Proposal</code>. The <a href='#startDateTime'>#startDateTime</a> and <a
		/// href='#endDateTime'>#endDateTime</a> will be returned in this time zone. This
		/// attribute is optional and defaults to the network's time zone. <span
		/// class="constraint Applicable">This attribute is applicable when:</span> <ul>
		/// <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public string timeZoneId {
			get {
				return this.timeZoneIdField;
			}
			set {
				this.timeZoneIdField = value;
			}
		}

		/// <summary>The status of the <code>Proposal</code>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public ProposalStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>The archival status of the <code>Proposal</code>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public bool isArchived {
			get {
				return this.isArchivedField;
			}
			set {
				this.isArchivedField = value;
				this.isArchivedSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isArchived"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isArchivedSpecified {
			get {
				return this.isArchivedFieldSpecified;
			}
			set {
				this.isArchivedFieldSpecified = value;
			}
		}

		/// <summary>The advertiser, to which this <code>Proposal</code> belongs, and a set of <a
		/// href='Contact'>Contact</a> objects associated with the advertiser. The <a
		/// href='ProposalCompanyAssociation#type'>ProposalCompanyAssociation#type</a> of
		/// this attribute should be <a
		/// href='ProposalCompanyAssociationType#ADVERTISER'>ProposalCompanyAssociationType#ADVERTISER</a>.
		/// This attribute is required when the proposal turns into an order, and its <a
		/// href='ProposalCompanyAssociation#companyId'>ProposalCompanyAssociation#companyId</a>
		/// will be copied to <a href='Order#advertiserId'>Order#advertiserId</a>. This
		/// attribute becomes readonly once the <code>Proposal</code> has been pushed.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public ProposalCompanyAssociation advertiser {
			get {
				return this.advertiserField;
			}
			set {
				this.advertiserField = value;
			}
		}

		/// <summary>List of agencies and the set of <a href='Contact'>Contact</a> objects associated
		/// with each agency. This attribute is optional. A <code>Proposal</code> only has
		/// at most one <a href='Company'>Company</a> with <a
		/// href='ProposalCompanyAssociationType#PRIMARY_AGENCY'>ProposalCompanyAssociationType#PRIMARY_AGENCY</a>
		/// type, but a <a href='Company'>Company</a> can appear more than once with
		/// different <a
		/// href='ProposalCompanyAssociationType'>ProposalCompanyAssociationType</a> values.
		/// If primary agency exists, its <a
		/// href='ProposalCompanyAssociation#companyId'>ProposalCompanyAssociation#companyId</a>
		/// will be copied to <a href='Order#agencyId'>Order#agencyId</a> when the proposal
		/// turns into an order.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("agencies", Order = 11)]
		public ProposalCompanyAssociation[] agencies {
			get {
				return this.agenciesField;
			}
			set {
				this.agenciesField = value;
			}
		}

		/// <summary>The probability to close this <code>Proposal</code>. This percentage value is in
		/// terms of millipercent, and should be multiples of 10 with the range from 0 to
		/// 100000. This attribute will be used to calculate the revenue in reporting. <span
		/// class="constraint Applicable">This attribute is applicable when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul> <span class="constraint
		/// Required">This attribute is required when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 12)]
		public long probabilityOfClose {
			get {
				return this.probabilityOfCloseField;
			}
			set {
				this.probabilityOfCloseField = value;
				this.probabilityOfCloseSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="probabilityOfClose" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool probabilityOfCloseSpecified {
			get {
				return this.probabilityOfCloseFieldSpecified;
			}
			set {
				this.probabilityOfCloseFieldSpecified = value;
			}
		}

		/// <summary>The billing cap of this <code>Proposal</code>. This attribute is optional and
		/// default value is <a
		/// href='BillingCap#CAPPED_CUMULATIVE'>BillingCap#CAPPED_CUMULATIVE</a>. Either
		/// this attribute or <a href='#billingSchedule'>#billingSchedule</a> will be used,
		/// according to the <a href='#billingSource'>#billingSource</a>. This attribute can
		/// be configured as editable after the proposal has been submitted. Please check
		/// with your network administrator for editable fields configuration. <span
		/// class="constraint Applicable">This attribute is applicable when:</span> <ul>
		/// <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 13)]
		public BillingCap billingCap {
			get {
				return this.billingCapField;
			}
			set {
				this.billingCapField = value;
				this.billingCapSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="billingCap"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool billingCapSpecified {
			get {
				return this.billingCapFieldSpecified;
			}
			set {
				this.billingCapFieldSpecified = value;
			}
		}

		/// <summary>The billing schedule of this <code>Proposal</code>. This attribute is optional
		/// and default value is <a
		/// href='BillingSchedule#PRORATED'>BillingSchedule#PRORATED</a>. Either this
		/// attribute or <a href='#billingCap'>#billingCap</a> will be used, according to
		/// the <a href='#billingSource'>#billingSource</a>. This attribute can be
		/// configured as editable after the proposal has been submitted. Please check with
		/// your network administrator for editable fields configuration. <span
		/// class="constraint Applicable">This attribute is applicable when:</span> <ul>
		/// <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 14)]
		public BillingSchedule billingSchedule {
			get {
				return this.billingScheduleField;
			}
			set {
				this.billingScheduleField = value;
				this.billingScheduleSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="billingSchedule" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool billingScheduleSpecified {
			get {
				return this.billingScheduleFieldSpecified;
			}
			set {
				this.billingScheduleFieldSpecified = value;
			}
		}

		/// <summary>The billing source of this <code>Proposal</code>. This attribute is optional and
		/// default value is <a
		/// href='BillingSource#THIRD_PARTY_VOLUME'>BillingSource#THIRD_PARTY_VOLUME</a>. If
		/// the value is <a href='BillingSource#CONTRACTED'>BillingSource#CONTRACTED</a>,
		/// the <a href='#billingSchedule'>#billingSchedule</a> will be used for billing,
		/// otherwise the <a href='billingCap'>billingCap</a> will be used. This attribute
		/// can be configured as editable after the proposal has been submitted. Please
		/// check with your network administrator for editable fields configuration. <span
		/// class="constraint Applicable">This attribute is applicable when:</span> <ul>
		/// <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 15)]
		public BillingSource billingSource {
			get {
				return this.billingSourceField;
			}
			set {
				this.billingSourceField = value;
				this.billingSourceSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="billingSource" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool billingSourceSpecified {
			get {
				return this.billingSourceFieldSpecified;
			}
			set {
				this.billingSourceFieldSpecified = value;
			}
		}

		/// <summary>The billing base of this <code>Proposal</code>. For example, for a flat fee <a
		/// href='BillingSource#CONTRACTED'>contracted</a> <a
		/// href='#billingSource'>#billingSource</a>, set this to <a
		/// href='BillingBase#REVENUE'>BillingBase#REVENUE</a>. This attribute is optional
		/// and defaults to <a href='BillingBase#VOLUME'>BillingBase#VOLUME</a>. This
		/// attribute can be configured as editable after the proposal has been submitted.
		/// Please check with your network administrator for editable fields configuration.
		/// <span class="constraint Applicable">This attribute is applicable when:</span>
		/// <ul> <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 16)]
		public BillingBase billingBase {
			get {
				return this.billingBaseField;
			}
			set {
				this.billingBaseField = value;
				this.billingBaseSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="billingBase"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool billingBaseSpecified {
			get {
				return this.billingBaseFieldSpecified;
			}
			set {
				this.billingBaseFieldSpecified = value;
			}
		}

		/// <summary>User defined purchase order number for the <code>Proposal</code>. This attribute
		/// is optional and has a maximum length of 63 characters. It is copied to <a
		/// href='Order#poNumber'>Order#poNumber</a> when the proposal turns into an order.
		/// This attribute can be configured as editable after the proposal has been
		/// submitted. Please check with your network administrator for editable fields
		/// configuration. <span class="constraint Applicable">This attribute is applicable
		/// when:</span> <ul> <li>using programmatic guaranteed, using sales
		/// management.</li> <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 17)]
		public string poNumber {
			get {
				return this.poNumberField;
			}
			set {
				this.poNumberField = value;
			}
		}

		/// <summary>Provides any additional notes that may annotate the <code></code>. This
		/// attribute is optional and has a maximum length of 65,535 characters. This
		/// attribute can be configured as editable after the proposal has been submitted.
		/// Please check with your network administrator for editable fields configuration.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 18)]
		public string internalNotes {
			get {
				return this.internalNotesField;
			}
			set {
				this.internalNotesField = value;
			}
		}

		/// <summary>The total budget allocated for all the proposal line items belonging to the
		/// <code>Proposal</code>. It supports precision of 2 decimal places in terms of the
		/// fundamental currency unit, so the <a
		/// href='Money#microAmount'>Money#microAmount</a> must be multiples of 10000. This
		/// attribute is optional and default value is 0. The <a
		/// href='Money#currencyCode'>Money#currencyCode</a> is readonly. <span
		/// class="constraint Applicable">This attribute is applicable when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 19)]
		public Money budget {
			get {
				return this.budgetField;
			}
			set {
				this.budgetField = value;
			}
		}

		/// <summary>The primary salesperson who brokered the transaction with the <a
		/// href='#advertiser'>#advertiser</a>. This attribute is required when the proposal
		/// turns into an order. This attribute can be configured as editable after the
		/// proposal has been submitted. Please check with your network administrator for
		/// editable fields configuration.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 20)]
		public SalespersonSplit primarySalesperson {
			get {
				return this.primarySalespersonField;
			}
			set {
				this.primarySalespersonField = value;
			}
		}

		/// <summary>List of secondary salespeople who are responsible for the sales of the
		/// <code>Proposal</code> besides primary salesperson. This attribute is optional. A
		/// proposal could have 8 secondary salespeople at most, but must also have a <a
		/// href='#primarySalesperson'>#primarySalesperson</a> if any secondary salesperson
		/// exists. This attribute can be configured as editable after the proposal has been
		/// submitted. Please check with your network administrator for editable fields
		/// configuration. <span class="constraint Applicable">This attribute is applicable
		/// when:</span> <ul> <li>using programmatic guaranteed, using sales
		/// management.</li> <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("secondarySalespeople", Order = 21)]
		public SalespersonSplit[] secondarySalespeople {
			get {
				return this.secondarySalespeopleField;
			}
			set {
				this.secondarySalespeopleField = value;
			}
		}

		/// <summary>List of unique IDs of <a href='User'>User</a> objects who are the sales planners
		/// of the <code>Proposal</code>. This attribute is optional. A proposal could have
		/// 8 sales planners at most. This attribute can be configured as editable after the
		/// proposal has been submitted. Please check with your network administrator for
		/// editable fields configuration.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("salesPlannerIds", Order = 22)]
		public long[] salesPlannerIds {
			get {
				return this.salesPlannerIdsField;
			}
			set {
				this.salesPlannerIdsField = value;
			}
		}

		/// <summary>The unique ID of the <a href='User'>User</a> who is primary trafficker and is
		/// responsible for trafficking the <code>Proposal</code>. This attribute is
		/// required when the proposal turns into an order, and will be copied to <a
		/// href='Order#primaryTraffickerId'>Order#primaryTraffickerId</a> . This attribute
		/// can be configured as editable after the proposal has been submitted. Please
		/// check with your network administrator for editable fields configuration.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 23)]
		public long primaryTraffickerId {
			get {
				return this.primaryTraffickerIdField;
			}
			set {
				this.primaryTraffickerIdField = value;
				this.primaryTraffickerIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="primaryTraffickerId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool primaryTraffickerIdSpecified {
			get {
				return this.primaryTraffickerIdFieldSpecified;
			}
			set {
				this.primaryTraffickerIdFieldSpecified = value;
			}
		}

		/// <summary>List of unique IDs of <a href='User'>User</a> objects who are responsible for
		/// trafficking the <code>Proposal</code> besides the primary trafficker. This
		/// attribute is optional. A proposal could have 8 secondary traffickers at most,
		/// but must also have a primary trafficker if any secondary trafficker exists. This
		/// attribute can be configured as editable after the proposal has been submitted.
		/// Please check with your network administrator for editable fields configuration.
		/// <span class="constraint Applicable">This attribute is applicable when:</span>
		/// <ul> <li>using programmatic guaranteed, using sales management.</li> <li>not
		/// using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("secondaryTraffickerIds", Order = 24)]
		public long[] secondaryTraffickerIds {
			get {
				return this.secondaryTraffickerIdsField;
			}
			set {
				this.secondaryTraffickerIdsField = value;
			}
		}

		/// <summary><a href='User'>users</a> who are the seller's contacts. <span class="constraint
		/// Applicable">This attribute is applicable when:</span> <ul> <li>using
		/// programmatic guaranteed, using sales management.</li> <li>using programmatic
		/// guaranteed, not using sales management.</li> <li>using preferred deals, not
		/// using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("sellerContactIds", Order = 25)]
		public long[] sellerContactIds {
			get {
				return this.sellerContactIdsField;
			}
			set {
				this.sellerContactIdsField = value;
			}
		}

		/// <summary>The IDs of all teams that the <code>Proposal</code> is on directly. This
		/// attribute is optional. This attribute can be configured as editable after the
		/// proposal has been submitted. Please check with your network administrator for
		/// editable fields configuration.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("appliedTeamIds", Order = 26)]
		public long[] appliedTeamIds {
			get {
				return this.appliedTeamIdsField;
			}
			set {
				this.appliedTeamIdsField = value;
			}
		}

		/// <summary>The values of the custom fields associated with the <code></code>. This
		/// attribute is optional. This attribute can be configured as editable after the
		/// proposal has been submitted. Please check with your network administrator for
		/// editable fields configuration.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("customFieldValues", Order = 27)]
		public BaseCustomFieldValue[] customFieldValues {
			get {
				return this.customFieldValuesField;
			}
			set {
				this.customFieldValuesField = value;
			}
		}

		/// <summary>The set of labels applied directly to the <code>Proposal</code>. This attribute
		/// is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("appliedLabels", Order = 28)]
		public AppliedLabel[] appliedLabels {
			get {
				return this.appliedLabelsField;
			}
			set {
				this.appliedLabelsField = value;
			}
		}

		/// <summary>Contains the set of labels applied directly to the proposal as well as those
		/// inherited ones. If a label has been negated, only the negated label is returned.
		/// This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("effectiveAppliedLabels", Order = 29)]
		public AppliedLabel[] effectiveAppliedLabels {
			get {
				return this.effectiveAppliedLabelsField;
			}
			set {
				this.effectiveAppliedLabelsField = value;
			}
		}

		/// <summary>The discount applied to the <code>Proposal</code> according to the <a
		/// href='#advertiser'>#advertiser</a>. The percentage value is stored as
		/// millipercents, and must be multiples of 10 with the range from 0 to 99990. This
		/// attribute is optional and default value is 0. <span class="constraint
		/// Applicable">This attribute is applicable when:</span> <ul> <li>using
		/// programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 30)]
		public long advertiserDiscount {
			get {
				return this.advertiserDiscountField;
			}
			set {
				this.advertiserDiscountField = value;
				this.advertiserDiscountSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="advertiserDiscount" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool advertiserDiscountSpecified {
			get {
				return this.advertiserDiscountFieldSpecified;
			}
			set {
				this.advertiserDiscountFieldSpecified = value;
			}
		}

		/// <summary>The proposal discount, which will be applied to all <a
		/// href='ProposalLineItem'>ProposalLineItem</a> objects in the <code></code>. The
		/// percentage value is stored as millipercents, and must be multiples of 10 with
		/// the range from 0 to 99990. This attribute is optional and default value is 0.
		/// <span class="constraint Applicable">This attribute is applicable when:</span>
		/// <ul> <li>using programmatic guaranteed, using sales management.</li> <li>not
		/// using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 31)]
		public long proposalDiscount {
			get {
				return this.proposalDiscountField;
			}
			set {
				this.proposalDiscountField = value;
				this.proposalDiscountSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="proposalDiscount" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool proposalDiscountSpecified {
			get {
				return this.proposalDiscountFieldSpecified;
			}
			set {
				this.proposalDiscountFieldSpecified = value;
			}
		}

		/// <summary>The currency code of this <code>Proposal</code>. This attribute is optional and
		/// defaults to network's currency code.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 32)]
		public string currencyCode {
			get {
				return this.currencyCodeField;
			}
			set {
				this.currencyCodeField = value;
			}
		}

		/// <summary>The exchange rate from the <a href='#currencyCode'>#currencyCode</a> to the <a
		/// href='Network#currencyCode'>network's currency</a>. The value is stored as the
		/// exchange rate times 10,000,000,000 truncated to a long. This attribute is
		/// assigned by Google when first created or updated with <a
		/// href='#refreshExchangeRate'>#refreshExchangeRate</a> set to <code>true</code>.
		/// This attribute is ignored if the feature is not enabled. This attribute is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 33)]
		public long exchangeRate {
			get {
				return this.exchangeRateField;
			}
			set {
				this.exchangeRateField = value;
				this.exchangeRateSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="exchangeRate" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool exchangeRateSpecified {
			get {
				return this.exchangeRateFieldSpecified;
			}
			set {
				this.exchangeRateFieldSpecified = value;
			}
		}

		/// <summary>Set this field to <code>true</code> to update the <a
		/// href='#exchangeRate'>#exchangeRate</a> to the latest exchange rate when updating
		/// the proposal. This attribute is optional and defaults to <code>false</code>.
		/// This attribute is ignored if the feature is not enabled.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 34)]
		public bool refreshExchangeRate {
			get {
				return this.refreshExchangeRateField;
			}
			set {
				this.refreshExchangeRateField = value;
				this.refreshExchangeRateSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="refreshExchangeRate" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool refreshExchangeRateSpecified {
			get {
				return this.refreshExchangeRateFieldSpecified;
			}
			set {
				this.refreshExchangeRateFieldSpecified = value;
			}
		}

		/// <summary>The commission for the primary agency of the <code>Proposal</code>. The
		/// percentage value is stored as millipercents, and must be multiples of 10 with
		/// the range from 0 to 99990. This attribute is optional and default value is 0.
		/// <span class="constraint Applicable">This attribute is applicable when:</span>
		/// <ul> <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 35)]
		public long agencyCommission {
			get {
				return this.agencyCommissionField;
			}
			set {
				this.agencyCommissionField = value;
				this.agencyCommissionSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="agencyCommission" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool agencyCommissionSpecified {
			get {
				return this.agencyCommissionFieldSpecified;
			}
			set {
				this.agencyCommissionFieldSpecified = value;
			}
		}

		/// <summary>The value added tax (VAT) applied on final cost of the <code></code>. The
		/// percentage value is stored as millipercents, and must be multiples of 10 with
		/// the range from 0 to 100000. This attribute is optional and default value is 0.
		/// <span class="constraint Applicable">This attribute is applicable when:</span>
		/// <ul> <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 36)]
		public long valueAddedTax {
			get {
				return this.valueAddedTaxField;
			}
			set {
				this.valueAddedTaxField = value;
				this.valueAddedTaxSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="valueAddedTax" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool valueAddedTaxSpecified {
			get {
				return this.valueAddedTaxFieldSpecified;
			}
			set {
				this.valueAddedTaxFieldSpecified = value;
			}
		}

		/// <summary>Indicates whether the proposal has been sold, i.e., corresponds to whether the
		/// status of an <a href='Order'>Order</a> is <a
		/// href='OrderStatus#APPROVED'>OrderStatus#APPROVED</a> or <a
		/// href='OrderStatus#PAUSED'>OrderStatus#PAUSED</a>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 37)]
		public bool isSold {
			get {
				return this.isSoldField;
			}
			set {
				this.isSoldField = value;
				this.isSoldSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isSold" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isSoldSpecified {
			get {
				return this.isSoldFieldSpecified;
			}
			set {
				this.isSoldFieldSpecified = value;
			}
		}

		/// <summary>The approval status of the <code>Proposal</code> for the active user or
		/// <code>null</code> if the active user has no action needed. <span
		/// class="constraint Applicable">This attribute is applicable when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul> <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 38)]
		public ProposalApprovalStatus approvalStatus {
			get {
				return this.approvalStatusField;
			}
			set {
				this.approvalStatusField = value;
				this.approvalStatusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="approvalStatus" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool approvalStatusSpecified {
			get {
				return this.approvalStatusFieldSpecified;
			}
			set {
				this.approvalStatusFieldSpecified = value;
			}
		}

		/// <summary>The progress report for the workflow applied on the <code></code>. <span
		/// class="constraint Applicable">This attribute is applicable when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul> <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 39)]
		public WorkflowProgress workflowProgress {
			get {
				return this.workflowProgressField;
			}
			set {
				this.workflowProgressField = value;
			}
		}

		/// <summary>The date and time this <code>Proposal</code> was last modified. This attribute
		/// is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 40)]
		public DateTime lastModifiedDateTime {
			get {
				return this.lastModifiedDateTimeField;
			}
			set {
				this.lastModifiedDateTimeField = value;
			}
		}

		/// <summary>The list of resources on this <code>Proposal</code>. This attribute is optional.
		/// This attribute can be configured as editable after the proposal has been
		/// submitted. Please check with your network administrator for editable fields
		/// configuration. <span class="constraint Applicable">This attribute is applicable
		/// when:</span> <ul> <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("resources", Order = 41)]
		public ProposalLink[] resources {
			get {
				return this.resourcesField;
			}
			set {
				this.resourcesField = value;
			}
		}

		/// <summary>The actual date and time at which the inventory reserved by the <a
		/// href='Proposal'>Proposal</a> will expire. <span class="constraint
		/// Applicable">This attribute is applicable when:</span> <ul> <li>using
		/// programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul> <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 42)]
		public DateTime actualExpiryTime {
			get {
				return this.actualExpiryTimeField;
			}
			set {
				this.actualExpiryTimeField = value;
			}
		}

		/// <summary>The expected date and time at which the inventory reserved by the <a
		/// href='Proposal'>Proposal</a> will expire. <span class="constraint
		/// Applicable">This attribute is applicable when:</span> <ul> <li>using
		/// programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul> <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 43)]
		public DateTime expectedExpiryTime {
			get {
				return this.expectedExpiryTimeField;
			}
			set {
				this.expectedExpiryTimeField = value;
			}
		}

		/// <summary>A predefined third party ad server, which will be used to fill in
		/// reconciliation. All predefined third party ad servers can be found in the
		/// <code>Third_Party_Company</code> PQL table. If actual third party ad server is
		/// not in the predefined list, this field is set to 0, and actual third party ad
		/// server name is set in <code></code>. Third party ad server is optional. By
		/// default, this field is 0, and <code></code> is null which means no third party
		/// ad server is specified. <span class="constraint Applicable">This attribute is
		/// applicable when:</span> <ul> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 44)]
		public int thirdPartyAdServerId {
			get {
				return this.thirdPartyAdServerIdField;
			}
			set {
				this.thirdPartyAdServerIdField = value;
				this.thirdPartyAdServerIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="thirdPartyAdServerId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool thirdPartyAdServerIdSpecified {
			get {
				return this.thirdPartyAdServerIdFieldSpecified;
			}
			set {
				this.thirdPartyAdServerIdFieldSpecified = value;
			}
		}

		/// <summary>When actual third party ad server is not in the predefined list,
		/// <code>thirdPartyAdServerId</code> is set to 0, and actual third party ad server
		/// name is set here. When <code>thirdPartyAdServerId</code> is not 0, this field is
		/// ignored. <span class="constraint Applicable">This attribute is applicable
		/// when:</span> <ul> <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 45)]
		public string customThirdPartyAdServerName {
			get {
				return this.customThirdPartyAdServerNameField;
			}
			set {
				this.customThirdPartyAdServerNameField = value;
			}
		}

		/// <summary>A list of terms and conditions for this <code>Proposal</code>. This field is
		/// optional. <span class="constraint Applicable">This attribute is applicable
		/// when:</span> <ul> <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("termsAndConditions", Order = 46)]
		public ProposalTermsAndConditions[] termsAndConditions {
			get {
				return this.termsAndConditionsField;
			}
			set {
				this.termsAndConditionsField = value;
			}
		}

		/// <summary>Details describing the most recent proposal retraction. <span class="constraint
		/// Applicable">This attribute is applicable when:</span> <ul> <li>using
		/// programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul> <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 47)]
		public RetractionDetails lastRetractionDetails {
			get {
				return this.lastRetractionDetailsField;
			}
			set {
				this.lastRetractionDetailsField = value;
			}
		}

		/// <summary>The marketplace info of this proposal if it has a corresponding order in
		/// Marketplace. <span class="constraint Applicable">This attribute is applicable
		/// when:</span> <ul> <li>using programmatic guaranteed, using sales
		/// management.</li> <li>using programmatic guaranteed, not using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 48)]
		public ProposalMarketplaceInfo marketplaceInfo {
			get {
				return this.marketplaceInfoField;
			}
			set {
				this.marketplaceInfoField = value;
			}
		}

		/// <summary>Errors that occurred during offline processes. If any errors occur during an
		/// offline process, such as reserving inventory, this field will be populated with
		/// those errors, otherwise this field will be null. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("offlineErrors", Order = 49)]
		public OfflineError[] offlineErrors {
			get {
				return this.offlineErrorsField;
			}
			set {
				this.offlineErrorsField = value;
			}
		}

		/// <summary>Whether errors occured during offline processes. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 50)]
		public bool hasOfflineErrors {
			get {
				return this.hasOfflineErrorsField;
			}
			set {
				this.hasOfflineErrorsField = value;
				this.hasOfflineErrorsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="hasOfflineErrors" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool hasOfflineErrorsSpecified {
			get {
				return this.hasOfflineErrorsFieldSpecified;
			}
			set {
				this.hasOfflineErrorsFieldSpecified = value;
			}
		}

		/// <summary>The buyer RFP associated with this <code>Proposal</code>, which is optional.
		/// This field will be null if the proposal is not initiated from RFP. <span
		/// class="constraint Applicable">This attribute is applicable when:</span> <ul>
		/// <li>using programmatic guaranteed, not using sales management.</li> <li>using
		/// preferred deals, not using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 51)]
		public BuyerRfp buyerRfp {
			get {
				return this.buyerRfpField;
			}
			set {
				this.buyerRfpField = value;
			}
		}

		/// <summary>Whether a <a href='Proposal'>Proposal</a> contains a <a
		/// href='BuyerRfp'>BuyerRfp</a> field. If this field is true, it indicates that the
		/// <a href='Proposal'>Proposal</a> in question orignated from a buyer. <span
		/// class="constraint Applicable">This attribute is applicable when:</span> <ul>
		/// <li>using programmatic guaranteed, not using sales management.</li> <li>using
		/// preferred deals, not using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 52)]
		public bool hasBuyerRfp {
			get {
				return this.hasBuyerRfpField;
			}
			set {
				this.hasBuyerRfpField = value;
				this.hasBuyerRfpSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="hasBuyerRfp"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool hasBuyerRfpSpecified {
			get {
				return this.hasBuyerRfpFieldSpecified;
			}
			set {
				this.hasBuyerRfpFieldSpecified = value;
			}
		}
	}


	/// <summary>The option to specify whether the proposal uses the Net or Gross pricing model.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum PricingModel {
		/// <summary>Indicates using net pricing model to calculate the price.
		/// </summary>
		NET = 0,
		/// <summary>Indicates using gross pricing model to calculate the price.
		/// </summary>
		GROSS = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Describes the <a href='Proposal'>Proposal</a> status.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProposalStatus {
		/// <summary>Indicates that the <a href='Proposal'>Proposal</a> has just been created or
		/// retracted but no approval has been requested yet.
		/// </summary>
		DRAFT = 0,
		/// <summary>Indicates that a request for approval has been made for the <a
		/// href='Proposal'>Proposal</a>.
		/// </summary>
		PENDING_APPROVAL = 1,
		/// <summary>Indicates that the <a href='Proposal'>Proposal</a> has been approved and is
		/// ready to serve.
		/// </summary>
		APPROVED = 2,
		/// <summary>Indicates that the <a href='Proposal'>Proposal</a> has been rejected in the
		/// approval workflow.
		/// </summary>
		REJECTED = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>Determines how the revenue amount will be capped for each billing month. This
	/// cannot be used when <a href='BillingSource'>BillingSource</a> is <a
	/// href='BillingSource#CONTRACTED'>BillingSource#CONTRACTED</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum BillingCap {
		/// <summary>There is no cap for each billing month.
		/// </summary>
		NO_CAP = 0,
		/// <summary>Use a billing source of capped actuals with a billing cap of cumulative to bill
		/// your advertiser up to a campaign's capped amount, regardless of the number of
		/// impressions that are served each month.
		/// </summary>
		CAPPED_CUMULATIVE = 1,
		/// <summary>Use a billing source of capped actuals with a billing cap of the billing cycle
		/// to bill your advertiser up to a capped amount for each billing cycle of a
		/// campaign, regardless of the number of impressions that are served.
		/// </summary>
		CAPPED_PER_BILLING_CYCLE = 2,
		/// <summary>Use a billing source of capped actuals with a billing cap of cumulative per
		/// billing cycle to bill your advertiser up to a capped amount for each billing
		/// cycle of a campaign and carry forward the balance of over- or under-delivered
		/// impressions towards the number of impressions delivered in future billing cycles
		/// of the campaign.
		/// </summary>
		CAPPED_CUMULATIVE_PER_BILLING_CYCLE = 3,
		/// <summary>Use a billing source of capped actuals with a billing cap of cumulative per
		/// billing cycle to bill your advertiser up to a capped amount for each cycle of a
		/// campaign and carry forward the balance of over- or under-delivered impressions
		/// towards the number of impressions delivered in future cycles of the campaign.
		/// </summary>
		CAPPED_WITH_ROLLOVER_PER_BILLING_CYCLE = 4,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 5,
	}


	/// <summary>Determines how much to bill in each billing cycle when a proposal is charged
	/// based on the contracted value. This can only be used when <a
	/// href='BillingSource'>BillingSource</a> is <a
	/// href='BillingSource#CONTRACTED'>BillingSource#CONTRACTED</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum BillingSchedule {
		/// <summary>Charged based on the contracted value after the first month of the campaign.
		/// </summary>
		PREPAID = 0,
		/// <summary>Charged based on the contracted value after the last month of the campaign.
		/// </summary>
		END_OF_THE_CAMPAIGN = 1,
		/// <summary>Use a billing source of contracted with a billing schedule of straightline to
		/// bill your advertiser the same amount each month, regardless of the number of
		/// days in each month.
		/// </summary>
		STRAIGHTLINE = 2,
		/// <summary>Use a billing source of contracted with a billing schedule of prorated to bill
		/// your advertiser proportionally based on the amount of days in each month.
		/// </summary>
		PRORATED = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>Determines which billable numbers or delivery data (impressions, clicks, and so
	/// on) will be used for billing purposes.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum BillingSource {
		/// <summary>Charge based on the quantity of impressions, clicks, or days booked, regardless
		/// of what actually delivered.
		/// </summary>
		CONTRACTED = 0,
		/// <summary>Charge based on what actually delivered, as counted by Ad Manager.
		/// </summary>
		DFP_VOLUME = 1,
		/// <summary>Charge based on what actually delivered, as counted by the third party ads
		/// server.
		/// </summary>
		THIRD_PARTY_VOLUME = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Determines the base of billing calculation.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum BillingBase {
		/// <summary>Billing calculation (eg. proration) should be based on volume.
		/// </summary>
		VOLUME = 0,
		/// <summary>Billing calculation (eg. proration) should be based on revenue.
		/// </summary>
		REVENUE = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Describes the <a href='Proposal'>Proposal</a> status in terms of pending
	/// approvals of active user.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProposalApprovalStatus {
		/// <summary>Indicates that the <a href='Proposal'>Proposal</a> is pending on active user's
		/// approval.
		/// </summary>
		PENDING = 0,
		/// <summary>Indicates that active user is the approver, and the related approval action(s)
		/// of the <a href='Proposal'>Proposal</a> has been performed or not activated yet,
		/// or the proposal is retracted.
		/// </summary>
		NON_PENDING = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Lists all errors associated with workflow validation. <p>In versions V201502 and
	/// earlier, the workflow error message defined by a network administrator that
	/// describes how a workflow rule is violated is stored in the <a
	/// href='#trigger'>#trigger</a>. Beginning in V201505, it is stored in the <a
	/// href='#errorString'>#errorString</a>.</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class WorkflowValidationError : ApiError {
		private WorkflowValidationErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public WorkflowValidationErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "WorkflowValidationError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum WorkflowValidationErrorReason {
		/// <summary>The rule condition validation result triggers a warning.
		/// </summary>
		WARNING = 0,
		/// <summary>The rule condition validation result triggers an error.
		/// </summary>
		ERROR = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Lists all errors associated with performing actions within <a
	/// href='WorkflowAction'>WorkflowAction</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class WorkflowActionError : ApiError {
		private WorkflowActionErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public WorkflowActionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "WorkflowActionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum WorkflowActionErrorReason {
		/// <summary>The action does not exist or is not applicable to the current state.
		/// </summary>
		NOT_APPLICABLE = 0,
		/// <summary>Means there's no workflow definition found for the entity.
		/// </summary>
		WORKFLOW_DEFINITION_NOT_FOUND = 1,
		/// <summary>Means no action is given, when user approve/reject a proposal, the action id
		/// list cannot be empty.
		/// </summary>
		EMPTY_ACTION_LIST = 2,
		/// <summary>Means the user is not an approver of this action.
		/// </summary>
		NOT_ACTION_APPROVER = 3,
		/// <summary>Means the workflow is already completed.
		/// </summary>
		WORKFLOW_ALREADY_COMPLETED = 4,
		/// <summary>Means the workflow is already failed.
		/// </summary>
		WORKFLOW_ALREADY_FAILED = 5,
		/// <summary>Means the workflow is already canceled.
		/// </summary>
		WORKFLOW_ALREADY_CANCELED = 6,
		/// <summary>Means the action is already completed.
		/// </summary>
		ACTION_COMPLETED = 7,
		/// <summary>Means the action is already failed.
		/// </summary>
		ACTION_FAILED = 8,
		/// <summary>Means the action is already canceled.
		/// </summary>
		ACTION_CANCELED = 9,
		/// <summary>Means the action currently is not active.
		/// </summary>
		ACTION_NOT_ACTIVE = 10,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 11,
	}


	/// <summary>Errors associated with programmatic <a href='ProposalLineItem'>proposal line
	/// items</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProposalLineItemProgrammaticError : ApiError {
		private ProposalLineItemProgrammaticErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ProposalLineItemProgrammaticErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ProposalLineItemProgrammaticError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProposalLineItemProgrammaticErrorReason {
		/// <summary>Programmatic <a href='ProposalLineItem'>proposal line items</a> only support <a
		/// href='ProductType#DFP'>ProductType#DFP</a>.
		/// </summary>
		INVALID_PRODUCT_TYPE = 0,
		/// <summary><a href='EnvironmentType#VIDEO_PLAYER'>EnvironmentType#VIDEO_PLAYER</a> is
		/// currently not supported.
		/// </summary>
		VIDEO_NOT_SUPPORTED = 1,
		/// <summary>Programmatic <a href='ProposalLineItem'>proposal line items</a> do not support
		/// <a href='RoadblockingType#CREATIVE_SET'>RoadblockingType#CREATIVE_SET</a>.
		/// </summary>
		ROADBLOCKING_NOT_SUPPORTED = 2,
		/// <summary>Programmatic <a href='ProposalLineItem'>proposal line items</a> do not support
		/// <a href='CreativeRotationType#SEQUENTIAL'>CreativeRotationType#SEQUENTIAL</a>.
		/// </summary>
		INVALID_CREATIVE_ROTATION = 3,
		/// <summary>Programmatic <a href='ProposalLineItem'>proposal line items</a> only support <a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a>.
		/// </summary>
		INVALID_PROPOSAL_LINE_ITEM_TYPE = 4,
		/// <summary>Programmatic <a href='ProposalLineItem'>proposal line items</a> only support <a
		/// href='RateType#CPM'>RateType#CPM</a>.
		/// </summary>
		INVALID_RATE_TYPE = 5,
		/// <summary>Programmatic <a href='ProposalLineItem'>proposal line items</a> do not support
		/// zero for <a href='ProposalLineItem#netRate'>ProposalLineItem#netRate</a>.
		/// </summary>
		ZERO_COST_PER_UNIT_NOT_SUPPORTED = 6,
		/// <summary>Only programmatic <a href='ProposalLineItem'>proposal line items</a> support <a
		/// href='ProgrammaticCreativeSource'>ProgrammaticCreativeSource</a>.
		/// </summary>
		INVALID_PROGRAMMATIC_CREATIVE_SOURCE = 7,
		/// <summary>Cannot update programmatic creative source if the <a
		/// href='ProposalLineItem'>proposal line item</a> has been sent to the buyer.
		/// </summary>
		CANNOT_UPDATE_PROGRAMMATIC_CREATIVE_SOURCE = 14,
		/// <summary>The <a href='Goal#units'>Goal#units</a> value is invalid. For <a
		/// href='RateType#CPD'>RateType#CPD</a> <a href='ProposalLineItem'>proposal line
		/// items</a>, only 100% is allowed
		/// </summary>
		INVALID_NUM_UNITS = 8,
		/// <summary>Cannot mix guaranteed and Preferred Deal proposal line items in a programmatic
		/// proposal.
		/// </summary>
		MIX_GUARANTEED_AND_PREFERRED_DEAL_NOT_ALLOWED = 15,
		/// <summary>Cannot mix native and banner size in a programmatic proposal line item.
		/// </summary>
		MIX_NATIVE_AND_BANNER_SIZE_NOT_ALLOWED = 12,
		/// <summary>Cannot update sizes when a programmatic proposal line item with publisher
		/// creative source is sent to a buyer.
		/// </summary>
		CANNOT_UPDATE_SIZES = 13,
		/// <summary>The {ProposalLineItem#contractedUnitsBought} cannot be <code>null</code> or zero
		/// for programmatic <a href='RateType#CPD'>RateType#CPD</a> <a
		/// href='ProposalLineItem'>proposal line items</a>.
		/// </summary>
		INVALID_SPONSORSHIP_CONTRACTED_UNITS_BOUGHT = 9,
		/// <summary>Only <a href='PricingModel#NET'>PricingModel#NET</a> is supported for
		/// programmatic <a href='ProposalLineItem'>proposal line items</a>.
		/// </summary>
		INVALID_PROGRAMMATIC_PRICING_MODEL = 11,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 10,
	}


	/// <summary>Lists all errors associated with proposal line items.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProposalLineItemError : ApiError {
		private ProposalLineItemErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ProposalLineItemErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ProposalLineItemError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProposalLineItemErrorReason {
		/// <summary>The proposal line item's rate card is not the same as other proposal line items
		/// in the proposal.
		/// </summary>
		NOT_SAME_RATE_CARD = 0,
		/// <summary>The proposal line item's type is not yet supported by Sales Manager.
		/// </summary>
		LINE_ITEM_TYPE_NOT_ALLOWED = 1,
		/// <summary>The proposal line item's end date time is not after its start date time.
		/// </summary>
		END_DATE_TIME_NOT_AFTER_START_TIME = 2,
		/// <summary>The proposal line item's end date time is after 1/1/2037.
		/// </summary>
		END_DATE_TIME_TOO_LATE = 3,
		/// <summary>The proposal line item's start date time is in past.
		/// </summary>
		START_DATE_TIME_IS_IN_PAST = 4,
		/// <summary>The proposal line item's end date time is in past.
		/// </summary>
		END_DATE_TIME_IS_IN_PAST = 5,
		/// <summary>Frontloaded delivery rate type is not allowed.
		/// </summary>
		FRONTLOADED_NOT_ALLOWED = 6,
		/// <summary>Roadblocking to display all creatives is not allowed.
		/// </summary>
		ALL_ROADBLOCK_NOT_ALLOWED = 7,
		/// <summary>Roadblocking to display all master and companion creative set is not allowed.
		/// </summary>
		CREATIVE_SET_ROADBLOCK_NOT_ALLOWED = 8,
		/// <summary>Some changes may not be allowed because the related line item has already
		/// started.
		/// </summary>
		ALREADY_STARTED = 9,
		/// <summary>The setting is conflict with product's restriction.
		/// </summary>
		CONFLICT_WITH_PRODUCT = 10,
		/// <summary>The proposal line item's setting violates the product's built-in targeting
		/// compatibility restriction.
		/// </summary>
		VIOLATE_BUILT_IN_TARGETING_COMPATIBILITY_RESTRICTION = 11,
		/// <summary>The proposal line item's setting violates the product's built-in targeting
		/// locked restriction.
		/// </summary>
		VIOLATE_BUILT_IN_TARGETING_LOCKED_RESTRICTION = 12,
		/// <summary>Cannot target mobile-only targeting criteria.
		/// </summary>
		MOBILE_TECH_CRITERIA_NOT_SUPPORTED = 13,
		/// <summary>The targeting criteria type is unsupported.
		/// </summary>
		UNSUPPORTED_TARGETING_TYPE = 14,
		/// <summary>The contracted cost does not match with what calculated from final rate and
		/// units bought.
		/// </summary>
		WRONG_COST = 15,
		/// <summary>The net rate or net cost must be equal to the gross rate or gross cost
		/// multiplied by one minus agency commission.
		/// </summary>
		AGENCY_COMMISSION_MISMATCH = 51,
		/// <summary>The cost calculated from cost per unit and units is too high.
		/// </summary>
		CALCULATED_COST_TOO_HIGH = 16,
		/// <summary>The line item priority is invalid if it's different than the default.
		/// </summary>
		INVALID_PRIORITY_FOR_LINE_ITEM_TYPE = 17,
		/// <summary>Propsoal line item cannot update when it is archived.
		/// </summary>
		UPDATE_PROPOSAL_LINE_ITEM_NOT_ALLOWED = 18,
		/// <summary>A proposal line item cannot be updated from having <a
		/// href='RoadblockingType#CREATIVE_SET'>RoadblockingType#CREATIVE_SET</a> to having
		/// a different RoadblockingType, or vice versa.
		/// </summary>
		CANNOT_UPDATE_TO_OR_FROM_CREATIVE_SET_ROADBLOCK = 19,
		/// <summary>Serving creatives exactly in sequential order is not allowed.
		/// </summary>
		SEQUENTIAL_CREATIVE_ROTATION_NOT_ALLOWED = 20,
		/// <summary>Proposal line item cannot update its reservation detail once start delivering.
		/// </summary>
		UPDATE_RESERVATION_NOT_ALLOWED = 21,
		/// <summary>The companion delivery option is not valid for the roadblocking type.
		/// </summary>
		INVALID_COMPANION_DELIVERY_OPTION_FOR_ROADBLOCKING_TYPE = 22,
		/// <summary>The companion delivery option is not valid for your environment type.
		/// </summary>
		INVALID_COMPANION_DELIVERY_OPTION_FOR_ENVIRONMENT_TYPE = 52,
		/// <summary>Roadblocking type is inconsistent with creative placeholders. If the
		/// roadblocking type is creative set, creative placeholders should contain
		/// companions, and vice versa.
		/// </summary>
		INCONSISTENT_ROADBLOCK_TYPE = 23,
		/// <summary>ContractedQuantityBuffer is only applicable to standard line item with <a
		/// href='RateType#CPC'>RateType#CPC</a>/<a href='RateType#CPM'>RateType#CPM</a>/<a
		/// href='RateType#VCPM'>RateType#VCPM</a> type.
		/// </summary>
		INVALID_CONTRACTED_QUANTITY_BUFFER = 36,
		/// <summary>One or more values on the proposal line item are not valid for a <a
		/// href='LineItemType#CLICK_TRACKING'>LineItemType#CLICK_TRACKING</a> line item
		/// type.
		/// </summary>
		INVALID_VALUES_FOR_CLICK_TRACKING_LINE_ITEM_TYPE = 25,
		/// <summary>Proposal line item cannot update its cost adjustment after first approval.
		/// </summary>
		UPDATE_COST_ADJUSTMENT_NOT_ALLOWED = 26,
		/// <summary>The currency code of the proposal line item's rate card is not supported by the
		/// current network. All supported currencies can be found in the union of <a
		/// href='Network#currencyCode'>Network#currencyCode</a> and <a
		/// href='Network#secondaryCurrencyCodes'>Network#secondaryCurrencyCodes</a>.
		/// </summary>
		UNSUPPORTED_RATE_CARD_CURRENCY_CODE = 27,
		/// <summary>The corresponding line item is paused, but the proposal line item's end date
		/// time is before the last paused time.
		/// </summary>
		END_DATE_TIME_IS_BEFORE_LAST_PAUSED_TIME = 28,
		/// <summary>Video line items cannot have roadblocking options.
		/// </summary>
		VIDEO_INVALID_ROADBLOCKING = 29,
		/// <summary>Time zone cannot be updated once the proposal line item has been sold.
		/// </summary>
		UPDATE_TIME_ZONE_NOT_ALLOWED = 30,
		/// <summary>Time zone must be network time zone if the proposal line item is <a
		/// href='RateType#VCPM'>RateType#VCPM</a>.
		/// </summary>
		INVALID_TIME_ZONE_FOR_RATE_TYPE = 37,
		/// <summary>Only the <a href='Network#timeZone'>Network#timeZone</a> is allowed for
		/// programmatic <a href='Proposal'>proposals</a>.
		/// </summary>
		INVALID_TIME_ZONE_FOR_DEALS = 55,
		/// <summary>The <a
		/// href='ProposalLineItem#environmentType'>ProposalLineItem#environmentType</a> is
		/// invalid.
		/// </summary>
		INVALID_ENVIRONMENT_TYPE = 38,
		/// <summary>At least one size must be specified.
		/// </summary>
		SIZE_REQUIRED = 31,
		/// <summary>A placeholder contains companions but the roadblocking type is not <a
		/// href='RoadblockingType#CREATIVE_SET'>RoadblockingType#CREATIVE_SET</a> or the <a
		/// href='ProductType'>product type</a> is offline.
		/// </summary>
		COMPANION_NOT_ALLOWED = 32,
		/// <summary>A placeholder does not contain companions but the roadblocking type is <a
		/// href='RoadblockingType#CREATIVE_SET'>RoadblockingType#CREATIVE_SET</a>.
		/// </summary>
		MISSING_COMPANION = 33,
		/// <summary>A placeholder's master size is the same as another placeholder's master size.
		/// </summary>
		DUPLICATED_MASTER_SIZE = 34,
		/// <summary>Only creative placeholders with standard <a
		/// href='CreativePlaceholder#size'>sizes</a> can set an expected creative count.
		/// </summary>
		INVALID_EXPECTED_CREATIVE_COUNT = 39,
		/// <summary>Non-native placeholders cannot have creative templates.
		/// </summary>
		CANNOT_HAVE_CREATIVE_TEMPLATE = 46,
		/// <summary>Placeholders can only have native creative templates.
		/// </summary>
		NATIVE_CREATIVE_TEMPLATE_REQUIRED = 47,
		/// <summary>Cannot include native placeholders without native creative templates.
		/// </summary>
		CANNOT_INCLUDE_NATIVE_PLACEHOLDER_WITHOUT_TEMPLATE_ID = 48,
		/// <summary>One or more values are not valid for a <a
		/// href='LineItemType#CLICK_TRACKING'>LineItemType#CLICK_TRACKING</a> line item
		/// type.
		/// </summary>
		INVALID_CLICK_TRACKING_LINE_ITEM_TYPE = 40,
		/// <summary>The targeting is not valid for a <a
		/// href='LineItemType#CLICK_TRACKING'>LineItemType#CLICK_TRACKING</a> line item
		/// type.
		/// </summary>
		INVALID_TARGETING_FOR_CLICK_TRACKING = 41,
		/// <summary>The <a href='RateCard'>RateCard</a> pricing model for this <a
		/// href='ProposalLineItem'>ProposalLineItem</a> is not the same as the pricing
		/// models for the other <a href='ProposalLineItem'>proposalLineItems</a> or <a
		/// href='Package'>packages</a> in the <a href='Proposal'>Proposal</a>.
		/// </summary>
		NOT_SAME_RATE_CARD_PRICING_MODEL = 49,
		/// <summary>The <a href='RateCard'>RateCard</a> workflow for this <a
		/// href='ProposalLineItem'>ProposalLineItem</a> is not the same as the workflows
		/// for the other <a href='ProposalLineItem'>proposalLineItems</a> or <a
		/// href='Package'>packages</a> in the <a href='Proposal'>Proposal</a>.
		/// </summary>
		NOT_SAME_RATE_CARD_WORKFLOW = 50,
		/// <summary>The contractedUnitsBought of the proposal line item is invalid.
		/// </summary>
		INVALID_CONTRACTED_UNITS_BOUGHT = 42,
		/// <summary>Only creative placeholders with standard <a
		/// href='CreativePlaceholder#size'>sizes</a> can contain labels.
		/// </summary>
		PLACEHOLDER_CANNOT_CONTAIN_LABELS = 43,
		/// <summary>One or more labels on a creative placeholder is invalid.
		/// </summary>
		INVALID_LABEL_TYPE_IN_PLACEHOLDER = 44,
		/// <summary>A placeholder cannot contain a negated label.
		/// </summary>
		PLACEHOLDER_CANNOT_CONTAIN_NEGATED_LABELS = 45,
		/// <summary>Marketplace <a href='RateCard'>RateCard</a> cannot be used with a
		/// non-programmatic <a href='ProposalLineItem'>ProposalLineItem</a>.
		/// </summary>
		MARKETPLACE_RATE_CARD_NOT_ALLOWED = 53,
		/// <summary>Cannot create <a href='ProposalLineItem'>ProposalLineItem</a> from a <a
		/// href='Product'>Product</a> if not using sales management.
		/// </summary>
		CANNOT_CREATE_FROM_PRODUCT = 54,
		/// <summary>Contracted impressions of programmatic proposal line item must be greater than
		/// already delivered impressions.
		/// </summary>
		CONTRACTED_UNITS_LESS_THAN_DELIVERED = 56,
		/// <summary>If AdExchangeEnvironment is DISPLAY, the proposal line item must have mobile
		/// apps as excluded device capability targeting.
		/// </summary>
		DISPLAY_ENVIRONMENT_MUST_HAVE_EXCLUDED_MOBILE_APPS_TARGETING = 57,
		/// <summary>If AdExchangeEnvironment is MOBILE, the proposal line item must have mobile apps
		/// as included device capability targeting.
		/// </summary>
		MOBILE_ENVIRONMENT_MUST_HAVE_INCLUDED_MOBILE_APPS_TARGETING = 58,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 35,
	}


	/// <summary>Lists all errors associated with proposals.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProposalError : ApiError {
		private ProposalErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ProposalErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ProposalError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProposalErrorReason {
		/// <summary>Unknown error from ad-server
		/// </summary>
		AD_SERVER_UNKNOWN_ERROR = 0,
		/// <summary>Ad-server reports an api error for the operation.
		/// </summary>
		AD_SERVER_API_ERROR = 1,
		/// <summary>Advertiser cannot be updated once the proposal has been reserved.
		/// </summary>
		UPDATE_ADVERTISER_NOT_ALLOWED = 2,
		/// <summary>Proposal cannot be updated when its status is not <code>DRAFT</code> or it is
		/// archived.
		/// </summary>
		UPDATE_PROPOSAL_NOT_ALLOWED = 3,
		/// <summary><a href='Contact'>Contacts</a> are not supported for <a
		/// href='Company.Type#ADVERTISER'>advertisers</a> in a programmatic <a
		/// href='Proposal'>Proposal</a>.
		/// </summary>
		CONTACT_UNSUPPORTED_FOR_ADVERTISER = 20,
		/// <summary>Contact associated with a proposal does not belong to the specific company.
		/// </summary>
		INVALID_CONTACT = 4,
		/// <summary>Contact associated with a proposal's advertiser or agency is duplicated.
		/// </summary>
		DUPLICATED_CONTACT = 5,
		/// <summary>A proposal cannot be created or updated because the company it is associated
		/// with has <a href='Company#creditStatus'>Company#creditStatus</a> that is not
		/// <code></code> or <code>ON_HOLD</code>.
		/// </summary>
		UNACCEPTABLE_COMPANY_CREDIT_STATUS = 6,
		/// <summary>Advertiser or agency associated with the proposal has <a
		/// href='Company#creditStatus'>Company#creditStatus</a> that is not <code></code>.
		/// </summary>
		COMPANY_CREDIT_STATUS_NOT_ACTIVE = 24,
		/// <summary>Cannot have other agencies without a primary agency.
		/// </summary>
		PRIMARY_AGENCY_REQUIRED = 7,
		/// <summary>Cannot have more than one primary agency.
		/// </summary>
		PRIMARY_AGENCY_NOT_UNIQUE = 8,
		/// <summary>The <a href='Company'>Company</a> association type is not supported for
		/// programmatic <a href='Proposal'>proposals</a>.
		/// </summary>
		UNSUPPORTED_COMPANY_ASSOCIATION_TYPE_FOR_PROGRAMMATIC_PROPOSAL = 21,
		/// <summary>Advertiser or agency associated with a proposal is duplicated.
		/// </summary>
		DUPLICATED_COMPANY_ASSOCIATION = 9,
		/// <summary>Found duplicated primary or secondary sales person.
		/// </summary>
		DUPLICATED_SALESPERSON = 10,
		/// <summary>Found duplicated sales planner.
		/// </summary>
		DUPLICATED_SALES_PLANNER = 11,
		/// <summary>Found duplicated primary or secondary trafficker.
		/// </summary>
		DUPLICATED_TRAFFICKER = 12,
		/// <summary>The proposal has no unarchived proposal line items.
		/// </summary>
		HAS_NO_UNARCHIVED_PROPOSAL_LINEITEMS = 13,
		/// <summary>One or more of the terms and conditions being added already exists on the
		/// proposal.
		/// </summary>
		DUPLICATE_TERMS_AND_CONDITIONS = 19,
		/// <summary>The currency code of the proposal is not supported by the current network. All
		/// supported currencies can be found in the union of <a
		/// href='Network#currencyCode'>Network#currencyCode</a> and <a
		/// href='Network#secondaryCurrencyCodes'>Network#secondaryCurrencyCodes</a>.
		/// </summary>
		UNSUPPORTED_PROPOSAL_CURRENCY_CODE = 14,
		/// <summary><a href='Proposal#marketplaceInfo'>Proposal#marketplaceInfo</a> fields should
		/// not be set for a non-programmatic <a href='Proposal'>Proposal</a>.
		/// </summary>
		INVALID_FIELDS_SET_FOR_NON_PROGRAMMATIC_PROPOSAL = 22,
		/// <summary>The POC value of the proposal is invalid.
		/// </summary>
		INVALID_POC = 15,
		/// <summary>Currency cannot be updated once the proposal has been reserved.
		/// </summary>
		UPDATE_CURRENCY_NOT_ALLOWED = 16,
		/// <summary>Time zone cannot be updated once the proposal has been sold.
		/// </summary>
		UPDATE_TIME_ZONE_NOT_ALLOWED = 17,
		/// <summary>Sales management features must be enabled to use non-programmatic <a
		/// href='Proposal'>Proposal</a>.
		/// </summary>
		NON_PROGRAMMATIC_PROPOSAL_NOT_ALLOWED = 23,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 18,
	}


	/// <summary>Lists all errors associated with performing actions on <a
	/// href='Proposal'>Proposal</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProposalActionError : ApiError {
		private ProposalActionErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ProposalActionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ProposalActionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProposalActionErrorReason {
		/// <summary>The operation is not applicable to the current state.
		/// </summary>
		NOT_APPLICABLE = 0,
		/// <summary>The operation cannot be applied because the proposal is archived.
		/// </summary>
		IS_ARCHIVED = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Lists all errors associated with <a href='Package'>Package</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PackageError : ApiError {
		private PackageErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public PackageErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the <a href='PackageError'>PackageError</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "PackageError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum PackageErrorReason {
		/// <summary>Package cannot be created from an inactive or archived product package.
		/// </summary>
		INVAILD_PRODUCT_PACKAGE = 0,
		/// <summary>The rate card is inactive.
		/// </summary>
		INACTIVE_RATE_CARD = 1,
		/// <summary>There is no association between the product package and the rate card.
		/// </summary>
		PRODUCT_PACKAGE_NOT_IN_RATE_CARD = 2,
		/// <summary>There are no unarchived product package items in this product package.
		/// </summary>
		HAS_NO_UNARCHIVED_PRODUCT_PACKAGE_ITEM = 3,
		/// <summary>The package's rate card is not the same as other packages or proposal line items
		/// in the proposal.
		/// </summary>
		NOT_SAME_RATE_CARD = 4,
		/// <summary>The <a href='RateCard'>RateCard</a> pricing model for this <a
		/// href='Package'>Package</a> is not the same as the pricing models for the other
		/// <a href='ProposalLineItem'>proposalLineItems</a> or <a
		/// href='Package'>packages</a> in the <a href='Proposal'>Proposal</a>.
		/// </summary>
		NOT_SAME_RATE_CARD_PRICING_MODEL = 6,
		/// <summary>The <a href='RateCard'>RateCard</a> workflow for this <a
		/// href='Package'>Package</a> is not the same as the workflows for the other <a
		/// href='ProposalLineItem'>proposalLineItems</a> or <a href='Package'>packages</a>
		/// in the <a href='Proposal'>Proposal</a>.
		/// </summary>
		NOT_SAME_RATE_CARD_WORKFLOW = 7,
		/// <summary>Package cannot be created in a programmatic proposal.
		/// </summary>
		PACKAGES_NOT_ALLOWED_IN_PROGRAMMATIC_PROPOSALS = 8,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 5,
	}


	/// <summary>Lists all errors for executing actions on <a href='Package'>Package</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PackageActionError : ApiError {
		private PackageActionErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public PackageActionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "PackageActionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum PackageActionErrorReason {
		/// <summary>The operation is not applicable because the proposal line items under these
		/// packages have already been created.
		/// </summary>
		PROPOSAL_LINE_ITEMS_HAVE_BEEN_CREATED = 0,
		/// <summary>The operation is not applicable because the containing proposal is not editable.
		/// </summary>
		PROPOSAL_NOT_EDITABLE = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Errors associated with creating or updating programmatic <a
	/// href='Proposal'>proposals</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DealError : ApiError {
		private DealErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public DealErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "DealError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum DealErrorReason {
		/// <summary>Cannot add new <a href='ProposalLineItem'>proposal line items</a> to a <a
		/// href='Proposal'>Proposal</a> when <a href='Proposal#isSold'>Proposal#isSold</a>
		/// is <code>true</code>.
		/// </summary>
		CANNOT_ADD_LINE_ITEM_WHEN_SOLD = 0,
		/// <summary>Cannot archive <a href='ProposalLineItem'>proposal line items</a> from a <a
		/// href='Proposal'>Proposal</a> when <a href='Proposal#isSold'>Proposal#isSold</a>
		/// is <code>true</code>.
		/// </summary>
		CANNOT_ARCHIVE_LINE_ITEM_WHEN_SOLD = 1,
		/// <summary>Cannot archive a <a href='Proposal'>Proposal</a> when <a
		/// href='Proposal#isSold'>Proposal#isSold</a> is <code>true</code>.
		/// </summary>
		CANNOT_ARCHIVE_PROPOSAL_WHEN_SOLD = 2,
		/// <summary>Cannot change a field that requires buyer approval during the current operation.
		/// </summary>
		CANNOT_CHANGE_FIELD_REQUIRING_BUYER_APPROVAL = 3,
		/// <summary>Cannot find seller ID for the <a href='Proposal'>Proposal</a>.
		/// </summary>
		CANNOT_GET_SELLER_ID = 4,
		/// <summary><a href='Proposal'>Proposal</a> must be marked as editable by <a
		/// href='EditProposalsForNegotiation'>EditProposalsForNegotiation</a> before
		/// performing requested action.
		/// </summary>
		CAN_ONLY_EXECUTE_IF_LOCAL_EDITS = 14,
		/// <summary><a href='Proposal'>Proposal</a> contains no <a href='ProposalLineItem'>proposal
		/// line items</a>.
		/// </summary>
		MISSING_PROPOSAL_LINE_ITEMS = 6,
		/// <summary>No environment set for <a href='Proposal'>Proposal</a>.
		/// </summary>
		MISSING_ENVIRONMENT = 7,
		/// <summary>The Ad Exchange property is not associated with the current network.
		/// </summary>
		MISSING_AD_EXCHANGE_PROPERTY = 8,
		/// <summary>Cannot find <a href='Proposal'>Proposal</a> in Marketplace.
		/// </summary>
		CANNOT_FIND_PROPOSAL_IN_MARKETPLACE = 9,
		/// <summary>No <a href='Product'>Product</a> exists for buyer-initiated programmatic <a
		/// href='Proposal'>proposals</a>.
		/// </summary>
		CANNOT_GET_PRODUCT = 10,
		/// <summary>A new version of the <a href='Proposal'>Proposal</a> was sent from buyer, cannot
		/// execute the requested action before performing <a
		/// href='DiscardLocalVersionEdits'>DiscardLocalVersionEdits</a>.
		/// </summary>
		NEW_VERSION_FROM_BUYER = 11,
		/// <summary>A new version of the <a href='Proposal'>Proposal</a> exists in Marketplace,
		/// cannot execute the requested action before the proposal is synced to newest
		/// revision.
		/// </summary>
		PROPOSAL_OUT_OF_SYNC_WITH_MARKETPLACE = 15,
		/// <summary>No <a href='Proposal'>Proposal</a> changes were found.
		/// </summary>
		NO_PROPOSAL_CHANGES_FOUND = 12,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 13,
	}


	/// <summary>Lists all errors associated with the billing settings of a proposal or proposal
	/// line item.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class BillingError : ApiError {
		private BillingErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public BillingErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "BillingError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum BillingErrorReason {
		/// <summary>Found unsupported billing schedule.
		/// </summary>
		UNSUPPORTED_BILLING_SCHEDULE = 0,
		/// <summary>Found unsupported billing cap.
		/// </summary>
		UNSUPPORTED_BILLING_CAP = 1,
		/// <summary>Billing source is missing when either billing scheule or billing cap is
		/// provided.
		/// </summary>
		MISSING_BILLING_SOURCE = 2,
		/// <summary>Billing schedule is missing when the provided billing source is CONSTRACTED.
		/// </summary>
		MISSING_BILLING_SCHEDULE = 3,
		/// <summary>Billing cap is missing when the provided billing source is not CONSTRACTED.
		/// </summary>
		MISSING_BILLING_CAP = 4,
		/// <summary>The billing source is invalid for offline proposal line item.
		/// </summary>
		INVALID_BILLING_SOURCE_FOR_OFFLINE = 5,
		/// <summary>Billing settings cannot be updated once the proposal has been approved.
		/// </summary>
		UPDATE_BILLING_NOT_ALLOWED = 6,
		/// <summary>Billing base is missing when the provided billing source is CONTRACTED.
		/// </summary>
		MISSING_BILLING_BASE = 7,
		/// <summary>The billing base is invalid for the provided billing source.
		/// </summary>
		INVALID_BILLING_BASE = 8,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 9,
	}


	/// <summary>Lists all errors associated with the availability of billing settings based on
	/// proposal network settings.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AvailableBillingError : ApiError {
		private AvailableBillingErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AvailableBillingErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The error reason represented by an enum.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AvailableBillingError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AvailableBillingErrorReason {
		/// <summary>The billing source provided is not available in proposal network settings.
		/// </summary>
		BILLING_SOURCE_IS_NOT_AVAILABLE = 0,
		/// <summary>The billing schedule provided is not available in proposal network settings.
		/// </summary>
		BILLING_SCHEDULE_IS_NOT_AVAILABLE = 1,
		/// <summary>The billing cap provided is not available in proposal network settings.
		/// </summary>
		BILLING_CAP_IS_NOT_AVAILABLE = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ProposalServiceInterface")]
	public interface ProposalServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ProposalService.createProposalsResponse createProposals(Wrappers.ProposalService.createProposalsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ProposalService.createProposalsResponse> createProposalsAsync(Wrappers.ProposalService.createProposalsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.MarketplaceCommentPage getMarketplaceCommentsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.MarketplaceCommentPage> getMarketplaceCommentsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ProposalPage getProposalsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProposalPage> getProposalsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performProposalAction(Google.Api.Ads.AdManager.v201802.ProposalAction proposalAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performProposalActionAsync(Google.Api.Ads.AdManager.v201802.ProposalAction proposalAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ProposalService.updateProposalsResponse updateProposals(Wrappers.ProposalService.updateProposalsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ProposalService.updateProposalsResponse> updateProposalsAsync(Wrappers.ProposalService.updateProposalsRequest request);
	}


	/// <summary>Captures a page of <a href='MarketplaceComment'>MarketplaceComment</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class MarketplaceCommentPage {
		private int startIndexField;

		private bool startIndexFieldSpecified;

		private MarketplaceComment[] resultsField;

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of results contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 1)]
		public MarketplaceComment[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>A comment associated with a programmatic <a href='Proposal'>Proposal</a> that
	/// has been sent to Marketplace.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class MarketplaceComment {
		private long proposalIdField;

		private bool proposalIdFieldSpecified;

		private string commentField;

		private DateTime creationTimeField;

		private bool createdBySellerField;

		private bool createdBySellerFieldSpecified;

		/// <summary>The unique ID of the <a href='Proposal'>Proposal</a> the comment belongs to.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long proposalId {
			get {
				return this.proposalIdField;
			}
			set {
				this.proposalIdField = value;
				this.proposalIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="proposalId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool proposalIdSpecified {
			get {
				return this.proposalIdFieldSpecified;
			}
			set {
				this.proposalIdFieldSpecified = value;
			}
		}

		/// <summary>The comment made on the <a href='Proposal'>Proposal</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string comment {
			get {
				return this.commentField;
			}
			set {
				this.commentField = value;
			}
		}

		/// <summary>The creation <a href='DateTime'>DateTime</a> of this <code></code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public DateTime creationTime {
			get {
				return this.creationTimeField;
			}
			set {
				this.creationTimeField = value;
			}
		}

		/// <summary>Indicates whether the <code>MarketplaceComment</code> was created by seller.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public bool createdBySeller {
			get {
				return this.createdBySellerField;
			}
			set {
				this.createdBySellerField = value;
				this.createdBySellerSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="createdBySeller" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool createdBySellerSpecified {
			get {
				return this.createdBySellerFieldSpecified;
			}
			set {
				this.createdBySellerFieldSpecified = value;
			}
		}
	}


	/// <summary>Captures a page of <a href='Proposal'>Proposal</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProposalPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private Proposal[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of proposals contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public Proposal[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a href='Proposal'>Proposal</a>
	/// objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UpdateOrderWithSellerData))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UnarchiveProposals))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(TerminateNegotiations))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SubmitProposalsForArchival))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SubmitProposalsForApproval))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SubmitProposalsForApprovalBypassValidation))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RetractProposals))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ReserveProposals))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RequestBuyerAcceptance))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(EditProposalsForNegotiation))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DiscardLocalVersionEdits))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CancelRetractionForProposals))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(BypassProposalWorkflowRules))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ArchiveProposals))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class ProposalAction {
	}


	/// <summary>The action to update a finalized Marketplace <a href='Order'>Order</a> with the
	/// seller's data. This action is only applicable for programmatic proposals.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UpdateOrderWithSellerData : ProposalAction {
	}


	/// <summary>The action used for unarchiving <a href='Proposal'>Proposal</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UnarchiveProposals : ProposalAction {
	}


	/// <summary>The action for marking all negotiations on the <a href='Proposal'>Proposal</a>
	/// as terminated in Marketplace.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class TerminateNegotiations : ProposalAction {
	}


	/// <summary>The action used for submitting <a href='Proposal'>Proposal</a> objects for
	/// archival. It will start a workflow to request approvals in order to proceed with
	/// archival. Using <a
	/// href='SubmitProposalsForArchival'>SubmitProposalsForArchival</a> is mandatory
	/// for <a href='Proposal'>proposals</a> when they are sold, but not completed.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SubmitProposalsForArchival : ProposalAction {
	}


	/// <summary>The action used for submitting <a href='Proposal'>Proposal</a> objects for
	/// approval.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SubmitProposalsForApproval : ProposalAction {
	}


	/// <summary>The action used for submitting <a href='Proposal'>Proposal</a> objects for
	/// approval and bypassing workflow validation.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SubmitProposalsForApprovalBypassValidation : ProposalAction {
	}


	/// <summary>The action used for retracting <a href='Proposal'>Proposal</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RetractProposals : ProposalAction {
		private RetractionDetails retractionDetailsField;

		/// <summary><a href='RetractionDetails'>Details</a> describing why the <a
		/// href='Proposal'>Proposal</a> is being retracted.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public RetractionDetails retractionDetails {
			get {
				return this.retractionDetailsField;
			}
			set {
				this.retractionDetailsField = value;
			}
		}
	}


	/// <summary>The action to reserve inventory for <a href='Proposal'>Proposal</a> objects. It
	/// does not allow overbooking unless <a href='#allowOverbook'>#allowOverbook</a> is
	/// set to <code>true</code>. This action is only applicable for programmatic
	/// proposals not using sales management.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReserveProposals : ProposalAction {
		private bool allowOverbookField;

		private bool allowOverbookFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool allowOverbook {
			get {
				return this.allowOverbookField;
			}
			set {
				this.allowOverbookField = value;
				this.allowOverbookSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowOverbook" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowOverbookSpecified {
			get {
				return this.allowOverbookFieldSpecified;
			}
			set {
				this.allowOverbookFieldSpecified = value;
			}
		}
	}


	/// <summary>The action used to request acceptance from the buyer for the <a
	/// href='Proposal'>Proposal</a> through Marketplace. This action is only applicable
	/// for programmatic proposals.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RequestBuyerAcceptance : ProposalAction {
	}


	/// <summary>Opens the non-free-editable fields of a <a href='Proposal'>Proposal</a> for
	/// edit. <p>This proposal will not receive updates from Marketplace while it's open
	/// for edit. If the buyer updates the proposal while it is open for local editing,
	/// Google will set <a
	/// href='ProposalMarketplaceInfo#isNewVersionFromBuyer'>ProposalMarketplaceInfo#isNewVersionFromBuyer</a>
	/// to <code>true</code>. You will then need to call <a
	/// href='DiscardProposalDrafts'>DiscardProposalDrafts</a> to revert your edits to
	/// get the buyer's latest changes, and then perform this action to start making
	/// your edits again.</p> <p>This action is only applicable for programmatic
	/// proposals.</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class EditProposalsForNegotiation : ProposalAction {
	}


	/// <summary>The action for reverting the local <a href='Proposal'>Proposal</a> modifications
	/// to reflect the latest terms and private data in Marketplace. This action is only
	/// applicable for programmatic proposals.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DiscardLocalVersionEdits : ProposalAction {
	}


	/// <summary>The action used for canceling retraction for <a href='Proposal'>Proposal</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CancelRetractionForProposals : ProposalAction {
	}


	/// <summary>The action used to bypass all rules associated with <a
	/// href='WorkflowRequest'>WorkflowRequests</a> for <a href='Proposal'>Proposal</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class BypassProposalWorkflowRules : ProposalAction {
	}


	/// <summary>The action used for archiving <a href='Proposal'>Proposal</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ArchiveProposals : ProposalAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ProposalServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ProposalServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for adding, updating and retrieving <a
	/// href='Proposal'>Proposal</a> objects.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ProposalService : AdManagerSoapClient<IProposalService>, IProposalService {
		/// <summary> Creates a new instance of the <see cref="ProposalService"/> class.
		/// </summary>
		public ProposalService() {
		}

		/// <summary> Creates a new instance of the <see cref="ProposalService"/> class.
		/// </summary>
		public ProposalService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="ProposalService"/> class.
		/// </summary>
		public ProposalService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ProposalService"/> class.
		/// </summary>
		public ProposalService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ProposalService"/> class.
		/// </summary>
		public ProposalService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ProposalService.createProposalsResponse Google.Api.Ads.AdManager.v201802.ProposalServiceInterface.createProposals(Wrappers.ProposalService.createProposalsRequest request) {
			return base.Channel.createProposals(request);
		}

		/// <summary>Creates new <a href='Proposal'>Proposal</a> objects. For each proposal, the
		/// following fields are required: <ul> <li><a
		/// href='Proposal#name'>Proposal#name</a></li> </ul>
		/// </summary><param name='proposals'>the proposals to create</param>
		/// <returns>the created proposals with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Proposal[] createProposals(Google.Api.Ads.AdManager.v201802.Proposal[] proposals) {
			Wrappers.ProposalService.createProposalsRequest inValue = new Wrappers.ProposalService.createProposalsRequest();
			inValue.proposals = proposals;
			Wrappers.ProposalService.createProposalsResponse retVal = ((Google.Api.Ads.AdManager.v201802.ProposalServiceInterface)(this)).createProposals(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ProposalService.createProposalsResponse> Google.Api.Ads.AdManager.v201802.ProposalServiceInterface.createProposalsAsync(Wrappers.ProposalService.createProposalsRequest request) {
			return base.Channel.createProposalsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Proposal[]> createProposalsAsync(Google.Api.Ads.AdManager.v201802.Proposal[] proposals) {
			Wrappers.ProposalService.createProposalsRequest inValue = new Wrappers.ProposalService.createProposalsRequest();
			inValue.proposals = proposals;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Proposal[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ProposalServiceInterface)(this)).createProposalsAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='MarketplaceCommentPage'>MarketplaceCommentPage</a> of <a
		/// href='MarketplaceComment'>MarketplaceComment</a> objects that satisfy the given
		/// <a href='Statement#query'>Statement#query</a>. This method only returns comments
		/// already sent to Marketplace, local draft <a
		/// href='ProposalMarketplaceInfo#marketplaceComment'>ProposalMarketplaceInfo#marketplaceComment</a>
		/// are not included. The following fields are supported for filtering: <table> <tr>
		/// <th scope="col">PQL Property</th> <th scope="col">Object Property</th> </tr>
		/// <tr> <td><code>proposalId</code></td> <td><a
		/// href='MarketplaceComment#proposalId'>MarketplaceComment#proposalId</a></td>
		/// </tr> </table> The query must specify a <code>proposalId</code>, and only
		/// supports a subset of PQL syntax:<br /> <code>[WHERE &lt;condition&gt; {AND
		/// &lt;condition&gt; ...}]</code><br /> <code>[ORDER BY &lt;property&gt; [ASC |
		/// DESC]]</code><br /> <code>[LIMIT {[&lt;offset&gt;,] &lt;count&gt;} |
		/// {&lt;count&gt; OFFSET &lt;offset&gt;}]</code><br />
		/// <p><code>&lt;condition&gt;</code><br /> #x160;#x160;#x160;#x160; <code>:=
		/// &lt;property&gt; = &lt;value&gt;</code><br /> <code>&lt;condition&gt; :=
		/// &lt;property&gt; IN &lt;list&gt;</code><br /> Only supports <code>ORDER
		/// BY</code> <a
		/// href='MarketplaceComment#creationTime'>MarketplaceComment#creationTime</a>. </p>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of marketplace comments</param>
		/// <returns>the marketplace comments that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.MarketplaceCommentPage getMarketplaceCommentsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getMarketplaceCommentsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.MarketplaceCommentPage> getMarketplaceCommentsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getMarketplaceCommentsByStatementAsync(filterStatement);
		}

		/// <summary>Gets a <a href='ProposalPage'>ProposalPage</a> of <a
		/// href='Proposal'>Proposal</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='Proposal#id'>Proposal#id</a></td> </tr> <tr>
		/// <td><code>dfpOrderId</code></td> <td><a
		/// href='Proposal#dfpOrderId'>Proposal#dfpOrderId</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a href='Proposal#name'>Proposal#name</a></td>
		/// </tr> <tr> <td><code>status</code></td> <td><a
		/// href='Proposal#status'>Proposal#status</a></td> </tr> <tr>
		/// <td><code>isArchived</code></td> <td><a
		/// href='Proposal#isArchived'>Proposal#isArchived</a></td> </tr> <tr>
		/// <td><code>approvalStatus</code> <div class="constraint">Only applicable for
		/// proposals using sales management</div> </td> <td><a
		/// href='Proposal#approvalStatus'>Proposal#approvalStatus</a></td> </tr> <tr>
		/// <td><code>lastModifiedDateTime</code></td> <td><a
		/// href='Proposal#lastModifiedDateTime'>Proposal#lastModifiedDateTime</a></td>
		/// </tr> <tr> <td><code>thirdPartyAdServerId</code> <div class="constraint">Only
		/// applicable for non-programmatic proposals using sales management</div> </td>
		/// <td><a
		/// href='Proposal#thirdPartyAdServerId'>Proposal#thirdPartyAdServerId</a></td>
		/// </tr> <tr> <td><code>customThirdPartyAdServerName</code> <div
		/// class="constraint">Only applicable for non-programmatic proposals using sales
		/// management</div> </td> <td><a
		/// href='Proposal#customThirdPartyAdServerName'>Proposal#customThirdPartyAdServerName</a></td>
		/// </tr> <tr> <td><code>hasOfflineErrors</code></td> <td><a
		/// href='Proposal#hasOfflineErrors'>Proposal#hasOfflineErrors</a></td> </tr> <tr>
		/// <td><code>isProgrammatic</code></td> <td><a
		/// href='Proposal#isProgrammatic'>Proposal#isProgrammatic</a></td> </tr> <tr>
		/// <td><code>negotiationStatus</code> <div class="constraint">Only applicable for
		/// programmatic proposals</div> </td> <td><a
		/// href='ProposalMarketplaceInfo#negotiationStatus'>ProposalMarketplaceInfo#negotiationStatus</a></td>
		/// </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of proposals</param>
		/// <returns>the proposals that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ProposalPage getProposalsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getProposalsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProposalPage> getProposalsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getProposalsByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='Proposal'>Proposal</a> objects that match the given
		/// <a href='Statement#query'>Statement#query</a>. The following fields are also
		/// required when submitting proposals for approval: <ul> <li><a
		/// href='Proposal#advertiser'>Proposal#advertiser</a></li> <li><a
		/// href='Proposal#primarySalesperson'>Proposal#primarySalesperson</a></li> <li><a
		/// href='Proposal#primaryTraffickerId'>Proposal#primaryTraffickerId</a></li> </ul>
		/// </summary><param name='proposalAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of proposals</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performProposalAction(Google.Api.Ads.AdManager.v201802.ProposalAction proposalAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performProposalAction(proposalAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performProposalActionAsync(Google.Api.Ads.AdManager.v201802.ProposalAction proposalAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performProposalActionAsync(proposalAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ProposalService.updateProposalsResponse Google.Api.Ads.AdManager.v201802.ProposalServiceInterface.updateProposals(Wrappers.ProposalService.updateProposalsRequest request) {
			return base.Channel.updateProposals(request);
		}

		/// <summary>Updates the specified <a href='Proposal'>Proposal</a> objects.
		/// </summary><param name='proposals'>the proposals to update</param>
		/// <returns>the updated proposals</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Proposal[] updateProposals(Google.Api.Ads.AdManager.v201802.Proposal[] proposals) {
			Wrappers.ProposalService.updateProposalsRequest inValue = new Wrappers.ProposalService.updateProposalsRequest();
			inValue.proposals = proposals;
			Wrappers.ProposalService.updateProposalsResponse retVal = ((Google.Api.Ads.AdManager.v201802.ProposalServiceInterface)(this)).updateProposals(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ProposalService.updateProposalsResponse> Google.Api.Ads.AdManager.v201802.ProposalServiceInterface.updateProposalsAsync(Wrappers.ProposalService.updateProposalsRequest request) {
			return base.Channel.updateProposalsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Proposal[]> updateProposalsAsync(Google.Api.Ads.AdManager.v201802.Proposal[] proposals) {
			Wrappers.ProposalService.updateProposalsRequest inValue = new Wrappers.ProposalService.updateProposalsRequest();
			inValue.proposals = proposals;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Proposal[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ProposalServiceInterface)(this)).updateProposalsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.ProposalLineItemService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createProposalLineItems", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createProposalLineItemsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("proposalLineItems")]
			public Google.Api.Ads.AdManager.v201802.ProposalLineItem[] proposalLineItems;

			/// <summary> Creates a new instance of the <see
			/// cref="createProposalLineItemsRequest"/> class. </summary>
			public createProposalLineItemsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createProposalLineItemsRequest"/> class. </summary>
			public createProposalLineItemsRequest(Google.Api.Ads.AdManager.v201802.ProposalLineItem[] proposalLineItems) {
				this.proposalLineItems = proposalLineItems;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createProposalLineItemsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createProposalLineItemsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ProposalLineItem[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createProposalLineItemsResponse"/> class. </summary>
			public createProposalLineItemsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createProposalLineItemsResponse"/> class. </summary>
			public createProposalLineItemsResponse(Google.Api.Ads.AdManager.v201802.ProposalLineItem[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateProposalLineItems", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateProposalLineItemsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("proposalLineItems")]
			public Google.Api.Ads.AdManager.v201802.ProposalLineItem[] proposalLineItems;

			/// <summary> Creates a new instance of the <see
			/// cref="updateProposalLineItemsRequest"/> class. </summary>
			public updateProposalLineItemsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateProposalLineItemsRequest"/> class. </summary>
			public updateProposalLineItemsRequest(Google.Api.Ads.AdManager.v201802.ProposalLineItem[] proposalLineItems) {
				this.proposalLineItems = proposalLineItems;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateProposalLineItemsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateProposalLineItemsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ProposalLineItem[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateProposalLineItemsResponse"/> class. </summary>
			public updateProposalLineItemsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateProposalLineItemsResponse"/> class. </summary>
			public updateProposalLineItemsResponse(Google.Api.Ads.AdManager.v201802.ProposalLineItem[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>Marketplace info for <a href='ProposalLineItem'>ProposalLineItem</a> with a
	/// corresponding deal in Marketplace.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProposalLineItemMarketplaceInfo {
		private AdExchangeEnvironment adExchangeEnvironmentField;

		private bool adExchangeEnvironmentFieldSpecified;

		/// <summary>The <a href='AdExchangeEnvironment'>AdExchangeEnvironment</a> of the marketplace
		/// web property that is associated with this line item. This is only for <a
		/// href='ProposalLineItem'>proposal line items</a> with a corresponding deal in
		/// Marketplace. <span class="constraint Required">This attribute is
		/// required.</span>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AdExchangeEnvironment adExchangeEnvironment {
			get {
				return this.adExchangeEnvironmentField;
			}
			set {
				this.adExchangeEnvironmentField = value;
				this.adExchangeEnvironmentSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="adExchangeEnvironment" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool adExchangeEnvironmentSpecified {
			get {
				return this.adExchangeEnvironmentFieldSpecified;
			}
			set {
				this.adExchangeEnvironmentFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents the status of a triggered <a
	/// href='PremiumRateValue'>PremiumRateValue</a> (formerly referred to as a
	/// <code>RateCardCustomization</code>).
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProposalLineItemPremium {
		private PremiumRateValue premiumRateValueField;

		private ProposalLineItemPremiumStatus statusField;

		private bool statusFieldSpecified;

		/// <summary>The <a href='PremiumRateValue'>PremiumRateValue</a> triggered by the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public PremiumRateValue premiumRateValue {
			get {
				return this.premiumRateValueField;
			}
			set {
				this.premiumRateValueField = value;
			}
		}

		/// <summary>The status of the triggered premium. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public ProposalLineItemPremiumStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}
	}


	/// <summary>Status of the premium triggered by a proposal line item.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProposalLineItemPremiumStatus {
		/// <summary>Indicating the premium is included in the pricing.
		/// </summary>
		INCLUDED = 0,
		/// <summary>Indicating the premium is excluded from the pricing.
		/// </summary>
		EXCLUDED = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>A <code>PropoalLineItemConstraints</code> represents all the constraints set for
	/// a <a href=''>ProposalLineItem</a> and is always readonly. It comes from the <a
	/// href='Product'>Product</a>, based on which the proposal line item is created.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProposalLineItemConstraints {
		private bool allowCreativePlaceholdersCustomizationField;

		private bool allowCreativePlaceholdersCustomizationFieldSpecified;

		private CreativePlaceholder[] builtInCreativePlaceholdersField;

		private RoadblockingType builtInRoadblockingTypeField;

		private bool builtInRoadblockingTypeFieldSpecified;

		private DeliveryRateType builtInDeliveryRateTypeField;

		private bool builtInDeliveryRateTypeFieldSpecified;

		private CreativeRotationType builtInCreativeRotationTypeField;

		private bool builtInCreativeRotationTypeFieldSpecified;

		private CompanionDeliveryOption builtInCompanionDeliveryOptionField;

		private bool builtInCompanionDeliveryOptionFieldSpecified;

		private FrequencyCap[] builtInFrequencyCapsField;

		private Targeting productBuiltInTargetingField;

		private CustomizableAttributes customizableAttributesField;

		/// <summary>Allows customization of <a href='CreativePlaceholder'>creative placeholders</a>
		/// when creating <a href='ProposalLineItem'>proposal line items</a>. <p>This
		/// attribute is read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool allowCreativePlaceholdersCustomization {
			get {
				return this.allowCreativePlaceholdersCustomizationField;
			}
			set {
				this.allowCreativePlaceholdersCustomizationField = value;
				this.allowCreativePlaceholdersCustomizationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowCreativePlaceholdersCustomization" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowCreativePlaceholdersCustomizationSpecified {
			get {
				return this.allowCreativePlaceholdersCustomizationFieldSpecified;
			}
			set {
				this.allowCreativePlaceholdersCustomizationFieldSpecified = value;
			}
		}

		/// <summary>The built-in <a href='CreativePlaceholder'>creative placeholders</a> for the
		/// created <a href='ProposalLineItem'>ProposalLineItem</a>. <p>This attribute is
		/// read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("builtInCreativePlaceholders", Order = 1)]
		public CreativePlaceholder[] builtInCreativePlaceholders {
			get {
				return this.builtInCreativePlaceholdersField;
			}
			set {
				this.builtInCreativePlaceholdersField = value;
			}
		}

		/// <summary>The built-in roadblocking type for the created <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. <p>This attribute is
		/// read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public RoadblockingType builtInRoadblockingType {
			get {
				return this.builtInRoadblockingTypeField;
			}
			set {
				this.builtInRoadblockingTypeField = value;
				this.builtInRoadblockingTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="builtInRoadblockingType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool builtInRoadblockingTypeSpecified {
			get {
				return this.builtInRoadblockingTypeFieldSpecified;
			}
			set {
				this.builtInRoadblockingTypeFieldSpecified = value;
			}
		}

		/// <summary>The built-in delivery rate type for the created <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. <p>This attribute is
		/// read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public DeliveryRateType builtInDeliveryRateType {
			get {
				return this.builtInDeliveryRateTypeField;
			}
			set {
				this.builtInDeliveryRateTypeField = value;
				this.builtInDeliveryRateTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="builtInDeliveryRateType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool builtInDeliveryRateTypeSpecified {
			get {
				return this.builtInDeliveryRateTypeFieldSpecified;
			}
			set {
				this.builtInDeliveryRateTypeFieldSpecified = value;
			}
		}

		/// <summary>The built-in creative rotation type for the created <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. <p>This attribute is
		/// read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public CreativeRotationType builtInCreativeRotationType {
			get {
				return this.builtInCreativeRotationTypeField;
			}
			set {
				this.builtInCreativeRotationTypeField = value;
				this.builtInCreativeRotationTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="builtInCreativeRotationType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool builtInCreativeRotationTypeSpecified {
			get {
				return this.builtInCreativeRotationTypeFieldSpecified;
			}
			set {
				this.builtInCreativeRotationTypeFieldSpecified = value;
			}
		}

		/// <summary>The built-in companion delivery option for the created <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. <p>This attribute is
		/// read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public CompanionDeliveryOption builtInCompanionDeliveryOption {
			get {
				return this.builtInCompanionDeliveryOptionField;
			}
			set {
				this.builtInCompanionDeliveryOptionField = value;
				this.builtInCompanionDeliveryOptionSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="builtInCompanionDeliveryOption" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool builtInCompanionDeliveryOptionSpecified {
			get {
				return this.builtInCompanionDeliveryOptionFieldSpecified;
			}
			set {
				this.builtInCompanionDeliveryOptionFieldSpecified = value;
			}
		}

		/// <summary>The built-in frequency caps for the created <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. <p>This attribute is
		/// read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("builtInFrequencyCaps", Order = 6)]
		public FrequencyCap[] builtInFrequencyCaps {
			get {
				return this.builtInFrequencyCapsField;
			}
			set {
				this.builtInFrequencyCapsField = value;
			}
		}

		/// <summary>Built-in targeting for the created <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. <p>This attribute is
		/// read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public Targeting productBuiltInTargeting {
			get {
				return this.productBuiltInTargetingField;
			}
			set {
				this.productBuiltInTargetingField = value;
			}
		}

		/// <summary>Specifies what targeting or attributes for the created <a
		/// href='ProposalLineItem'>ProposalLineItem</a> are customizable. <p>This attribute
		/// is read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public CustomizableAttributes customizableAttributes {
			get {
				return this.customizableAttributesField;
			}
			set {
				this.customizableAttributesField = value;
			}
		}
	}


	/// <summary>A <code>ProposalLineItem</code> is an instance of sales <a
	/// href='Product'>Product</a>. It belongs to a <a href='Proposal'>Proposal</a> and
	/// is created according to a <a href='Product'>Product</a> and <a
	/// href='RateCard'>RateCard</a>. When the proposal is turned into an <a
	/// href='Order'>Order</a>, this object is turned into a <a
	/// href='LineItem'>LineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProposalLineItem {
		private long idField;

		private bool idFieldSpecified;

		private long proposalIdField;

		private bool proposalIdFieldSpecified;

		private long packageIdField;

		private bool packageIdFieldSpecified;

		private long rateCardIdField;

		private bool rateCardIdFieldSpecified;

		private long productIdField;

		private bool productIdFieldSpecified;

		private string nameField;

		private DateTime startDateTimeField;

		private DateTime endDateTimeField;

		private string timeZoneIdField;

		private string internalNotesField;

		private CostAdjustment costAdjustmentField;

		private bool costAdjustmentFieldSpecified;

		private bool isArchivedField;

		private bool isArchivedFieldSpecified;

		private Goal goalField;

		private int contractedQuantityBufferField;

		private bool contractedQuantityBufferFieldSpecified;

		private long scheduledQuantityField;

		private bool scheduledQuantityFieldSpecified;

		private long contractedUnitsBoughtField;

		private bool contractedUnitsBoughtFieldSpecified;

		private DeliveryRateType deliveryRateTypeField;

		private bool deliveryRateTypeFieldSpecified;

		private RoadblockingType roadblockingTypeField;

		private bool roadblockingTypeFieldSpecified;

		private CompanionDeliveryOption companionDeliveryOptionField;

		private bool companionDeliveryOptionFieldSpecified;

		private CreativeRotationType creativeRotationTypeField;

		private bool creativeRotationTypeFieldSpecified;

		private long videoMaxDurationField;

		private bool videoMaxDurationFieldSpecified;

		private FrequencyCap[] frequencyCapsField;

		private long dfpLineItemIdField;

		private bool dfpLineItemIdFieldSpecified;

		private LineItemType lineItemTypeField;

		private bool lineItemTypeFieldSpecified;

		private int lineItemPriorityField;

		private bool lineItemPriorityFieldSpecified;

		private RateType rateTypeField;

		private bool rateTypeFieldSpecified;

		private CreativePlaceholder[] creativePlaceholdersField;

		private Targeting targetingField;

		private BaseCustomFieldValue[] customFieldValuesField;

		private AppliedLabel[] appliedLabelsField;

		private AppliedLabel[] effectiveAppliedLabelsField;

		private bool disableSameAdvertiserCompetitiveExclusionField;

		private bool disableSameAdvertiserCompetitiveExclusionFieldSpecified;

		private ProposalLineItemConstraints productConstraintsField;

		private ProposalLineItemPremium[] premiumsField;

		private bool isSoldField;

		private bool isSoldFieldSpecified;

		private Money baseRateField;

		private Money netRateField;

		private Money grossRateField;

		private Money netCostField;

		private Money grossCostField;

		private DeliveryIndicator deliveryIndicatorField;

		private long[] deliveryDataField;

		private ComputedStatus computedStatusField;

		private bool computedStatusFieldSpecified;

		private BillingCap billingCapField;

		private bool billingCapFieldSpecified;

		private BillingSchedule billingScheduleField;

		private bool billingScheduleFieldSpecified;

		private BillingSource billingSourceField;

		private bool billingSourceFieldSpecified;

		private BillingBase billingBaseField;

		private bool billingBaseFieldSpecified;

		private DateTime lastModifiedDateTimeField;

		private ReservationStatus reservationStatusField;

		private bool reservationStatusFieldSpecified;

		private DateTime lastReservationDateTimeField;

		private bool useThirdPartyAdServerFromProposalField;

		private bool useThirdPartyAdServerFromProposalFieldSpecified;

		private int thirdPartyAdServerIdField;

		private bool thirdPartyAdServerIdFieldSpecified;

		private string customThirdPartyAdServerNameField;

		private EnvironmentType environmentTypeField;

		private bool environmentTypeFieldSpecified;

		private bool isProgrammaticField;

		private bool isProgrammaticFieldSpecified;

		private LinkStatus linkStatusField;

		private bool linkStatusFieldSpecified;

		private ProposalLineItemMarketplaceInfo marketplaceInfoField;

		private PricingModel rateCardPricingModelField;

		private bool rateCardPricingModelFieldSpecified;

		private string additionalTermsField;

		private ProgrammaticCreativeSource programmaticCreativeSourceField;

		private bool programmaticCreativeSourceFieldSpecified;

		private long estimatedMinimumImpressionsField;

		private bool estimatedMinimumImpressionsFieldSpecified;

		/// <summary>The unique ID of the <code>ProposalLineItem</code>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The unique ID of the <a href='Proposal'>Proposal</a>, to which the
		/// <code>ProposalLineItem</code> belongs. This attribute is required for creation
		/// and then is readonly. <span class="constraint Required">This attribute is
		/// required.</span>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long proposalId {
			get {
				return this.proposalIdField;
			}
			set {
				this.proposalIdField = value;
				this.proposalIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="proposalId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool proposalIdSpecified {
			get {
				return this.proposalIdFieldSpecified;
			}
			set {
				this.proposalIdFieldSpecified = value;
			}
		}

		/// <summary>The unique ID of the <a href='Package'>Package</a>, to which the
		/// <code>ProposalLineItem</code> belongs. This attribute is assigned by Google when
		/// creating the <code>ProposalLineItem</code> by performing the package action <a
		/// href='CreateProposalLineItemsFromPackages'>CreateProposalLineItemsFromPackages</a>.
		/// <span class="constraint Applicable">This attribute is applicable when:</span>
		/// <ul> <li>not using programmatic, using sales management.</li> </ul> <span
		/// class="constraint ReadOnly">This attribute is read-only when:</span> <ul>
		/// <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public long packageId {
			get {
				return this.packageIdField;
			}
			set {
				this.packageIdField = value;
				this.packageIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="packageId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool packageIdSpecified {
			get {
				return this.packageIdFieldSpecified;
			}
			set {
				this.packageIdFieldSpecified = value;
			}
		}

		/// <summary>The unique ID of the <a href='RateCard'>RateCard</a>, based on which the
		/// <code>ProposalLineItem</code> is priced. The rate card must be associated with a
		/// rate belonging to the <a href='#productId'>product</a>. This attribute is
		/// required for creation and then is readonly. <span class="constraint
		/// Applicable">This attribute is applicable when:</span> <ul> <li>using
		/// programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul> <span class="constraint
		/// Required">This attribute is required when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public long rateCardId {
			get {
				return this.rateCardIdField;
			}
			set {
				this.rateCardIdField = value;
				this.rateCardIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="rateCardId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool rateCardIdSpecified {
			get {
				return this.rateCardIdFieldSpecified;
			}
			set {
				this.rateCardIdFieldSpecified = value;
			}
		}

		/// <summary>The unique ID of the <a href='Product'>Product</a>, which the
		/// <code>ProposalLineItem</code> is created from. This attribute is readonly after
		/// creation. <span class="constraint ReadOnly">This attribute is read-only
		/// when:</span> <ul> <li>using programmatic guaranteed, not using sales
		/// management.</li> </ul> <span class="constraint Required">This attribute is
		/// required when:</span> <ul> <li>using programmatic guaranteed, using sales
		/// management.</li> <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public long productId {
			get {
				return this.productIdField;
			}
			set {
				this.productIdField = value;
				this.productIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="productId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool productIdSpecified {
			get {
				return this.productIdFieldSpecified;
			}
			set {
				this.productIdFieldSpecified = value;
			}
		}

		/// <summary>The name of the <code>ProposalLineItem</code> which should be unique under the
		/// same <a href='Proposal'>Proposal</a>. This attribute has a maximum length of 255
		/// characters. This attribute can be configured as editable after the proposal has
		/// been submitted. Please check with your network administrator for editable fields
		/// configuration. <span class="constraint Required">This attribute is
		/// required.</span>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The date and time at which the line item associated with the <code></code> is
		/// enabled to begin serving. This attribute is optional during creation, but
		/// required and must be in the future when it turns into a line item. The <a
		/// href='DateTime#timeZoneID'>DateTime#timeZoneID</a> is required if start date
		/// time is not <code>null</code>. This attribute becomes readonly once the
		/// <code>ProposalLineItem</code> has started delivering.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public DateTime startDateTime {
			get {
				return this.startDateTimeField;
			}
			set {
				this.startDateTimeField = value;
			}
		}

		/// <summary>The date and time at which the line item associated with the <code></code> stops
		/// beening served. This attribute is optional during creation, but required and
		/// must be after the <a href='#startDateTime'>#startDateTime</a>. The <a
		/// href='DateTime#timeZoneID'>DateTime#timeZoneID</a> is required if end date time
		/// is not <code>null</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public DateTime endDateTime {
			get {
				return this.endDateTimeField;
			}
			set {
				this.endDateTimeField = value;
			}
		}

		/// <summary>The time zone ID in tz database format (e.g. "America/Los_Angeles") for this
		/// <code>ProposalLineItem</code>. The number of serving days is calculated in this
		/// time zone. So if <a href=''>#rateType</a> is <a
		/// href='RateType#CPD'>RateType#CPD</a>, it will affect the cost calculation. The
		/// <a href=''>#startDateTime</a> and <a href='#endDateTime'>#endDateTime</a> will
		/// be returned in this time zone. This attribute is optional and defaults to the
		/// network's time zone. <span class="constraint ReadOnly">This attribute is
		/// read-only when:</span> <ul> <li>using programmatic guaranteed, using sales
		/// management.</li> <li>using programmatic guaranteed, not using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public string timeZoneId {
			get {
				return this.timeZoneIdField;
			}
			set {
				this.timeZoneIdField = value;
			}
		}

		/// <summary>Provides any additional notes that may annotate the <code></code>. This
		/// attribute is optional and has a maximum length of 65,535 characters. This
		/// attribute can be configured as editable after the proposal has been submitted.
		/// Please check with your network administrator for editable fields configuration.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public string internalNotes {
			get {
				return this.internalNotesField;
			}
			set {
				this.internalNotesField = value;
			}
		}

		/// <summary>The cost adjustment applied to the <code>ProposalLineItem</code>. This attribute
		/// is optional and default value is <a
		/// href='CostAdjustment#NONE'>CostAdjustment#NONE</a>. <span class="constraint
		/// Applicable">This attribute is applicable when:</span> <ul> <li>using
		/// programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul> <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public CostAdjustment costAdjustment {
			get {
				return this.costAdjustmentField;
			}
			set {
				this.costAdjustmentField = value;
				this.costAdjustmentSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="costAdjustment" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool costAdjustmentSpecified {
			get {
				return this.costAdjustmentFieldSpecified;
			}
			set {
				this.costAdjustmentFieldSpecified = value;
			}
		}

		/// <summary>The archival status of the <code>ProposalLineItem</code>. This attribute is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 11)]
		public bool isArchived {
			get {
				return this.isArchivedField;
			}
			set {
				this.isArchivedField = value;
				this.isArchivedSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isArchived"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isArchivedSpecified {
			get {
				return this.isArchivedFieldSpecified;
			}
			set {
				this.isArchivedFieldSpecified = value;
			}
		}

		/// <summary>The goal(i.e. contracted quantity, quantity or limit) that this
		/// <code>ProposalLineItem</code> is associated with, which is used in its pacing
		/// and budgeting. <a href='Goal#units'>Goal#units</a> must be greater than 0 when
		/// the proposal line item turns into a line item, <a
		/// href='Goal#goalType'>Goal#goalType</a> and <a href=''>Goal#unitType</a> are
		/// readonly. For a Preferred deal <code></code>, the goal type can only be <a
		/// href='GoalType#NONE'>GoalType#NONE</a>. <span class="constraint Required">This
		/// attribute is required.</span>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 12)]
		public Goal goal {
			get {
				return this.goalField;
			}
			set {
				this.goalField = value;
			}
		}

		/// <summary>A percentage number to a STANDARD line item with CPM or CPC as the rate type, so
		/// that the scheduled delivery goal could be relaxed. This number is milli-percent
		/// based, i.e. 10% would be 10000. <span class="constraint Applicable">This
		/// attribute is applicable when:</span> <ul> <li>not using programmatic, using
		/// sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 13)]
		public int contractedQuantityBuffer {
			get {
				return this.contractedQuantityBufferField;
			}
			set {
				this.contractedQuantityBufferField = value;
				this.contractedQuantityBufferSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="contractedQuantityBuffer" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool contractedQuantityBufferSpecified {
			get {
				return this.contractedQuantityBufferFieldSpecified;
			}
			set {
				this.contractedQuantityBufferFieldSpecified = value;
			}
		}

		/// <summary>The scheduled number of impressions or clicks of a STANDARD line item with CPM
		/// or CPC as the rate type, so that the scheduled delivery goal could be relaxed.
		/// This attribute is calculated from <a href='Goal#units'>Goal#units</a> and <a
		/// href='#contractedQuantityBuffer'>#contractedQuantityBuffer</a>. <span
		/// class="constraint Applicable">This attribute is applicable when:</span> <ul>
		/// <li>not using programmatic, using sales management.</li> </ul> <span
		/// class="constraint ReadOnly">This attribute is read-only when:</span> <ul>
		/// <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 14)]
		public long scheduledQuantity {
			get {
				return this.scheduledQuantityField;
			}
			set {
				this.scheduledQuantityField = value;
				this.scheduledQuantitySpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="scheduledQuantity" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool scheduledQuantitySpecified {
			get {
				return this.scheduledQuantityFieldSpecified;
			}
			set {
				this.scheduledQuantityFieldSpecified = value;
			}
		}

		/// <summary>The contracted number of impressions or clicks. If this is a <a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a> <code></code>, has
		/// <a href='RateType#CPD'>RateType#CPD</a> as a rate type, and <a
		/// href='#isProgrammatic'>#isProgrammatic</a> is false, then this represents the
		/// lifetime minimum impression. If this is a <a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a> <code></code>, has
		/// <a href='RateType#CPD'>RateType#CPD</a> as a rate type, and <a
		/// href='#isProgrammatic'>#isProgrammatic</a> is true, then this represents the
		/// daily minimum impression. <p>This attribute is required for
		/// percentage-based-goal <a href='ProposalLineItem'>proposal line items</a>. It
		/// does not impact ad-serving and is for reporting purposes only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 15)]
		public long contractedUnitsBought {
			get {
				return this.contractedUnitsBoughtField;
			}
			set {
				this.contractedUnitsBoughtField = value;
				this.contractedUnitsBoughtSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="contractedUnitsBought" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool contractedUnitsBoughtSpecified {
			get {
				return this.contractedUnitsBoughtFieldSpecified;
			}
			set {
				this.contractedUnitsBoughtFieldSpecified = value;
			}
		}

		/// <summary>The strategy for delivering ads over the course of the <code></code>'s duration.
		/// This attribute is optional and default value is <a
		/// href='DeliveryRateType#EVENLY'>DeliveryRateType#EVENLY</a>. For a Preferred deal
		/// <code>ProposalLineItem</code>, the value can only be <a
		/// href='DeliveryRateType#FRONTLOADED'>DeliveryRateType#FRONTLOADED</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 16)]
		public DeliveryRateType deliveryRateType {
			get {
				return this.deliveryRateTypeField;
			}
			set {
				this.deliveryRateTypeField = value;
				this.deliveryRateTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="deliveryRateType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool deliveryRateTypeSpecified {
			get {
				return this.deliveryRateTypeFieldSpecified;
			}
			set {
				this.deliveryRateTypeFieldSpecified = value;
			}
		}

		/// <summary>The strategy for serving roadblocked creatives, i.e. instances where multiple
		/// creatives must be served together on a single web page. This attribute is
		/// optional during creation and defaults to the <a
		/// href='Product#roadblockingType'>product's roadblocking type</a>, or <a
		/// href='RoadblockingType#ONE_OR_MORE'>RoadblockingType#ONE_OR_MORE</a> if not
		/// specified by the product.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 17)]
		public RoadblockingType roadblockingType {
			get {
				return this.roadblockingTypeField;
			}
			set {
				this.roadblockingTypeField = value;
				this.roadblockingTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="roadblockingType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool roadblockingTypeSpecified {
			get {
				return this.roadblockingTypeFieldSpecified;
			}
			set {
				this.roadblockingTypeFieldSpecified = value;
			}
		}

		/// <summary>The delivery option for companions. This is only valid if the roadblocking type
		/// is <a href='RoadblockingType#CREATIVE_SET'>RoadblockingType#CREATIVE_SET</a>.
		/// The default value for roadblocking creatives is <a
		/// href='CompanionDeliveryOption#OPTIONAL'>CompanionDeliveryOption#OPTIONAL</a>.
		/// The default value in other cases is <a
		/// href='CompanionDeliveryOption#UNKNOWN'>CompanionDeliveryOption#UNKNOWN</a>.
		/// Providing something other than <a
		/// href='CompanionDeliveryOption#UNKNOWN'>CompanionDeliveryOption#UNKNOWN</a> will
		/// cause an error.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 18)]
		public CompanionDeliveryOption companionDeliveryOption {
			get {
				return this.companionDeliveryOptionField;
			}
			set {
				this.companionDeliveryOptionField = value;
				this.companionDeliveryOptionSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="companionDeliveryOption" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool companionDeliveryOptionSpecified {
			get {
				return this.companionDeliveryOptionFieldSpecified;
			}
			set {
				this.companionDeliveryOptionFieldSpecified = value;
			}
		}

		/// <summary>The strategy used for displaying multiple <a href='Creative'>Creative</a>
		/// objects that are associated with the <code></code>. This attribute is optional
		/// and default value is <a
		/// href='CreativeRotationType#OPTIMIZED'>CreativeRotationType#OPTIMIZED</a>. <span
		/// class="constraint Applicable">This attribute is applicable when:</span> <ul>
		/// <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 19)]
		public CreativeRotationType creativeRotationType {
			get {
				return this.creativeRotationTypeField;
			}
			set {
				this.creativeRotationTypeField = value;
				this.creativeRotationTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="creativeRotationType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool creativeRotationTypeSpecified {
			get {
				return this.creativeRotationTypeFieldSpecified;
			}
			set {
				this.creativeRotationTypeFieldSpecified = value;
			}
		}

		/// <summary>The max duration of a video creative associated with this <code></code> in
		/// milliseconds. This attribute is optional, defaults to the <a
		/// href='Product#videoMaxDuration'>Product#videoMaxDuration</a> on the <a
		/// href='Product'>Product</a> it was created with, and only meaningful if this is a
		/// video proposal line item.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 20)]
		public long videoMaxDuration {
			get {
				return this.videoMaxDurationField;
			}
			set {
				this.videoMaxDurationField = value;
				this.videoMaxDurationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="videoMaxDuration" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool videoMaxDurationSpecified {
			get {
				return this.videoMaxDurationFieldSpecified;
			}
			set {
				this.videoMaxDurationFieldSpecified = value;
			}
		}

		/// <summary>The set of frequency capping units for this <code></code>. This attribute is
		/// optional during creation and defaults to the <a
		/// href='Product#frequencyCaps'>product's frequency caps</a> if <a
		/// href='Product#allowFrequencyCapsCustomization'>Product#allowFrequencyCapsCustomization</a>
		/// is <code>false</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("frequencyCaps", Order = 21)]
		public FrequencyCap[] frequencyCaps {
			get {
				return this.frequencyCapsField;
			}
			set {
				this.frequencyCapsField = value;
			}
		}

		/// <summary>The unique ID of corresponding <a href='LineItem'>LineItem</a>. This will be
		/// <code>null</code> if the <a href=''>Proposal</a> has not been pushed to Ad
		/// Manager. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 22)]
		public long dfpLineItemId {
			get {
				return this.dfpLineItemIdField;
			}
			set {
				this.dfpLineItemIdField = value;
				this.dfpLineItemIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="dfpLineItemId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool dfpLineItemIdSpecified {
			get {
				return this.dfpLineItemIdFieldSpecified;
			}
			set {
				this.dfpLineItemIdFieldSpecified = value;
			}
		}

		/// <summary>The corresponding <a href='LineItemType'>LineItemType</a> of the
		/// <code>ProposalLineItem</code>. For a programmatic <code></code>, the value can
		/// only be one of: <ul> <li><a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a></li> <li><a
		/// href='LineItemType#STANDARD'>LineItemType#STANDARD</a></li> <li><a
		/// href='LineItemType#PREFERRED_DEAL'>LineItemType#PREFERRED_DEAL</a></li> </ul>
		/// <span class="constraint Required">This attribute is required.</span>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 23)]
		public LineItemType lineItemType {
			get {
				return this.lineItemTypeField;
			}
			set {
				this.lineItemTypeField = value;
				this.lineItemTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lineItemType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lineItemTypeSpecified {
			get {
				return this.lineItemTypeFieldSpecified;
			}
			set {
				this.lineItemTypeFieldSpecified = value;
			}
		}

		/// <summary>The priority for the corresponding <a href='LineItem'>LineItem</a> of the
		/// <code>ProposalLineItem</code>. This attribute is optional during creation and
		/// defaults to the <a href='Product#priority'>product's priority</a>, or a default
		/// value assigned by Google. See <a href='LineItem#priority'>LineItem#priority</a>
		/// for more information.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 24)]
		public int lineItemPriority {
			get {
				return this.lineItemPriorityField;
			}
			set {
				this.lineItemPriorityField = value;
				this.lineItemPrioritySpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lineItemPriority" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lineItemPrioritySpecified {
			get {
				return this.lineItemPriorityFieldSpecified;
			}
			set {
				this.lineItemPriorityFieldSpecified = value;
			}
		}

		/// <summary>The method used for billing the <code>ProposalLineItem</code>. <span
		/// class="constraint ReadOnly">This attribute is read-only when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul> <span class="constraint
		/// Required">This attribute is required when:</span> <ul> <li>using programmatic
		/// guaranteed, not using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 25)]
		public RateType rateType {
			get {
				return this.rateTypeField;
			}
			set {
				this.rateTypeField = value;
				this.rateTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="rateType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool rateTypeSpecified {
			get {
				return this.rateTypeFieldSpecified;
			}
			set {
				this.rateTypeFieldSpecified = value;
			}
		}

		/// <summary>Details about the creatives that are expected to serve through the
		/// <code>ProposalLineItem</code>. This attribute is optional during creation and
		/// defaults to the <a href='Product#creativePlaceholders'>product's creative
		/// placeholders</a>. <span class="constraint Required">This attribute is required
		/// when:</span> <ul> <li>using programmatic guaranteed, not using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("creativePlaceholders", Order = 26)]
		public CreativePlaceholder[] creativePlaceholders {
			get {
				return this.creativePlaceholdersField;
			}
			set {
				this.creativePlaceholdersField = value;
			}
		}

		/// <summary>Contains the targeting criteria for the <code>ProposalLineItem</code>. This
		/// attribute is optional during creation and defaults to the <a
		/// href='Product#targeting'>product's targeting</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 27)]
		public Targeting targeting {
			get {
				return this.targetingField;
			}
			set {
				this.targetingField = value;
			}
		}

		/// <summary>The values of the custom fields associated with the <code></code>. This
		/// attribute is optional. This attribute can be configured as editable after the
		/// proposal has been submitted. Please check with your network administrator for
		/// editable fields configuration.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("customFieldValues", Order = 28)]
		public BaseCustomFieldValue[] customFieldValues {
			get {
				return this.customFieldValuesField;
			}
			set {
				this.customFieldValuesField = value;
			}
		}

		/// <summary>The set of labels applied directly to the <code>ProposalLineItem</code>. This
		/// attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("appliedLabels", Order = 29)]
		public AppliedLabel[] appliedLabels {
			get {
				return this.appliedLabelsField;
			}
			set {
				this.appliedLabelsField = value;
			}
		}

		/// <summary>Contains the set of labels applied directly to the proposal as well as those
		/// inherited ones. If a label has been negated, only the negated label is returned.
		/// This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("effectiveAppliedLabels", Order = 30)]
		public AppliedLabel[] effectiveAppliedLabels {
			get {
				return this.effectiveAppliedLabelsField;
			}
			set {
				this.effectiveAppliedLabelsField = value;
			}
		}

		/// <summary>If a line item has a series of competitive exclusions on it, it could be blocked
		/// from serving with line items from the same advertiser. Setting this to
		/// <code>true</code> will allow line items from the same advertiser to serve
		/// regardless of the other competitive exclusion labels being applied. <p>This
		/// attribute is optional and defaults to false.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 31)]
		public bool disableSameAdvertiserCompetitiveExclusion {
			get {
				return this.disableSameAdvertiserCompetitiveExclusionField;
			}
			set {
				this.disableSameAdvertiserCompetitiveExclusionField = value;
				this.disableSameAdvertiserCompetitiveExclusionSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="disableSameAdvertiserCompetitiveExclusion" />, <code>false</code>
		/// otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool disableSameAdvertiserCompetitiveExclusionSpecified {
			get {
				return this.disableSameAdvertiserCompetitiveExclusionFieldSpecified;
			}
			set {
				this.disableSameAdvertiserCompetitiveExclusionFieldSpecified = value;
			}
		}

		/// <summary>All the product constraints set for this <code>ProposalLineItem</code>. <span
		/// class="constraint Applicable">This attribute is applicable when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul> <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 32)]
		public ProposalLineItemConstraints productConstraints {
			get {
				return this.productConstraintsField;
			}
			set {
				this.productConstraintsField = value;
			}
		}

		/// <summary>The premiums triggered by this <code>ProposalLineItem</code> and their statuses.
		/// For those triggered premiums whose statues are not specified, the default status
		/// is <a
		/// href='ProposalLineItemPremiumStatus#INCLUDED'>ProposalLineItemPremiumStatus#INCLUDED</a>.
		/// <span class="constraint Applicable">This attribute is applicable when:</span>
		/// <ul> <li>using programmatic guaranteed, using sales management.</li> <li>not
		/// using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("premiums", Order = 33)]
		public ProposalLineItemPremium[] premiums {
			get {
				return this.premiumsField;
			}
			set {
				this.premiumsField = value;
			}
		}

		/// <summary>Indicates whether this <code>ProposalLineItem</code> has been sold. This
		/// attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 34)]
		public bool isSold {
			get {
				return this.isSoldField;
			}
			set {
				this.isSoldField = value;
				this.isSoldSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isSold" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isSoldSpecified {
			get {
				return this.isSoldFieldSpecified;
			}
			set {
				this.isSoldFieldSpecified = value;
			}
		}

		/// <summary>The base rate of the <code>ProposalLineItem</code> in proposal currency. <span
		/// class="constraint Applicable">This attribute is applicable when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul> <span class="constraint
		/// ReadOnly">This attribute is read-only when:</span> <ul> <li>using programmatic
		/// guaranteed, using sales management.</li> <li>not using programmatic, using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 35)]
		public Money baseRate {
			get {
				return this.baseRateField;
			}
			set {
				this.baseRateField = value;
			}
		}

		/// <summary>The amount of money to spend per impression or click in proposal currency. It
		/// supports precision of 4 decimal places in terms of the fundamental currency
		/// unit, so the <a href='Money#getAmountInMicros'>Money#getAmountInMicros</a> must
		/// be multiples of 100. It doesn't include agency commission. <p>For example, if <a
		/// href='Proposal#currencyCode'>Proposal#currencyCode</a> is 'USD', then $123.4567
		/// could be represented as 123456700, but further precision is not supported.</p>
		/// <p>When using sales management, at least one of the four fields <a
		/// href='ProposalLineItem#netRate'>ProposalLineItem#netRate</a>, <a
		/// href='ProposalLineItem#grossRate'>ProposalLineItem#grossRate</a>, <a
		/// href='ProposalLineItem#netCost'>ProposalLineItem#netCost</a> and <a
		/// href='ProposalLineItem#grossCost'>ProposalLineItem#grossCost</a> is
		/// required.</p> <p>When not using sales management, at least one of the two fields
		/// <a href='ProposalLineItem#netRate'>ProposalLineItem#netRate</a> and <a
		/// href='ProposalLineItem#netCost'>ProposalLineItem#netCost</a> is required.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 36)]
		public Money netRate {
			get {
				return this.netRateField;
			}
			set {
				this.netRateField = value;
			}
		}

		/// <summary>The amount of money to spend per impression or click in proposal currency. It
		/// supports precision of 4 decimal places in terms of the fundamental currency
		/// unit, so the <a href='Money#getAmountInMicros'>Money#getAmountInMicros</a> must
		/// be multiples of 100. It includes agency commission. <p>For example, if <a
		/// href='Proposal#currencyCode'>Proposal#currencyCode</a> is 'USD', then $123.4567
		/// could be represented as 123456700, but further precision is not supported.</p>
		/// <p>At least one of the four fields <a
		/// href='ProposalLineItem#netRate'>ProposalLineItem#netRate</a>, <a
		/// href='ProposalLineItem#grossRate'>ProposalLineItem#grossRate</a>, <a
		/// href='ProposalLineItem#netCost'>ProposalLineItem#netCost</a> and <a
		/// href='ProposalLineItem#grossCost'>ProposalLineItem#grossCost</a> is required.
		/// <span class="constraint Applicable">This attribute is applicable
		/// when:</span></p> <ul> <li>using programmatic guaranteed, using sales
		/// management.</li> <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 37)]
		public Money grossRate {
			get {
				return this.grossRateField;
			}
			set {
				this.grossRateField = value;
			}
		}

		/// <summary>The cost of the <code>ProposalLineItem</code> in proposal currency. It supports
		/// precision of 2 decimal places in terms of the fundamental currency unit, so the
		/// <a href='Money#getAmountInMicros'>Money#getAmountInMicros</a> must be multiples
		/// of 10000. It doesn't include agency commission. <p>For example, if <a
		/// href='Proposal#currencyCode'>Proposal#currencyCode</a> is 'USD', then $123.45
		/// could be represented as 123450000, but further precision is not supported.</p>
		/// <p>When using sales management, at least one of the four fields <a
		/// href='ProposalLineItem#netRate'>ProposalLineItem#netRate</a>, <a
		/// href='ProposalLineItem#grossRate'>ProposalLineItem#grossRate</a>, <a
		/// href='ProposalLineItem#netCost'>ProposalLineItem#netCost</a> and <a
		/// href='ProposalLineItem#grossCost'>ProposalLineItem#grossCost</a> is
		/// required.</p> <p>When not using sales management, at least one of the two fields
		/// <a href='ProposalLineItem#netRate'>ProposalLineItem#netRate</a> and <a
		/// href='ProposalLineItem#netCost'>ProposalLineItem#netCost</a> is required.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 38)]
		public Money netCost {
			get {
				return this.netCostField;
			}
			set {
				this.netCostField = value;
			}
		}

		/// <summary>The cost of the <code>ProposalLineItem</code> in proposal currency. It supports
		/// precision of 2 decimal places in terms of the fundamental currency unit, so the
		/// <a href='Money#getAmountInMicros'>Money#getAmountInMicros</a> must be multiples
		/// of 10000. It includes agency commission. <p>At least one of the four fields <a
		/// href='ProposalLineItem#netRate'>ProposalLineItem#netRate</a>, <a
		/// href='ProposalLineItem#grossRate'>ProposalLineItem#grossRate</a>, <a
		/// href='ProposalLineItem#netCost'>ProposalLineItem#netCost</a> and <a
		/// href='ProposalLineItem#grossCost'>ProposalLineItem#grossCost</a> is required.
		/// <span class="constraint Applicable">This attribute is applicable
		/// when:</span></p> <ul> <li>using programmatic guaranteed, using sales
		/// management.</li> <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 39)]
		public Money grossCost {
			get {
				return this.grossCostField;
			}
			set {
				this.grossCostField = value;
			}
		}

		/// <summary>Indicates how well the line item generated from this proposal line item has been
		/// performing. This will be <code>null</code> if the delivery indicator information
		/// is not available due to one of the following reasons: <ol> <li>The proposal line
		/// item has not pushed to Ad Manager.</li> <li>The line item is not
		/// delivering.</li> <li>The line item has an unlimited goal or cap.</li> <li>The
		/// line item has a percentage based goal or cap.</li> </ol> This attribute is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 40)]
		public DeliveryIndicator deliveryIndicator {
			get {
				return this.deliveryIndicatorField;
			}
			set {
				this.deliveryIndicatorField = value;
			}
		}

		/// <summary>Delivery data provides the number of clicks or impressions delivered for the <a
		/// href='LineItem'>LineItem</a> generated from this proposal line item in the last
		/// 7 days. This will be <code></code> if the delivery data cannot be computed due
		/// to one of the following reasons: <ol> <li>The proposal line item has not pushed
		/// to Ad Manager.</li> <li>The line item is not deliverable.</li> <li>The line item
		/// has completed delivering more than 7 days ago.</li> <li>The line item has an
		/// absolute-based goal. <a
		/// href='ProposalLineItem#deliveryIndicator'>ProposalLineItem#deliveryIndicator</a>
		/// should be used to track its progress in this case.</li> <li style="list-style:
		/// none">This attribute is read-only.</li> </ol>
		/// </summary>
		[System.Xml.Serialization.XmlArrayAttribute(Order = 41)]
		[System.Xml.Serialization.XmlArrayItemAttribute("units", IsNullable = false)]
		public long[] deliveryData {
			get {
				return this.deliveryDataField;
			}
			set {
				this.deliveryDataField = value;
			}
		}

		/// <summary>The status of the <a href='LineItem'>LineItem</a> generated from this proposal
		/// line item. This will be <code>null</code> if the proposal line item has not
		/// pushed to Ad Manager. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 42)]
		public ComputedStatus computedStatus {
			get {
				return this.computedStatusField;
			}
			set {
				this.computedStatusField = value;
				this.computedStatusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="computedStatus" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool computedStatusSpecified {
			get {
				return this.computedStatusFieldSpecified;
			}
			set {
				this.computedStatusFieldSpecified = value;
			}
		}

		/// <summary>Overrides the billing cap of this <code>ProposalLineItem</code>. This attribute
		/// is optional. If this field is overridden, then other required billing fields (<a
		/// href='#billingSource'>#billingSource</a>, or <a
		/// href='#billingBase'>#billingBase</a>) also need to be overridden depending on
		/// the <a href='#billingSource'>#billingSource</a>. That is, none of the billing
		/// fields will inherit from their <a href='Proposal'>Proposal</a> object anymore.
		/// This attribute can be configured as editable after the proposal has been
		/// submitted. Please check with your network administrator for editable fields
		/// configuration. <span class="constraint Applicable">This attribute is applicable
		/// when:</span> <ul> <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 43)]
		public BillingCap billingCap {
			get {
				return this.billingCapField;
			}
			set {
				this.billingCapField = value;
				this.billingCapSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="billingCap"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool billingCapSpecified {
			get {
				return this.billingCapFieldSpecified;
			}
			set {
				this.billingCapFieldSpecified = value;
			}
		}

		/// <summary>Overrides the billing schedule of this <code>ProposalLineItem</code>. This
		/// attribute is optional. If this field is overridden, then other required billing
		/// fields (<a href='#billingSource'>#billingSource</a>, or <a
		/// href='#billingBase'>#billingBase</a>) also need to be overridden depending on
		/// the <a href='#billingSource'>#billingSource</a>. That is, none of the billing
		/// fields will inherit from their <a href='Proposal'>Proposal</a> object anymore.
		/// This attribute can be configured as editable after the proposal has been
		/// submitted. Please check with your network administrator for editable fields
		/// configuration. <span class="constraint Applicable">This attribute is applicable
		/// when:</span> <ul> <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 44)]
		public BillingSchedule billingSchedule {
			get {
				return this.billingScheduleField;
			}
			set {
				this.billingScheduleField = value;
				this.billingScheduleSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="billingSchedule" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool billingScheduleSpecified {
			get {
				return this.billingScheduleFieldSpecified;
			}
			set {
				this.billingScheduleFieldSpecified = value;
			}
		}

		/// <summary>Overrides the billing source of this <code>ProposalLineItem</code>. This
		/// attribute is optional. If this field is overridden, then other required billing
		/// fields (<a href='#billingCap'>#billingCap</a>, <a
		/// href='#billingSchedule'>#billingSchedule</a>, or <a
		/// href='#billingBase'>#billingBase</a>) also need to be overridden depending on
		/// this field. That is, none of the billing fields will inherit from their <a
		/// href='Proposal'>Proposal</a> object anymore. This attribute can be configured as
		/// editable after the proposal has been submitted. Please check with your network
		/// administrator for editable fields configuration. <span class="constraint
		/// Applicable">This attribute is applicable when:</span> <ul> <li>not using
		/// programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 45)]
		public BillingSource billingSource {
			get {
				return this.billingSourceField;
			}
			set {
				this.billingSourceField = value;
				this.billingSourceSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="billingSource" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool billingSourceSpecified {
			get {
				return this.billingSourceFieldSpecified;
			}
			set {
				this.billingSourceFieldSpecified = value;
			}
		}

		/// <summary>Overrides the billing base of this <code>ProposalLineItem</code>. This attribute
		/// is optional. <p>If this field is overridden, then other required billing fields
		/// (<a href='#billingCap'>#billingCap</a>, <a href=''>#billingSchedule</a>, or <a
		/// href='#billingSource'>#billingSource</a>) also need to be overridden depending
		/// on the <a href='#billingSource'>#billingSource</a>. That is, none of the billing
		/// fields will inherit from their <a href=''>Proposal</a> object anymore. This
		/// attribute can be configured as editable after the proposal has been submitted.
		/// Please check with your network administrator for editable fields configuration.
		/// <span class="constraint Applicable">This attribute is applicable
		/// when:</span></p> <ul> <li>not using programmatic, using sales management.</li>
		/// </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 46)]
		public BillingBase billingBase {
			get {
				return this.billingBaseField;
			}
			set {
				this.billingBaseField = value;
				this.billingBaseSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="billingBase"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool billingBaseSpecified {
			get {
				return this.billingBaseFieldSpecified;
			}
			set {
				this.billingBaseFieldSpecified = value;
			}
		}

		/// <summary>The date and time this <code>ProposalLineItem</code> was last modified. <p>This
		/// attribute is assigned by Google when a <code></code> is updated. This attribute
		/// is read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 47)]
		public DateTime lastModifiedDateTime {
			get {
				return this.lastModifiedDateTimeField;
			}
			set {
				this.lastModifiedDateTimeField = value;
			}
		}

		/// <summary>The reservation status of the <a href='ProposalLineItem'>ProposalLineItem</a>.
		/// This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 48)]
		public ReservationStatus reservationStatus {
			get {
				return this.reservationStatusField;
			}
			set {
				this.reservationStatusField = value;
				this.reservationStatusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="reservationStatus" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reservationStatusSpecified {
			get {
				return this.reservationStatusFieldSpecified;
			}
			set {
				this.reservationStatusFieldSpecified = value;
			}
		}

		/// <summary>The last <a href='DateTime'>DateTime</a> when the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> reserved inventory. This attribute
		/// is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 49)]
		public DateTime lastReservationDateTime {
			get {
				return this.lastReservationDateTimeField;
			}
			set {
				this.lastReservationDateTimeField = value;
			}
		}

		/// <summary>Whether to use the corresponding proposal's third party ad server. If this field
		/// is true, <code>thirdPartyAdServerId</code> and <code></code> will be ignored.
		/// <span class="constraint Applicable">This attribute is applicable when:</span>
		/// <ul> <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 50)]
		public bool useThirdPartyAdServerFromProposal {
			get {
				return this.useThirdPartyAdServerFromProposalField;
			}
			set {
				this.useThirdPartyAdServerFromProposalField = value;
				this.useThirdPartyAdServerFromProposalSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="useThirdPartyAdServerFromProposal" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool useThirdPartyAdServerFromProposalSpecified {
			get {
				return this.useThirdPartyAdServerFromProposalFieldSpecified;
			}
			set {
				this.useThirdPartyAdServerFromProposalFieldSpecified = value;
			}
		}

		/// <summary>A predefined third party ad server, which will be used to fill in
		/// reconciliation. All predefined third party ad servers can be found in the
		/// <code>Third_Party_Company</code> PQL table. If actual third party ad server is
		/// not in the predefined list, this field is set to 0, and actual third party ad
		/// server name is set in <code></code>. <span class="constraint Applicable">This
		/// attribute is applicable when:</span> <ul> <li>not using programmatic, using
		/// sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 51)]
		public int thirdPartyAdServerId {
			get {
				return this.thirdPartyAdServerIdField;
			}
			set {
				this.thirdPartyAdServerIdField = value;
				this.thirdPartyAdServerIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="thirdPartyAdServerId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool thirdPartyAdServerIdSpecified {
			get {
				return this.thirdPartyAdServerIdFieldSpecified;
			}
			set {
				this.thirdPartyAdServerIdFieldSpecified = value;
			}
		}

		/// <summary>When actual third party ad server is not in the predefined list,
		/// <code>thirdPartyAdServerId</code> is set to 0, and actual third party ad server
		/// name is set here. When <code>thirdPartyAdServerId</code> is not 0, this field is
		/// ignored. <span class="constraint Applicable">This attribute is applicable
		/// when:</span> <ul> <li>not using programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 52)]
		public string customThirdPartyAdServerName {
			get {
				return this.customThirdPartyAdServerNameField;
			}
			set {
				this.customThirdPartyAdServerNameField = value;
			}
		}

		/// <summary>The environment that the <code>ProposalLineItem</code> is targeting. The default
		/// value is <a href='EnvironmentType#BROWSER'>EnvironmentType#BROWSER</a>. If this
		/// value is <a
		/// href='EnvironmentType#VIDEO_PLAYER'>EnvironmentType#VIDEO_PLAYER</a>, then this
		/// <code>ProposalLineItem</code> can only target <a href='AdUnit'>ad units</a> that
		/// have <a href='AdUnitSize'>sizes</a> whose <a
		/// href='AdUnitSize#environmentType'>AdUnitSize#environmentType</a> is also <a
		/// href='EnvironmentType#VIDEO_PLAYER'>EnvironmentType#VIDEO_PLAYER</a>. <p>This
		/// field can only be changed if the <a href='#linkStatus'>#linkStatus</a> is <a
		/// href='LinkStatus#UNLINKED'>LinkStatus#UNLINKED</a>. Otherwise its value is
		/// read-only and set to <a
		/// href='Product#environmentType'>Product#environmentType</a> of the product this
		/// proposal line item was created from.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 53)]
		public EnvironmentType environmentType {
			get {
				return this.environmentTypeField;
			}
			set {
				this.environmentTypeField = value;
				this.environmentTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="environmentType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool environmentTypeSpecified {
			get {
				return this.environmentTypeFieldSpecified;
			}
			set {
				this.environmentTypeFieldSpecified = value;
			}
		}

		/// <summary>Whether or not the <a href='Proposal'>Proposal</a> for this <code></code> is a
		/// programmatic deal. This attribute is populated from <a
		/// href='Proposal#isProgrammatic'>Proposal#isProgrammatic</a>. This attribute is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 54)]
		public bool isProgrammatic {
			get {
				return this.isProgrammaticField;
			}
			set {
				this.isProgrammaticField = value;
				this.isProgrammaticSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isProgrammatic" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isProgrammaticSpecified {
			get {
				return this.isProgrammaticFieldSpecified;
			}
			set {
				this.isProgrammaticFieldSpecified = value;
			}
		}

		/// <summary>The status of the link between this <code>ProposalLineItem</code> and its {link
		/// Product}. <span class="constraint Applicable">This attribute is applicable
		/// when:</span> <ul> <li>using programmatic guaranteed, using sales
		/// management.</li> <li>not using programmatic, using sales management.</li> </ul>
		/// <span class="constraint ReadOnly">This attribute is read-only when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 55)]
		public LinkStatus linkStatus {
			get {
				return this.linkStatusField;
			}
			set {
				this.linkStatusField = value;
				this.linkStatusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="linkStatus"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool linkStatusSpecified {
			get {
				return this.linkStatusFieldSpecified;
			}
			set {
				this.linkStatusFieldSpecified = value;
			}
		}

		/// <summary>The marketplace info if this proposal line item is programmatic, null otherwise.
		/// <span class="constraint Applicable">This attribute is applicable when:</span>
		/// <ul> <li>using programmatic guaranteed, using sales management.</li> <li>using
		/// programmatic guaranteed, not using sales management.</li> </ul> <span
		/// class="constraint Required">This attribute is required when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> <li>using
		/// programmatic guaranteed, not using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 56)]
		public ProposalLineItemMarketplaceInfo marketplaceInfo {
			get {
				return this.marketplaceInfoField;
			}
			set {
				this.marketplaceInfoField = value;
			}
		}

		/// <summary><a href='RateCard'>RateCard</a> pricing model for the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. When the pricing model is <a
		/// href='PricingModel#NET'>PricingModel#NET</a> refer to the <a
		/// href='netCost'>netCost</a> and <a href='netRate'>netRate</a> fields. When the
		/// pricing model is <a href='PricingModel#GROSS'>PricingModel#GROSS</a> refer to
		/// the <a href='grossCost'>grossCost</a> and <a href='grossRate'>grossRate</a>
		/// fields. <span class="constraint Applicable">This attribute is applicable
		/// when:</span> <ul> <li>using programmatic guaranteed, using sales
		/// management.</li> <li>not using programmatic, using sales management.</li> </ul>
		/// <span class="constraint ReadOnly">This attribute is read-only when:</span> <ul>
		/// <li>using programmatic guaranteed, using sales management.</li> <li>not using
		/// programmatic, using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 57)]
		public PricingModel rateCardPricingModel {
			get {
				return this.rateCardPricingModelField;
			}
			set {
				this.rateCardPricingModelField = value;
				this.rateCardPricingModelSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="rateCardPricingModel" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool rateCardPricingModelSpecified {
			get {
				return this.rateCardPricingModelFieldSpecified;
			}
			set {
				this.rateCardPricingModelFieldSpecified = value;
			}
		}

		/// <summary>Additional terms shown to the buyer in Marketplace. <span class="constraint
		/// Applicable">This attribute is applicable when:</span> <ul> <li>using
		/// programmatic guaranteed, using sales management.</li> <li>using programmatic
		/// guaranteed, not using sales management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 58)]
		public string additionalTerms {
			get {
				return this.additionalTermsField;
			}
			set {
				this.additionalTermsField = value;
			}
		}

		/// <summary>Indicates the <a
		/// href='ProgrammaticCreativeSource'>ProgrammaticCreativeSource</a> of the
		/// programmatic line item. <span class="constraint Applicable">This attribute is
		/// applicable when:</span> <ul> <li>using programmatic guaranteed, using sales
		/// management.</li> <li>using programmatic guaranteed, not using sales
		/// management.</li> </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 59)]
		public ProgrammaticCreativeSource programmaticCreativeSource {
			get {
				return this.programmaticCreativeSourceField;
			}
			set {
				this.programmaticCreativeSourceField = value;
				this.programmaticCreativeSourceSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="programmaticCreativeSource" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool programmaticCreativeSourceSpecified {
			get {
				return this.programmaticCreativeSourceFieldSpecified;
			}
			set {
				this.programmaticCreativeSourceFieldSpecified = value;
			}
		}

		/// <summary>The estimated minimum impressions that should be delivered for a proposal line
		/// item. <span class="constraint Applicable">This attribute is applicable
		/// when:</span> <ul> <li>using preferred deals, not using sales management.</li>
		/// </ul>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 60)]
		public long estimatedMinimumImpressions {
			get {
				return this.estimatedMinimumImpressionsField;
			}
			set {
				this.estimatedMinimumImpressionsField = value;
				this.estimatedMinimumImpressionsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="estimatedMinimumImpressions" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool estimatedMinimumImpressionsSpecified {
			get {
				return this.estimatedMinimumImpressionsFieldSpecified;
			}
			set {
				this.estimatedMinimumImpressionsFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes the cost adjustment of <a
	/// href='ProposalLineItem'>ProposalLineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CostAdjustment {
		/// <summary>Indicates that the <a href='ProposalLineItem'>ProposalLineItem</a> has no cost
		/// adjustment.
		/// </summary>
		NONE = 0,
		/// <summary>Indicates that the cost adjustment of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> is make good.
		/// </summary>
		MAKE_GOOD = 1,
		/// <summary>Indicates that the cost adjustment of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> is barter.
		/// </summary>
		BARTER = 2,
		/// <summary>Indicates that the cost adjustment of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> is added value.
		/// </summary>
		ADDED_VALUE = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>Represents the inventory reservation status for <a
	/// href='ProposalLineItem'>ProposalLineItem</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ReservationStatus {
		/// <summary>The inventory is reserved.
		/// </summary>
		RESERVED = 0,
		/// <summary>The proposal line item's inventory is never reserved.
		/// </summary>
		NOT_RESERVED = 1,
		/// <summary>The inventory is once reserved and now released.
		/// </summary>
		RELEASED = 2,
		/// <summary>The reservation status of the corresponding <a href='LineItem'>LineItem</a>
		/// should be used for this <a href='ProposalLineItem'>ProposalLineItem</a>.
		/// </summary>
		CHECK_LINE_ITEM_RESERVATION_STATUS = 5,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>Status of the link between <a href='ProposalLineItem'>ProposalLineItem</a> and
	/// its <a href='Product'>Product</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum LinkStatus {
		LINKED = 0,
		UNLINKED = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Lists all errors for executing operations on proposal line items.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProposalLineItemActionError : ApiError {
		private ProposalLineItemActionErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ProposalLineItemActionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ProposalLineItemActionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProposalLineItemActionErrorReason {
		/// <summary>The operation is not applicable to the current state.
		/// </summary>
		NOT_APPLICABLE = 0,
		/// <summary>The operation is not applicable because the containing proposal is not editable.
		/// </summary>
		PROPOSAL_NOT_EDITABLE = 1,
		/// <summary>The archive operation is not applicable because it would cause some mandatory
		/// products to have no unarchived proposal line items in the package.
		/// </summary>
		CANNOT_SELECTIVELY_ARCHIVE_PROPOSAL_LINE_ITEMS_FROM_MANDATORY_PRODUCTS = 3,
		/// <summary>The unarchive operation is not applicable because it would cause some mandatory
		/// products to have no unarchived proposal line items in the package.
		/// </summary>
		CANNOT_SELECTIVELY_UNARCHIVE_PROPOSAL_LINE_ITEMS_FROM_MANDATORY_PRODUCTS = 4,
		/// <summary>Sold programmatic <a href='ProposalLineItem'>ProposalLineItem</a> cannot be
		/// unarchived.
		/// </summary>
		CANNOT_UNARCHIVE_SOLD_PROGRAMMATIC_PROPOSAL_LINE_ITEM = 5,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ProposalLineItemServiceInterface")]
	public interface ProposalLineItemServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ProposalLineItemService.createProposalLineItemsResponse createProposalLineItems(Wrappers.ProposalLineItemService.createProposalLineItemsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ProposalLineItemService.createProposalLineItemsResponse> createProposalLineItemsAsync(Wrappers.ProposalLineItemService.createProposalLineItemsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ProposalLineItemPage getProposalLineItemsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProposalLineItemPage> getProposalLineItemsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performProposalLineItemAction(Google.Api.Ads.AdManager.v201802.ProposalLineItemAction proposalLineItemAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performProposalLineItemActionAsync(Google.Api.Ads.AdManager.v201802.ProposalLineItemAction proposalLineItemAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ProposalLineItemService.updateProposalLineItemsResponse updateProposalLineItems(Wrappers.ProposalLineItemService.updateProposalLineItemsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ProposalLineItemService.updateProposalLineItemsResponse> updateProposalLineItemsAsync(Wrappers.ProposalLineItemService.updateProposalLineItemsRequest request);
	}


	/// <summary>Captures a page of <a href='ProposalLineItem'>ProposalLineItem</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProposalLineItemPage {
		private ProposalLineItem[] resultsField;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		/// <summary>The collection of proposal line items contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 0)]
		public ProposalLineItem[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a
	/// href='ProposalLineItem'>ProposalLineItem</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UnlinkProposalLineItems))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UnarchiveProposalLineItems))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ResumeProposalLineItems))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ReserveProposalLineItems))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ReleaseProposalLineItems))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(PauseProposalLineItems))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ArchiveProposalLineItems))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActualizeProposalLineItems))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class ProposalLineItemAction {
	}


	/// <summary>The action used for unlinking <a href='ProposalLineItem'>ProposalLineItem</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UnlinkProposalLineItems : ProposalLineItemAction {
	}


	/// <summary>The action used for unarchiving <a href='ProposalLineItem'>ProposalLineItem</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UnarchiveProposalLineItems : ProposalLineItemAction {
	}


	/// <summary>The action used for resuming <a href='ProposalLineItem'>ProposalLineItem</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ResumeProposalLineItems : ProposalLineItemAction {
	}


	/// <summary>The action to reserve inventory for <a
	/// href='ProposalLineItem'>ProposalLineItem</a> objects. It does not overbook
	/// inventory unless <a href='#allowOverbook'>#allowOverbook</a> is set to
	/// <code>true</code>. This action is only applicable for programmatic proposals not
	/// using sales management.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReserveProposalLineItems : ProposalLineItemAction {
		private bool allowOverbookField;

		private bool allowOverbookFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool allowOverbook {
			get {
				return this.allowOverbookField;
			}
			set {
				this.allowOverbookField = value;
				this.allowOverbookSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="allowOverbook" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool allowOverbookSpecified {
			get {
				return this.allowOverbookFieldSpecified;
			}
			set {
				this.allowOverbookFieldSpecified = value;
			}
		}
	}


	/// <summary>The action used for releasing inventory for <a
	/// href='ProposalLineItem'>ProposalLineItem</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReleaseProposalLineItems : ProposalLineItemAction {
	}


	/// <summary>The action used for pausing <a href='ProposalLineItem'>ProposalLineItem</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PauseProposalLineItems : ProposalLineItemAction {
	}


	/// <summary>The action used for archiving <a href='ProposalLineItem'>ProposalLineItem</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ArchiveProposalLineItems : ProposalLineItemAction {
	}


	/// <summary>The action used for actualizing <a href='ProposalLineItem'>ProposalLineItem</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActualizeProposalLineItems : ProposalLineItemAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ProposalLineItemServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ProposalLineItemServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='ProposalLineItem'>ProposalLineItem</a> objects. <p>To use this service,
	/// you need to have the new sales management solution enabled on your network. If
	/// you do not see a "Sales" tab in <a href="https://www.google.com/dfp">DoubleClick
	/// for Publishers (DFP)</a>, you will not be able to use this service.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ProposalLineItemService : AdManagerSoapClient<IProposalLineItemService>, IProposalLineItemService {
		/// <summary> Creates a new instance of the <see cref="ProposalLineItemService"/>
		/// class. </summary>
		public ProposalLineItemService() {
		}

		/// <summary> Creates a new instance of the <see cref="ProposalLineItemService"/>
		/// class. </summary>
		public ProposalLineItemService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="ProposalLineItemService"/>
		/// class. </summary>
		public ProposalLineItemService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ProposalLineItemService"/>
		/// class. </summary>
		public ProposalLineItemService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ProposalLineItemService"/>
		/// class. </summary>
		public ProposalLineItemService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ProposalLineItemService.createProposalLineItemsResponse Google.Api.Ads.AdManager.v201802.ProposalLineItemServiceInterface.createProposalLineItems(Wrappers.ProposalLineItemService.createProposalLineItemsRequest request) {
			return base.Channel.createProposalLineItems(request);
		}

		/// <summary>Creates new <a href='ProposalLineItem'>ProposalLineItem</a> objects.
		/// </summary><param name='proposalLineItems'>the proposal line items to create</param>
		/// <returns>the created proposal line items with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ProposalLineItem[] createProposalLineItems(Google.Api.Ads.AdManager.v201802.ProposalLineItem[] proposalLineItems) {
			Wrappers.ProposalLineItemService.createProposalLineItemsRequest inValue = new Wrappers.ProposalLineItemService.createProposalLineItemsRequest();
			inValue.proposalLineItems = proposalLineItems;
			Wrappers.ProposalLineItemService.createProposalLineItemsResponse retVal = ((Google.Api.Ads.AdManager.v201802.ProposalLineItemServiceInterface)(this)).createProposalLineItems(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ProposalLineItemService.createProposalLineItemsResponse> Google.Api.Ads.AdManager.v201802.ProposalLineItemServiceInterface.createProposalLineItemsAsync(Wrappers.ProposalLineItemService.createProposalLineItemsRequest request) {
			return base.Channel.createProposalLineItemsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProposalLineItem[]> createProposalLineItemsAsync(Google.Api.Ads.AdManager.v201802.ProposalLineItem[] proposalLineItems) {
			Wrappers.ProposalLineItemService.createProposalLineItemsRequest inValue = new Wrappers.ProposalLineItemService.createProposalLineItemsRequest();
			inValue.proposalLineItems = proposalLineItems;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProposalLineItem[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ProposalLineItemServiceInterface)(this)).createProposalLineItemsAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='ProposalLineItemPage'>ProposalLineItemPage</a> of <a
		/// href='ProposalLineItem'>ProposalLineItem</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='ProposalLineItem#id'>ProposalLineItem#id</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a
		/// href='ProposalLineItem#name'>ProposalLineItem#name</a></td> </tr> <tr>
		/// <td><code>proposalId</code></td> <td><a
		/// href='ProposalLineItem#proposalId'>ProposalLineItem#proposalId</a></td> </tr>
		/// <tr> <td><code>startDateTime</code></td> <td><a
		/// href='ProposalLineItem#startDateTime'>ProposalLineItem#startDateTime</a></td>
		/// </tr> <tr> <td><code>endDateTime</code></td> <td><a
		/// href='ProposalLineItem#endDateTime'>ProposalLineItem#endDateTime</a></td> </tr>
		/// <tr> <td><code>isArchived</code></td> <td><a
		/// href='ProposalLineItem#isArchived'>ProposalLineItem#isArchived</a></td> </tr>
		/// <tr> <td><code>lastModifiedDateTime</code></td> <td><a
		/// href='ProposalLineItem#lastModifiedDateTime'>ProposalLineItem#lastModifiedDateTime</a></td>
		/// </tr> <tr> <td><code>useThirdPartyAdServerFromProposal</code> <div
		/// class="constraint">Only applicable for non-programmatic proposal line items
		/// using sales management</div> </td> <td><a
		/// href='ProposalLineItem#useThirdPartyAdServerFromProposal'>ProposalLineItem#useThirdPartyAdServerFromProposal</a></td>
		/// </tr> <tr> <td><code>thirdPartyAdServerId</code> <div class="constraint">Only
		/// applicable for non-programmatic proposal line items using sales management</div>
		/// </td> <td><a
		/// href='ProposalLineItem#thirdPartyAdServerId'>ProposalLineItem#thirdPartyAdServerId</a></td>
		/// </tr> <tr> <td><code>customThirdPartyAdServerName</code> <div
		/// class="constraint">Only applicable for non-programmatic proposal line items
		/// using sales management</div> </td> <td><a
		/// href='ProposalLineItem#customThirdPartyAdServerName'>ProposalLineItem#customThirdPartyAdServerName</a></td>
		/// </tr> <tr> <td><code>isProgrammatic</code></td> <td><a
		/// href='ProposalLineItem#isProgrammatic'>ProposalLineItem#isProgrammatic</a></td>
		/// </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of proposal line items</param>
		/// <returns>the proposal line items that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ProposalLineItemPage getProposalLineItemsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getProposalLineItemsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProposalLineItemPage> getProposalLineItemsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getProposalLineItemsByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='ProposalLineItem'>ProposalLineItem</a> objects that
		/// match the given <a href='Statement#query'>Statement#query</a>.
		/// </summary><param name='proposalLineItemAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of proposal line items</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performProposalLineItemAction(Google.Api.Ads.AdManager.v201802.ProposalLineItemAction proposalLineItemAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performProposalLineItemAction(proposalLineItemAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performProposalLineItemActionAsync(Google.Api.Ads.AdManager.v201802.ProposalLineItemAction proposalLineItemAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performProposalLineItemActionAsync(proposalLineItemAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ProposalLineItemService.updateProposalLineItemsResponse Google.Api.Ads.AdManager.v201802.ProposalLineItemServiceInterface.updateProposalLineItems(Wrappers.ProposalLineItemService.updateProposalLineItemsRequest request) {
			return base.Channel.updateProposalLineItems(request);
		}

		/// <summary>Updates the specified <a href='ProposalLineItem'>ProposalLineItem</a> objects.
		/// </summary><param name='proposalLineItems'>the proposal line items to update</param>
		/// <returns>the updated proposal line items</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ProposalLineItem[] updateProposalLineItems(Google.Api.Ads.AdManager.v201802.ProposalLineItem[] proposalLineItems) {
			Wrappers.ProposalLineItemService.updateProposalLineItemsRequest inValue = new Wrappers.ProposalLineItemService.updateProposalLineItemsRequest();
			inValue.proposalLineItems = proposalLineItems;
			Wrappers.ProposalLineItemService.updateProposalLineItemsResponse retVal = ((Google.Api.Ads.AdManager.v201802.ProposalLineItemServiceInterface)(this)).updateProposalLineItems(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ProposalLineItemService.updateProposalLineItemsResponse> Google.Api.Ads.AdManager.v201802.ProposalLineItemServiceInterface.updateProposalLineItemsAsync(Wrappers.ProposalLineItemService.updateProposalLineItemsRequest request) {
			return base.Channel.updateProposalLineItemsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProposalLineItem[]> updateProposalLineItemsAsync(Google.Api.Ads.AdManager.v201802.ProposalLineItem[] proposalLineItems) {
			Wrappers.ProposalLineItemService.updateProposalLineItemsRequest inValue = new Wrappers.ProposalLineItemService.updateProposalLineItemsRequest();
			inValue.proposalLineItems = proposalLineItems;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProposalLineItem[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ProposalLineItemServiceInterface)(this)).updateProposalLineItemsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.PublisherQueryLanguageService
	{
	}
	/// <summary>Each <a href='Row'>Row</a> object represents data about one entity in a <a
	/// href='ResultSet'>ResultSet</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Row {
		private Value[] valuesField;

		/// <summary>Represents a collection of values belonging to one entity.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("values", Order = 0)]
		public Value[] values {
			get {
				return this.valuesField;
			}
			set {
				this.valuesField = value;
			}
		}
	}


	/// <summary>Contains a <a href='Targeting'>Targeting</a> value. <p><b>This object is
	/// experimental! <code>TargetingValue</code> is an experimental, innovative, and
	/// rapidly changing new feature for Ad Manager. Unfortunately, being on the
	/// bleeding edge means that we may make backwards-incompatible changes to
	/// <code>TargetingValue</code>. We will inform the community when this feature is
	/// no longer experimental.</b></p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class TargetingValue : ObjectValue {
		private Targeting valueField;

		/// <summary>The <code>Targeting</code> value.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public Targeting value {
			get {
				return this.valueField;
			}
			set {
				this.valueField = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ChangeHistoryValue : ObjectValue {
		private ChangeHistoryEntityType entityTypeField;

		private bool entityTypeFieldSpecified;

		private ChangeHistoryOperation operationField;

		private bool operationFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ChangeHistoryEntityType entityType {
			get {
				return this.entityTypeField;
			}
			set {
				this.entityTypeField = value;
				this.entityTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="entityType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool entityTypeSpecified {
			get {
				return this.entityTypeFieldSpecified;
			}
			set {
				this.entityTypeFieldSpecified = value;
			}
		}

		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public ChangeHistoryOperation operation {
			get {
				return this.operationField;
			}
			set {
				this.operationField = value;
				this.operationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="operation"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool operationSpecified {
			get {
				return this.operationFieldSpecified;
			}
			set {
				this.operationFieldSpecified = value;
			}
		}
	}


	/// <summary>The type of entity a change occurred on.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ChangeHistoryEntityType {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		BASE_RATE = 17,
		COMPANY = 1,
		CONTACT = 2,
		CREATIVE = 3,
		CREATIVE_SET = 4,
		CUSTOM_FIELD = 5,
		CUSTOM_KEY = 6,
		CUSTOM_VALUE = 7,
		PLACEMENT = 8,
		AD_UNIT = 9,
		LABEL = 10,
		LINE_ITEM = 11,
		NETWORK = 12,
		ORDER = 13,
		PREMIUM_RATE = 18,
		PRODUCT = 19,
		PRODUCT_PACKAGE = 20,
		PRODUCT_PACKAGE_ITEM = 21,
		PRODUCT_TEMPLATE = 22,
		PROPOSAL = 23,
		PROPOSAL_LINK = 24,
		PROPOSAL_LINE_ITEM = 25,
		PACKAGE = 26,
		RATE_CARD = 27,
		ROLE = 14,
		TEAM = 15,
		USER = 16,
		WORKFLOW = 28,
	}


	/// <summary>An operation that was performed on an entity.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ChangeHistoryOperation {
		CREATE = 0,
		UPDATE = 1,
		DELETE = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Contains information about a column in a <a href='ResultSet'>ResultSet</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ColumnType {
		private string labelNameField;

		/// <summary>Represents the column's name.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string labelName {
			get {
				return this.labelNameField;
			}
			set {
				this.labelNameField = value;
			}
		}
	}


	/// <summary>The <code>ResultSet</code> represents a table of data obtained from the
	/// execution of a PQL <a href=''>Statement</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ResultSet {
		private ColumnType[] columnTypesField;

		private Row[] rowsField;

		/// <summary>A collection of <a href='ColumnType'>ColumnType</a> objects.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("columnTypes", Order = 0)]
		public ColumnType[] columnTypes {
			get {
				return this.columnTypesField;
			}
			set {
				this.columnTypesField = value;
			}
		}

		/// <summary>A collection of <a href='Row'>Row</a> objects.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("rows", Order = 1)]
		public Row[] rows {
			get {
				return this.rowsField;
			}
			set {
				this.rowsField = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.PublisherQueryLanguageServiceInterface")]
	public interface PublisherQueryLanguageServiceInterface
	{
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ResultSet select(Google.Api.Ads.AdManager.v201802.Statement selectStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ResultSet> selectAsync(Google.Api.Ads.AdManager.v201802.Statement selectStatement);
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface PublisherQueryLanguageServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.PublisherQueryLanguageServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for executing a PQL <a href='Statement'>Statement</a> to
	/// retrieve information from the system. In order to support the selection of
	/// columns of interest from various tables, <a href='Statement'>Statement</a>
	/// objects support a "select" clause. <p>An example query text might be
	/// <code>"select CountryCode, Name from Geo_Target"</code>, where
	/// <code>CountryCode</code> and <code>Name</code> are columns of interest and
	/// <code>Geo_Target</code> is the table.</p> <p>The following tables are
	/// supported:</p> <h2>Geo_Target</h2> <table> <tr> <th scope="col">Column Name</th>
	/// <th scope="col">Description</th> </tr> <tr> <td>Id</td> <td>Unique identifier
	/// for the Geo target</td> </tr> <tr> <td>Name</td> <td>The name of the Geo
	/// target</td> </tr> <tr> <td>CanonicalParentId</td> <td>The criteria ID of the
	/// direct parent that defines the canonical name of the geo target. For example, if
	/// the current geo target is "San Francisco", its canonical name would be "San
	/// Francisco, California, United States" thus the canonicalParentId would be the
	/// criteria ID of California and the canonicalParentId of California would be the
	/// criteria ID of United states</td> </tr> <tr> <td>ParentIds</td> <td>A comma
	/// separated list of criteria IDs of all parents of the geo target ordered by
	/// ascending size</td> </tr> <tr> <td>CountryCode</td> <td>Country code as defined
	/// by ISO 3166-1 alpha-2</td> </tr> <tr> <td>Type</td> <td>Allowable values: <ul>
	/// <li>Airport</li> <li>Autonomous_Community</li> <li>Canton</li> <li>City</li>
	/// <li>Congressional_District</li> <li>Country</li> <li>County</li>
	/// <li>Department</li> <li>DMA_Region</li> <li>Governorate</li>
	/// <li>Municipality</li> <li>Neighborhood</li> <li>Postal_Code</li>
	/// <li>Prefecture</li> <li>Province</li> <li>Region</li> <li>State</li>
	/// <li>Territory</li> <li>Tv_Region</li> <li>Union_Territory</li> </ul> </td> </tr>
	/// <tr> <td>Targetable</td> <td>Indicates whether geographical targeting is
	/// allowed</td> </tr> </table> <h2>Bandwidth_Group</h2> <table> <tr> <th
	/// scope="col">Column Name</th> <th scope="col">Description</th> </tr> <tr>
	/// <td>Id</td> <td>Unique identifier for the bandwidth group</td> </tr> <tr>
	/// <td>BandwidthName</td> <td>Name of the bandwidth group</td> </tr> </table>
	/// <h2>Browser</h2> <table> <tr> <th scope="col">Column Name</th> <th
	/// scope="col">Description</th> </tr> <tr> <td>Id</td> <td>Unique identifier for
	/// the browser</td> </tr> <tr> <td>BrowserName</td> <td>Name of the browser</td>
	/// </tr> <tr> <td>MajorVersion</td> <td>Major version of the browser</td> </tr>
	/// <tr> <td>MinorVersion</td> <td>Minor version of the browser</td> </tr> </table>
	/// <h2>Browser_Language</h2> <table> <tr> <th scope="col">Column Name</th> <th
	/// scope="col">Description</th> </tr> <tr> <td>Id</td> <td>Unique identifier for
	/// the browser language</td> </tr> <tr> <td>BrowserLanguageName</td> <td>Browser's
	/// language</td> </tr> </table> <h2>Device_Capability</h2> <table> <tr> <th
	/// scope="col">Column Name</th> <th scope="col">Description</th> </tr> <tr>
	/// <td>Id</td> <td>Unique identifier for the device capability</td> </tr> <tr>
	/// <td>DeviceCapabilityName</td> <td>Name of the device capability</td> </tr>
	/// </table> <h2>Device_Category</h2> <table> <tr> <th scope="col">Column Name</th>
	/// <th scope="col">Description</th> </tr> <tr> <td>Id</td> <td>Unique identifier
	/// for the device category</td> </tr> <tr> <td>DeviceCategoryName</td> <td>Name of
	/// the device category</td> </tr> </table> <h2>Device_Manufacturer</h2> <table>
	/// <tr> <th scope="col">Column Name</th> <th scope="col">Description</th> </tr>
	/// <tr> <td>Id</td> <td>Unique identifier for the device manufacturer</td> </tr>
	/// <tr> <td>MobileDeviceManufacturerName</td> <td>Name of the device
	/// manufacturer</td> </tr> </table> <h2>Mobile_Carrier</h2> <table> <tr> <th
	/// scope="col">Column Name</th> <th scope="col">Description</th> </tr> <tr>
	/// <td>Id</td> <td>Unique identifier for the mobile carrier</td> </tr> <tr>
	/// <td>CountryCode</td> <td>The country code of the mobile carrier</td> </tr> <tr>
	/// <td>MobileCarrierName</td> <td>Name of the mobile carrier</td> </tr> </table>
	/// <h2>Mobile_Device</h2> <table> <tr> <th scope="col">Column Name</th> <th
	/// scope="col">Description</th> </tr> <tr> <td>Id</td> <td>Unique identifier for
	/// the mobile device</td> </tr> <tr> <td>MobileDeviceManufacturerId</td> <td>Id of
	/// the device manufacturer</td> </tr> <tr> <td>MobileDeviceName</td> <td>Name of
	/// the mobile device</td> </tr> </table> <h2>Mobile_Device_Submodel</h2> <table>
	/// <tr> <th scope="col">Column Name</th> <th scope="col">Description</th> </tr>
	/// <tr> <td>Id</td> <td>Unique identifier for the mobile device submodel</td> </tr>
	/// <tr> <td>MobileDeviceId</td> <td>Id of the mobile device</td> </tr> <tr>
	/// <td>MobileDeviceSubmodelName</td> <td>Name of the mobile device submodel</td>
	/// </tr> </table> <h2>Operating_System</h2> <table> <tr> <th scope="col">Column
	/// Name</th> <th scope="col">Description</th> </tr> <tr> <td>Id</td> <td>Unique
	/// identifier for the operating system</td> </tr> <tr> <td>OperatingSystemName</td>
	/// <td>Name of the operating system</td> </tr> </table>
	/// <h2>Operating_System_Version</h2> <table> <tr> <th scope="col">Column Name</th>
	/// <th scope="col">Description</th> </tr> <tr> <td>Id</td> <td>Unique identifier
	/// for the operating system version</td> </tr> <tr> <td>OperatingSystemId</td>
	/// <td>Id of the operating system</td> </tr> <tr> <td>MajorVersion</td> <td>The
	/// operating system major version</td> </tr> <tr> <td>MinorVersion</td> <td>The
	/// operating system minor version</td> </tr> <tr> <td>MicroVersion</td> <td>The
	/// operating system micro version</td> </tr> </table> <h2>Third_Party_Company</h2>
	/// <table> <tr> <th scope="col">Column Name</th> <th scope="col">Description</th>
	/// </tr> <tr> <td>Id</td> <td>Unique identifier for the third party company</td>
	/// </tr> <tr> <td>Name</td> <td>The third party company name</td> </tr> <tr>
	/// <td>Type</td> <td>The third party company type</td> </tr> <tr> <td>Status</td>
	/// <td>The status of the third party company</td> </tr> </table> <h2
	/// id="Line_Item">Line_Item</h2> <table> <tr> <th>Column name</th> <th>Type</th>
	/// <th>Description</th> </tr> <tr> <td>CostType</td> <td><code>Text</code></td>
	/// <td>The method used for billing this <code>LineItem</code>.</td> </tr> <tr>
	/// <td>CreationDateTime</td> <td><code>Datetime</code></td> <td>The date and time
	/// this <code>LineItem</code> was last created. This attribute may be null for
	/// <code>LineItem</code>s created before this feature was introduced.</td> </tr>
	/// <tr> <td>DeliveryRateType</td> <td><code>Text</code></td> <td>The strategy for
	/// delivering ads over the course of the <code></code>'s duration. This attribute
	/// is optional and defaults to <a
	/// href='DeliveryRateType#EVENLY'>DeliveryRateType#EVENLY</a>. Starting in v201306,
	/// it may default to <a
	/// href='DeliveryRateType#FRONTLOADED'>DeliveryRateType#FRONTLOADED</a> if
	/// specifically configured to on the network.</td> </tr> <tr> <td>EndDateTime</td>
	/// <td><code>Datetime</code></td> <td>The date and time on which the
	/// <code>LineItem</code> stops serving.</td> </tr> <tr> <td>ExternalId</td>
	/// <td><code>Text</code></td> <td>An identifier for the <code>LineItem</code> that
	/// is meaningful to the publisher.</td> </tr> <tr> <td>Id</td>
	/// <td><code>Number</code></td> <td>Uniquely identifies the <code>LineItem</code>.
	/// This attribute is read-only and is assigned by Google when a line item is
	/// created.</td> </tr> <tr> <td>IsMissingCreatives</td>
	/// <td><code>Boolean</code></td> <td>Indicates if a <code>LineItem</code> is
	/// missing any <a href='Creative'>creatives</a> for the
	/// <code>creativePlaceholders</code> specified.</td> </tr> <tr>
	/// <td>IsSetTopBoxEnabled</td> <td><code>Boolean</code></td> <td>Whether or not
	/// this line item is set-top box enabled.</td> </tr> <tr>
	/// <td>LastModifiedDateTime</td> <td><code>Datetime</code></td> <td>The date and
	/// time this <code>LineItem</code> was last modified.</td> </tr> <tr>
	/// <td>LineItemType</td> <td><code>Text</code></td> <td>Indicates the line item
	/// type of a <code>LineItem</code>.</td> </tr> <tr> <td>Name</td>
	/// <td><code>Text</code></td> <td>The name of the <code>LineItem</code>.</td> </tr>
	/// <tr> <td>OrderId</td> <td><code>Number</code></td> <td>The ID of the <a
	/// href='Order'>Order</a> to which the <code></code> belongs.</td> </tr> <tr>
	/// <td>StartDateTime</td> <td><code>Datetime</code></td> <td>The date and time on
	/// which the <code>LineItem</code> is enabled to begin serving.</td> </tr> <tr>
	/// <td>Status</td> <td><code>Text</code></td> <td>The status of the
	/// <code>LineItem</code>.</td> </tr> <tr> <td>Targeting</td>
	/// <td><code>Targeting</code></td> <td>The targeting criteria for the ad
	/// campaign.&lt;p&gt; &lt;b&gt;This object is experimental!
	/// &lt;code&gt;Targeting&lt;/code&gt; is an experimental, innovative, and rapidly
	/// changing new feature for DFP. Unfortunately, being on the bleeding edge means
	/// that we may make backwards-incompatible changes to
	/// &lt;code&gt;Targeting&lt;/code&gt;. We will inform the community when this
	/// feature is no longer experimental.&lt;/b&gt;</td> </tr> <tr>
	/// <td>UnitsBought</td> <td><code>Number</code></td> <td>The total number of
	/// impressions or clicks that will be reserved for the <code>LineItem</code>. If
	/// the line item is of type <a
	/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a>, then it represents
	/// the percentage of available impressions reserved.</td> </tr> </table> <h2
	/// id="Ad_Unit">Ad_Unit</h2> <table> <tr> <th>Column name</th> <th>Type</th>
	/// <th>Description</th> </tr> <tr> <td>AdUnitCode</td> <td><code>Text</code></td>
	/// <td>A string used to uniquely identify the ad unit for the purposes of serving
	/// the ad. This attribute is read-only and is assigned by Google when an ad unit is
	/// created.</td> </tr> <tr> <td>ExternalSetTopBoxChannelId</td>
	/// <td><code>Text</code></td> <td>The channel ID for set-top box enabled <a
	/// href='AdUnit'>ad units</a>.</td> </tr> <tr> <td>Id</td>
	/// <td><code>Number</code></td> <td>Uniquely identifies the ad unit. This value is
	/// read-only and is assigned by Google when an ad unit is created.</td> </tr> <tr>
	/// <td>LastModifiedDateTime</td> <td><code>Datetime</code></td> <td>The date and
	/// time this ad unit was last modified.</td> </tr> <tr> <td>Name</td>
	/// <td><code>Text</code></td> <td>The name of the ad unit.</td> </tr> <tr>
	/// <td>ParentId</td> <td><code>Number</code></td> <td>The ID of the ad unit's
	/// parent. Every ad unit has a parent except for the root ad unit, which is created
	/// by Google.</td> </tr> </table> <h2 id="User">User</h2> <table> <tr> <th>Column
	/// name</th> <th>Type</th> <th>Description</th> </tr> <tr> <td>Email</td>
	/// <td><code>Text</code></td> <td>The email or login of the user.</td> </tr> <tr>
	/// <td>ExternalId</td> <td><code>Text</code></td> <td>An identifier for the user
	/// that is meaningful to the publisher.</td> </tr> <tr> <td>Id</td>
	/// <td><code>Number</code></td> <td>The unique ID of the user.</td> </tr> <tr>
	/// <td>IsServiceAccount</td> <td><code>Boolean</code></td> <td>True if this user is
	/// an OAuth2 service account user, false otherwise.</td> </tr> <tr> <td>Name</td>
	/// <td><code>Text</code></td> <td>The name of the user.</td> </tr> <tr>
	/// <td>RoleId</td> <td><code>Number</code></td> <td>The unique role ID of the user.
	/// <a href='Role'>Role</a> objects that are created by Google will have negative
	/// IDs.</td> </tr> <tr> <td>RoleName</td> <td><code>Text</code></td> <td>The name
	/// of the <a href='Role'>Role</a> assigned to the user.</td> </tr> </table> <h2
	/// id="Exchange_Rate">Exchange_Rate</h2> <table> <tr> <th>Column name</th>
	/// <th>Type</th> <th>Description</th> </tr> <tr> <td>CurrencyCode</td>
	/// <td><code>Text</code></td> <td>The currency code that the exchange rate is
	/// related to. The exchange rate is between this currency and <a
	/// href='Network#currencyCode'>the network's currency</a>. This attribute is
	/// required for creation and then is readonly.</td> </tr> <tr> <td>Direction</td>
	/// <td><code>Text</code></td> <td>The direction that the exchange rate is in. It
	/// determines whether the exchange rate is from this currency to <a
	/// href='Network#currencyCode'>the network's currency</a>, or from <a
	/// href='Network#currencyCode'>the network's currency</a> to this currency. This
	/// attribute can be updated.</td> </tr> <tr> <td>ExchangeRate</td>
	/// <td><code>Number</code></td> <td>The latest exchange rate at current refresh
	/// rate and in current direction. The value is stored as the exchange rate times
	/// 10,000,000,000 truncated to a long. Setting this attribute requires the refresh
	/// rate to be already set to <a
	/// href='ExchangeRateRefreshRate#FIXED'>ExchangeRateRefreshRate#FIXED</a>.
	/// Otherwise an exception will be thrown.</td> </tr> <tr> <td>Id</td>
	/// <td><code>Number</code></td> <td>The ID of the <code>ExchangeRate</code>. This
	/// attribute is readonly and is assigned by Google when an exchange rate is
	/// created.</td> </tr> <tr> <td>RefreshRate</td> <td><code>Text</code></td> <td>The
	/// refresh rate at which the exchange rate is updated. Setting this attribute to <a
	/// href='ExchangeRateRefreshRate#FIXED'>ExchangeRateRefreshRate#FIXED</a> without
	/// setting the exchange rate value will cause unknown exchange rate value returned
	/// in future queries.</td> </tr> </table> <h2
	/// id="Programmatic_Buyer">Programmatic_Buyer</h2> <table> <tr> <th>Column
	/// name</th> <th>Type</th> <th>Description</th> </tr> <tr> <td>BuyerAccountId</td>
	/// <td><code>Number</code></td> <td>The ID used by Adx to bill the appropriate
	/// buyer network for a programmatic order.</td> </tr> <tr>
	/// <td>EnabledForPreferredDeals</td> <td><code>Boolean</code></td> <td>Whether the
	/// buyer is allowed to negotiate Preferred Deals.</td> </tr> <tr>
	/// <td>EnabledForProgrammaticGuaranteed</td> <td><code>Boolean</code></td>
	/// <td>Whether the buyer is enabled for Programmatic Guaranteed deals.</td> </tr>
	/// <tr> <td>Name</td> <td><code>Text</code></td> <td>Display name that references
	/// the buyer.</td> </tr> <tr> <td>ParentId</td> <td><code>Number</code></td>
	/// <td>The ID of the programmatic buyer's sponsor. If the programmatic buyer has no
	/// sponsor, this field will be -1.</td> </tr> </table> <h2
	/// id="Audience_Segment_Category">Audience_Segment_Category</h2> <table> <tr>
	/// <th>Column name</th> <th>Type</th> <th>Description</th> </tr> <tr> <td>Id</td>
	/// <td><code>Number</code></td> <td>The unique identifier for the audience segment
	/// category.</td> </tr> <tr> <td>Name</td> <td><code>Text</code></td> <td>The name
	/// of the audience segment category.</td> </tr> <tr> <td>ParentId</td>
	/// <td><code>Number</code></td> <td>The unique identifier of the audience segment
	/// category's parent.</td> </tr> </table> <h2
	/// id="Audience_Segment">Audience_Segment</h2> <table> <tr> <th>Column name</th>
	/// <th>Type</th> <th>Description</th> </tr> <tr> <td>AdIdSize</td>
	/// <td><code>Number</code></td> <td>The number of AdID users in the segment.</td>
	/// </tr> <tr> <td>CategoryIds</td> <td><code>Set of number</code></td> <td>The ids
	/// of the categories that this audience segment belongs to.</td> </tr> <tr>
	/// <td>Id</td> <td><code>Number</code></td> <td>The unique identifier for the
	/// audience segment.</td> </tr> <tr> <td>IdfaSize</td> <td><code>Number</code></td>
	/// <td>The number of IDFA users in the segment.</td> </tr> <tr>
	/// <td>MobileWebSize</td> <td><code>Number</code></td> <td>The number of mobile web
	/// users in the segment.</td> </tr> <tr> <td>Name</td> <td><code>Text</code></td>
	/// <td>The name of the audience segment.</td> </tr> <tr> <td>OwnerAccountId</td>
	/// <td><code>Number</code></td> <td>The owner account id of the audience
	/// segment.</td> </tr> <tr> <td>OwnerName</td> <td><code>Text</code></td> <td>The
	/// owner name of the audience segment.</td> </tr> <tr> <td>PpidSize</td>
	/// <td><code>Number</code></td> <td>The number of PPID users in the segment.</td>
	/// </tr> <tr> <td>SegmentType</td> <td><code>Text</code></td> <td>The type of the
	/// audience segment.</td> </tr> </table> <h2
	/// id="Proposal_Retraction_Reason">Proposal_Retraction_Reason</h2> <table> <tr>
	/// <th>Column name</th> <th>Type</th> <th>Description</th> </tr> <tr> <td>Id</td>
	/// <td><code>Number</code></td> <td>The ID of the
	/// <code>ProposalRetractionReason</code>. This attribute is readonly and is
	/// assigned by Google when a proposal retraction reason is created.</td> </tr> <tr>
	/// <td>IsActive</td> <td><code>Boolean</code></td> <td>True if the
	/// <code>ProposalRetractionReason</code> is active.</td> </tr> <tr> <td>Name</td>
	/// <td><code>Text</code></td> <td>The name of the
	/// <code>ProposalRetractionReason</code>.</td> </tr> </table> <h2
	/// id="Audience_Explorer">Audience_Explorer</h2> <table> <tr> <th>Column name</th>
	/// <th>Type</th> <th>Description</th> </tr> <tr> <td>Id</td>
	/// <td><code>Number</code></td> <td>Uniquely identifies the audience segment. This
	/// table has been deprecated since December 2017, and returns empty data.</td>
	/// </tr> <tr> <td>ThirtyDayActiveSize</td> <td><code>Number</code></td> <td>The
	/// number of active unique cookies in this segment over the last 30 days. This
	/// table has been deprecated since December 2017, and returns empty data.</td>
	/// </tr> <tr> <td>ThirtyDayClicks</td> <td><code>Number</code></td> <td>The number
	/// of clicks for this segment over the last 30 days. This table has been deprecated
	/// since December 2017, and returns empty data.</td> </tr> <tr>
	/// <td>ThirtyDayImpressions</td> <td><code>Number</code></td> <td>The number of
	/// impressions for this segment over the last 30 days. This table has been
	/// deprecated since December 2017, and returns empty data.</td> </tr> </table> <h2
	/// id="Time_Zone">Time_Zone</h2> <table> <tr> <th>Column name</th> <th>Type</th>
	/// <th>Description</th> </tr> <tr> <td>Id</td> <td><code>Text</code></td> <td>The
	/// id of time zone in the form of <code></code>.</td> </tr> <tr>
	/// <td>StandardGmtOffset</td> <td><code>Text</code></td> <td>The standard GMT
	/// offset in current time in the form of <code></code> for
	/// <code>America/New_York</code>, excluding the Daylight Saving Time.</td> </tr>
	/// </table> <h2 id="Proposal_Terms_And_Conditions">
	/// Proposal_Terms_And_Conditions</h2> <table> <tr> <th>Column name</th>
	/// <th>Type</th> <th>Description</th> </tr> <tr> <td>Content</td>
	/// <td><code>Text</code></td> <td>The content of the terms and conditions.</td>
	/// </tr> <tr> <td>Id</td> <td><code>Number</code></td> <td>Uniquely identifies the
	/// terms and conditions.</td> </tr> <tr> <td>IsDefault</td>
	/// <td><code>Boolean</code></td> <td>Whether or not this set of terms and
	/// conditions are the default for a network.</td> </tr> <tr>
	/// <td>LastModifiedDateTime</td> <td><code>Datetime</code></td> <td>The date and
	/// time this terms and conditions was last modified.</td> </tr> <tr> <td>Name</td>
	/// <td><code>Text</code></td> <td>The name of the terms and conditions.</td> </tr>
	/// </table> <h2 id="Change_History">Change_History</h2> Restrictions: Only ordering
	/// by <code>ChangeDateTime</code> descending is supported. <code>OFFSET</code> is
	/// not supported. To page through results, filter on the earliest change
	/// <code>Id</code> as a continuation token. For example <code>"WHERE Id &lt;
	/// :id"</code>. On each query, both an upper bound and a lower bound for the
	/// <code>ChangeDateTime</code> are required. <table> <tr> <th>Column name</th>
	/// <th>Type</th> <th>Description</th> </tr> <tr> <td>ChangeDateTime</td>
	/// <td><code>Datetime</code></td> <td>The date and time this change happened.</td>
	/// </tr> <tr> <td>EntityId</td> <td><code>Number</code></td> <td>The ID of the
	/// entity that was changed.</td> </tr> <tr> <td>EntityType</td>
	/// <td><code>Text</code></td> <td>The <a href='ChangeHistoryEntityType'>type</a> of
	/// the entity that was changed.</td> </tr> <tr> <td>Id</td>
	/// <td><code>Text</code></td> <td>The ID of this change. IDs may only be used with
	/// <code>"&lt;"</code> operator for paging and are subject to change. Do not store
	/// IDs. Note that the <code>"&lt;"</code> here does not compare the value of the ID
	/// but the row in the change history table it represents.</td> </tr> <tr>
	/// <td>Operation</td> <td><code>Text</code></td> <td>The <a
	/// href='ChangeHistoryOperation'>operation</a> that was performed on this
	/// entity.</td> </tr> <tr> <td>UserId</td> <td><code>Number</code></td> <td>The <a
	/// href='User#id'>ID</a> of the user that made this change.</td> </tr> </table>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class PublisherQueryLanguageService : AdManagerSoapClient<IPublisherQueryLanguageService>, IPublisherQueryLanguageService {
		/// <summary> Creates a new instance of the <see
		/// cref="PublisherQueryLanguageService"/> class. </summary>
		public PublisherQueryLanguageService() {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="PublisherQueryLanguageService"/> class. </summary>
		public PublisherQueryLanguageService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="PublisherQueryLanguageService"/> class. </summary>
		public PublisherQueryLanguageService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="PublisherQueryLanguageService"/> class. </summary>
		public PublisherQueryLanguageService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="PublisherQueryLanguageService"/> class. </summary>
		public PublisherQueryLanguageService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		/// <summary>Retrieves rows of data that satisfy the given <a
		/// href='Statement#query'>Statement#query</a> from the system.
		/// </summary><param name='selectStatement'>a Publisher Query Language statement used to
		/// specify what data needs to returned</param>
		/// <returns>a result set of data that matches the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ResultSet select(Google.Api.Ads.AdManager.v201802.Statement selectStatement) {
			return base.Channel.select(selectStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ResultSet> selectAsync(Google.Api.Ads.AdManager.v201802.Statement selectStatement) {
			return base.Channel.selectAsync(selectStatement);
		}
	}
	namespace Wrappers.RateCardService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createRateCards", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createRateCardsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rateCards")]
			public Google.Api.Ads.AdManager.v201802.RateCard[] rateCards;

			/// <summary> Creates a new instance of the <see cref="createRateCardsRequest"/>
			/// class. </summary>
			public createRateCardsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createRateCardsRequest"/>
			/// class. </summary>
			public createRateCardsRequest(Google.Api.Ads.AdManager.v201802.RateCard[] rateCards) {
				this.rateCards = rateCards;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createRateCardsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createRateCardsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.RateCard[] rval;

			/// <summary> Creates a new instance of the <see cref="createRateCardsResponse"/>
			/// class. </summary>
			public createRateCardsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createRateCardsResponse"/>
			/// class. </summary>
			public createRateCardsResponse(Google.Api.Ads.AdManager.v201802.RateCard[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateRateCards", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateRateCardsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rateCards")]
			public Google.Api.Ads.AdManager.v201802.RateCard[] rateCards;

			/// <summary> Creates a new instance of the <see cref="updateRateCardsRequest"/>
			/// class. </summary>
			public updateRateCardsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updateRateCardsRequest"/>
			/// class. </summary>
			public updateRateCardsRequest(Google.Api.Ads.AdManager.v201802.RateCard[] rateCards) {
				this.rateCards = rateCards;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateRateCardsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateRateCardsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.RateCard[] rval;

			/// <summary> Creates a new instance of the <see cref="updateRateCardsResponse"/>
			/// class. </summary>
			public updateRateCardsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updateRateCardsResponse"/>
			/// class. </summary>
			public updateRateCardsResponse(Google.Api.Ads.AdManager.v201802.RateCard[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>Defines a collection of rules, including base rates for product templates and
	/// products, premiums, proposal line item level adjustments and proposal level
	/// adjustments.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RateCard {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private string currencyCodeField;

		private RateCardStatus statusField;

		private bool statusFieldSpecified;

		private bool forMarketplaceField;

		private bool forMarketplaceFieldSpecified;

		private PricingModel pricingModelField;

		private bool pricingModelFieldSpecified;

		private long[] appliedTeamIdsField;

		private DateTime lastModifiedDateTimeField;

		/// <summary>The ID of the <code>RateCard</code>. This attribute is read-only and is assigned
		/// by Google when a rate card is created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the <code>RateCard</code>. This attribute is required and has a
		/// maximum length of 255 characters. This attribute must also be case-insensitive
		/// unique.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The ISO currency code for the currency used by the <code></code>. This attribute
		/// is optional to create a <code>RateCard</code> and defaults to the <a
		/// href='Network#currencyCode'>network's currency</a>. This attribute is read-only
		/// if either the <code></code> is for Marketplace or once a <a
		/// href='ProposalLineItem'>ProposalLineItem</a> has been created using this
		/// <code>RateCard</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string currencyCode {
			get {
				return this.currencyCodeField;
			}
			set {
				this.currencyCodeField = value;
			}
		}

		/// <summary>The status of the <code>RateCard</code>. This attribute is read-only and is
		/// assigned by Google. Rate cards are created in the <a
		/// href='RateCardStatus#INACTIVE'>RateCardStatus#INACTIVE</a> state.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public RateCardStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>Whether or not the <code>RateCard</code> can be used for Marketplace <a
		/// href='Product'>products</a>. This attribute is read-only and assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public bool forMarketplace {
			get {
				return this.forMarketplaceField;
			}
			set {
				this.forMarketplaceField = value;
				this.forMarketplaceSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="forMarketplace" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool forMarketplaceSpecified {
			get {
				return this.forMarketplaceFieldSpecified;
			}
			set {
				this.forMarketplaceFieldSpecified = value;
			}
		}

		/// <summary>The <a href='PricingModel'>PricingModel</a> of the <code></code>. <p>This
		/// attribute is required to create a <code>RateCard</code>.</p> <p>This attribute
		/// is read-only if either the <code>RateCard</code> is for Marketplace or once a <a
		/// href='ProposalLineItem'>ProposalLineItem</a> has been created using this
		/// <code>RateCard</code>.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public PricingModel pricingModel {
			get {
				return this.pricingModelField;
			}
			set {
				this.pricingModelField = value;
				this.pricingModelSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="pricingModel" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool pricingModelSpecified {
			get {
				return this.pricingModelFieldSpecified;
			}
			set {
				this.pricingModelFieldSpecified = value;
			}
		}

		/// <summary>The IDs of all teams this rate card is directly in. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("appliedTeamIds", Order = 6)]
		public long[] appliedTeamIds {
			get {
				return this.appliedTeamIdsField;
			}
			set {
				this.appliedTeamIdsField = value;
			}
		}

		/// <summary>The date and time this <code>RateCard</code> was last modified. <p>This
		/// attribute is readonly and is assigned by Google when a <code>RateCard</code> is
		/// updated.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public DateTime lastModifiedDateTime {
			get {
				return this.lastModifiedDateTimeField;
			}
			set {
				this.lastModifiedDateTimeField = value;
			}
		}
	}


	/// <summary>Describes the status of <a href='RateCard'>RateCard</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RateCardStatus {
		/// <summary>The rate card has been activated.
		/// </summary>
		ACTIVE = 0,
		/// <summary>The rate card has not been activated.
		/// </summary>
		INACTIVE = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>An error having to do with <a href='RateCard'>RateCard</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RateCardError : ApiError {
		private RateCardErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public RateCardErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "RateCardError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RateCardErrorReason {
		/// <summary>The currency code is invalid and does not follow ISO 4217.
		/// </summary>
		INVALID_CURRENCY_CODE = 0,
		/// <summary>The <a href='PricingModel'>PricingModel</a> is invalid.
		/// </summary>
		INVALID_PRICING_MODEL = 4,
		/// <summary>Marketplace <a href='RateCard'>RateCard</a> cannot have <a
		/// href='ProductPackage'>ProductPackage</a> association.
		/// </summary>
		PRODUCT_PACKAGE_NOT_APPLICABLE_ON_MARKETPLACE_RATE_CARD = 5,
		/// <summary>The currency code is not supported by current network. A supported currency can
		/// be either <a href='Network#currencyCode'>Network#currencyCode</a> or one of <a
		/// href='Network#secondaryCurrencyCodes'>Network#secondaryCurrencyCodes</a>.
		/// </summary>
		UNSUPPORTED_CURRENCY_CODE = 1,
		/// <summary>The currency code is unchangeable as long as there is any proposal line item
		/// created with the rate card.
		/// </summary>
		UNCHANGEABLE_CURRENCY_CODE = 2,
		/// <summary>The <a href='PricingModel'>PricingModel</a> cannot be changed after <a
		/// href='ProposalLineItem'>proposal line items</a> have been created using the <a
		/// href='RateCard'>RateCard</a>.
		/// </summary>
		UNCHANGEABLE_PRICING_MODEL = 6,
		/// <summary>Only one Marketplace <a href='RateCard'>RateCard</a> per <a
		/// href='Network'>Network</a> is allowed.
		/// </summary>
		MARKETPLACE_RATE_CARD_NOT_UNIQUE = 7,
		/// <summary>Legal agreement must be accepted before activating the Marketplace <a
		/// href='RateCard'>RateCard</a>.
		/// </summary>
		NOT_ACCEPT_DEALS_SALES_ON_LEGAL_AGREEMENT = 8,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>An error lists all error reasons associated with performing action on <a
	/// href='RateCard'>RateCard</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RateCardActionError : ApiError {
		private RateCardActionErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public RateCardActionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "RateCardActionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RateCardActionErrorReason {
		/// <summary>The operation is not applicable to the current status.
		/// </summary>
		NOT_APPLICABLE = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.RateCardServiceInterface")]
	public interface RateCardServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.RateCardService.createRateCardsResponse createRateCards(Wrappers.RateCardService.createRateCardsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.RateCardService.createRateCardsResponse> createRateCardsAsync(Wrappers.RateCardService.createRateCardsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.RateCardPage getRateCardsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.RateCardPage> getRateCardsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performRateCardAction(Google.Api.Ads.AdManager.v201802.RateCardAction rateCardAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performRateCardActionAsync(Google.Api.Ads.AdManager.v201802.RateCardAction rateCardAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.RateCardService.updateRateCardsResponse updateRateCards(Wrappers.RateCardService.updateRateCardsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.RateCardService.updateRateCardsResponse> updateRateCardsAsync(Wrappers.RateCardService.updateRateCardsRequest request);
	}


	/// <summary>Captures a page of <a href='RateCard'>RateCard</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RateCardPage {
		private RateCard[] resultsField;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		/// <summary>The collection of rate cards contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 0)]
		public RateCard[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a href='RateCard'>RateCard</a>
	/// objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeactivateRateCards))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateRateCards))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class RateCardAction {
	}


	/// <summary>The action used to deactivate <a href='RateCard'>RateCard</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeactivateRateCards : RateCardAction {
	}


	/// <summary>The action used to activate <a href='RateCard'>RateCard</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateRateCards : RateCardAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface RateCardServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.RateCardServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for managing <a href='RateCard'>RateCard</a> objects. <p>To use
	/// this service, you need to have the new sales management solution enabled on your
	/// network. If you do not see a "Sales" tab in <a
	/// href="https://www.google.com/dfp">DoubleClick for Publishers (DFP)</a>, you will
	/// not be able to use this service.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class RateCardService : AdManagerSoapClient<IRateCardService>, IRateCardService {
		/// <summary> Creates a new instance of the <see cref="RateCardService"/> class.
		/// </summary>
		public RateCardService() {
		}

		/// <summary> Creates a new instance of the <see cref="RateCardService"/> class.
		/// </summary>
		public RateCardService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="RateCardService"/> class.
		/// </summary>
		public RateCardService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="RateCardService"/> class.
		/// </summary>
		public RateCardService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="RateCardService"/> class.
		/// </summary>
		public RateCardService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.RateCardService.createRateCardsResponse Google.Api.Ads.AdManager.v201802.RateCardServiceInterface.createRateCards(Wrappers.RateCardService.createRateCardsRequest request) {
			return base.Channel.createRateCards(request);
		}

		/// <summary>Creates a list of <a href='RateCard'>RateCard</a> objects. Rate cards must be
		/// activated before being associated with proposal line items and products.
		/// </summary><param name='rateCards'>the rate cards to be created</param>
		/// <returns>the created rate cards.</returns>
		public virtual Google.Api.Ads.AdManager.v201802.RateCard[] createRateCards(Google.Api.Ads.AdManager.v201802.RateCard[] rateCards) {
			Wrappers.RateCardService.createRateCardsRequest inValue = new Wrappers.RateCardService.createRateCardsRequest();
			inValue.rateCards = rateCards;
			Wrappers.RateCardService.createRateCardsResponse retVal = ((Google.Api.Ads.AdManager.v201802.RateCardServiceInterface)(this)).createRateCards(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.RateCardService.createRateCardsResponse> Google.Api.Ads.AdManager.v201802.RateCardServiceInterface.createRateCardsAsync(Wrappers.RateCardService.createRateCardsRequest request) {
			return base.Channel.createRateCardsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.RateCard[]> createRateCardsAsync(Google.Api.Ads.AdManager.v201802.RateCard[] rateCards) {
			Wrappers.RateCardService.createRateCardsRequest inValue = new Wrappers.RateCardService.createRateCardsRequest();
			inValue.rateCards = rateCards;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.RateCard[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.RateCardServiceInterface)(this)).createRateCardsAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='RateCardPage'>RateCardPage</a> of <a
		/// href='RateCard'>RateCard</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th>PQL property</th> <th>Entity property</th> </tr>
		/// <tr> <td><code>ForMarketplace</code></td> <td><a
		/// href='RateCard#forMarketplace'>RateCard#forMarketplace</a></td> </tr> <tr>
		/// <td><code>Id</code></td> <td><a href='RateCard#id'>RateCard#id</a></td> </tr>
		/// <tr> <td><code>LastModifiedDateTime</code></td> <td><a
		/// href='RateCard#lastModifiedDateTime'>RateCard#lastModifiedDateTime</a></td>
		/// </tr> <tr> <td><code>Name</code></td> <td><a
		/// href='RateCard#name'>RateCard#name</a></td> </tr> <tr>
		/// <td><code>Status</code></td> <td><a
		/// href='RateCard#status'>RateCard#status</a></td> </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement to filter a
		/// list of rate cards.</param>
		/// <returns>the rate cards that match the filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.RateCardPage getRateCardsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getRateCardsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.RateCardPage> getRateCardsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getRateCardsByStatementAsync(filterStatement);
		}

		/// <summary>Performs action on <a href='RateCard'>RateCard</a> objects that satisfy the
		/// given <a href='Statement#query'>Statement#query</a>.
		/// </summary><param name='rateCardAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of rate cards.</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performRateCardAction(Google.Api.Ads.AdManager.v201802.RateCardAction rateCardAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performRateCardAction(rateCardAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performRateCardActionAsync(Google.Api.Ads.AdManager.v201802.RateCardAction rateCardAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performRateCardActionAsync(rateCardAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.RateCardService.updateRateCardsResponse Google.Api.Ads.AdManager.v201802.RateCardServiceInterface.updateRateCards(Wrappers.RateCardService.updateRateCardsRequest request) {
			return base.Channel.updateRateCards(request);
		}

		/// <summary>Updates a list of <a href='RateCard'>RateCard</a> objects.
		/// </summary><param name='rateCards'>the rate cards to be updated</param>
		/// <returns>the updated rate cards</returns>
		public virtual Google.Api.Ads.AdManager.v201802.RateCard[] updateRateCards(Google.Api.Ads.AdManager.v201802.RateCard[] rateCards) {
			Wrappers.RateCardService.updateRateCardsRequest inValue = new Wrappers.RateCardService.updateRateCardsRequest();
			inValue.rateCards = rateCards;
			Wrappers.RateCardService.updateRateCardsResponse retVal = ((Google.Api.Ads.AdManager.v201802.RateCardServiceInterface)(this)).updateRateCards(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.RateCardService.updateRateCardsResponse> Google.Api.Ads.AdManager.v201802.RateCardServiceInterface.updateRateCardsAsync(Wrappers.RateCardService.updateRateCardsRequest request) {
			return base.Channel.updateRateCardsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.RateCard[]> updateRateCardsAsync(Google.Api.Ads.AdManager.v201802.RateCard[] rateCards) {
			Wrappers.RateCardService.updateRateCardsRequest inValue = new Wrappers.RateCardService.updateRateCardsRequest();
			inValue.rateCards = rateCards;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.RateCard[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.RateCardServiceInterface)(this)).updateRateCardsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.ReconciliationOrderReportService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateReconciliationOrderReports", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateReconciliationOrderReportsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("reconciliationOrderReports")]
			public Google.Api.Ads.AdManager.v201802.ReconciliationOrderReport[] reconciliationOrderReports;

			/// <summary> Creates a new instance of the <see
			/// cref="updateReconciliationOrderReportsRequest"/> class. </summary>
			public updateReconciliationOrderReportsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateReconciliationOrderReportsRequest"/> class. </summary>
			public updateReconciliationOrderReportsRequest(Google.Api.Ads.AdManager.v201802.ReconciliationOrderReport[] reconciliationOrderReports) {
				this.reconciliationOrderReports = reconciliationOrderReports;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateReconciliationOrderReportsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateReconciliationOrderReportsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ReconciliationOrderReport[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateReconciliationOrderReportsResponse"/> class. </summary>
			public updateReconciliationOrderReportsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateReconciliationOrderReportsResponse"/> class. </summary>
			public updateReconciliationOrderReportsResponse(Google.Api.Ads.AdManager.v201802.ReconciliationOrderReport[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>Contains reconciliation data of an <a href='Order'>Order</a> and/or <a
	/// href='Proposal'>Proposal</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReconciliationOrderReport {
		private long idField;

		private bool idFieldSpecified;

		private long reconciliationReportIdField;

		private bool reconciliationReportIdFieldSpecified;

		private long orderIdField;

		private bool orderIdFieldSpecified;

		private long proposalIdField;

		private bool proposalIdFieldSpecified;

		private ReconciliationOrderReportStatus statusField;

		private bool statusFieldSpecified;

		private DateTime submissionDateTimeField;

		private long submitterIdField;

		private bool submitterIdFieldSpecified;

		private Money proposalNetBillableRevenueManualAdjustmentField;

		private Money proposalGrossBillableRevenueManualAdjustmentField;

		/// <summary>Uniquely identifies the <code>ReconciliationOrderReport</code>. This value is
		/// read-only and assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The ID of the <a href='ReconciliationReport'>ReconciliationReport</a> this
		/// <code></code> belongs to. This value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long reconciliationReportId {
			get {
				return this.reconciliationReportIdField;
			}
			set {
				this.reconciliationReportIdField = value;
				this.reconciliationReportIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="reconciliationReportId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reconciliationReportIdSpecified {
			get {
				return this.reconciliationReportIdFieldSpecified;
			}
			set {
				this.reconciliationReportIdFieldSpecified = value;
			}
		}

		/// <summary>If this reconciliation data is for an <a href='Order'>Order</a>, then this
		/// contains that order's ID. Otherwise, this field will have a value of 0. This
		/// value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public long orderId {
			get {
				return this.orderIdField;
			}
			set {
				this.orderIdField = value;
				this.orderIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="orderId" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool orderIdSpecified {
			get {
				return this.orderIdFieldSpecified;
			}
			set {
				this.orderIdFieldSpecified = value;
			}
		}

		/// <summary>If this reconciliation data is for a <a href='Proposal'>Proposal</a>, then this
		/// contains that proposal's ID. Otherwise, this field will have a value of 0. This
		/// value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public long proposalId {
			get {
				return this.proposalIdField;
			}
			set {
				this.proposalIdField = value;
				this.proposalIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="proposalId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool proposalIdSpecified {
			get {
				return this.proposalIdFieldSpecified;
			}
			set {
				this.proposalIdFieldSpecified = value;
			}
		}

		/// <summary>The status of this <code>ReconciliationOrderReport</code>. This value is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public ReconciliationOrderReportStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>The time when this order report is submitted. This value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public DateTime submissionDateTime {
			get {
				return this.submissionDateTimeField;
			}
			set {
				this.submissionDateTimeField = value;
			}
		}

		/// <summary>The ID of the <a href='User'>User</a> who submitted this order report. This
		/// value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public long submitterId {
			get {
				return this.submitterIdField;
			}
			set {
				this.submitterIdField = value;
				this.submitterIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="submitterId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool submitterIdSpecified {
			get {
				return this.submitterIdFieldSpecified;
			}
			set {
				this.submitterIdFieldSpecified = value;
			}
		}

		/// <summary>If this reconciliation data is for a <a href='Proposal'>Proposal</a>, then this
		/// contains the net revenue manual adjustment for that proposal. Otherwise, this is
		/// <code>null</code>. This value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public Money proposalNetBillableRevenueManualAdjustment {
			get {
				return this.proposalNetBillableRevenueManualAdjustmentField;
			}
			set {
				this.proposalNetBillableRevenueManualAdjustmentField = value;
			}
		}

		/// <summary>If this reconciliation data is for a <a href='Proposal'>Proposal</a>, then this
		/// contains the gross revenue manual adjustment for that proposal. Otherwise, this
		/// is <code></code>. This value is editable.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public Money proposalGrossBillableRevenueManualAdjustment {
			get {
				return this.proposalGrossBillableRevenueManualAdjustmentField;
			}
			set {
				this.proposalGrossBillableRevenueManualAdjustmentField = value;
			}
		}
	}


	/// <summary>The status of the reconciliation order report.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ReconciliationOrderReportStatus {
		/// <summary>The starting status of a reconciliation order report. Rows are updatable in the
		/// <code>DRAFT</code> state. Reconciliation order reports can be submitted with the
		/// <a href='SubmitReconciliationOrderReports'>SubmitReconciliationOrderReports</a>
		/// action to change the status to <a href='#RECONCILED'>#RECONCILED</a>.
		/// </summary>
		DRAFT = 0,
		/// <summary>The final status of a reconciliation order report. Rows are not updatable in the
		/// <code>RECONCILED</code> state. Reconciliation order reports can be reverted with
		/// the <a
		/// href='RevertReconciliationOrderReports'>RevertReconciliationOrderReports</a>
		/// action to change the status to <a href='#REVERTED'>#REVERTED</a>.
		/// </summary>
		RECONCILED = 1,
		/// <summary>A similar status to <code>DRAFT</code>. Rows are updatable in the <code></code>
		/// state. Reconciliation order reports can be submitted with the <a
		/// href='SubmitReconciliationOrderReports'>SubmitReconciliationOrderReports</a>
		/// action to change the status to <a href='#RECONCILED'>#RECONCILED</a>.
		/// </summary>
		REVERTED = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Captures a page of <a
	/// href='ReconciliationOrderReport'>ReconciliationOrderReport</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReconciliationOrderReportPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private ReconciliationOrderReport[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of reconciliation order reports contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public ReconciliationOrderReport[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Lists all errors associated with reconciliation.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReconciliationError : ApiError {
		private ReconciliationErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ReconciliationErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ReconciliationError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ReconciliationErrorReason {
		/// <summary>Reconciliation report is reconciled, and need to revert. Or reconciliation
		/// report is Deleted, and not possible.
		/// </summary>
		CANNOT_CREATE_RECONCILIATION_REPORT_VERSION = 0,
		/// <summary>Reconciliation report can't be put into that reconciliation state.
		/// </summary>
		INVALID_RECONCILIATION_REPORT_STATE_TRANSITION = 1,
		/// <summary>Previous cycles of the proposal must be reconciled first.
		/// </summary>
		INVALID_RECONCILIATION_PROPOSAL_SUBMISSION_SEQUENCE = 2,
		/// <summary>User does not have permission to put reconciliation report into reconciled
		/// state.
		/// </summary>
		USER_CANNOT_RECONCILE_RECONCILIATION_REPORT = 3,
		/// <summary>The billed from is contracted, but the contracted volume cannot be null.
		/// </summary>
		CONTRACTED_VOLUME_CANNOT_BE_NULL = 4,
		/// <summary>The billed from is DFP, but the DFP volume cannot be null.
		/// </summary>
		DFP_VOLUME_CANNOT_BE_NULL = 5,
		/// <summary>The billed from is manual, but the manual volume cannot be null.
		/// </summary>
		MANUAL_VOLUME_CANNOT_BE_NULL = 6,
		/// <summary>The billed from is third-party, but the third-party volume cannot be null.
		/// </summary>
		THIRD_PARTY_VOLUME_CANNOT_BE_NULL = 7,
		/// <summary>Duplicate tuples of (line item ID, creative ID).
		/// </summary>
		DUPLICATE_LINE_ITEM_AND_CREATIVE = 8,
		/// <summary>Cannot reconcile the <a
		/// href='ReconciliationReportRow'>ReconciliationReportRow</a> as the line item ID
		/// and the creative ID association is invalid.
		/// </summary>
		CANNOT_RECONCILE_LINE_ITEM_CREATIVE = 9,
		/// <summary>Third-party days delivered and manual days delivered cannot differ for rows with
		/// same line item ID when line item cost type is CPD.
		/// </summary>
		LINE_ITEM_DAYS_MISMATCH = 10,
		/// <summary><a href='ReconciliationReportRow#billFrom'>ReconciliationReportRow#billFrom</a>
		/// field cannot differ for rows with same line item id when line item cost type is
		/// CPD.
		/// </summary>
		LINE_ITEM_BILL_OFF_OF_MISMATCH = 11,
		/// <summary>The order of the modifying rows in under reconciled status. The row couldn't be
		/// changed.
		/// </summary>
		CANNOT_MODIFY_RECONCILED_ORDER = 12,
		/// <summary>Can not modify across multiple reconciliation reports.
		/// </summary>
		CANNOT_MODIFY_ACROSS_MULTIPLE_RECONCILIATION_REPORTS = 13,
		/// <summary>Can not query across multiple reconciliation reports.
		/// </summary>
		CANNOT_QUERY_ACROSS_MULTIPLE_RECONCILIATION_REPORTS = 16,
		/// <summary>Cannot update reconciled volume when a billable revenue override is set.
		/// </summary>
		CANNOT_UPDATE_VOLUME_WHEN_BILLABLE_REVENUE_OVERRIDDEN = 15,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 14,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ReconciliationOrderReportServiceInterface")]
	public interface ReconciliationOrderReportServiceInterface
	{
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ReconciliationOrderReportPage getReconciliationOrderReportsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationOrderReportPage> getReconciliationOrderReportsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performReconciliationOrderReportAction(Google.Api.Ads.AdManager.v201802.ReconciliationOrderReportAction reconciliationOrderReportAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performReconciliationOrderReportActionAsync(Google.Api.Ads.AdManager.v201802.ReconciliationOrderReportAction reconciliationOrderReportAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ReconciliationOrderReportService.updateReconciliationOrderReportsResponse updateReconciliationOrderReports(Wrappers.ReconciliationOrderReportService.updateReconciliationOrderReportsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ReconciliationOrderReportService.updateReconciliationOrderReportsResponse> updateReconciliationOrderReportsAsync(Wrappers.ReconciliationOrderReportService.updateReconciliationOrderReportsRequest request);
	}


	/// <summary>Represents the actions that can be performed on the <a
	/// href='ReconciliationOrderReport'>ReconciliationOrderReport</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RevertReconciliationOrderReports))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SubmitReconciliationOrderReports))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class ReconciliationOrderReportAction {
	}


	/// <summary>The action used to revert the reconciliation on the <a
	/// href='ReconciliationOrderReport'>ReconciliationOrderReport</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RevertReconciliationOrderReports : ReconciliationOrderReportAction {
	}


	/// <summary>The action used for submit the reconciliation on the <a
	/// href='ReconciliationOrderReport'>ReconciliationOrderReport</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SubmitReconciliationOrderReports : ReconciliationOrderReportAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ReconciliationOrderReportServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ReconciliationOrderReportServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for retrieving, reconciling, and reverting <a
	/// href='ReconciliationOrderReport'>ReconciliationOrderReport</a> objects.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ReconciliationOrderReportService : AdManagerSoapClient<IReconciliationOrderReportService>, IReconciliationOrderReportService {
		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationOrderReportService"/> class. </summary>
		public ReconciliationOrderReportService() {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationOrderReportService"/> class. </summary>
		public ReconciliationOrderReportService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationOrderReportService"/> class. </summary>
		public ReconciliationOrderReportService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationOrderReportService"/> class. </summary>
		public ReconciliationOrderReportService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationOrderReportService"/> class. </summary>
		public ReconciliationOrderReportService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		/// <summary>Gets an <a
		/// href='ReconciliationOrderReportPage'>ReconciliationOrderReportPage</a> of <a
		/// href='ReconciliationOrderReport'>ReconciliationOrderReport</a> objects that
		/// satisfy the given <a href='Statement#query'>Statement#query</a>. The following
		/// fields are supported for filtering: <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>reconciliationReportId</code></td> <td><a
		/// href='ReconciliationOrderReport#reconciliationReportId'>ReconciliationOrderReport#reconciliationReportId</a></td>
		/// </tr> <tr> <td><code>id</code></td> <td><a
		/// href='ReconciliationOrderReport#id'>ReconciliationOrderReport#id</a></td> </tr>
		/// <tr> <td><code>orderId</code></td> <td><a
		/// href='ReconciliationOrderReport#orderId'>ReconciliationOrderReport#orderId</a></td>
		/// </tr> <tr> <td><code>proposalId</code></td> <td><a
		/// href='ReconciliationOrderReport#proposalId'>ReconciliationOrderReport#proposalId</a></td>
		/// </tr> <tr> <td><code>status</code></td> <td><a
		/// href='ReconciliationOrderReport#status'>ReconciliationOrderReport#status</a></td>
		/// </tr> <tr> <td><code>submissionDateTime</code></td> <td><a
		/// href='ReconciliationOrderReport#submissionDateTime'>ReconciliationOrderReport#submissionDateTime</a></td>
		/// </tr> <tr> <td><code>submitterId</code></td> <td><a
		/// href='ReconciliationOrderReport#submitterId'>ReconciliationOrderReport#submitterId</a></td>
		/// </tr> </table> The <code>reconciliationReportId</code> field is required and can
		/// only be combined with an <code>AND</code> to other conditions. Furthermore, the
		/// results may only belong to one <a
		/// href='ReconciliationReport'>ReconciliationReport</a>.
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of reconciliation order reports.</param>
		/// <returns>the reconciliation order reports that match the given filter.</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ReconciliationOrderReportPage getReconciliationOrderReportsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getReconciliationOrderReportsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationOrderReportPage> getReconciliationOrderReportsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getReconciliationOrderReportsByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on the <a
		/// href='ReconciliationOrderReport'>ReconciliationOrderReport</a> objects that
		/// match the given <a href='Statement#query'>Statement#query</a>. The following
		/// fields are supported for filtering: <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>orderId</code></td> <td><a
		/// href='ReconciliationOrderReport#orderId'>ReconciliationOrderReport#orderId</a></td>
		/// </tr> <tr> <td><code>proposalId</code></td> <td><a
		/// href='ReconciliationOrderReport#proposalId'>ReconciliationOrderReport#proposalId</a></td>
		/// </tr> <tr> <td><code>reconciliationReportId</code></td> <td><a
		/// href='ReconciliationOrderReport#reconciliationReportId'>ReconciliationOrderReport#reconciliationReportId</a></td>
		/// </tr> </table> The following statement patterns are supported: <ul>
		/// <li>reconciliationReportId = :reconciliationReportId AND orderId = :orderId</li>
		/// <li>reconciliationReportId = :reconciliationReportId AND proposalId =
		/// :proposalId</li> <li>reconciliationReportId = :reconciliationReportId AND
		/// (orderId IN (...) OR proposalId IN (...))</li> </ul> The IN clause could be
		/// expanded to multiple OR expressions like (orderId = :orderId OR orderId =
		/// :orderId OR ...) Only orders to which the API user has access will be included.
		/// </summary><param name='reconciliationOrderReportAction'>the action to perform.</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of orders and one reconciliation report.</param>
		/// <returns>the result of the action performed.</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performReconciliationOrderReportAction(Google.Api.Ads.AdManager.v201802.ReconciliationOrderReportAction reconciliationOrderReportAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performReconciliationOrderReportAction(reconciliationOrderReportAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performReconciliationOrderReportActionAsync(Google.Api.Ads.AdManager.v201802.ReconciliationOrderReportAction reconciliationOrderReportAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performReconciliationOrderReportActionAsync(reconciliationOrderReportAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ReconciliationOrderReportService.updateReconciliationOrderReportsResponse Google.Api.Ads.AdManager.v201802.ReconciliationOrderReportServiceInterface.updateReconciliationOrderReports(Wrappers.ReconciliationOrderReportService.updateReconciliationOrderReportsRequest request) {
			return base.Channel.updateReconciliationOrderReports(request);
		}

		/// <summary>Updates a list of <a href='ReconciliationOrderReport'>reconciliation order
		/// reports</a> which belong to a <a
		/// href='ReconciliationReport'>ReconciliationReport</a>.
		/// </summary><param name='reconciliationOrderReports'>a list of <a
		/// href='ReconciliationOrderReport'>reconciliation order reports</a> to
		/// update</param>
		/// <returns>the updated reconciliation order reports</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ReconciliationOrderReport[] updateReconciliationOrderReports(Google.Api.Ads.AdManager.v201802.ReconciliationOrderReport[] reconciliationOrderReports) {
			Wrappers.ReconciliationOrderReportService.updateReconciliationOrderReportsRequest inValue = new Wrappers.ReconciliationOrderReportService.updateReconciliationOrderReportsRequest();
			inValue.reconciliationOrderReports = reconciliationOrderReports;
			Wrappers.ReconciliationOrderReportService.updateReconciliationOrderReportsResponse retVal = ((Google.Api.Ads.AdManager.v201802.ReconciliationOrderReportServiceInterface)(this)).updateReconciliationOrderReports(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ReconciliationOrderReportService.updateReconciliationOrderReportsResponse> Google.Api.Ads.AdManager.v201802.ReconciliationOrderReportServiceInterface.updateReconciliationOrderReportsAsync(Wrappers.ReconciliationOrderReportService.updateReconciliationOrderReportsRequest request) {
			return base.Channel.updateReconciliationOrderReportsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationOrderReport[]> updateReconciliationOrderReportsAsync(Google.Api.Ads.AdManager.v201802.ReconciliationOrderReport[] reconciliationOrderReports) {
			Wrappers.ReconciliationOrderReportService.updateReconciliationOrderReportsRequest inValue = new Wrappers.ReconciliationOrderReportService.updateReconciliationOrderReportsRequest();
			inValue.reconciliationOrderReports = reconciliationOrderReports;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationOrderReport[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ReconciliationOrderReportServiceInterface)(this)).updateReconciliationOrderReportsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.ReconciliationLineItemReportService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateReconciliationLineItemReports", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateReconciliationLineItemReportsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("reconciliationLineItemReports")]
			public Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReport[] reconciliationLineItemReports;

			/// <summary> Creates a new instance of the <see
			/// cref="updateReconciliationLineItemReportsRequest"/> class. </summary>
			public updateReconciliationLineItemReportsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateReconciliationLineItemReportsRequest"/> class. </summary>
			public updateReconciliationLineItemReportsRequest(Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReport[] reconciliationLineItemReports) {
				this.reconciliationLineItemReports = reconciliationLineItemReports;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateReconciliationLineItemReportsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateReconciliationLineItemReportsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReport[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateReconciliationLineItemReportsResponse"/> class. </summary>
			public updateReconciliationLineItemReportsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateReconciliationLineItemReportsResponse"/> class. </summary>
			public updateReconciliationLineItemReportsResponse(Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReport[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>Billable revenue overrides for a <a
	/// href='ReconciliationLineItemReport'>ReconciliationLineItemReport</a> to be used
	/// instead of the Google calculated ones.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class BillableRevenueOverrides {
		private Money netBillableRevenueOverrideField;

		private Money grossBillableRevenueOverrideField;

		private Money billableRevenueOverrideField;

		/// <summary>The overridden <a
		/// href='ReconciliationLineItemReport#netBillableRevenue'>ReconciliationLineItemReport#netBillableRevenue</a>.
		/// <p>If the <a
		/// href='ReconciliationLineItemReport'>ReconciliationLineItemReport</a> data is for
		/// a <a href='ProposalLineItem'>ProposalLineItem</a> and the <a
		/// href='ReconciliationLineItemReport#pricingModel'>ReconciliationLineItemReport#pricingModel</a>
		/// is <a href='PricingModel#GROSS'>PricingModel#GROSS</a>, then this value will be
		/// calculated using the <a
		/// href='#billableRevenueOverride'>#billableRevenueOverride</a> and the proposal
		/// line item's billing settings. Otherwise, the value of this field will be the
		/// same as the <a href='#billableRevenueOverride'>#billableRevenueOverride</a>.</p>
		/// <p>This value is read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public Money netBillableRevenueOverride {
			get {
				return this.netBillableRevenueOverrideField;
			}
			set {
				this.netBillableRevenueOverrideField = value;
			}
		}

		/// <summary>The overriden <a
		/// href='ReconciliationLineItemReport#grossBillableRevenue'>ReconciliationLineItemReport#grossBillableRevenue</a>.
		/// <p>The value of this field will always be the same as what is set in the <a
		/// href='#billableRevenueOverride'>#billableRevenueOverride</a>.</p> <p>This value
		/// is read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public Money grossBillableRevenueOverride {
			get {
				return this.grossBillableRevenueOverrideField;
			}
			set {
				this.grossBillableRevenueOverrideField = value;
			}
		}

		/// <summary>The manually entered billable revenue override, which will be used to calculate
		/// both the <a href='#netBillableRevenueOverride'>#netBillableRevenueOverride</a>
		/// and the <a
		/// href='#grossBillableRevenueOverride'>#grossBillableRevenueOverride</a>. This
		/// value is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public Money billableRevenueOverride {
			get {
				return this.billableRevenueOverrideField;
			}
			set {
				this.billableRevenueOverrideField = value;
			}
		}
	}


	/// <summary>Contains reconciliation data of a <a href='LineItem'>LineItem</a> and/or <a
	/// href='ProposalLineItem'>ProposalLineItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReconciliationLineItemReport {
		private long idField;

		private bool idFieldSpecified;

		private long reconciliationReportIdField;

		private bool reconciliationReportIdFieldSpecified;

		private long orderIdField;

		private bool orderIdFieldSpecified;

		private long proposalIdField;

		private bool proposalIdFieldSpecified;

		private long lineItemIdField;

		private bool lineItemIdFieldSpecified;

		private long proposalLineItemIdField;

		private bool proposalLineItemIdFieldSpecified;

		private RateType rateTypeField;

		private bool rateTypeFieldSpecified;

		private Money netRateField;

		private Money grossRateField;

		private PricingModel pricingModelField;

		private bool pricingModelFieldSpecified;

		private long dfpVolumeField;

		private bool dfpVolumeFieldSpecified;

		private long thirdPartyVolumeField;

		private bool thirdPartyVolumeFieldSpecified;

		private long manualVolumeField;

		private bool manualVolumeFieldSpecified;

		private BillFrom reconciliationSourceField;

		private bool reconciliationSourceFieldSpecified;

		private long reconciledVolumeField;

		private bool reconciledVolumeFieldSpecified;

		private long capVolumeField;

		private bool capVolumeFieldSpecified;

		private long rolloverVolumeField;

		private bool rolloverVolumeFieldSpecified;

		private long billableVolumeField;

		private bool billableVolumeFieldSpecified;

		private Money netBillableRevenueField;

		private Money grossBillableRevenueField;

		private BillableRevenueOverrides billableRevenueOverridesField;

		/// <summary>Uniquely identifies the <code>ReconciliationLineItemReport</code>. This value is
		/// read-only and assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The ID of the <a href='ReconciliationReport'>ReconciliationReport</a> this
		/// <code></code> belongs to. This value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long reconciliationReportId {
			get {
				return this.reconciliationReportIdField;
			}
			set {
				this.reconciliationReportIdField = value;
				this.reconciliationReportIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="reconciliationReportId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reconciliationReportIdSpecified {
			get {
				return this.reconciliationReportIdFieldSpecified;
			}
			set {
				this.reconciliationReportIdFieldSpecified = value;
			}
		}

		/// <summary>If this reconciliation data is for a <a href='LineItem'>LineItem</a>, then this
		/// contains the ID of the order that line item belongs to. Otherwise, this field
		/// will have a value of 0. This value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public long orderId {
			get {
				return this.orderIdField;
			}
			set {
				this.orderIdField = value;
				this.orderIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="orderId" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool orderIdSpecified {
			get {
				return this.orderIdFieldSpecified;
			}
			set {
				this.orderIdFieldSpecified = value;
			}
		}

		/// <summary>If this reconciliation data is for a <a
		/// href='ProposalLineItem'>ProposalLineItem</a>, then this contains the ID of the
		/// proposal that proposal line item belongs to. Otherwise, this field will have a
		/// value of 0. This value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public long proposalId {
			get {
				return this.proposalIdField;
			}
			set {
				this.proposalIdField = value;
				this.proposalIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="proposalId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool proposalIdSpecified {
			get {
				return this.proposalIdFieldSpecified;
			}
			set {
				this.proposalIdFieldSpecified = value;
			}
		}

		/// <summary>If this reconciliation data is for a <a href='LineItem'>LineItem</a>, then this
		/// contains that line item's ID. Otherwise, this field will have a value of 0. This
		/// value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public long lineItemId {
			get {
				return this.lineItemIdField;
			}
			set {
				this.lineItemIdField = value;
				this.lineItemIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="lineItemId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lineItemIdSpecified {
			get {
				return this.lineItemIdFieldSpecified;
			}
			set {
				this.lineItemIdFieldSpecified = value;
			}
		}

		/// <summary>If this reconciliation data is for a <a
		/// href='ProposalLineItem'>ProposalLineItem</a>, then this contains that proposal
		/// line item's ID. Otherwise, this field will have a value of 0. This value is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public long proposalLineItemId {
			get {
				return this.proposalLineItemIdField;
			}
			set {
				this.proposalLineItemIdField = value;
				this.proposalLineItemIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="proposalLineItemId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool proposalLineItemIdSpecified {
			get {
				return this.proposalLineItemIdFieldSpecified;
			}
			set {
				this.proposalLineItemIdFieldSpecified = value;
			}
		}

		/// <summary>The <a href='RateType'>RateType</a> of the <a href='LineItem'>LineItem</a>
		/// and/or <a href='ProposalLineItem'>ProposalLineItem</a> this reconciliation data
		/// is for. This value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public RateType rateType {
			get {
				return this.rateTypeField;
			}
			set {
				this.rateTypeField = value;
				this.rateTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="rateType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool rateTypeSpecified {
			get {
				return this.rateTypeFieldSpecified;
			}
			set {
				this.rateTypeFieldSpecified = value;
			}
		}

		/// <summary>The <a href='Money'>net rate</a> of the <a href='LineItem'>LineItem</a> and/or
		/// <a href='ProposalLineItem'>ProposalLineItem</a> this reconciliation data is for.
		/// This value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public Money netRate {
			get {
				return this.netRateField;
			}
			set {
				this.netRateField = value;
			}
		}

		/// <summary>If this reconciliation data is for a <a
		/// href='ProposalLineItem'>ProposalLineItem</a> and the <a
		/// href='#pricingModel'>#pricingModel</a> is <a
		/// href='PricingModel#GROSS'>PricingModel#GROSS</a>, then this contains the <a
		/// href='Money'>gross rate</a> of the proposal line item. Otherwise, the value of
		/// this field will be the same as the <a href='#netRate'>#netRate</a>. This value
		/// is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public Money grossRate {
			get {
				return this.grossRateField;
			}
			set {
				this.grossRateField = value;
			}
		}

		/// <summary>If this reconciliation data is for a <a
		/// href='ProposalLineItem'>ProposalLineItem</a>, then this contains that proposal
		/// line item's proposal's pricing model. Otherwise, the value of this field will be
		/// <a href='PricingModel#NET'>PricingModel#NET</a>. This value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public PricingModel pricingModel {
			get {
				return this.pricingModelField;
			}
			set {
				this.pricingModelField = value;
				this.pricingModelSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="pricingModel" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool pricingModelSpecified {
			get {
				return this.pricingModelFieldSpecified;
			}
			set {
				this.pricingModelFieldSpecified = value;
			}
		}

		/// <summary>The volume recorded by the DoubleClick for Publishers ad server. The meaning of
		/// this value depends on the <a href='#rateType'>#rateType</a>, for example if the
		/// <a href='#rateType'>#rateType</a> is <a href='RateType#CPC'>RateType#CPC</a>, it
		/// represents clicks; if the <a href='#rateType'>#rateType</a> is <a
		/// href='RateType#CPM'>RateType#CPM</a>, it represents impressions; if the <a
		/// href='#rateType'>#rateType</a> is <a href='RateType#CPD'>RateType#CPD</a>, it
		/// represents line item days. This value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public long dfpVolume {
			get {
				return this.dfpVolumeField;
			}
			set {
				this.dfpVolumeField = value;
				this.dfpVolumeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="dfpVolume"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool dfpVolumeSpecified {
			get {
				return this.dfpVolumeFieldSpecified;
			}
			set {
				this.dfpVolumeFieldSpecified = value;
			}
		}

		/// <summary>The volume recorded by the third-party ad server. The meaning of this value
		/// depends on the <a href='#rateType'>#rateType</a>, for example if the <a
		/// href='#rateType'>#rateType</a> is <a href='RateType#CPC'>RateType#CPC</a>, it
		/// represents clicks; if the <a href='#rateType'>#rateType</a> is <a
		/// href='RateType#CPM'>RateType#CPM</a>, it represents impressions; if the <a
		/// href='#rateType'>#rateType</a> is <a href='RateType#CPD'>RateType#CPD</a>, it
		/// represents line item days. This value is optional and defaults to
		/// <code>null</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 11)]
		public long thirdPartyVolume {
			get {
				return this.thirdPartyVolumeField;
			}
			set {
				this.thirdPartyVolumeField = value;
				this.thirdPartyVolumeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="thirdPartyVolume" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool thirdPartyVolumeSpecified {
			get {
				return this.thirdPartyVolumeFieldSpecified;
			}
			set {
				this.thirdPartyVolumeFieldSpecified = value;
			}
		}

		/// <summary>A manually entered volume. The meaning of this value depends on the <a
		/// href='#rateType'>#rateType</a>, for example if the <a
		/// href='#rateType'>#rateType</a> is <a href='RateType#CPC'>RateType#CPC</a>, it
		/// represents clicks; if the <a href='#rateType'>#rateType</a> is <a
		/// href='RateType#CPM'>RateType#CPM</a>, it represents impressions; if the <a
		/// href='#rateType'>#rateType</a> is <a href='RateType#CPD'>RateType#CPD</a>, it
		/// represents line item days. This value is optional and defaults to
		/// <code>null</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 12)]
		public long manualVolume {
			get {
				return this.manualVolumeField;
			}
			set {
				this.manualVolumeField = value;
				this.manualVolumeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="manualVolume" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool manualVolumeSpecified {
			get {
				return this.manualVolumeFieldSpecified;
			}
			set {
				this.manualVolumeFieldSpecified = value;
			}
		}

		/// <summary>Specifies which of <a href='#dfpVolume'>#dfpVolume</a>, <a
		/// href='#thirdPartyVolume'>#thirdPartyVolume</a>, or <a
		/// href='#manualVolume'>#manualVolume</a> should be used as the <a
		/// href='#reconciledVolume'>#reconciledVolume</a>. The value is optional. If this
		/// reconciliation data is for a <a href='ProposalLineItem'>ProposalLineItem</a>
		/// then this will default to the proposal line item's <a
		/// href='ProposalLineItem#billingSource'>ProposalLineItem#billingSource</a>.
		/// Otherwise, this will default to <a href='BillFrom#DFP'>BillFrom#DFP</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 13)]
		public BillFrom reconciliationSource {
			get {
				return this.reconciliationSourceField;
			}
			set {
				this.reconciliationSourceField = value;
				this.reconciliationSourceSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="reconciliationSource" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reconciliationSourceSpecified {
			get {
				return this.reconciliationSourceFieldSpecified;
			}
			set {
				this.reconciliationSourceFieldSpecified = value;
			}
		}

		/// <summary>The reconciled volume, which is a <i>view</i> of one of the other volume fields
		/// depending on what the <a href='#reconciliationSource'>#reconciliationSource</a>
		/// is set to. The different possibilities are as follows: <table> <tr> <th><a
		/// href='#reconciliationSource'>Reconciliation source</a></th> <th>Value of this
		/// field</th> </tr> <tr> <td><a href='BillFrom#MANUAL'>BillFrom#MANUAL</a></td>
		/// <td><a href='#manualVolume'>#manualVolume</a></td> </tr> <tr> <td><a
		/// href='BillFrom#DFP'>BillFrom#DFP</a></td> <td><a
		/// href='#dfpVolume'>#dfpVolume</a></td> </tr> <tr> <td><a
		/// href='BillFrom#THIRD_PARTY'>BillFrom#THIRD_PARTY</a></td> <td><a
		/// href='#thirdPartyVolume'>#thirdPartyVolume</a></td> </tr> <tr> <td><a
		/// href='BillFrom#DEFAULT'>BillFrom#DEFAULT</a></td> <td>Calculated by Google to be
		/// either <a href='#dfpVolume'>#dfpVolume</a> or <a
		/// href='#thirdPartyVolume'>#thirdPartyVolume</a>.</td> </tr> </table> The meaning
		/// of this value depends on the <a href='#rateType'>#rateType</a>, for example if
		/// the <a href='#rateType'>#rateType</a> is <a
		/// href='RateType#CPC'>RateType#CPC</a>, it represents clicks; if the <a
		/// href='#rateType'>#rateType</a> is <a href='RateType#CPM'>RateType#CPM</a>, it
		/// represents impressions; if the <a href='#rateType'>#rateType</a> is <a
		/// href='RateType#CPD'>RateType#CPD</a>, it represents line item days. This value
		/// is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 14)]
		public long reconciledVolume {
			get {
				return this.reconciledVolumeField;
			}
			set {
				this.reconciledVolumeField = value;
				this.reconciledVolumeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="reconciledVolume" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reconciledVolumeSpecified {
			get {
				return this.reconciledVolumeFieldSpecified;
			}
			set {
				this.reconciledVolumeFieldSpecified = value;
			}
		}

		/// <summary>If this reconciliation data is for a <a
		/// href='ProposalLineItem'>ProposalLineItem</a>, then this contains the cap volume,
		/// which is calculated based on the proposal line item's billing settings (may be
		/// <code>null</code> for certain billing settings). Otherwise, this is
		/// <code>null</code>. This value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 15)]
		public long capVolume {
			get {
				return this.capVolumeField;
			}
			set {
				this.capVolumeField = value;
				this.capVolumeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="capVolume"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool capVolumeSpecified {
			get {
				return this.capVolumeFieldSpecified;
			}
			set {
				this.capVolumeFieldSpecified = value;
			}
		}

		/// <summary>If this reconciliation data is for a <a
		/// href='ProposalLineItem'>ProposalLineItem</a>, then this contains the rollover
		/// volume from previous cycles, which is calculated based on the proposal line
		/// item's billing settings (may be <code>null</code> for certain billing settings).
		/// Otherwise, this is <code>null</code>. This value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 16)]
		public long rolloverVolume {
			get {
				return this.rolloverVolumeField;
			}
			set {
				this.rolloverVolumeField = value;
				this.rolloverVolumeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="rolloverVolume" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool rolloverVolumeSpecified {
			get {
				return this.rolloverVolumeFieldSpecified;
			}
			set {
				this.rolloverVolumeFieldSpecified = value;
			}
		}

		/// <summary>If this reconciliation data is for a <a
		/// href='ProposalLineItem'>ProposalLineItem</a>, then this contains the billable
		/// volume, which is calculated from the <a
		/// href='#reconciledVolume'>#reconciledVolume</a> and the proposal line item's
		/// billing settings (may be <code>null</code> for certain billing settings).
		/// Otherwise, the value of this field will be the same as the <a
		/// href='#reconciledVolume'>#reconciledVolume</a>. This value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 17)]
		public long billableVolume {
			get {
				return this.billableVolumeField;
			}
			set {
				this.billableVolumeField = value;
				this.billableVolumeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="billableVolume" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool billableVolumeSpecified {
			get {
				return this.billableVolumeFieldSpecified;
			}
			set {
				this.billableVolumeFieldSpecified = value;
			}
		}

		/// <summary>The net billable revenue. If this reconciliation data is for a <a
		/// href='ProposalLineItem'>ProposalLineItem</a>, this is calculated from the <a
		/// href='#netRate'>#netRate</a>, <a href='#billableVolume'>#billableVolume</a>, and
		/// the proposal line item's billing settings. This may be <code>null</code> for
		/// certain billing settings. Otherwise, this is calculated from the <a
		/// href='#netRate'>#netRate</a> and <a href='#billableVolume'>#billableVolume</a>.
		/// This value is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 18)]
		public Money netBillableRevenue {
			get {
				return this.netBillableRevenueField;
			}
			set {
				this.netBillableRevenueField = value;
			}
		}

		/// <summary>The gross billable revenue. If this reconciliation data is for a <a
		/// href='ProposalLineItem'>ProposalLineItem</a> and the <a
		/// href='#pricingModel'>#pricingModel</a> is <a
		/// href='PricingModel#GROSS'>PricingModel#GROSS</a>, this is calculated from the <a
		/// href='#grossRate'>#grossRate</a>, <a href='#billableVolume'>#billableVolume</a>,
		/// and the proposal line item's billing settings. This may be <code>null</code> for
		/// certain billing settings. Otherwise, the value of this field will be the same as
		/// the <a href='#netBillableRevenue'>#netBillableRevenue</a>. This value is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 19)]
		public Money grossBillableRevenue {
			get {
				return this.grossBillableRevenueField;
			}
			set {
				this.grossBillableRevenueField = value;
			}
		}

		/// <summary>Manual overrides for the Google calculated billable revenue fields. If set, it
		/// indicates that these values should be used as the final billable revenue instead
		/// of the Google calculated ones. This value is optional and defaults to
		/// <code>null</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 20)]
		public BillableRevenueOverrides billableRevenueOverrides {
			get {
				return this.billableRevenueOverridesField;
			}
			set {
				this.billableRevenueOverridesField = value;
			}
		}
	}


	/// <summary>Values for which to bill from.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum BillFrom {
		/// <summary>Use default bill from. Google checks whether line item is created in DoubleClick
		/// Sales Manager. If yes, the <a
		/// href='Proposal#billingSource'>Proposal#billingSource</a> will be the billing
		/// source. Otherwise, the <code>DFP</code> will be the billing source.
		/// </summary>
		DEFAULT = 0,
		/// <summary>DFP volume.
		/// </summary>
		DFP = 1,
		/// <summary>Third-party volume.
		/// </summary>
		THIRD_PARTY = 2,
		/// <summary>Manual volume.
		/// </summary>
		MANUAL = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>Captures a page of <a
	/// href='ReconciliationLineItemReport'>ReconciliationLineItemReport</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReconciliationLineItemReportPage {
		private ReconciliationLineItemReport[] resultsField;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		/// <summary>The collection of <a
		/// href='ReconciliationLineItemReport'>ReconciliationLineItemReport</a> objects
		/// contained in this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 0)]
		public ReconciliationLineItemReport[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReportServiceInterface")]
	public interface ReconciliationLineItemReportServiceInterface
	{
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReportPage getReconciliationLineItemReportsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReportPage> getReconciliationLineItemReportsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ReconciliationLineItemReportService.updateReconciliationLineItemReportsResponse updateReconciliationLineItemReports(Wrappers.ReconciliationLineItemReportService.updateReconciliationLineItemReportsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ReconciliationLineItemReportService.updateReconciliationLineItemReportsResponse> updateReconciliationLineItemReportsAsync(Wrappers.ReconciliationLineItemReportService.updateReconciliationLineItemReportsRequest request);
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ReconciliationLineItemReportServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReportServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for retrieving and updating <a
	/// href='ReconciliationLineItemReport'>ReconciliationLineItemReport</a> objects.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ReconciliationLineItemReportService : AdManagerSoapClient<IReconciliationLineItemReportService>, IReconciliationLineItemReportService {
		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationLineItemReportService"/> class. </summary>
		public ReconciliationLineItemReportService() {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationLineItemReportService"/> class. </summary>
		public ReconciliationLineItemReportService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationLineItemReportService"/> class. </summary>
		public ReconciliationLineItemReportService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationLineItemReportService"/> class. </summary>
		public ReconciliationLineItemReportService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationLineItemReportService"/> class. </summary>
		public ReconciliationLineItemReportService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		/// <summary>Gets a <a
		/// href='ReconciliationLineItemReportPage'>ReconciliationLineItemReportPage</a> of
		/// <a href='ReconciliationLineItemReport'>ReconciliationLineItemReport</a> objects
		/// that satisfy the given <a href='Statement#query'>Statement#query</a>. The
		/// following fields are supported for filtering: <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>id</code></td> <td><a
		/// href='ReconciliationLineItemReport#id'>ReconciliationLineItemReport#id</a></td>
		/// </tr> <tr> <td><code>reconciliationReportId</code></td> <td><a
		/// href='ReconciliationLineItemReport#reconciliationReportId'>ReconciliationLineItemReport#reconciliationReportId</a></td>
		/// </tr> <tr> <td><code>orderId</code></td> <td><a
		/// href='ReconciliationLineItemReport#orderId'>ReconciliationLineItemReport#orderId</a></td>
		/// </tr> <tr> <td><code>proposalId</code></td> <td><a
		/// href='ReconciliationLineItemReport#proposalId'>ReconciliationLineItemReport#proposalId</a></td>
		/// </tr> <tr> <td><code>lineItemId</code></td> <td><a
		/// href='ReconciliationLineItemReport#lineItemId'>ReconciliationLineItemReport#lineItemId</a></td>
		/// </tr> <tr> <td><code>proposalLineItemId</code></td> <td><a
		/// href='ReconciliationLineItemReport#proposalLineItemId'>ReconciliationLineItemReport#proposalLineItemId</a></td>
		/// </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter the result</param>
		/// <returns>the <a
		/// href='ReconciliationLineItemReport'>ReconciliationLineItemReport</a> objects
		/// that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReportPage getReconciliationLineItemReportsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getReconciliationLineItemReportsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReportPage> getReconciliationLineItemReportsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getReconciliationLineItemReportsByStatementAsync(filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ReconciliationLineItemReportService.updateReconciliationLineItemReportsResponse Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReportServiceInterface.updateReconciliationLineItemReports(Wrappers.ReconciliationLineItemReportService.updateReconciliationLineItemReportsRequest request) {
			return base.Channel.updateReconciliationLineItemReports(request);
		}

		/// <summary>Updates a list of <a
		/// href='ReconciliationLineItemReport'>ReconciliationLineItemReport</a> objects
		/// which belong to same <a href='ReconciliationReport'>ReconciliationReport</a>.
		/// </summary><param name='reconciliationLineItemReports'>a list of <a
		/// href='ReconciliationLineItemReport'>reconciliation line item reports</a> to
		/// update</param>
		/// <returns>the updated <a
		/// href='ReconciliationLineItemReport'>ReconciliationLineItemReport</a>
		/// objects</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReport[] updateReconciliationLineItemReports(Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReport[] reconciliationLineItemReports) {
			Wrappers.ReconciliationLineItemReportService.updateReconciliationLineItemReportsRequest inValue = new Wrappers.ReconciliationLineItemReportService.updateReconciliationLineItemReportsRequest();
			inValue.reconciliationLineItemReports = reconciliationLineItemReports;
			Wrappers.ReconciliationLineItemReportService.updateReconciliationLineItemReportsResponse retVal = ((Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReportServiceInterface)(this)).updateReconciliationLineItemReports(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ReconciliationLineItemReportService.updateReconciliationLineItemReportsResponse> Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReportServiceInterface.updateReconciliationLineItemReportsAsync(Wrappers.ReconciliationLineItemReportService.updateReconciliationLineItemReportsRequest request) {
			return base.Channel.updateReconciliationLineItemReportsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReport[]> updateReconciliationLineItemReportsAsync(Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReport[] reconciliationLineItemReports) {
			Wrappers.ReconciliationLineItemReportService.updateReconciliationLineItemReportsRequest inValue = new Wrappers.ReconciliationLineItemReportService.updateReconciliationLineItemReportsRequest();
			inValue.reconciliationLineItemReports = reconciliationLineItemReports;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReport[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReportServiceInterface)(this)).updateReconciliationLineItemReportsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.ReconciliationReportService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateReconciliationReports", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateReconciliationReportsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("reconciliationReports")]
			public Google.Api.Ads.AdManager.v201802.ReconciliationReport[] reconciliationReports;

			/// <summary> Creates a new instance of the <see
			/// cref="updateReconciliationReportsRequest"/> class. </summary>
			public updateReconciliationReportsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateReconciliationReportsRequest"/> class. </summary>
			public updateReconciliationReportsRequest(Google.Api.Ads.AdManager.v201802.ReconciliationReport[] reconciliationReports) {
				this.reconciliationReports = reconciliationReports;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateReconciliationReportsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateReconciliationReportsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ReconciliationReport[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateReconciliationReportsResponse"/> class. </summary>
			public updateReconciliationReportsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateReconciliationReportsResponse"/> class. </summary>
			public updateReconciliationReportsResponse(Google.Api.Ads.AdManager.v201802.ReconciliationReport[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>A <code>ReconciliationReport</code> represents a report that can be reconciled.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReconciliationReport {
		private long idField;

		private bool idFieldSpecified;

		private ReconciliationReportStatus statusField;

		private bool statusFieldSpecified;

		private Date startDateField;

		private string notesField;

		/// <summary>The unique ID of the <code>ReconciliationReport</code>. This attribute is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The reconciliation state of the <code>ReconciliationReport</code>. This
		/// attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public ReconciliationReportStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>The start date of a billing period. Billing period is monthly. This attribute is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public Date startDate {
			get {
				return this.startDateField;
			}
			set {
				this.startDateField = value;
			}
		}

		/// <summary>The reconciliation report notes. This attribute is optional and has a maximum
		/// length of 65535.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string notes {
			get {
				return this.notesField;
			}
			set {
				this.notesField = value;
			}
		}
	}


	/// <summary>A <code>ReconciliationReportStatus</code> represents the status of a <a
	/// href='ReconciliationReport'>ReconciliationReport</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ReconciliationReportStatus {
		/// <summary>The starting status of a reconciliation report. Reconciliation reports are
		/// updatable in the <code>DRAFT</code> state.
		/// </summary>
		DRAFT = 0,
		/// <summary>The final status of a reconciliation report. Reconciliation reports are not
		/// updatable in the <code>RECONCILED</code> state.
		/// </summary>
		RECONCILED = 1,
		/// <summary>A similar status as <code>DRAFT</code>. Reconciliation reports are updatable in
		/// the <code>REVERTED</code> state.
		/// </summary>
		REVERTED = 2,
		/// <summary>It indicates that the reconciliation report is not ready for various of reasons.
		/// Reconciliation reports in the <code>PENDING</code> state can't be viewed in the
		/// DoubleClick for Publisher UI.
		/// </summary>
		PENDING = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>Captures a page of <a href='ReconciliationReport'>ReconciliationReport</a>
	/// objects
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReconciliationReportPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private ReconciliationReport[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of reconciliation reports contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public ReconciliationReport[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>The API errors for reconciliation CSV import.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReconciliationImportError : ApiError {
		private ReconciliationImportErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ReconciliationImportErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ReconciliationImportError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ReconciliationImportErrorReason {
		/// <summary>The imported CSV missing some editable and essential columns.
		/// </summary>
		MISSING_EDITABLE_COLUMN = 0,
		/// <summary>The imported CSV columns count doesn't equal with defined columns count.
		/// </summary>
		INCONSISTENT_IMPORT_COLUMNS = 1,
		/// <summary>The imported CSV column value cannot be converted to defined entity type.
		/// </summary>
		COLUMN_CONVERSION_TYPE_ERROR = 2,
		/// <summary>The imported CSV column values count are less or more than field headers count.
		/// </summary>
		INCONSISTENT_COLUMNS_COUNT = 3,
		/// <summary>The imported CSV cause an internal error which is out of expectation.
		/// </summary>
		IMPORT_INTERNAL_ERROR = 4,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 5,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ReconciliationReportServiceInterface")]
	public interface ReconciliationReportServiceInterface
	{
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ReconciliationReportPage getReconciliationReportsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationReportPage> getReconciliationReportsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ReconciliationReportService.updateReconciliationReportsResponse updateReconciliationReports(Wrappers.ReconciliationReportService.updateReconciliationReportsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ReconciliationReportService.updateReconciliationReportsResponse> updateReconciliationReportsAsync(Wrappers.ReconciliationReportService.updateReconciliationReportsRequest request);
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ReconciliationReportServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ReconciliationReportServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for retrieving, submitting and reverting the <a
	/// href='ReconciliationReport'>ReconciliationReport</a> objects. <p>A <a
	/// href='ReconciliationReport'>ReconciliationReport</a> is a group of <a
	/// href='ReconciliationReportRow'>ReconciliationReportRow</a> objects.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ReconciliationReportService : AdManagerSoapClient<IReconciliationReportService>, IReconciliationReportService {
		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationReportService"/> class. </summary>
		public ReconciliationReportService() {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationReportService"/> class. </summary>
		public ReconciliationReportService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationReportService"/> class. </summary>
		public ReconciliationReportService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationReportService"/> class. </summary>
		public ReconciliationReportService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationReportService"/> class. </summary>
		public ReconciliationReportService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		/// <summary>Gets an <a href='ReconciliationReportPage'>ReconciliationReportPage</a> of <a
		/// href='ReconciliationReport'>ReconciliationReport</a> objects that satisfy the
		/// given <a href='Statement#query'>Statement#query</a>. The following fields are
		/// supported for filtering. <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='ReconciliationReport#id'>ReconciliationReport#id</a></td> </tr> <tr>
		/// <td><code>status</code></td> <td><a
		/// href='ReconciliationReport#status'>ReconciliationReport#status</a></td> </tr>
		/// <tr> <td><code>startDate</code></td> <td><a
		/// href='ReconciliationReport#startDate'>ReconciliationReport#startDate</a></td>
		/// </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of reconciliation reports</param>
		/// <returns>the reconciliation reports that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ReconciliationReportPage getReconciliationReportsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getReconciliationReportsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationReportPage> getReconciliationReportsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getReconciliationReportsByStatementAsync(filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ReconciliationReportService.updateReconciliationReportsResponse Google.Api.Ads.AdManager.v201802.ReconciliationReportServiceInterface.updateReconciliationReports(Wrappers.ReconciliationReportService.updateReconciliationReportsRequest request) {
			return base.Channel.updateReconciliationReports(request);
		}

		/// <summary>Updates the specified <a href='ReconciliationReport'>ReconciliationReport</a>
		/// objects.
		/// </summary><param name='reconciliationReports'>the reconciliation reports to update</param>
		/// <returns>the updated reconciliation reports</returns>
		/// ApiException
		public virtual Google.Api.Ads.AdManager.v201802.ReconciliationReport[] updateReconciliationReports(Google.Api.Ads.AdManager.v201802.ReconciliationReport[] reconciliationReports) {
			Wrappers.ReconciliationReportService.updateReconciliationReportsRequest inValue = new Wrappers.ReconciliationReportService.updateReconciliationReportsRequest();
			inValue.reconciliationReports = reconciliationReports;
			Wrappers.ReconciliationReportService.updateReconciliationReportsResponse retVal = ((Google.Api.Ads.AdManager.v201802.ReconciliationReportServiceInterface)(this)).updateReconciliationReports(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ReconciliationReportService.updateReconciliationReportsResponse> Google.Api.Ads.AdManager.v201802.ReconciliationReportServiceInterface.updateReconciliationReportsAsync(Wrappers.ReconciliationReportService.updateReconciliationReportsRequest request) {
			return base.Channel.updateReconciliationReportsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationReport[]> updateReconciliationReportsAsync(Google.Api.Ads.AdManager.v201802.ReconciliationReport[] reconciliationReports) {
			Wrappers.ReconciliationReportService.updateReconciliationReportsRequest inValue = new Wrappers.ReconciliationReportService.updateReconciliationReportsRequest();
			inValue.reconciliationReports = reconciliationReports;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationReport[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ReconciliationReportServiceInterface)(this)).updateReconciliationReportsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.AdRuleService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createAdRules", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createAdRulesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("adRules")]
			public Google.Api.Ads.AdManager.v201802.AdRule[] adRules;

			/// <summary> Creates a new instance of the <see cref="createAdRulesRequest"/>
			/// class. </summary>
			public createAdRulesRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createAdRulesRequest"/>
			/// class. </summary>
			public createAdRulesRequest(Google.Api.Ads.AdManager.v201802.AdRule[] adRules) {
				this.adRules = adRules;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createAdRulesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createAdRulesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.AdRule[] rval;

			/// <summary> Creates a new instance of the <see cref="createAdRulesResponse"/>
			/// class. </summary>
			public createAdRulesResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createAdRulesResponse"/>
			/// class. </summary>
			public createAdRulesResponse(Google.Api.Ads.AdManager.v201802.AdRule[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateAdRules", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateAdRulesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("adRules")]
			public Google.Api.Ads.AdManager.v201802.AdRule[] adRules;

			/// <summary> Creates a new instance of the <see cref="updateAdRulesRequest"/>
			/// class. </summary>
			public updateAdRulesRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updateAdRulesRequest"/>
			/// class. </summary>
			public updateAdRulesRequest(Google.Api.Ads.AdManager.v201802.AdRule[] adRules) {
				this.adRules = adRules;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateAdRulesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateAdRulesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.AdRule[] rval;

			/// <summary> Creates a new instance of the <see cref="updateAdRulesResponse"/>
			/// class. </summary>
			public updateAdRulesResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updateAdRulesResponse"/>
			/// class. </summary>
			public updateAdRulesResponse(Google.Api.Ads.AdManager.v201802.AdRule[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>Simple object representing an ad slot within an <a href='AdRule'>AdRule</a>. Ad
	/// rule slots contain information about the types/number of ads to display, as well
	/// as additional information on how the ad server will generate playlists.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UnknownAdRuleSlot))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(StandardPoddingAdRuleSlot))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(OptimizedPoddingAdRuleSlot))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(NoPoddingAdRuleSlot))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class BaseAdRuleSlot {
		private AdRuleSlotBehavior slotBehaviorField;

		private bool slotBehaviorFieldSpecified;

		private long minVideoAdDurationField;

		private bool minVideoAdDurationFieldSpecified;

		private long maxVideoAdDurationField;

		private bool maxVideoAdDurationFieldSpecified;

		private MidrollFrequencyType videoMidrollFrequencyTypeField;

		private bool videoMidrollFrequencyTypeFieldSpecified;

		private string videoMidrollFrequencyField;

		private AdRuleSlotBumper bumperField;

		private bool bumperFieldSpecified;

		private long maxBumperDurationField;

		private bool maxBumperDurationFieldSpecified;

		private long minPodDurationField;

		private bool minPodDurationFieldSpecified;

		private long maxPodDurationField;

		private bool maxPodDurationFieldSpecified;

		private int maxAdsInPodField;

		private bool maxAdsInPodFieldSpecified;

		/// <summary>The <a href='AdRuleSlotBehavior'>AdRuleSlotBehavior</a> for video ads for this
		/// slot. This attribute is optional and defaults to <a
		/// href='AdRuleSlotBehavior#DEFER'>AdRuleSlotBehavior#DEFER</a>. <p>Indicates
		/// whether video ads are allowed for this slot, or if the decision is deferred to a
		/// lower-priority ad rule.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AdRuleSlotBehavior slotBehavior {
			get {
				return this.slotBehaviorField;
			}
			set {
				this.slotBehaviorField = value;
				this.slotBehaviorSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="slotBehavior" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool slotBehaviorSpecified {
			get {
				return this.slotBehaviorFieldSpecified;
			}
			set {
				this.slotBehaviorFieldSpecified = value;
			}
		}

		/// <summary>The minimum duration in milliseconds of video ads within this slot. This
		/// attribute is optional and defaults to 0.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long minVideoAdDuration {
			get {
				return this.minVideoAdDurationField;
			}
			set {
				this.minVideoAdDurationField = value;
				this.minVideoAdDurationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="minVideoAdDuration" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool minVideoAdDurationSpecified {
			get {
				return this.minVideoAdDurationFieldSpecified;
			}
			set {
				this.minVideoAdDurationFieldSpecified = value;
			}
		}

		/// <summary>The maximum duration in milliseconds of video ads within this slot. This
		/// attribute is optional and defaults to 0.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public long maxVideoAdDuration {
			get {
				return this.maxVideoAdDurationField;
			}
			set {
				this.maxVideoAdDurationField = value;
				this.maxVideoAdDurationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="maxVideoAdDuration" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool maxVideoAdDurationSpecified {
			get {
				return this.maxVideoAdDurationFieldSpecified;
			}
			set {
				this.maxVideoAdDurationFieldSpecified = value;
			}
		}

		/// <summary>The frequency type for video ads in this ad rule slot. This attribute is
		/// required for mid-rolls, but if this is not a mid-roll, the value is set to <a
		/// href='MidrollFrequencyType#NONE'>MidrollFrequencyType#NONE</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public MidrollFrequencyType videoMidrollFrequencyType {
			get {
				return this.videoMidrollFrequencyTypeField;
			}
			set {
				this.videoMidrollFrequencyTypeField = value;
				this.videoMidrollFrequencyTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="videoMidrollFrequencyType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool videoMidrollFrequencyTypeSpecified {
			get {
				return this.videoMidrollFrequencyTypeFieldSpecified;
			}
			set {
				this.videoMidrollFrequencyTypeFieldSpecified = value;
			}
		}

		/// <summary>The mid-roll frequency of this ad rule slot for video ads. This attribute is
		/// required for mid-rolls, but if <a
		/// href='MidrollFrequencyType'>MidrollFrequencyType</a> is set to <a
		/// href='MidrollFrequencyType#NONE'>MidrollFrequencyType#NONE</a>, this value
		/// should be ignored. For example, if this slot has a frequency type of <a
		/// href='MidrollFrequencyType#EVERY_N_SECONDS'>MidrollFrequencyType#EVERY_N_SECONDS</a>
		/// and <code>#videoMidrollFrequency</code> = "60", this would mean " play a
		/// mid-roll every 60 seconds."
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string videoMidrollFrequency {
			get {
				return this.videoMidrollFrequencyField;
			}
			set {
				this.videoMidrollFrequencyField = value;
			}
		}

		/// <summary>The <a href='AdRuleSlotBumper'>AdRuleSlotBumper</a> for this slot. This
		/// attribute is optional and defaults to <a
		/// href='AdRuleSlotBumper#NONE'>AdRuleSlotBumper#NONE</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public AdRuleSlotBumper bumper {
			get {
				return this.bumperField;
			}
			set {
				this.bumperField = value;
				this.bumperSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="bumper" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool bumperSpecified {
			get {
				return this.bumperFieldSpecified;
			}
			set {
				this.bumperFieldSpecified = value;
			}
		}

		/// <summary>The maximum duration of bumper ads within this slot. This attribute is optional
		/// and defaults to 0.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public long maxBumperDuration {
			get {
				return this.maxBumperDurationField;
			}
			set {
				this.maxBumperDurationField = value;
				this.maxBumperDurationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="maxBumperDuration" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool maxBumperDurationSpecified {
			get {
				return this.maxBumperDurationFieldSpecified;
			}
			set {
				this.maxBumperDurationFieldSpecified = value;
			}
		}

		/// <summary>The minimum pod duration in milliseconds for this slot. This attribute is
		/// optional and defaults to 0.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public long minPodDuration {
			get {
				return this.minPodDurationField;
			}
			set {
				this.minPodDurationField = value;
				this.minPodDurationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="minPodDuration" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool minPodDurationSpecified {
			get {
				return this.minPodDurationFieldSpecified;
			}
			set {
				this.minPodDurationFieldSpecified = value;
			}
		}

		/// <summary>The maximum pod duration in milliseconds for this slot. This attribute is
		/// optional and defaults to 0.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public long maxPodDuration {
			get {
				return this.maxPodDurationField;
			}
			set {
				this.maxPodDurationField = value;
				this.maxPodDurationSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="maxPodDuration" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool maxPodDurationSpecified {
			get {
				return this.maxPodDurationFieldSpecified;
			}
			set {
				this.maxPodDurationFieldSpecified = value;
			}
		}

		/// <summary>The maximum number of ads allowed in a pod in this slot. This attribute is
		/// optional and defaults to 0.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public int maxAdsInPod {
			get {
				return this.maxAdsInPodField;
			}
			set {
				this.maxAdsInPodField = value;
				this.maxAdsInPodSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="maxAdsInPod"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool maxAdsInPodSpecified {
			get {
				return this.maxAdsInPodFieldSpecified;
			}
			set {
				this.maxAdsInPodFieldSpecified = value;
			}
		}
	}


	/// <summary>The types of behaviors for ads within a <a href='BaseAdRuleSlot'>ad rule
	/// slot</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdRuleSlotBehavior {
		/// <summary>This ad rule always includes this slot's ads.
		/// </summary>
		ALWAYS_SHOW = 0,
		/// <summary>This ad rule never includes this slot's ads.
		/// </summary>
		NEVER_SHOW = 1,
		/// <summary>Defer to lower priority rules. This ad rule doesn't specify guidelines for this
		/// slot's ads.
		/// </summary>
		DEFER = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Frequency types for mid-roll <a href='BaseAdRuleSlot'>ad rule slots</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum MidrollFrequencyType {
		/// <summary>The ad rule slot is not a mid-roll and hence <code></code> should be ignored.
		/// </summary>
		NONE = 0,
		/// <summary><code>MidrollFrequency</code> is a time interval and mentioned as a single
		/// numeric value in seconds. For example, "100" would mean "play a mid-roll every
		/// 100 seconds".
		/// </summary>
		EVERY_N_SECONDS = 1,
		/// <summary><code>MidrollFrequency</code> is a comma-delimited list of points in time (in
		/// seconds) when an ad should play. For example, "100,300" would mean "play an ad
		/// at 100 seconds and 300 seconds".
		/// </summary>
		FIXED_TIME = 2,
		/// <summary><code>MidrollFrequency</code> is a cue point interval and is a single integer
		/// value, such as "5", which means "play a mid-roll every 5th cue point".
		/// </summary>
		EVERY_N_CUEPOINTS = 3,
		/// <summary>Same as <a href='#FIXED_TIME'>#FIXED_TIME</a>, except the values represent the
		/// ordinal cue points ("1,3,5", for example).
		/// </summary>
		FIXED_CUE_POINTS = 4,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 5,
	}


	/// <summary>Types of bumper ads on an ad rule slot.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdRuleSlotBumper {
		/// <summary>Do not show a bumper ad.
		/// </summary>
		NONE = 0,
		/// <summary>Show a bumper ad before the slot's other ads.
		/// </summary>
		BEFORE = 1,
		/// <summary>Show a bumper ad after the slot's other ads.
		/// </summary>
		AFTER = 2,
		/// <summary>Show a bumper before and after the slot's other ads.
		/// </summary>
		BEFORE_AND_AFTER = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	/// <summary>The <a href='BaseAdRuleSlot'>BaseAdRuleSlot</a> subtype returned if the actual
	/// type is not exposed by the requested API version.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UnknownAdRuleSlot : BaseAdRuleSlot {
	}


	/// <summary>An ad rule slot with standard podding. A standard pod is a series of video ads
	/// played back to back. Standard pods are defined by a <a
	/// href='BaseAdRuleSlot#maxAdsInPod'>BaseAdRuleSlot#maxAdsInPod</a> and a <a
	/// href='BaseAdRuleSlot#maxVideoAdDuration'>BaseAdRuleSlot#maxVideoAdDuration</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class StandardPoddingAdRuleSlot : BaseAdRuleSlot {
	}


	/// <summary>Ad rule slot with optimized podding. Optimized pods are defined by a <a
	/// href='BaseAdRuleSlot#maxPodDuration'>BaseAdRuleSlot#maxPodDuration</a> and a <a
	/// href='BaseAdRuleSlot#maxAdsInPod'>BaseAdRuleSlot#maxAdsInPod</a>, and the ad
	/// server chooses the best ads for the alloted duration.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class OptimizedPoddingAdRuleSlot : BaseAdRuleSlot {
	}


	/// <summary>An ad rule slot with no podding. It is defined by a <a
	/// href='BaseAdRuleSlot#maxVideoAdDuration'>BaseAdRuleSlot#maxVideoAdDuration</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class NoPoddingAdRuleSlot : BaseAdRuleSlot {
	}


	/// <summary>An <a href='AdRule'>AdRule</a> contains data that the ad server will use to
	/// generate a playlist of video ads.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdRule {
		private long adRuleIdField;

		private bool adRuleIdFieldSpecified;

		private string nameField;

		private int priorityField;

		private bool priorityFieldSpecified;

		private Targeting targetingField;

		private DateTime startDateTimeField;

		private StartDateTimeType startDateTimeTypeField;

		private bool startDateTimeTypeFieldSpecified;

		private DateTime endDateTimeField;

		private bool unlimitedEndDateTimeField;

		private bool unlimitedEndDateTimeFieldSpecified;

		private AdRuleStatus statusField;

		private bool statusFieldSpecified;

		private FrequencyCapBehavior frequencyCapBehaviorField;

		private bool frequencyCapBehaviorFieldSpecified;

		private int maxImpressionsPerLineItemPerStreamField;

		private bool maxImpressionsPerLineItemPerStreamFieldSpecified;

		private int maxImpressionsPerLineItemPerPodField;

		private bool maxImpressionsPerLineItemPerPodFieldSpecified;

		private BaseAdRuleSlot prerollField;

		private BaseAdRuleSlot midrollField;

		private BaseAdRuleSlot postrollField;

		/// <summary>The unique ID of the <a href='AdRule'>AdRule</a>. This value is readonly and is
		/// assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long adRuleId {
			get {
				return this.adRuleIdField;
			}
			set {
				this.adRuleIdField = value;
				this.adRuleIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="adRuleId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool adRuleIdSpecified {
			get {
				return this.adRuleIdFieldSpecified;
			}
			set {
				this.adRuleIdFieldSpecified = value;
			}
		}

		/// <summary>The unique name of the <a href='AdRule'>AdRule</a>. This attribute is required
		/// to create an ad rule and has a maximum length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The priority of the <a href='AdRule'>AdRule</a>. This attribute is required and
		/// can range from 1 to 1000, with 1 being the highest possible priority.
		/// <p>Changing an ad rule's priority can affect the priorities of other ad rules.
		/// For example, increasing an ad rule's priority from 5 to 1 will shift the ad
		/// rules that were previously in priority positions 1 through 4 down one.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public int priority {
			get {
				return this.priorityField;
			}
			set {
				this.priorityField = value;
				this.prioritySpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="priority"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool prioritySpecified {
			get {
				return this.priorityFieldSpecified;
			}
			set {
				this.priorityFieldSpecified = value;
			}
		}

		/// <summary>The targeting criteria of the <a href='AdRule'>AdRule</a>. This attribute is
		/// required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public Targeting targeting {
			get {
				return this.targetingField;
			}
			set {
				this.targetingField = value;
			}
		}

		/// <summary>This <a href='AdRule'>AdRule</a> object's start date and time. This attribute is
		/// required and must be a date in the future for new ad rules.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public DateTime startDateTime {
			get {
				return this.startDateTimeField;
			}
			set {
				this.startDateTimeField = value;
			}
		}

		/// <summary>Specifies whether to start using the <a href='AdRule'>AdRule</a> right away, in
		/// an hour, etc. This attribute is optional and defaults to <a
		/// href='StartDateTimeType#USE_START_DATE_TIME'>StartDateTimeType#USE_START_DATE_TIME</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public StartDateTimeType startDateTimeType {
			get {
				return this.startDateTimeTypeField;
			}
			set {
				this.startDateTimeTypeField = value;
				this.startDateTimeTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="startDateTimeType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startDateTimeTypeSpecified {
			get {
				return this.startDateTimeTypeFieldSpecified;
			}
			set {
				this.startDateTimeTypeFieldSpecified = value;
			}
		}

		/// <summary>This <a href='AdRule'>AdRule</a> object's end date and time. This attribute is
		/// required unless <code>unlimitedEndDateTime</code> is set to <code>true</code>.
		/// If specified, it must be after the <code></code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public DateTime endDateTime {
			get {
				return this.endDateTimeField;
			}
			set {
				this.endDateTimeField = value;
			}
		}

		/// <summary>Specifies whether the <a href='AdRule'>AdRule</a> has an end time. This
		/// attribute is optional and defaults to false.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public bool unlimitedEndDateTime {
			get {
				return this.unlimitedEndDateTimeField;
			}
			set {
				this.unlimitedEndDateTimeField = value;
				this.unlimitedEndDateTimeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="unlimitedEndDateTime" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool unlimitedEndDateTimeSpecified {
			get {
				return this.unlimitedEndDateTimeFieldSpecified;
			}
			set {
				this.unlimitedEndDateTimeFieldSpecified = value;
			}
		}

		/// <summary>The <a href='AdRuleStatus'>AdRuleStatus</a> of the ad rule. This attribute is
		/// read-only and defaults to <a
		/// href='AdRuleStatus#INACTIVE'>AdRuleStatus#INACTIVE</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public AdRuleStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>The <a href='FrequencyCapBehavior'>FrequencyCapBehavior</a> of the <a
		/// href='AdRule'>AdRule</a>. This attribute is optional and defaults to <a
		/// href='FrequencyCapBehavior#DEFER'>FrequencyCapBehavior#DEFER</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public FrequencyCapBehavior frequencyCapBehavior {
			get {
				return this.frequencyCapBehaviorField;
			}
			set {
				this.frequencyCapBehaviorField = value;
				this.frequencyCapBehaviorSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="frequencyCapBehavior" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool frequencyCapBehaviorSpecified {
			get {
				return this.frequencyCapBehaviorFieldSpecified;
			}
			set {
				this.frequencyCapBehaviorFieldSpecified = value;
			}
		}

		/// <summary>This <a href='AdRule'>AdRule</a> object's frequency cap for the maximum
		/// impressions per stream. This attribute is optional and defaults to 0.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public int maxImpressionsPerLineItemPerStream {
			get {
				return this.maxImpressionsPerLineItemPerStreamField;
			}
			set {
				this.maxImpressionsPerLineItemPerStreamField = value;
				this.maxImpressionsPerLineItemPerStreamSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="maxImpressionsPerLineItemPerStream" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool maxImpressionsPerLineItemPerStreamSpecified {
			get {
				return this.maxImpressionsPerLineItemPerStreamFieldSpecified;
			}
			set {
				this.maxImpressionsPerLineItemPerStreamFieldSpecified = value;
			}
		}

		/// <summary>This <a href='AdRule'>AdRule</a> object's frequency cap for the maximum
		/// impressions per pod. This attribute is optional and defaults to 0.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 11)]
		public int maxImpressionsPerLineItemPerPod {
			get {
				return this.maxImpressionsPerLineItemPerPodField;
			}
			set {
				this.maxImpressionsPerLineItemPerPodField = value;
				this.maxImpressionsPerLineItemPerPodSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="maxImpressionsPerLineItemPerPod" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool maxImpressionsPerLineItemPerPodSpecified {
			get {
				return this.maxImpressionsPerLineItemPerPodFieldSpecified;
			}
			set {
				this.maxImpressionsPerLineItemPerPodFieldSpecified = value;
			}
		}

		/// <summary>This <a href='AdRule'>AdRule</a> object's pre-roll slot. This attribute is
		/// required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 12)]
		public BaseAdRuleSlot preroll {
			get {
				return this.prerollField;
			}
			set {
				this.prerollField = value;
			}
		}

		/// <summary>This <a href='AdRule'>AdRule</a> object's mid-roll slot. This attribute is
		/// required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 13)]
		public BaseAdRuleSlot midroll {
			get {
				return this.midrollField;
			}
			set {
				this.midrollField = value;
			}
		}

		/// <summary>This <a href='AdRule'>AdRule</a> object's post-roll slot. This attribute is
		/// required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 14)]
		public BaseAdRuleSlot postroll {
			get {
				return this.postrollField;
			}
			set {
				this.postrollField = value;
			}
		}
	}


	/// <summary>Represents the status of ad rules and ad rule slots.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdRuleStatus {
		/// <summary>Created and ready to be served. Is user-visible.
		/// </summary>
		ACTIVE = 0,
		/// <summary>Paused, user-visible.
		/// </summary>
		INACTIVE = 1,
		/// <summary>Marked as deleted, not user-visible.
		/// </summary>
		DELETED = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Types of behavior for frequency caps within ad rules.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum FrequencyCapBehavior {
		/// <summary>Turn on at least one of the frequency caps.
		/// </summary>
		TURN_ON = 0,
		/// <summary>Turn off all frequency caps.
		/// </summary>
		TURN_OFF = 1,
		/// <summary>Defer frequency cap decisions to the next ad rule in priority order.
		/// </summary>
		DEFER = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Errors related to podding fields in ad rule slots.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PoddingError : ApiError {
		private PoddingErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public PoddingErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes reason for <code>PoddingError</code>s.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "PoddingError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum PoddingErrorReason {
		/// <summary>Invalid podding type NONE, but has podding fields filled in. Podding types are
		/// defined in <a
		/// href='com.google.ads.publisher.domain.entity.adrule.export.PoddingType'>com.google.ads.publisher.domain.entity.adrule.export.PoddingType</a>.
		/// </summary>
		INVALID_PODDING_TYPE_NONE = 0,
		/// <summary>Invalid podding type STANDARD, but doesn't specify the max ads in pod and max ad
		/// duration podding fields.
		/// </summary>
		INVALID_PODDING_TYPE_STANDARD = 1,
		/// <summary>Invalid podding type OPTIMIZED, but doesn't specify pod duration.
		/// </summary>
		INVALID_OPTIMIZED_POD_WITHOUT_DURATION = 2,
		/// <summary>Invalid optimized pod that does not specify a valid max ads in pod, which must
		/// either be a positive number or -1 to signify that there is no maximum.
		/// </summary>
		INVALID_OPTIMIZED_POD_WITHOUT_ADS = 3,
		/// <summary>Min pod ad duration is greater than max pod ad duration.
		/// </summary>
		INVALID_POD_DURATION_RANGE = 4,
	}


	/// <summary>Lists all errors associated with ad rule targeting.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdRuleTargetingError : ApiError {
		private AdRuleTargetingErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AdRuleTargetingErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes reasons for <code>AdRuleTargetingError ad rule targeting
	/// errors</code>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AdRuleTargetingError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdRuleTargetingErrorReason {
		/// <summary>Cannot target video positions.
		/// </summary>
		VIDEO_POSITION_TARGETING_NOT_ALLOWED = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>Errors associated with ad rule priorities.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdRulePriorityError : ApiError {
		private AdRulePriorityErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AdRulePriorityErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Reasons for an <code>AdRulePriorityError</code>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AdRulePriorityError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdRulePriorityErrorReason {
		/// <summary>Ad rules must have unique priorities.
		/// </summary>
		DUPLICATE_PRIORITY = 0,
		/// <summary>One or more priorities are missing.
		/// </summary>
		PRIORITIES_NOT_SEQUENTIAL = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Errors related to ad rule frequency caps
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdRuleFrequencyCapError : ApiError {
		private AdRuleFrequencyCapErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AdRuleFrequencyCapErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes reason for <code>AdRuleFrequencyCapError</code>s.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AdRuleFrequencyCapError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdRuleFrequencyCapErrorReason {
		/// <summary>The ad rule specifies that frequency caps should be turned on, but then none of
		/// the frequency caps have actually been set.
		/// </summary>
		NO_FREQUENCY_CAPS_SPECIFIED_WHEN_FREQUENCY_CAPS_TURNED_ON = 0,
		/// <summary>The ad rule specifies that frequency caps should not be turned on, but then some
		/// frequency caps were actually set.
		/// </summary>
		FREQUENCY_CAPS_SPECIFIED_WHEN_FREQUENCY_CAPS_TURNED_OFF = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Lists all errors associated with ad rule start and end dates.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdRuleDateError : ApiError {
		private AdRuleDateErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public AdRuleDateErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>Describes reasons for <code>AdRuleDateError</code>s.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AdRuleDateError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AdRuleDateErrorReason {
		/// <summary>Cannot create a new ad rule with a start date in the past.
		/// </summary>
		START_DATE_TIME_IS_IN_PAST = 0,
		/// <summary>Cannot update an existing ad rule that has already completely passed with a new
		/// end date that is still in the past.
		/// </summary>
		END_DATE_TIME_IS_IN_PAST = 1,
		/// <summary>End date must be after the start date.
		/// </summary>
		END_DATE_TIME_NOT_AFTER_START_TIME = 2,
		/// <summary><code>DateTime</code>s after 1 January 2037 are not supported.
		/// </summary>
		END_DATE_TIME_TOO_LATE = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 4,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.AdRuleServiceInterface")]
	public interface AdRuleServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.AdRuleService.createAdRulesResponse createAdRules(Wrappers.AdRuleService.createAdRulesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.AdRuleService.createAdRulesResponse> createAdRulesAsync(Wrappers.AdRuleService.createAdRulesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.AdRulePage getAdRulesByStatement(Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdRulePage> getAdRulesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performAdRuleAction(Google.Api.Ads.AdManager.v201802.AdRuleAction adRuleAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performAdRuleActionAsync(Google.Api.Ads.AdManager.v201802.AdRuleAction adRuleAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.AdRuleService.updateAdRulesResponse updateAdRules(Wrappers.AdRuleService.updateAdRulesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.AdRuleService.updateAdRulesResponse> updateAdRulesAsync(Wrappers.AdRuleService.updateAdRulesRequest request);
	}


	/// <summary>Captures a page of <a href='AdRule'>AdRule</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AdRulePage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private AdRule[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of ad rules contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public AdRule[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a href='AdRule'>AdRule</a>
	/// objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeleteAdRules))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeactivateAdRules))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateAdRules))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class AdRuleAction {
	}


	/// <summary>The action used for deleting <a href='AdRule'>AdRule</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeleteAdRules : AdRuleAction {
	}


	/// <summary>The action used for pausing <a href='AdRule'>AdRule</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeactivateAdRules : AdRuleAction {
	}


	/// <summary>The action used for resuming <a href='AdRule'>AdRule</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateAdRules : AdRuleAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface AdRuleServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.AdRuleServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='AdRule'>AdRule</a> objects. <p>Ad rules contain data that the ad server
	/// uses to generate a playlist of video ads.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class AdRuleService : AdManagerSoapClient<IAdRuleService>, IAdRuleService {
		/// <summary> Creates a new instance of the <see cref="AdRuleService"/> class.
		/// </summary>
		public AdRuleService() {
		}

		/// <summary> Creates a new instance of the <see cref="AdRuleService"/> class.
		/// </summary>
		public AdRuleService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="AdRuleService"/> class.
		/// </summary>
		public AdRuleService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="AdRuleService"/> class.
		/// </summary>
		public AdRuleService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="AdRuleService"/> class.
		/// </summary>
		public AdRuleService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.AdRuleService.createAdRulesResponse Google.Api.Ads.AdManager.v201802.AdRuleServiceInterface.createAdRules(Wrappers.AdRuleService.createAdRulesRequest request) {
			return base.Channel.createAdRules(request);
		}

		/// <summary>Creates new <a href='AdRule'>AdRule</a> objects.
		/// </summary><param name='adRules'>the ad rules to create</param>
		/// <returns>the created ad rules with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.AdRule[] createAdRules(Google.Api.Ads.AdManager.v201802.AdRule[] adRules) {
			Wrappers.AdRuleService.createAdRulesRequest inValue = new Wrappers.AdRuleService.createAdRulesRequest();
			inValue.adRules = adRules;
			Wrappers.AdRuleService.createAdRulesResponse retVal = ((Google.Api.Ads.AdManager.v201802.AdRuleServiceInterface)(this)).createAdRules(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.AdRuleService.createAdRulesResponse> Google.Api.Ads.AdManager.v201802.AdRuleServiceInterface.createAdRulesAsync(Wrappers.AdRuleService.createAdRulesRequest request) {
			return base.Channel.createAdRulesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdRule[]> createAdRulesAsync(Google.Api.Ads.AdManager.v201802.AdRule[] adRules) {
			Wrappers.AdRuleService.createAdRulesRequest inValue = new Wrappers.AdRuleService.createAdRulesRequest();
			inValue.adRules = adRules;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdRule[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.AdRuleServiceInterface)(this)).createAdRulesAsync(inValue)).Result.rval);
		}

		/// <summary>Gets an <a href='AdRulePage'>AdRulePage</a> of <a href='AdRule'>AdRule</a>
		/// objects that satisfy the given <a href=''>Statement#query</a>. The following
		/// fields are supported for filtering: <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>id</code></td> <td><a href='AdRule#id'>AdRule#id</a> (<a
		/// href='AdRule#adRuleId'>AdRule#adRuleId</a> beginning in v201702)</td> </tr> <tr>
		/// <td><code>name</code></td> <td><a href='AdRule#name'>AdRule#name</a></td> </tr>
		/// <tr> <td><code>priority</code></td> <td><a
		/// href='AdRule#priority'>AdRule#priority</a></td> </tr> <tr>
		/// <td><code>status</code></td> <td><a href='AdRule#status'>AdRule#status</a></td>
		/// </tr> </table>
		/// </summary><param name='statement'>a Publisher Query Language statement used to filter a
		/// set of ad rules</param>
		/// <returns>the ad rules that match the given filter</returns>
		/// <exception cref='ApiException'>if the ID of the active network does not exist or
		/// there is a backend error</exception>
		public virtual Google.Api.Ads.AdManager.v201802.AdRulePage getAdRulesByStatement(Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.getAdRulesByStatement(statement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdRulePage> getAdRulesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.getAdRulesByStatementAsync(statement);
		}

		/// <summary>Performs actions on <a href='AdRule'>AdRule</a> objects that match the given <a
		/// href='Statement#query'>Statement#query</a>.
		/// </summary><param name='adRuleAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of ad rules</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performAdRuleAction(Google.Api.Ads.AdManager.v201802.AdRuleAction adRuleAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performAdRuleAction(adRuleAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performAdRuleActionAsync(Google.Api.Ads.AdManager.v201802.AdRuleAction adRuleAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performAdRuleActionAsync(adRuleAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.AdRuleService.updateAdRulesResponse Google.Api.Ads.AdManager.v201802.AdRuleServiceInterface.updateAdRules(Wrappers.AdRuleService.updateAdRulesRequest request) {
			return base.Channel.updateAdRules(request);
		}

		/// <summary>Updates the specified <a href='AdRule'>AdRule</a> objects.
		/// </summary><param name='adRules'>the ad rules to update</param>
		/// <returns>the updated ad rules</returns>
		/// <exception cref='ApiException'>if there is an error updating the ad
		/// rules</exception>
		public virtual Google.Api.Ads.AdManager.v201802.AdRule[] updateAdRules(Google.Api.Ads.AdManager.v201802.AdRule[] adRules) {
			Wrappers.AdRuleService.updateAdRulesRequest inValue = new Wrappers.AdRuleService.updateAdRulesRequest();
			inValue.adRules = adRules;
			Wrappers.AdRuleService.updateAdRulesResponse retVal = ((Google.Api.Ads.AdManager.v201802.AdRuleServiceInterface)(this)).updateAdRules(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.AdRuleService.updateAdRulesResponse> Google.Api.Ads.AdManager.v201802.AdRuleServiceInterface.updateAdRulesAsync(Wrappers.AdRuleService.updateAdRulesRequest request) {
			return base.Channel.updateAdRulesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdRule[]> updateAdRulesAsync(Google.Api.Ads.AdManager.v201802.AdRule[] adRules) {
			Wrappers.AdRuleService.updateAdRulesRequest inValue = new Wrappers.AdRuleService.updateAdRulesRequest();
			inValue.adRules = adRules;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdRule[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.AdRuleServiceInterface)(this)).updateAdRulesAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.ReconciliationReportRowService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateReconciliationReportRows", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateReconciliationReportRowsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("reconciliationReportRows")]
			public Google.Api.Ads.AdManager.v201802.ReconciliationReportRow[] reconciliationReportRows;

			/// <summary> Creates a new instance of the <see
			/// cref="updateReconciliationReportRowsRequest"/> class. </summary>
			public updateReconciliationReportRowsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateReconciliationReportRowsRequest"/> class. </summary>
			public updateReconciliationReportRowsRequest(Google.Api.Ads.AdManager.v201802.ReconciliationReportRow[] reconciliationReportRows) {
				this.reconciliationReportRows = reconciliationReportRows;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateReconciliationReportRowsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateReconciliationReportRowsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ReconciliationReportRow[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateReconciliationReportRowsResponse"/> class. </summary>
			public updateReconciliationReportRowsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateReconciliationReportRowsResponse"/> class. </summary>
			public updateReconciliationReportRowsResponse(Google.Api.Ads.AdManager.v201802.ReconciliationReportRow[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>A <code>ReconciliationReportRow</code> represents each row in the reconciliation
	/// report. Each row is identified by its <a
	/// href='#reconciliationReportId'>#reconciliationReportId</a>, <a
	/// href='#lineItemId'>#lineItemId</a>, <a href='#creativeId'>#creativeId</a>, and
	/// <a href='#proposalLineItemId'>#proposalLineItemId</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReconciliationReportRow {
		private long idField;

		private bool idFieldSpecified;

		private long reconciliationReportIdField;

		private bool reconciliationReportIdFieldSpecified;

		private long lineItemIdField;

		private bool lineItemIdFieldSpecified;

		private long creativeIdField;

		private bool creativeIdFieldSpecified;

		private long orderIdField;

		private bool orderIdFieldSpecified;

		private long advertiserIdField;

		private bool advertiserIdFieldSpecified;

		private long proposalLineItemIdField;

		private bool proposalLineItemIdFieldSpecified;

		private long proposalIdField;

		private bool proposalIdFieldSpecified;

		private BillFrom reconciliationSourceField;

		private bool reconciliationSourceFieldSpecified;

		private RateType rateTypeField;

		private bool rateTypeFieldSpecified;

		private Money lineItemCostPerUnitField;

		private long lineItemContractedUnitsBoughtField;

		private bool lineItemContractedUnitsBoughtFieldSpecified;

		private long dfpVolumeField;

		private bool dfpVolumeFieldSpecified;

		private long thirdPartyVolumeField;

		private bool thirdPartyVolumeFieldSpecified;

		private long manualVolumeField;

		private bool manualVolumeFieldSpecified;

		private long reconciledVolumeField;

		private bool reconciledVolumeFieldSpecified;

		private Money contractedRevenueField;

		private Money dfpRevenueField;

		private Money thirdPartyRevenueField;

		private Money manualRevenueField;

		private Money reconciledRevenueField;

		private string commentsField;

		/// <summary>Uniquely identifies the <code>ReconciliationReportRow</code>. This value is
		/// read-only and assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The ID of the <a href='ReconciliationReport'>ReconciliationReport</a>. This
		/// attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long reconciliationReportId {
			get {
				return this.reconciliationReportIdField;
			}
			set {
				this.reconciliationReportIdField = value;
				this.reconciliationReportIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="reconciliationReportId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reconciliationReportIdSpecified {
			get {
				return this.reconciliationReportIdFieldSpecified;
			}
			set {
				this.reconciliationReportIdFieldSpecified = value;
			}
		}

		/// <summary>The ID of the <a href='LineItem'>LineItem</a>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public long lineItemId {
			get {
				return this.lineItemIdField;
			}
			set {
				this.lineItemIdField = value;
				this.lineItemIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="lineItemId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lineItemIdSpecified {
			get {
				return this.lineItemIdFieldSpecified;
			}
			set {
				this.lineItemIdFieldSpecified = value;
			}
		}

		/// <summary>The ID of the <a href='Creative'>Creative</a>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public long creativeId {
			get {
				return this.creativeIdField;
			}
			set {
				this.creativeIdField = value;
				this.creativeIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="creativeId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool creativeIdSpecified {
			get {
				return this.creativeIdFieldSpecified;
			}
			set {
				this.creativeIdFieldSpecified = value;
			}
		}

		/// <summary>The ID of the <a href='Order'>Order</a>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public long orderId {
			get {
				return this.orderIdField;
			}
			set {
				this.orderIdField = value;
				this.orderIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="orderId" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool orderIdSpecified {
			get {
				return this.orderIdFieldSpecified;
			}
			set {
				this.orderIdFieldSpecified = value;
			}
		}

		/// <summary>The ID of the <a href='Company'>Company</a>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public long advertiserId {
			get {
				return this.advertiserIdField;
			}
			set {
				this.advertiserIdField = value;
				this.advertiserIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="advertiserId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool advertiserIdSpecified {
			get {
				return this.advertiserIdFieldSpecified;
			}
			set {
				this.advertiserIdFieldSpecified = value;
			}
		}

		/// <summary>The ID of the <a href='ProposalLineItem'>ProposalLineItem</a> associated with
		/// this report row. This value is 0 if there is no related <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public long proposalLineItemId {
			get {
				return this.proposalLineItemIdField;
			}
			set {
				this.proposalLineItemIdField = value;
				this.proposalLineItemIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="proposalLineItemId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool proposalLineItemIdSpecified {
			get {
				return this.proposalLineItemIdFieldSpecified;
			}
			set {
				this.proposalLineItemIdFieldSpecified = value;
			}
		}

		/// <summary>The ID of the <a href='Proposal'>Proposal</a> associated with this report row.
		/// This value is 0 if there is no related <a href='Proposal'>Proposal</a>. This
		/// attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public long proposalId {
			get {
				return this.proposalIdField;
			}
			set {
				this.proposalIdField = value;
				this.proposalIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="proposalId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool proposalIdSpecified {
			get {
				return this.proposalIdFieldSpecified;
			}
			set {
				this.proposalIdFieldSpecified = value;
			}
		}

		/// <summary>Specifies which of <a href='#dfpVolume'>#dfpVolume</a>, <a
		/// href='#thirdPartyVolume'>#thirdPartyVolume</a>, or <a
		/// href='#manualVolume'>#manualVolume</a> should be used as the <a
		/// href='#reconciledVolume'>#reconciledVolume</a>. The value is optional. If this
		/// reconciliation data is for a <a href='ProposalLineItem'>ProposalLineItem</a>
		/// then this will default to the proposal line item's <a
		/// href='ProposalLineItem#billingSource'>ProposalLineItem#billingSource</a>.
		/// Otherwise, this will default to <a href='BillFrom#DFP'>BillFrom#DFP</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public BillFrom reconciliationSource {
			get {
				return this.reconciliationSourceField;
			}
			set {
				this.reconciliationSourceField = value;
				this.reconciliationSourceSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="reconciliationSource" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reconciliationSourceSpecified {
			get {
				return this.reconciliationSourceFieldSpecified;
			}
			set {
				this.reconciliationSourceFieldSpecified = value;
			}
		}

		/// <summary><a href='RateType'>RateType</a> of the line item and proposal line item this row
		/// represents. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public RateType rateType {
			get {
				return this.rateTypeField;
			}
			set {
				this.rateTypeField = value;
				this.rateTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="rateType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool rateTypeSpecified {
			get {
				return this.rateTypeFieldSpecified;
			}
			set {
				this.rateTypeFieldSpecified = value;
			}
		}

		/// <summary>The <a href='LineItem#costPerUnit'>LineItem#costPerUnit</a> of the line item
		/// this row represents. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public Money lineItemCostPerUnit {
			get {
				return this.lineItemCostPerUnitField;
			}
			set {
				this.lineItemCostPerUnitField = value;
			}
		}

		/// <summary>The <a href='LineItem#contractedUnitsBought'>LineItem#contractedUnitsBought</a>
		/// of the line item this row represents. <code>null</code> if it is unlimited. This
		/// attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 11)]
		public long lineItemContractedUnitsBought {
			get {
				return this.lineItemContractedUnitsBoughtField;
			}
			set {
				this.lineItemContractedUnitsBoughtField = value;
				this.lineItemContractedUnitsBoughtSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="lineItemContractedUnitsBought" />, <code>false</code> otherwise.
		/// </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool lineItemContractedUnitsBoughtSpecified {
			get {
				return this.lineItemContractedUnitsBoughtFieldSpecified;
			}
			set {
				this.lineItemContractedUnitsBoughtFieldSpecified = value;
			}
		}

		/// <summary>The volume recorded by the DoubleClick for Publishers server. The meaning of
		/// this value depends on the <a href='#rateType'>#rateType</a>, for example if the
		/// <a href='#rateType'>#rateType</a> is <a href='RateType#CPC'>RateType#CPC</a>, it
		/// represents clicks; if the <a href='#rateType'>#rateType</a> is <a
		/// href='RateType#CPM'>RateType#CPM</a>, it represents impressions; if the <a
		/// href='#rateType'>#rateType</a> is <a href='RateType#CPD'>RateType#CPD</a>, it
		/// represents line item days. <p>If the <a href='#billFrom'>#billFrom</a> is <a
		/// href='BillFrom#DFP'>BillFrom#DFP</a>, this attribute will be set to <a
		/// href=''>#reconciledVolume</a> and used to calculate the <a
		/// href='#reconciledRevenue'>#reconciledRevenue</a>.</p> <p>This attribute is
		/// read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 12)]
		public long dfpVolume {
			get {
				return this.dfpVolumeField;
			}
			set {
				this.dfpVolumeField = value;
				this.dfpVolumeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="dfpVolume"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool dfpVolumeSpecified {
			get {
				return this.dfpVolumeFieldSpecified;
			}
			set {
				this.dfpVolumeFieldSpecified = value;
			}
		}

		/// <summary>The volume recorded by the third-party ad server. The meaning of this value
		/// depends on the <a href='#rateType'>#rateType</a>, for example if the <a
		/// href='#rateType'>#rateType</a> is <a href='RateType#CPC'>RateType#CPC</a>, it
		/// represents clicks; if the <a href='#rateType'>#rateType</a> is <a
		/// href='RateType#CPM'>RateType#CPM</a>, it represents impressions; if the <a
		/// href='#rateType'>#rateType</a> is <a href='RateType#CPD'>RateType#CPD</a>, it
		/// represents line item days. If the <a href='#billFrom'>#billFrom</a> is <a
		/// href='BillFrom#THIRD_PARTY'>BillFrom#THIRD_PARTY</a>, this attribute will be set
		/// to <a href='#reconciledVolume'>#reconciledVolume</a> and used to calculate the
		/// <a href='#reconciledRevenue'>#reconciledRevenue</a>. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 13)]
		public long thirdPartyVolume {
			get {
				return this.thirdPartyVolumeField;
			}
			set {
				this.thirdPartyVolumeField = value;
				this.thirdPartyVolumeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="thirdPartyVolume" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool thirdPartyVolumeSpecified {
			get {
				return this.thirdPartyVolumeFieldSpecified;
			}
			set {
				this.thirdPartyVolumeFieldSpecified = value;
			}
		}

		/// <summary>The volume manually entered. The meaning of this value depends on the <a
		/// href='#rateType'>#rateType</a>, for example if the <a
		/// href='#rateType'>#rateType</a> is <a href='RateType#CPC'>RateType#CPC</a>, it
		/// represents clicks; if the <a href=''>#rateType</a> is <a
		/// href='RateType#CPM'>RateType#CPM</a>, it represents impressions; if the <a
		/// href='#rateType'>#rateType</a> is <a href='RateType#CPD'>RateType#CPD</a>, it
		/// represents line item days. <p>If the <a href='#billFrom'>#billFrom</a> is <a
		/// href='BillFrom#MANUAL'>BillFrom#MANUAL</a>, this attribute will be set to <a
		/// href=''>#reconciledVolume</a> and used to calculate the <a
		/// href='#reconciledRevenue'>#reconciledRevenue</a>.</p> <p>This attribute is
		/// optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 14)]
		public long manualVolume {
			get {
				return this.manualVolumeField;
			}
			set {
				this.manualVolumeField = value;
				this.manualVolumeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="manualVolume" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool manualVolumeSpecified {
			get {
				return this.manualVolumeFieldSpecified;
			}
			set {
				this.manualVolumeFieldSpecified = value;
			}
		}

		/// <summary>The volume depending upon the <a href='#billFrom'>#billFrom</a> value. The
		/// meaning of this value depends on the <a href='#rateType'>#rateType</a>, for
		/// example if the <a href='#rateType'>#rateType</a> is <a
		/// href='RateType#CPC'>RateType#CPC</a>, it represents clicks; if the <a
		/// href='#rateType'>#rateType</a> is <a href='RateType#CPM'>RateType#CPM</a>, it
		/// represents impressions; if the <a href='#rateType'>#rateType</a> is <a
		/// href='RateType#CPD'>RateType#CPD</a>, it represents line item days. This
		/// attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 15)]
		public long reconciledVolume {
			get {
				return this.reconciledVolumeField;
			}
			set {
				this.reconciledVolumeField = value;
				this.reconciledVolumeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="reconciledVolume" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reconciledVolumeSpecified {
			get {
				return this.reconciledVolumeFieldSpecified;
			}
			set {
				this.reconciledVolumeFieldSpecified = value;
			}
		}

		/// <summary>The revenue calculated based on the <a
		/// href='#contractedGoal'>#contractedGoal</a> and <a
		/// href='#costPerUnit'>#costPerUnit</a>. This attribute is calculated by Google and
		/// is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 16)]
		public Money contractedRevenue {
			get {
				return this.contractedRevenueField;
			}
			set {
				this.contractedRevenueField = value;
			}
		}

		/// <summary>The revenue calculated based on the <a href='#costPerUnit'>#costPerUnit</a>, <a
		/// href='#costType'>#costType</a>, <a href='#dfpClicks'>#dfpClicks</a>, <a
		/// href='#dfpImpressions'>#dfpImpressions</a> and <a
		/// href='#dfpLineItemDays'>#dfpLineItemDays</a>. This attribute is calculated by
		/// Google and is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 17)]
		public Money dfpRevenue {
			get {
				return this.dfpRevenueField;
			}
			set {
				this.dfpRevenueField = value;
			}
		}

		/// <summary>The revenue calculated based on the <a href='#costPerUnit'>#costPerUnit</a>, <a
		/// href='#costType'>#costType</a>, <a
		/// href='#thirdPartyClicks'>#thirdPartyClicks</a>, <a
		/// href='#thirdPartyImpressions'>#thirdPartyImpressions</a> and <a
		/// href='#thirdPartyLineItemDays'>#thirdPartyLineItemDays</a>. This attribute is
		/// calculated by Google and is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 18)]
		public Money thirdPartyRevenue {
			get {
				return this.thirdPartyRevenueField;
			}
			set {
				this.thirdPartyRevenueField = value;
			}
		}

		/// <summary>The revenue calculated based on the <a href='#costPerUnit'>#costPerUnit</a>, <a
		/// href='#costType'>#costType</a>, <a href='#manualClicks'>#manualClicks</a>, <a
		/// href='#manualImpressions'>#manualImpressions</a> and <a
		/// href='#manualLineItemDays'>#manualLineItemDays</a>. This attribute is calculated
		/// by Google and is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 19)]
		public Money manualRevenue {
			get {
				return this.manualRevenueField;
			}
			set {
				this.manualRevenueField = value;
			}
		}

		/// <summary>The revenue calculated based on the <a href='#billFrom'>#billFrom</a>, <a
		/// href='#contractedRevenue'>#contractedRevenue</a>, <a
		/// href='#dfpRevenue'>#dfpRevenue</a>, <a
		/// href='#thirdPartyRevenue'>#thirdPartyRevenue</a> and <a
		/// href='#manualRevenue'>#manualRevenue</a>. This attribute is calculated by Google
		/// and is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 20)]
		public Money reconciledRevenue {
			get {
				return this.reconciledRevenueField;
			}
			set {
				this.reconciledRevenueField = value;
			}
		}

		/// <summary>The comments for this row. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 21)]
		public string comments {
			get {
				return this.commentsField;
			}
			set {
				this.commentsField = value;
			}
		}
	}


	/// <summary>Captures a page of <a href='ReconciliationReportRow'>ReconciliationReportRow</a>
	/// objects
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReconciliationReportRowPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private ReconciliationReportRow[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of reconciliation report rows contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public ReconciliationReportRow[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ReconciliationReportRowServiceInterface")]
	public interface ReconciliationReportRowServiceInterface
	{
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ReconciliationReportRowPage getReconciliationReportRowsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationReportRowPage> getReconciliationReportRowsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ReconciliationReportRowService.updateReconciliationReportRowsResponse updateReconciliationReportRows(Wrappers.ReconciliationReportRowService.updateReconciliationReportRowsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ReconciliationReportRowService.updateReconciliationReportRowsResponse> updateReconciliationReportRowsAsync(Wrappers.ReconciliationReportRowService.updateReconciliationReportRowsRequest request);
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ReconciliationReportRowServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ReconciliationReportRowServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for retrieving and updating the <a
	/// href='ReconciliationReportRow'>ReconciliationReportRow</a> objects.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ReconciliationReportRowService : AdManagerSoapClient<IReconciliationReportRowService>, IReconciliationReportRowService {
		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationReportRowService"/> class. </summary>
		public ReconciliationReportRowService() {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationReportRowService"/> class. </summary>
		public ReconciliationReportRowService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationReportRowService"/> class. </summary>
		public ReconciliationReportRowService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationReportRowService"/> class. </summary>
		public ReconciliationReportRowService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see
		/// cref="ReconciliationReportRowService"/> class. </summary>
		public ReconciliationReportRowService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		/// <summary>Gets a <a href='ReconciliationReportRowPage'>ReconciliationReportRowPage</a> of
		/// <a href='ReconciliationReportRow'>ReconciliationReportRow</a> objects that
		/// satisfy the given <a href='Statement#query'>Statement#query</a>. The following
		/// fields are supported for filtering: <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>reconciliationReportId</code></td> <td><a
		/// href='ReconciliationReportRow#reconciliationReportId'>ReconciliationReportRow#reconciliationReportId</a></td>
		/// </tr> <tr> <td><code>advertiserId</code></td> <td><a
		/// href='ReconciliationReportRow#advertiserId'>ReconciliationReportRow#advertiserId</a></td>
		/// </tr> <tr> <td><code>orderId</code></td> <td><a
		/// href='ReconciliationReportRow#orderId'>ReconciliationReportRow#orderId</a></td>
		/// </tr> <tr> <td><code>lineItemId</code></td> <td><a
		/// href='ReconciliationReportRow#lineItemId'>ReconciliationReportRow#lineItemId</a></td>
		/// </tr> <tr> <td><code>proposalLineItemId</code></td> <td><a
		/// href='ReconciliationReportRow#proposalLineItemId'>ReconciliationReportRow#proposalLineItemId</a></td>
		/// </tr> <tr> <td><code>creativeId</code></td> <td><a
		/// href='ReconciliationReportRow#creativeId'>ReconciliationReportRow#creativeId</a></td>
		/// </tr> <tr> <td><code>lineItemCostType</code></td> <td><a
		/// href='ReconciliationReportRow#lineItemCostType'>ReconciliationReportRow#lineItemCostType</a></td>
		/// </tr> <tr> <td><code>dfpClicks</code></td> <td><a
		/// href='ReconciliationReportRow#dfpClicks'>ReconciliationReportRow#dfpClicks</a></td>
		/// </tr> <tr> <td><code>dfpImpressions</code></td> <td><a
		/// href='ReconciliationReportRow#dfpImpressions'>ReconciliationReportRow#dfpImpressions</a></td>
		/// </tr> <tr> <td><code>dfpLineItemDays</code></td> <td><a
		/// href='ReconciliationReportRow#dfpLineItemDays'>ReconciliationReportRow#dfpLineItemDays</a></td>
		/// </tr> <tr> <td><code>thirdPartyClicks</code></td> <td><a
		/// href='ReconciliationReportRow#thirdPartyClicks'>ReconciliationReportRow#thirdPartyClicks</a></td>
		/// </tr> <tr> <td><code>thirdPartyImpressions</code></td> <td><a
		/// href='ReconciliationReportRow#thirdPartyImpressions'>ReconciliationReportRow#thirdPartyImpressions</a></td>
		/// </tr> <tr> <td><code>thirdPartyLineItemDays</code></td> <td><a
		/// href='ReconciliationReportRow#thirdPartyLineItemDays'>ReconciliationReportRow#thirdPartyLineItemDays</a></td>
		/// </tr> <tr> <td><code>manualClicks</code></td> <td><a
		/// href='ReconciliationReportRow#manualClicks'>ReconciliationReportRow#manualClicks</a></td>
		/// </tr> <tr> <td><code>manualImpressions</code></td> <td><a
		/// href='ReconciliationReportRow#manualImpressions'>ReconciliationReportRow#manualImpressions</a></td>
		/// </tr> <tr> <td><code>manualLineItemDays</code></td> <td><a
		/// href='ReconciliationReportRow#manualLineItemDays'>ReconciliationReportRow#manualLineItemDays</a></td>
		/// </tr> <tr> <td><code>reconciledClicks</code></td> <td><a
		/// href='ReconciliationReportRow#reconciledClicks'>ReconciliationReportRow#reconciledClicks</a></td>
		/// </tr> <tr> <td><code>reconciledImpressions</code></td> <td><a
		/// href='ReconciliationReportRow#reconciledImpressions'>ReconciliationReportRow#reconciledImpressions</a></td>
		/// </tr> <tr> <td><code>reconciledLineItemDays</code></td> <td><a
		/// href='ReconciliationReportRow#reconciledLineItemDays'>ReconciliationReportRow#reconciledLineItemDays</a></td>
		/// </tr> </table> The <code>reconciliationReportId</code> field is required and can
		/// only be combined with an <code>AND</code> to other conditions. Furthermore, the
		/// results may only belong to one <a
		/// href='ReconciliationReport'>ReconciliationReport</a>.
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of reconciliation report rows</param>
		/// <returns>the reconciliation report rows that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ReconciliationReportRowPage getReconciliationReportRowsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getReconciliationReportRowsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationReportRowPage> getReconciliationReportRowsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getReconciliationReportRowsByStatementAsync(filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ReconciliationReportRowService.updateReconciliationReportRowsResponse Google.Api.Ads.AdManager.v201802.ReconciliationReportRowServiceInterface.updateReconciliationReportRows(Wrappers.ReconciliationReportRowService.updateReconciliationReportRowsRequest request) {
			return base.Channel.updateReconciliationReportRows(request);
		}

		/// <summary>Updates a list of <a href='ReconciliationReportRow'>ReconciliationReportRow</a>
		/// which belong to same <a href='ReconciliationReport'>ReconciliationReport</a>.
		/// </summary><param name='reconciliationReportRows'>a list of reconciliation report rows to
		/// update</param>
		/// <returns>the updated reconciliation report rows</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ReconciliationReportRow[] updateReconciliationReportRows(Google.Api.Ads.AdManager.v201802.ReconciliationReportRow[] reconciliationReportRows) {
			Wrappers.ReconciliationReportRowService.updateReconciliationReportRowsRequest inValue = new Wrappers.ReconciliationReportRowService.updateReconciliationReportRowsRequest();
			inValue.reconciliationReportRows = reconciliationReportRows;
			Wrappers.ReconciliationReportRowService.updateReconciliationReportRowsResponse retVal = ((Google.Api.Ads.AdManager.v201802.ReconciliationReportRowServiceInterface)(this)).updateReconciliationReportRows(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ReconciliationReportRowService.updateReconciliationReportRowsResponse> Google.Api.Ads.AdManager.v201802.ReconciliationReportRowServiceInterface.updateReconciliationReportRowsAsync(Wrappers.ReconciliationReportRowService.updateReconciliationReportRowsRequest request) {
			return base.Channel.updateReconciliationReportRowsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationReportRow[]> updateReconciliationReportRowsAsync(Google.Api.Ads.AdManager.v201802.ReconciliationReportRow[] reconciliationReportRows) {
			Wrappers.ReconciliationReportRowService.updateReconciliationReportRowsRequest inValue = new Wrappers.ReconciliationReportRowService.updateReconciliationReportRowsRequest();
			inValue.reconciliationReportRows = reconciliationReportRows;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationReportRow[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ReconciliationReportRowServiceInterface)(this)).updateReconciliationReportRowsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.ReportService
	{
	}
	/// <summary>An error for an exception that occurred while running the report.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReportError : ApiError {
		private ReportErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ReportErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ReportError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ReportErrorReason {
		/// <summary>Default <code>ReportError</code> when the reason is not among any already
		/// defined.
		/// </summary>
		DEFAULT = 0,
		/// <summary>User does not have permission to access the report.
		/// </summary>
		REPORT_ACCESS_NOT_ALLOWED = 1,
		/// <summary>User does not have permission to view one or more <a
		/// href='Dimension'>Dimension</a>.
		/// </summary>
		DIMENSION_VIEW_NOT_ALLOWED = 2,
		/// <summary>User has no permission to view one or more attributes.
		/// </summary>
		ATTRIBUTE_VIEW_NOT_ALLOWED = 4,
		/// <summary>User does not have permission to view one or more <a href='Column'>Column</a>.
		/// </summary>
		COLUMN_VIEW_NOT_ALLOWED = 5,
		/// <summary>The user has exceeded the limit on the number of reports that can be run
		/// concurrently. The current limit is 30 per user.
		/// </summary>
		TOO_MANY_CONCURRENT_REPORTS = 6,
		/// <summary>The report query exceeds the maximum allowed number of characters.
		/// </summary>
		REPORT_QUERY_TOO_LONG = 7,
		/// <summary>Invalid report job state for the given operation.
		/// </summary>
		INVALID_OPERATION_FOR_REPORT_STATE = 8,
		/// <summary>Invalid <a href='Dimension'>Dimension</a> objects specified.
		/// </summary>
		INVALID_DIMENSIONS = 9,
		/// <summary>The attribute ID(s) are not valid.
		/// </summary>
		INVALID_ATTRIBUTES = 10,
		/// <summary>The API error when running the report with <a
		/// href='ContentHierarchyDimension'>ContentHierarchyDimension</a>. There are three
		/// reasons for this error. <ol> <li><a
		/// href='ReportQuery#dimensions'>ReportQuery#dimensions</a> contains <a
		/// href='Dimension#CONTENT_HIERARCHY'>Dimension#CONTENT_HIERARCHY</a>, but <a
		/// href='ReportQuery#contentMetadataHierarchyCustomTargetingKeyIds'>ReportQuery#contentMetadataHierarchyCustomTargetingKeyIds</a>
		/// is empty.</li> <li><a
		/// href='ReportQuery#contentMetadataHierarchyCustomTargetingKeyIds'>ReportQuery#contentMetadataHierarchyCustomTargetingKeyIds</a>
		/// is non-empty, but <a href='ReportQuery#dimensions'>ReportQuery#dimensions</a>
		/// does not contain <a
		/// href='Dimension#CONTENT_HIERARCHY'>Dimension#CONTENT_HIERARCHY</a>.</li> <li>The
		/// <a
		/// href='ReportQuery#contentMetadataKeyHierarchyCustomTargetingKeyIds'>ReportQuery#contentMetadataKeyHierarchyCustomTargetingKeyIds</a>
		/// specified along with the <a
		/// href='Dimension#CONTENT_HIERARCHY'>Dimension#CONTENT_HIERARCHY</a> are not
		/// valid, i.e., these IDs are not defined in the content hierarchy by the
		/// publisher.</li> </ol>
		/// </summary>
		INVALID_CONTENT_HIERARCHY_DIMENSIONS = 11,
		/// <summary>Invalid <a href='Column'>Column</a> objects specified.
		/// </summary>
		INVALID_COLUMNS = 12,
		/// <summary>Invalid <a href='DimensionFilter'>DimensionFilter</a> objects specified.
		/// </summary>
		INVALID_DIMENSION_FILTERS = 13,
		/// <summary>Invalid date.
		/// </summary>
		INVALID_DATE = 14,
		/// <summary>The start date for running the report should not be later than the end date.
		/// </summary>
		END_DATE_TIME_NOT_AFTER_START_TIME = 15,
		/// <summary>The start date for running the report should not be more than three years before
		/// now.
		/// </summary>
		START_DATE_MORE_THAN_THREE_YEARS_AGO = 26,
		/// <summary>The list of <a href='Dimension'>Dimension</a> and <a href='Column'>Column</a>
		/// objects cannot be empty.
		/// </summary>
		NOT_NULL = 16,
		/// <summary>Attribute has to be selected in combination with dimensions.
		/// </summary>
		ATTRIBUTES_NOT_SUPPORTED_FOR_REQUEST = 17,
		/// <summary>The provided report violates one or more constraints, which govern
		/// incompatibilities and requirements between different report properties. Some
		/// reasons for constraint violations include: <ul> <li>Not all <a
		/// href='Column'>Column</a> objects requested are supported for the given set of <a
		/// href='Dimension'>Dimension</a> objects.</li> <li>The report's date range is not
		/// compatible with the given set of <a href='Column'>Column</a> objects.</li>
		/// <li>The report's <a href='TimeZoneType'>TimeZoneType</a> is not compatible with
		/// the given set of <a href='Column'>Column</a> and <a
		/// href='Dimension'>Dimension</a> objects (version 201802 and later).</li> <li>The
		/// report's currency is not compatible with the given set of <a
		/// href='Column'>Column</a> objects (version 201802 and later).</li> </ul>
		/// </summary>
		REPORT_CONSTRAINT_VIOLATION = 27,
		/// <summary>Failed to store/cache a report.
		/// </summary>
		FAILED_TO_STORE_REPORT = 19,
		/// <summary>The requested report does not exist.
		/// </summary>
		REPORT_NOT_FOUND = 20,
		/// <summary>User has no permission to view in another network.
		/// </summary>
		SR_CANNOT_RUN_REPORT_IN_ANOTHER_NETWORK = 21,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 25,
	}


	/// <summary>Errors related to currency codes.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CurrencyCodeError : ApiError {
		private CurrencyCodeErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CurrencyCodeErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reason behind the currency code error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CurrencyCodeError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CurrencyCodeErrorReason {
		/// <summary>The currency code is invalid and does not follow ISO 4217.
		/// </summary>
		INVALID = 0,
		/// <summary>The currency code is valid, but is not supported.
		/// </summary>
		UNSUPPORTED = 1,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ReportServiceInterface")]
	public interface ReportServiceInterface
	{
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		string getReportDownloadURL(long reportJobId, Google.Api.Ads.AdManager.v201802.ExportFormat exportFormat);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<string> getReportDownloadURLAsync(long reportJobId, Google.Api.Ads.AdManager.v201802.ExportFormat exportFormat);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		string getReportDownloadUrlWithOptions(long reportJobId, Google.Api.Ads.AdManager.v201802.ReportDownloadOptions reportDownloadOptions);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<string> getReportDownloadUrlWithOptionsAsync(long reportJobId, Google.Api.Ads.AdManager.v201802.ReportDownloadOptions reportDownloadOptions);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ReportJobStatus getReportJobStatus(long reportJobId);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReportJobStatus> getReportJobStatusAsync(long reportJobId);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.SavedQueryPage getSavedQueriesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.SavedQueryPage> getSavedQueriesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ReportJob runReportJob(Google.Api.Ads.AdManager.v201802.ReportJob reportJob);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReportJob> runReportJobAsync(Google.Api.Ads.AdManager.v201802.ReportJob reportJob);
	}


	/// <summary>The file formats available for creating the report.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ExportFormat {
		/// <summary>The report file is generated as a list of Tab Separated Values.
		/// </summary>
		TSV = 0,
		/// <summary>The report file is generated as a list of tab-separated values for Excel.
		/// </summary>
		TSV_EXCEL = 5,
		/// <summary>The report file is generated as a list of Comma Separated Values, to be used
		/// with automated machine processing. <p> <ul> <li>There is no pretty printing for
		/// the output, and no total row.</li> <li>Column headers are the qualified name
		/// e.g. "Dimension.ORDER_NAME".</li> <li>Network currency Monetary amounts are
		/// represented as micros in the <a href='Network#currencyCode'>currency of the
		/// network</a>.</li> <li>Starting from v201705, local currency Monetary amounts are
		/// represented as currency symbol + ' ' + micros.</li> <li>Dates are formatted
		/// according to the ISO 8601 standard YYYY-MM-DD</li> <li>DateTimes are formatted
		/// according to the ISO 8601 standard YYYY-MM-DDThh:mm:ss[+-]hh:mm</li> </ul></p>
		/// </summary>
		CSV_DUMP = 2,
		/// <summary>The report file is generated as XML.
		/// </summary>
		XML = 3,
		/// <summary>The report file is generated as an Office Open XML spreadsheet designed for
		/// Excel 2007+.
		/// </summary>
		XLSX = 4,
	}


	/// <summary>Represents the options for an API report download request. See <a
	/// href='ReportService#getReportDownloadUrlWithOptions'>ReportService#getReportDownloadUrlWithOptions</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReportDownloadOptions {
		private ExportFormat exportFormatField;

		private bool exportFormatFieldSpecified;

		private bool includeReportPropertiesField;

		private bool includeReportPropertiesFieldSpecified;

		private bool includeTotalsRowField;

		private bool includeTotalsRowFieldSpecified;

		private bool useGzipCompressionField;

		private bool useGzipCompressionFieldSpecified;

		/// <summary>The <a href='ExportFormat'>ExportFormat</a> used to generate the report. Default
		/// value is <a href='ExportFormat#CSV_DUMP'>ExportFormat#CSV_DUMP</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ExportFormat exportFormat {
			get {
				return this.exportFormatField;
			}
			set {
				this.exportFormatField = value;
				this.exportFormatSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="exportFormat" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool exportFormatSpecified {
			get {
				return this.exportFormatFieldSpecified;
			}
			set {
				this.exportFormatFieldSpecified = value;
			}
		}

		/// <summary>Whether or not to include the report properties (e.g. network, user, date
		/// generated...) in the generated report. Default is false.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public bool includeReportProperties {
			get {
				return this.includeReportPropertiesField;
			}
			set {
				this.includeReportPropertiesField = value;
				this.includeReportPropertiesSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="includeReportProperties" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool includeReportPropertiesSpecified {
			get {
				return this.includeReportPropertiesFieldSpecified;
			}
			set {
				this.includeReportPropertiesFieldSpecified = value;
			}
		}

		/// <summary>Whether or not to include the totals row. Default is true for all formats except
		/// <a href='ExportFormat#CSV_DUMP'>ExportFormat#CSV_DUMP</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public bool includeTotalsRow {
			get {
				return this.includeTotalsRowField;
			}
			set {
				this.includeTotalsRowField = value;
				this.includeTotalsRowSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="includeTotalsRow" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool includeTotalsRowSpecified {
			get {
				return this.includeTotalsRowFieldSpecified;
			}
			set {
				this.includeTotalsRowFieldSpecified = value;
			}
		}

		/// <summary>Whether or not to compress the report file to a gzip file. Default is true.
		/// <p>Regardless of value, gzip http compression is available from the URL by
		/// normal means.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public bool useGzipCompression {
			get {
				return this.useGzipCompressionField;
			}
			set {
				this.useGzipCompressionField = value;
				this.useGzipCompressionSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="useGzipCompression" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool useGzipCompressionSpecified {
			get {
				return this.useGzipCompressionFieldSpecified;
			}
			set {
				this.useGzipCompressionFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents the status of a <a href='ReportJob'>ReportJob</a> running on the
	/// server.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ReportJobStatus {
		/// <summary>The <a href='ReportJob'>ReportJob</a> has completed successfully and is ready to
		/// download.
		/// </summary>
		COMPLETED = 0,
		/// <summary>The <a href='ReportJob'>ReportJob</a> is still being executed.
		/// </summary>
		IN_PROGRESS = 1,
		/// <summary>The <a href='ReportJob'>ReportJob</a> has failed to run to completion.
		/// </summary>
		FAILED = 2,
	}


	/// <summary>A page of <a href='SavedQuery'>SavedQuery</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SavedQueryPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private SavedQuery[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of saved queries contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public SavedQuery[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>A saved <a href='ReportQuery'>ReportQuery</a> representing the selection
	/// criteria for running a report.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SavedQuery {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private ReportQuery reportQueryField;

		private bool isCompatibleWithApiVersionField;

		private bool isCompatibleWithApiVersionFieldSpecified;

		/// <summary>The ID of the saved query.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the saved query.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The <a href='ReportQuery'>ReportQuery</a> representing the selection criteria
		/// for the saved query. This will be non-null if and only if <a
		/// href='SavedQuery#isCompatibleWithApiVersion'>SavedQuery#isCompatibleWithApiVersion</a>
		/// is <code>true</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public ReportQuery reportQuery {
			get {
				return this.reportQueryField;
			}
			set {
				this.reportQueryField = value;
			}
		}

		/// <summary>Whether or not the saved query is compatible with the current API version. This
		/// will be <code>true</code> if and only if <a
		/// href='SavedQuery#reportQuery'>SavedQuery#reportQuery</a> is non-null. A saved
		/// query will be incompatible with the API if it uses columns, dimensions, or other
		/// reporting features from the UI that are not available in the <a
		/// href='ReportQuery'>ReportQuery</a> entity.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public bool isCompatibleWithApiVersion {
			get {
				return this.isCompatibleWithApiVersionField;
			}
			set {
				this.isCompatibleWithApiVersionField = value;
				this.isCompatibleWithApiVersionSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isCompatibleWithApiVersion" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isCompatibleWithApiVersionSpecified {
			get {
				return this.isCompatibleWithApiVersionFieldSpecified;
			}
			set {
				this.isCompatibleWithApiVersionFieldSpecified = value;
			}
		}
	}


	/// <summary>A <code>ReportQuery</code> object allows you to specify the selection criteria
	/// for generating a report. Only reports with at least one <a
	/// href='Column'>Column</a> are supported.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReportQuery {
		private Dimension[] dimensionsField;

		private ReportQueryAdUnitView adUnitViewField;

		private bool adUnitViewFieldSpecified;

		private Column[] columnsField;

		private DimensionAttribute[] dimensionAttributesField;

		private long[] customFieldIdsField;

		private long[] contentMetadataKeyHierarchyCustomTargetingKeyIdsField;

		private Date startDateField;

		private Date endDateField;

		private DateRangeType dateRangeTypeField;

		private bool dateRangeTypeFieldSpecified;

		private Statement statementField;

		private bool includeZeroSalesRowsField;

		private bool includeZeroSalesRowsFieldSpecified;

		private string adxReportCurrencyField;

		private TimeZoneType timeZoneTypeField;

		private bool timeZoneTypeFieldSpecified;

		/// <summary>The list of break-down types being requested in the report. The generated report
		/// will contain the dimensions in the same order as requested. This field is
		/// required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("dimensions", Order = 0)]
		public Dimension[] dimensions {
			get {
				return this.dimensionsField;
			}
			set {
				this.dimensionsField = value;
			}
		}

		/// <summary>The ad unit view for the report. Defaults to <a
		/// href='AdUnitView#TOP_LEVEL'>AdUnitView#TOP_LEVEL</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public ReportQueryAdUnitView adUnitView {
			get {
				return this.adUnitViewField;
			}
			set {
				this.adUnitViewField = value;
				this.adUnitViewSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="adUnitView"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool adUnitViewSpecified {
			get {
				return this.adUnitViewFieldSpecified;
			}
			set {
				this.adUnitViewFieldSpecified = value;
			}
		}

		/// <summary>The list of trafficking statistics and revenue information being requested in
		/// the report. The generated report will contain the columns in the same order as
		/// requested. This field is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("columns", Order = 2)]
		public Column[] columns {
			get {
				return this.columnsField;
			}
			set {
				this.columnsField = value;
			}
		}

		/// <summary>The list of break-down attributes being requested in this report. Some <a
		/// href='DimensionAttribute'>DimensionAttribute</a> values can only be used with
		/// certain <a href='Dimension'>Dimension</a> values that must be included in the <a
		/// href='#dimensions'>#dimensions</a> attribute. The generated report will contain
		/// the attributes in the same order as requested.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("dimensionAttributes", Order = 3)]
		public DimensionAttribute[] dimensionAttributes {
			get {
				return this.dimensionAttributesField;
			}
			set {
				this.dimensionAttributesField = value;
			}
		}

		/// <summary>The list of <a href='CustomField#id'>CustomField#id</a> being requested in this
		/// report. To add a <a href='CustomField'>CustomField</a> to the report, you must
		/// include its corresponding <a href='Dimension'>Dimension</a>, determined by the
		/// <a href='CustomField#entityType'>CustomField#entityType</a>, as a <a
		/// href='#dimensions'>dimension</a>. <table> <tr> <th scope="col" colspan="2"><a
		/// href='CustomFieldEntityType#entityType'>CustomFieldEntityType#entityType</a></th>
		/// </tr> <tr> <td><a
		/// href='CustomFieldEntityType#LINE_ITEM'>CustomFieldEntityType#LINE_ITEM</a></td>
		/// <td><a href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a></td> </tr>
		/// <tr> <td><a
		/// href='CustomFieldEntityType#ORDER'>CustomFieldEntityType#ORDER</a></td> <td><a
		/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a></td> </tr> <tr> <td><a
		/// href='CustomFieldEntityType#CREATIVE'>CustomFieldEntityType#CREATIVE</a></td>
		/// <td><a href='Dimension#CREATIVE_NAME'>Dimension#CREATIVE_NAME</a></td> </tr>
		/// <tr> <td><a
		/// href='CustomFieldEntityType#PRODUCT_TEMPLATE'>CustomFieldEntityType#PRODUCT_TEMPLATE</a></td>
		/// <td><a
		/// href='Dimension#PRODUCT_TEMPLATE_NAME'>Dimension#PRODUCT_TEMPLATE_NAME</a></td>
		/// </tr> <tr> <td><a
		/// href='CustomFieldEntityType#PRODUCT'>CustomFieldEntityType#PRODUCT</a></td>
		/// <td><a href='Dimension#PRODUCT_NAME'>Dimension#PRODUCT_NAME</a></td> </tr> <tr>
		/// <td><a
		/// href='CustomFieldEntityType#PROPOSAL'>CustomFieldEntityType#PROPOSAL</a></td>
		/// <td><a href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a></td> </tr>
		/// <tr> <td><a
		/// href='CustomFieldEntityType#PROPOSAL_LINE_ITEM'>CustomFieldEntityType#PROPOSAL_LINE_ITEM</a></td>
		/// <td><a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a></td>
		/// </tr> </table>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("customFieldIds", Order = 4)]
		public long[] customFieldIds {
			get {
				return this.customFieldIdsField;
			}
			set {
				this.customFieldIdsField = value;
			}
		}

		/// <summary>The list of content metadata hierarchy custom targeting key <a
		/// href='CustomTargetingKey#id'>IDs</a> being requested in this report. Each of
		/// these IDs must have been defined in the <a
		/// href='ContentMetadataKeyHierarchy'>content metadata key hierarchy</a>. This will
		/// include dimensions in the form of <code></code> and <code></code> where where
		/// <code>ID</code> is the ID of the <a href='CustomTargetingValue#id'>custom
		/// targeting value</a> and <code></code> is the <a
		/// href='CustomTargetingValue#name'>name</a>. <p>To add <a
		/// href='CustomTargetingKey#id'>IDs</a>, you must include <a
		/// href='Dimension#CONTENT_HIERARCHY'>Dimension#CONTENT_HIERARCHY</a> in <a
		/// href='#dimensions'>#dimensions</a>, and specify a non-empty list of custom
		/// targeting key IDs. The order of content hierarchy columns in the report
		/// correspond to the place of <a
		/// href='Dimension#CONTENT_HIERARCHY'>Dimension#CONTENT_HIERARCHY</a> in <a
		/// href='#dimensions'>#dimensions</a>. For example, if <a
		/// href='#dimensions'>#dimensions</a> contains the following dimensions in the
		/// order: <a href='Dimension#ADVERTISER_NAME'>Dimension#ADVERTISER_NAME</a>, <a
		/// href='Dimension#CONTENT_HIERARCHY'>Dimension#CONTENT_HIERARCHY</a> and <a
		/// href='Dimension#COUNTRY_NAME'>Dimension#COUNTRY_NAME</a>, and <a
		/// href='#contentMetadataKeyHierarchyCustomTargetingKeyIds'>#contentMetadataKeyHierarchyCustomTargetingKeyIds</a>
		/// contains the following IDs in the order: 1001 and 1002. The order of dimensions
		/// in the report will be: Dimension.ADVERTISER_NAME,
		/// Dimension.CONTENT_HIERARCHY_CUSTOM_TARGETING_KEY[1001]_VALUE,
		/// Dimension.CONTENT_HIERARCHY_CUSTOM_TARGETING_KEY[1002]_VALUE,
		/// Dimension.COUNTRY_NAME, Dimension.ADVERTISER_ID,
		/// Dimension.CONTENT_HIERARCHY_CUSTOM_TARGETING_KEY[1001]_ID,
		/// Dimension.CONTENT_HIERARCHY_CUSTOM_TARGETING_KEY[1002]_ID,
		/// Dimension.COUNTRY_CRITERIA_ID</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("contentMetadataKeyHierarchyCustomTargetingKeyIds", Order = 5)]
		public long[] contentMetadataKeyHierarchyCustomTargetingKeyIds {
			get {
				return this.contentMetadataKeyHierarchyCustomTargetingKeyIdsField;
			}
			set {
				this.contentMetadataKeyHierarchyCustomTargetingKeyIdsField = value;
			}
		}

		/// <summary>The start date from which the reporting information is gathered. The
		/// <code>ReportQuery#dateRangeType</code> field must be set to <a
		/// href='DateRangeType#CUSTOM_DATE'>DateRangeType#CUSTOM_DATE</a> in order to use
		/// this.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public Date startDate {
			get {
				return this.startDateField;
			}
			set {
				this.startDateField = value;
			}
		}

		/// <summary>The end date upto which the reporting information is gathered. The
		/// <code>ReportQuery#dateRangeType</code> field must be set to <a
		/// href='DateRangeType#CUSTOM_DATE'>DateRangeType#CUSTOM_DATE</a> in order to use
		/// this.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public Date endDate {
			get {
				return this.endDateField;
			}
			set {
				this.endDateField = value;
			}
		}

		/// <summary>The period of time for which the reporting data is being generated. In order to
		/// define custom time periods, set this to <a
		/// href='DateRangeType#CUSTOM_DATE'>DateRangeType#CUSTOM_DATE</a>. If set to <a
		/// href='DateRangeType#CUSTOM_DATE'>DateRangeType#CUSTOM_DATE</a>, then <a
		/// href='ReportQuery#startDate'>ReportQuery#startDate</a> and <a
		/// href='ReportQuery#endDate'>ReportQuery#endDate</a> will be used.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public DateRangeType dateRangeType {
			get {
				return this.dateRangeTypeField;
			}
			set {
				this.dateRangeTypeField = value;
				this.dateRangeTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="dateRangeType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool dateRangeTypeSpecified {
			get {
				return this.dateRangeTypeFieldSpecified;
			}
			set {
				this.dateRangeTypeFieldSpecified = value;
			}
		}

		/// <summary>Specifies a filter to use for reporting on data. This filter will be used in
		/// conjunction (joined with an AND statement) with the date range selected through
		/// <a href='#dateRangeType'>#dateRangeType</a>, <a
		/// href='#startDate'>#startDate</a>, and <a href='#endDate'>#endDate</a> and the
		/// dimension filters selected through <a
		/// href='#dimensionFilters'>#dimensionFilters</a>. The syntax currently allowed for
		/// <a href='Statement#query'>Statement#query</a> is<br /> <code>[WHERE
		/// &lt;condition&gt; {AND &lt;condition&gt; ...}]</code><br />
		/// <p>&lt;condition&gt;<br /> #x160;#x160;#x160;#x160; <code>:= &lt;property&gt; =
		/// &lt;value&gt;</code><br /> <code>&lt;condition&gt;</code><br />
		/// #x160;#x160;#x160;#x160; <code>:= &lt;property&gt; = &lt;bind
		/// variable&gt;</code><br /> <code>&lt;condition&gt; := &lt;property&gt; IN
		/// &lt;list&gt;</code><br /> <code>&lt;bind variable&gt; := :&lt;name&gt;</code><br
		/// /> where property is the enumeration name of a <a href='Dimension'>Dimension</a>
		/// that can be filtered.</p> <p>For example, the statement "WHERE LINE_ITEM_ID IN
		/// (34344, 23235)" can be used to generate a report for a specific set of line
		/// items</p> <p>Filtering on IDs is highly recommended over filtering on names,
		/// especially for geographical entities. When filtering on names, matching is case
		/// sensitive.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public Statement statement {
			get {
				return this.statementField;
			}
			set {
				this.statementField = value;
			}
		}

		/// <summary>Whether report includes rows with all zero metric values. This field is only
		/// eligible for sales reports. This field is optional and defaults to
		/// <code>false</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public bool includeZeroSalesRows {
			get {
				return this.includeZeroSalesRowsField;
			}
			set {
				this.includeZeroSalesRowsField = value;
				this.includeZeroSalesRowsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="includeZeroSalesRows" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool includeZeroSalesRowsSpecified {
			get {
				return this.includeZeroSalesRowsFieldSpecified;
			}
			set {
				this.includeZeroSalesRowsFieldSpecified = value;
			}
		}

		/// <summary>The currency for Ad Exchange revenue metrics. This field is only valid for Ad
		/// Exchange metrics, and an exception will be thrown if this field is used with
		/// non-Ad Exchange metrics. Defaults to the network currency if left
		/// <code>null</code>. The supported currency codes can be found in <a
		/// href="https://support.google.com/adxseller/answer/6019533">this Help Center
		/// article.</a>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 11)]
		public string adxReportCurrency {
			get {
				return this.adxReportCurrencyField;
			}
			set {
				this.adxReportCurrencyField = value;
			}
		}

		/// <summary>Gets the <a href='TimeZoneType'>TimeZoneType</a> for this report, which
		/// determines the time zone used for the report's date range. Defaults to <a
		/// href='TimeZoneType.PUBLISHER'>TimeZoneType.PUBLISHER</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 12)]
		public TimeZoneType timeZoneType {
			get {
				return this.timeZoneTypeField;
			}
			set {
				this.timeZoneTypeField = value;
				this.timeZoneTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="timeZoneType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool timeZoneTypeSpecified {
			get {
				return this.timeZoneTypeFieldSpecified;
			}
			set {
				this.timeZoneTypeFieldSpecified = value;
			}
		}
	}


	/// <summary><code>Dimension</code> provides the break-down and filterable types available
	/// for running a <a href='ReportJob'>ReportJob</a>. Aggregate and percentage
	/// columns will be calculated based on these groupings.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum Dimension {
		/// <summary>Breaks down reporting data by month and year in the network time zone. Can be
		/// used to filter on month using ISO 4601 format 'YYYY-MM'. <p><b>Note:</b> In
		/// v201802 and later, this dimension is compatible with the following time zone
		/// types:</p> <ul> <li><a
		/// href='TimeZoneType.PUBLISHER'>TimeZoneType.PUBLISHER</a></li> <li><a
		/// href='TimeZoneType.PROPOSAL_LOCAL'>TimeZoneType.PROPOSAL_LOCAL</a></li> </ul>
		/// <p>Corresponds to "Month and year" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, SELL_THROUGH, REACH, SALES,
		/// PARTNER_FINANCE, CREATIVE_QOS.</p>
		/// </summary>
		MONTH_AND_YEAR = 0,
		/// <summary>Breaks down reporting data by week of the year in the network time zone. Cannot
		/// be used for filtering. <p><b>Note:</b> In v201802 and later, this dimension is
		/// compatible with the following time zone types:</p> <ul> <li><a
		/// href='TimeZoneType.PUBLISHER'>TimeZoneType.PUBLISHER</a></li> <li><a
		/// href='TimeZoneType.PROPOSAL_LOCAL'>TimeZoneType.PROPOSAL_LOCAL</a></li> </ul>
		/// <p>Corresponds to "Week" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES, DATA_LEAKAGE,
		/// CREATIVE_QOS.</p>
		/// </summary>
		WEEK = 1,
		/// <summary>Breaks down reporting data by date in the network time zone. Can be used to
		/// filter by date using ISO 8601's format 'YYYY-MM-DD'". <p><b>Note:</b> In v201802
		/// and later, this dimension is compatible with the following time zone types:</p>
		/// <ul> <li><a href='TimeZoneType.PUBLISHER'>TimeZoneType.PUBLISHER</a></li> <li><a
		/// href='TimeZoneType.PROPOSAL_LOCAL'>TimeZoneType.PROPOSAL_LOCAL</a></li> </ul>
		/// <p>Corresponds to "Date" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES,
		/// CREATIVE_QOS.</p>
		/// </summary>
		DATE = 2,
		/// <summary>Breaks down reporting data by day of the week in the network time zone. Can be
		/// used to filter by day of the week using the index of the day (from 1 for Monday
		/// is 1 to 7 for Sunday). <p>Corresponds to "Day of week" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SELL_THROUGH,
		/// REACH, SALES, CREATIVE_QOS.</p>
		/// </summary>
		DAY = 3,
		/// <summary>Breaks down reporting data by hour of the day in the network time zone. Can be
		/// used to filter by hour of the day (from 0 to 23). <p>Corresponds to "Hour" in
		/// the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, REACH.</p>
		/// </summary>
		HOUR = 4,
		/// <summary>Breaks down reporting data by <a href='LineItem#id'>LineItem#id</a>. Can be used
		/// to filter by <a href='LineItem#id'>LineItem#id</a>. <p>Compatible with any of
		/// the following report types: HISTORICAL, SELL_THROUGH, REACH, SALES,
		/// DATA_LEAKAGE, CREATIVE_QOS.</p>
		/// </summary>
		LINE_ITEM_ID = 5,
		/// <summary>Breaks down reporting data by line item. <a
		/// href='LineItem#name'>LineItem#name</a> and <a href='LineItem#id'>LineItem#id</a>
		/// are automatically included as columns in the report. Can be used to filter by <a
		/// href='LineItem#name'>LineItem#name</a>. <p>Corresponds to "Line item" in the Ad
		/// Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// SELL_THROUGH, REACH, SALES, DATA_LEAKAGE, CREATIVE_QOS.</p>
		/// </summary>
		LINE_ITEM_NAME = 6,
		/// <summary>Breaks down reporting data by <a
		/// href='LineItem#lineItemType'>LineItem#lineItemType</a>. Can be used to filter by
		/// line item type using <a href='LineItemType'>LineItemType</a> enumeration names.
		/// <p>Corresponds to "Line item type" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, SELL_THROUGH, REACH, DATA_LEAKAGE,
		/// CREATIVE_QOS.</p>
		/// </summary>
		LINE_ITEM_TYPE = 7,
		/// <summary>Breaks down reporting data by aggregated demand channel type. <p>This field is
		/// deprecated and will be removed in v201805.</p> <p>Compatible with any of the
		/// following report types: HISTORICAL, REACH.</p>
		/// </summary>
		AGGREGATED_DEMAND_CHANNEL = 141,
		/// <summary>Breaks down reporting data by <a href='Order#id'>Order#id</a>. Can be used to
		/// filter by <a href='Order#id'>Order#id</a>. <p>Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES, DATA_LEAKAGE,
		/// CREATIVE_QOS.</p>
		/// </summary>
		ORDER_ID = 8,
		/// <summary>Breaks down reporting data by order. <a href='Order#name'>Order#name</a> and <a
		/// href='Order#id'>Order#id</a> are automatically included as columns in the
		/// report. Can be used to filter by <a href='Order#name'>Order#name</a>.
		/// <p>Corresponds to "Order" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES, DATA_LEAKAGE,
		/// CREATIVE_QOS.</p>
		/// </summary>
		ORDER_NAME = 9,
		/// <summary>Delivery status of the order. Not available as a dimension to report on, but
		/// exists as a dimension in order to filter on it using PQL. Valid values are
		/// 'STARTED', 'NOT_STARTED' and 'COMPLETED'. <p>Compatible with any of the
		/// following report types: HISTORICAL, REACH.</p>
		/// </summary>
		ORDER_DELIVERY_STATUS = 142,
		/// <summary>Breaks down reporting data by advertising company <a
		/// href='Company#id'>Company#id</a>. Can be used to filter by <a
		/// href='Company#id'>Company#id</a>. <p>Compatible with any of the following report
		/// types: HISTORICAL, SELL_THROUGH, REACH, SALES, DATA_LEAKAGE, CREATIVE_QOS.</p>
		/// </summary>
		ADVERTISER_ID = 10,
		/// <summary>Breaks down reporting data by advertising company. <a
		/// href='Company#name'>Company#name</a> and <a href='Company#id'>Company#id</a> are
		/// automatically included as columns in the report. Can be used to filter by <a
		/// href='Company#name'>Company#name</a>. <p>Corresponds to "Advertiser" in the Ad
		/// Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// SELL_THROUGH, REACH, SALES, DATA_LEAKAGE, CREATIVE_QOS.</p>
		/// </summary>
		ADVERTISER_NAME = 11,
		/// <summary>The network that provided the ad for SDK ad mediation. <p>If selected for a
		/// report, that report will include only SDK mediation ads and will not contain
		/// non-SDK mediation ads.</p> <p>SDK mediation ads are ads for mobile devices. They
		/// have a list of ad networks which can provide ads to serve. Not every ad network
		/// will have an ad to serve so the device will try each network one-by-one until it
		/// finds an ad network with an ad to serve. The ad network that ends up serving the
		/// ad will appear here. Note that this id does not correlate to anything in the
		/// companies table and is not the same id as is served by <a
		/// href='#ADVERTISER_ID'>#ADVERTISER_ID</a>.</p> <p>Compatible with any of the
		/// following report types: HISTORICAL, REACH.</p>
		/// </summary>
		AD_NETWORK_ID = 12,
		/// <summary>The name of the network defined in <a href='#AD_NETWORK_ID'>#AD_NETWORK_ID</a>.
		/// <p>Corresponds to "Ad network name" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		AD_NETWORK_NAME = 13,
		/// <summary>Breaks down reporting data by salesperson <a href='User#id'>User#id</a>. Can be
		/// used to filter by <a href='User#id'>User#id</a>. <p>Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES, DATA_LEAKAGE,
		/// CREATIVE_QOS.</p>
		/// </summary>
		SALESPERSON_ID = 14,
		/// <summary>Breaks down reporting data by salesperson. <a href='User#name'>User#name</a> and
		/// <a href='User#id'>User#id</a> of the salesperson are automatically included as
		/// columns in the report. Can be used to filter by <a
		/// href='User#name'>User#name</a>. <p>Corresponds to "Salesperson" in the Ad
		/// Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// SELL_THROUGH, REACH, SALES, DATA_LEAKAGE, CREATIVE_QOS.</p>
		/// </summary>
		SALESPERSON_NAME = 15,
		/// <summary>Breaks down reporting data by <a href='Creative#id'>Creative#id</a> or creative
		/// set id (master's <a href='Creative#id'>Creative#id</a>) if the creative is part
		/// of a creative set. Can be used to filter by <a
		/// href='Creative#id'>Creative#id</a>. <p>Compatible with any of the following
		/// report types: HISTORICAL, REACH, DATA_LEAKAGE, CREATIVE_QOS.</p>
		/// </summary>
		CREATIVE_ID = 16,
		/// <summary>Breaks down reporting data by creative. <a
		/// href='Creative#name'>Creative#name</a> and <a href='Creative#id'>Creative#id</a>
		/// are automatically included as columns in the report. Can be used to filter by <a
		/// href='Creative#name'>Creative#name</a>. <p>Corresponds to "Creative" in the Ad
		/// Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// REACH, DATA_LEAKAGE, CREATIVE_QOS.</p>
		/// </summary>
		CREATIVE_NAME = 17,
		/// <summary>Breaks down reporting data by creative type. <p>Corresponds to "Creative type"
		/// in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, REACH.</p>
		/// </summary>
		CREATIVE_TYPE = 18,
		/// <summary>Breaks down reporting data by creative billing type. <p>Corresponds to "Creative
		/// billing type" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, REACH.</p>
		/// </summary>
		CREATIVE_BILLING_TYPE = 19,
		/// <summary>Breaks down reporting data by custom event ID. <p>Compatible with any of the
		/// following report types: HISTORICAL, REACH.</p>
		/// </summary>
		CUSTOM_EVENT_ID = 20,
		/// <summary>Breaks down reporting data by custom event name. <p>Corresponds to "Custom
		/// event" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, REACH.</p>
		/// </summary>
		CUSTOM_EVENT_NAME = 21,
		/// <summary>Breaks down reporting data by custom event type (timer/exit/counter).
		/// <p>Corresponds to "Custom event type" in the Ad Manager UI. Compatible with any
		/// of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		CUSTOM_EVENT_TYPE = 22,
		/// <summary>Breaks down reporting data by <a href='Creative#size'>Creative#size</a>. Cannot
		/// be used for filtering. <p>Corresponds to "Creative size" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		CREATIVE_SIZE = 23,
		/// <summary>Breaks down reporting data by <a href='AdUnit#id'>AdUnit#id</a>. Can be used to
		/// filter by <a href='AdUnit#id'>AdUnit#id</a>. <a
		/// href='#AD_UNIT_NAME'>#AD_UNIT_NAME</a>, i.e. <a
		/// href='AdUnit#name'>AdUnit#name</a>, is automatically included as a dimension in
		/// the report. <p>Compatible with any of the following report types: HISTORICAL,
		/// SELL_THROUGH, REACH, SALES, CREATIVE_QOS.</p>
		/// </summary>
		AD_UNIT_ID = 24,
		/// <summary>Breaks down reporting data by ad unit. <a href='AdUnit#name'>AdUnit#name</a> and
		/// <a href='AdUnit#id'>AdUnit#id</a> are automatically included as columns in the
		/// report. Can be used to filter by <a href='AdUnit#name'>AdUnit#name</a>.
		/// <p>Corresponds to "Ad unit" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES,
		/// CREATIVE_QOS.</p>
		/// </summary>
		AD_UNIT_NAME = 25,
		/// <summary>Used to filter on all the descendants of an ad unit by <a
		/// href='AdUnit#id'>AdUnit#id</a>. Not available as a dimension to report on.
		/// <p>Compatible with any of the following report types: HISTORICAL, SELL_THROUGH,
		/// REACH, SALES, CREATIVE_QOS.</p>
		/// </summary>
		PARENT_AD_UNIT_ID = 26,
		/// <summary>Used to filter on all the descendants of an ad unit by <a
		/// href='AdUnit#name'>AdUnit#name</a>. Not available as a dimension to report on.
		/// <p>Compatible with any of the following report types: HISTORICAL, SELL_THROUGH,
		/// REACH, SALES, CREATIVE_QOS.</p>
		/// </summary>
		PARENT_AD_UNIT_NAME = 27,
		/// <summary>Breaks down reporting data by <a href='Placement#id'>Placement#id</a>. Can be
		/// used to filter by <a href='Placement#id'>Placement#id</a>. <p>Compatible with
		/// any of the following report types: HISTORICAL, SELL_THROUGH, REACH.</p>
		/// </summary>
		PLACEMENT_ID = 28,
		/// <summary>Breaks down reporting data by placement. <a
		/// href='Placement#name'>Placement#name</a> and <a
		/// href='Placement#id'>Placement#id</a> are automatically included as columns in
		/// the report. Can be used to filter by <a
		/// href='Placement#name'>Placement#name</a>. <p>Corresponds to "Placement" in the
		/// Ad Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// SELL_THROUGH, REACH.</p>
		/// </summary>
		PLACEMENT_NAME = 29,
		/// <summary>Status of the placement. Not available as a dimension to report on, but exists
		/// as a dimension in order to filter on it using PQL. Can be used to filter on <a
		/// href='Placement#status'>Placement#status</a> by using <a
		/// href='InventoryStatus'>InventoryStatus</a> enumeration names. <p>Compatible with
		/// any of the following report types: HISTORICAL, SELL_THROUGH, REACH.</p>
		/// </summary>
		PLACEMENT_STATUS = 143,
		/// <summary>Breaks down reporting data by criteria predefined by Ad Manager like the
		/// operating system, browser etc. Cannot be used for filtering. <p>Corresponds to
		/// "Targeting" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, REACH.</p>
		/// </summary>
		TARGETING = 30,
		/// <summary>The ID of the device category to which an ad is being targeted. Can be used to
		/// filter by device category ID. <p>Compatible with any of the following report
		/// types: HISTORICAL, REACH, CREATIVE_QOS.</p>
		/// </summary>
		DEVICE_CATEGORY_ID = 31,
		/// <summary>The category of device (smartphone, feature phone, tablet, or desktop) to which
		/// an ad is being targeted. Can be used to filter by device category name.
		/// <p>Corresponds to "Device category" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, REACH, CREATIVE_QOS.</p>
		/// </summary>
		DEVICE_CATEGORY_NAME = 32,
		/// <summary>Breaks down reporting data by country criteria ID. Can be used to filter by
		/// country criteria ID. <p>Compatible with any of the following report types:
		/// HISTORICAL, SELL_THROUGH, REACH, CREATIVE_QOS.</p>
		/// </summary>
		COUNTRY_CRITERIA_ID = 33,
		/// <summary>Breaks down reporting data by country name. The country name and the country
		/// criteria ID are automatically included as columns in the report. Can be used to
		/// filter by country name using the US English name. <p>Corresponds to "Country" in
		/// the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, SELL_THROUGH, REACH, CREATIVE_QOS.</p>
		/// </summary>
		COUNTRY_NAME = 34,
		/// <summary>Breaks down reporting data by region criteria ID. Can be used to filter by
		/// region criteria ID. <p>Compatible with any of the following report types:
		/// HISTORICAL, REACH.</p>
		/// </summary>
		REGION_CRITERIA_ID = 35,
		/// <summary>Breaks down reporting data by region name. The region name and the region
		/// criteria ID are automatically included as columns in the report. Can be used to
		/// filter by region name using the US English name. <p>Corresponds to "Region" in
		/// the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, REACH.</p>
		/// </summary>
		REGION_NAME = 36,
		/// <summary>Breaks down reporting data by city criteria ID. Can be used to filter by city
		/// criteria ID. <p>Compatible with any of the following report types: HISTORICAL,
		/// REACH.</p>
		/// </summary>
		CITY_CRITERIA_ID = 37,
		/// <summary>Breaks down reporting data by city name. The city name and the city criteria ID
		/// are automatically included as columns in the report. Can be used to filter by
		/// city name using the US English name. <p>Corresponds to "City" in the Ad Manager
		/// UI. Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		CITY_NAME = 38,
		/// <summary>Breaks down reporting data by metro criteria ID. Can be used to filter by metro
		/// criteria ID. <p>Compatible with any of the following report types: HISTORICAL,
		/// REACH.</p>
		/// </summary>
		METRO_CRITERIA_ID = 39,
		/// <summary>Breaks down reporting data by metro name. The metro name and the metro criteria
		/// ID are automatically included as columns in the report. Can be used to filter by
		/// metro name using the US English name. <p>Corresponds to "Metro" in the Ad
		/// Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// REACH.</p>
		/// </summary>
		METRO_NAME = 40,
		/// <summary>Breaks down reporting data by postal code criteria ID. Can be used to filter by
		/// postal code criteria ID. <p>Compatible with any of the following report types:
		/// HISTORICAL, REACH.</p>
		/// </summary>
		POSTAL_CODE_CRITERIA_ID = 41,
		/// <summary>Breaks down reporting data by postal code. The postal code and the postal code
		/// criteria ID are automatically included as columns in the report. Can be used to
		/// filter by postal code. <p>Corresponds to "Postal code" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		POSTAL_CODE = 42,
		/// <summary>Breaks down reporting data by <a
		/// href='CustomTargetingValue#id'>CustomTargetingValue#id</a>. Can be used to
		/// filter by <a href='CustomTargetingValue#id'>CustomTargetingValue#id</a>.
		/// <p>Compatible with any of the following report types: HISTORICAL, REACH,
		/// SALES.</p>
		/// </summary>
		CUSTOM_TARGETING_VALUE_ID = 43,
		/// <summary>Breaks down reporting data by custom criteria. The <a
		/// href='CustomTargetingValue'>CustomTargetingValue</a> is displayed in the form:
		/// <ul> <li>car=honda when value match type is <a
		/// href='CustomTargetingValue.MatchType#EXACT'>CustomTargetingValue.MatchType#EXACT</a></li>
		/// <li>car~honda when value match type is <a
		/// href='CustomTargetingValue.MatchType#BROAD'>CustomTargetingValue.MatchType#BROAD</a></li>
		/// <li>car=*honda when value match type is <a
		/// href='CustomTargetingValue.MatchType#PREFIX'>CustomTargetingValue.MatchType#PREFIX</a></li>
		/// <li>car~*honda when value match type is <a
		/// href='CustomTargetingValue.MatchType#BROAD_PREFIX'>CustomTargetingValue.MatchType#BROAD_PREFIX</a></li>
		/// </ul> <a href='#CUSTOM_TARGETING_VALUE_ID'>#CUSTOM_TARGETING_VALUE_ID</a>, i.e.
		/// <a href='CustomTargetingValue#id'>CustomTargetingValue#id</a> is automatically
		/// included as a column in the report. Cannot be used for filtering; use <a
		/// href='#CUSTOM_TARGETING_VALUE_ID'>#CUSTOM_TARGETING_VALUE_ID</a> instead.
		/// <p>When using this <code>Dimension</code>, metrics for freeform key values are
		/// only reported on when they are registered with <code></code>.</p> <p>Corresponds
		/// to "Key-values" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		CUSTOM_CRITERIA = 44,
		/// <summary>Breaks down reporting data by activity ID. Can be used to filter by activity ID.
		/// <p>Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		ACTIVITY_ID = 45,
		/// <summary>Breaks down reporting data by activity. The activity name and the activity ID
		/// are automatically included as columns in the report. Can be used to filter by
		/// activity name. <p>Corresponds to "Activity" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		ACTIVITY_NAME = 46,
		/// <summary>Breaks down reporting data by activity group ID. Can be used to filter by
		/// activity group ID. <p>Compatible with any of the following report types:
		/// HISTORICAL, REACH.</p>
		/// </summary>
		ACTIVITY_GROUP_ID = 47,
		/// <summary>Breaks down reporting data by activity group. The activity group name and the
		/// activity group ID are automatically included as columns in the report. Can be
		/// used to filter by activity group name. <p>Corresponds to "Activity group" in the
		/// Ad Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// REACH.</p>
		/// </summary>
		ACTIVITY_GROUP_NAME = 48,
		/// <summary>Breaks down reporting data by <a href='Content#id'>Content#id</a>. Can be used
		/// to filter by <a href='Content#id'>Content#id</a>. <p>Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH.</p>
		/// </summary>
		CONTENT_ID = 49,
		/// <summary>Breaks down reporting data by content. <a href='Content#name'>Content#name</a>
		/// and <a href='Content#id'>Content#id</a> are automatically included as columns in
		/// the report. Can be used to filter by <a href='Content#name'>Content#name</a>.
		/// <p>Corresponds to "Content" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH.</p>
		/// </summary>
		CONTENT_NAME = 50,
		/// <summary>Breaks down reporting data by <a href='ContentBundle#id'>ContentBundle#id</a>.
		/// Can be used to filter by <a href='ContentBundle#id'>ContentBundle#id</a>.
		/// <p>Compatible with any of the following report types: HISTORICAL, SELL_THROUGH,
		/// REACH.</p>
		/// </summary>
		CONTENT_BUNDLE_ID = 51,
		/// <summary>Breaks down reporting data by content bundle. <a
		/// href='ContentBundle#name'>ContentBundle#name</a> and <a
		/// href='ContentBundle#id'>ContentBundle#id</a> are automatically included as
		/// columns in the report. Can be used to filter by <a
		/// href='ContentBundle#name'>ContentBundle#name</a>. <p>Corresponds to "Content
		/// bundle" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, SELL_THROUGH, REACH.</p>
		/// </summary>
		CONTENT_BUNDLE_NAME = 52,
		/// <summary>Breaks down reporting data by the content hierarchy. To use this dimension, a
		/// list of custom targeting key IDs must be specified in <a
		/// href='ReportQuery#contentMetadataKeyHierarchyCustomTargetingKeyIds'>ReportQuery#contentMetadataKeyHierarchyCustomTargetingKeyIds</a>.
		/// <p>This dimension can be used as a filter in the <a
		/// href='Statement'>Statement</a> in PQL syntax:
		/// CONTENT_HIERARCHY_CUSTOM_TARGETING_KEY[keyId]_ID = <a
		/// href='CustomTargetingValue#id'>custom targeting value ID</a></p> <p>For example:
		/// WHERE CONTENT_HIERARCHY_CUSTOM_TARGETING_KEY[4242]_ID = 53423</p>
		/// </summary>
		CONTENT_HIERARCHY = 53,
		/// <summary>Breaks down reporting data by the fallback position of the video ad, i.e.,
		/// <code>NON_FALLBACK</code>, <code>FALLBACK_POSITION_1</code>, <code></code>, etc.
		/// Can be used for filtering. <p>Corresponds to "Fallback position" in the Ad
		/// Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// REACH, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_FALLBACK_POSITION = 54,
		/// <summary>Breaks down reporting data by the position of the video ad within the video
		/// stream, i.e., <code>UNKNOWN_POSITION</code>, <code>PREROLL</code>,
		/// <code>POSTROLL</code>, <code>UNKNOWN_MIDROLL</code>, <code>MIDROLL_1</code>,
		/// <code>MIDROLL_2</code>, etc. <code>UNKNOWN_MIDROLL</code> represents a midroll,
		/// but which specific midroll is unknown. Can be used for filtering. <p>Corresponds
		/// to "Position of pod" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH, CREATIVE_QOS.</p>
		/// </summary>
		POSITION_OF_POD = 55,
		/// <summary>Breaks down reporting data by the position of the video ad within the pod, i.e.,
		/// <code>UNKNOWN_POSITION</code>, <code>POSITION_1</code>, <code></code>, etc. Can
		/// be used for filtering. <p>Corresponds to "Position in pod" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, REACH,
		/// CREATIVE_QOS.</p>
		/// </summary>
		POSITION_IN_POD = 56,
		/// <summary>Breaks down reporting data by partner <a href='Company#id'>Company#id</a>.
		/// <p>Compatible with any of the following report types: HISTORICAL, REACH,
		/// PARTNER_FINANCE.</p>
		/// </summary>
		PARTNER_MANAGEMENT_PARTNER_ID = 57,
		/// <summary>Breaks down reporting data by partner <a href='Company#name'>Company#name</a>
		/// and <a href='Company#id'>Company#id</a> are automatically included as columns in
		/// the report. <p>Corresponds to "Partner" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, REACH, PARTNER_FINANCE.</p>
		/// </summary>
		PARTNER_MANAGEMENT_PARTNER_NAME = 58,
		/// <summary>Breaks down reporting data by partner label <a href='Label#id'>Label#id</a>.
		/// <p>Compatible with any of the following report types: HISTORICAL, REACH,
		/// PARTNER_FINANCE.</p>
		/// </summary>
		PARTNER_MANAGEMENT_PARTNER_LABEL_ID = 59,
		/// <summary>Breaks down reporting data by partner label. <a href='Label#name'>Label#name</a>
		/// and <a href='Label#id'>Label#id</a> are automatically included as columns in the
		/// report. <p>Corresponds to "Partner label" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, REACH, PARTNER_FINANCE.</p>
		/// </summary>
		PARTNER_MANAGEMENT_PARTNER_LABEL_NAME = 60,
		/// <summary>Breaks down reporting data by partner assignment id. <p>Compatible with any of
		/// the following report types: HISTORICAL, REACH, PARTNER_FINANCE.</p>
		/// </summary>
		PARTNER_MANAGEMENT_ASSIGNMENT_ID = 195,
		/// <summary>Breaks down reporting data by partner assignment name. ParnterAssignment name
		/// and id are automatically included as columns in the report. <p>Corresponds to
		/// "Assignment" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, REACH, PARTNER_FINANCE.</p>
		/// </summary>
		PARTNER_MANAGEMENT_ASSIGNMENT_NAME = 196,
		/// <summary>Breaks down reporting data by gender and age group, i.e., MALE_13_TO_17,
		/// MALE_18_TO_24, MALE_25_TO_34, MALE_35_TO_44, MALE_45_TO_54, MALE_55_TO_64,
		/// MALE_65_PLUS, FEMALE_13_TO_17, FEMALE_18_TO_24, FEMALE_25_TO_34,
		/// FEMALE_35_TO_44, FEMALE_45_TO_54, FEMALE_55_TO_64, FEMALE_65_PLUS,
		/// UNKNOWN_0_TO_17 and UNKNOWN. Whenever this dimension is selected, <a
		/// href=''>#COUNTRY_NAME</a> must be selected. <p>This dimension is supported only
		/// for GRP columns.</p> <p>Can correspond to any of the following in the Ad Manager
		/// UI: Demographics, comScore vCE demographics. Compatible with any of the
		/// following report types: HISTORICAL, REACH.</p>
		/// </summary>
		GRP_DEMOGRAPHICS = 61,
		/// <summary>Size of the creative requested for an ad. <p>This field is deprecated and will
		/// be removed in v201808.</p> <p>Compatible with any of the following report types:
		/// HISTORICAL, REACH.</p>
		/// </summary>
		AD_REQUEST_SIZE = 62,
		/// <summary>Breaks down reporting data by the ad unit sizes specified in ad requests.
		/// <p>Formatted as comma separated values, e.g. "300x250,300x250v,300x60".</p>
		/// <p>This dimension is supported only for sell-through columns.</p> <p>Corresponds
		/// to "Ad request sizes" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH.</p>
		/// </summary>
		AD_REQUEST_AD_UNIT_SIZES = 63,
		/// <summary>Breaks down reporting data by the custom criteria specified in ad requests.
		/// <p>Formatted as comma separated <a href='CustomTargetingKey'>key</a>-<a
		/// href='CustomTargetingValue'>values</a>, where a key-value is formatted as
		/// <code></code>.</p> <p>This dimension is supported only for sell-through
		/// columns.</p> <p>Corresponds to "Key-values" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, SELL_THROUGH, REACH.</p>
		/// </summary>
		AD_REQUEST_CUSTOM_CRITERIA = 64,
		/// <summary>The unique identifier used for an ad network that is associated with the company
		/// that the ad is served for.
		/// </summary>
		BUYER_ID = 65,
		/// <summary>The name of the ad network that is associated with the company that the ad is
		/// served for. <p>Corresponds to "Buyer" in the Ad Manager UI.</p>
		/// </summary>
		BUYER_NAME = 66,
		/// <summary>Whether the report contains only Ad Exchange traffic fulfilled by First Look
		/// Deals or omits it. If this filter isn't included, the report will include First
		/// Look Deals traffic in addition to any other traffic. Not available as a
		/// dimension to report on. <p>Compatible with any of the following report types:
		/// HISTORICAL, REACH.</p>
		/// </summary>
		IS_FIRST_LOOK_DEAL = 154,
		/// <summary>Breaks down reporting data by mediation group ID. A mediation group is an
		/// abstraction of inventory used in Ad Manager Mediation. <p>This field is
		/// deprecated and will be removed in v201805.</p> <p>Compatible with any of the
		/// following report types: HISTORICAL, REACH.</p>
		/// </summary>
		MEDIATION_GROUP_ID = 157,
		/// <summary>Breaks down reporting data by mediation group name. A mediation group is an
		/// abstraction of inventory used in Ad Manager Mediation. <p>This field is
		/// deprecated and will be removed in v201805.</p> <p>Compatible with any of the
		/// following report types: HISTORICAL, REACH.</p>
		/// </summary>
		MEDIATION_GROUP_NAME = 158,
		/// <summary>Breaks down reporting data by yield group ID. <p>Compatible with any of the
		/// following report types: HISTORICAL, REACH.</p>
		/// </summary>
		YIELD_GROUP_ID = 197,
		/// <summary>Breaks down reporting data by yield group name. <p>Corresponds to "Yield group"
		/// in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, REACH.</p>
		/// </summary>
		YIELD_GROUP_NAME = 198,
		/// <summary>Breaks down reporting data by yield partner. <p>Corresponds to "Yield partner"
		/// in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, REACH.</p>
		/// </summary>
		YIELD_PARTNER = 199,
		/// <summary>Breaks down reporting data by the tag of a yield partner in a yield group.
		/// <p>Corresponds to "Yield partner tag" in the Ad Manager UI. Compatible with any
		/// of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		YIELD_PARTNER_TAG = 200,
		/// <summary>Breaks down mapped Ad Exchange web property data by mediation network. <p>This
		/// field is deprecated and will be removed in v201805.</p> <p>Compatible with any
		/// of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		MEDIATION_NETWORK = 159,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange network tag
		/// name. <p>This field is deprecated and will be removed in v201805.</p>
		/// <p>Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		MEDIATION_NETWORK_TAG = 160,
		/// <summary>Breaks down reporting data by mediation type. A mediation type can be web,
		/// mobile app or video. <p>Corresponds to "Mediation type" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		MEDIATION_TYPE = 161,
		/// <summary>Breaks down reporting data by native template (also known as creative template)
		/// ID. <p>Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		NATIVE_TEMPLATE_ID = 155,
		/// <summary>Breaks down reporting data by native template (also known as creative template)
		/// name. <p>Corresponds to "Native ad format name" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		NATIVE_TEMPLATE_NAME = 156,
		/// <summary>Breaks down reporting data by native style ID. <p>Compatible with any of the
		/// following report types: HISTORICAL, REACH.</p>
		/// </summary>
		NATIVE_STYLE_ID = 162,
		/// <summary>Breaks down reporting data by native style name. <p>Corresponds to "Native style
		/// name" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, REACH.</p>
		/// </summary>
		NATIVE_STYLE_NAME = 163,
		/// <summary>Breaks down reporting data by mobile app name. Can be used for filtering.
		/// <p>Corresponds to "App names" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, REACH.</p>
		/// </summary>
		MOBILE_APP_NAME = 164,
		/// <summary>Breaks down reporting data by device name. Can be used for filtering.
		/// <p>Corresponds to "Devices" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, REACH, CREATIVE_QOS.</p>
		/// </summary>
		MOBILE_DEVICE_NAME = 165,
		/// <summary>Breaks down reporting data by inventory type. Can be used for filtering.
		/// <p>Corresponds to "Inventory types" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		MOBILE_INVENTORY_TYPE = 166,
		/// <summary>Breaks down reporting data by request type. Can be used for filtering.
		/// <p>Corresponds to "Request type" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		REQUEST_TYPE = 201,
		/// <summary>ID of the advertiser that filled the ad either directly (through Ad Manager) or
		/// indirectly via Google Ad Exchange or another ad network or exchange. <p>This
		/// field is deprecated and will be removed in v201808.</p>
		/// </summary>
		VERIFIED_ADVERTISER_ID = 67,
		/// <summary>Name of the advertiser that filled the ad either directly (through Ad Manager)
		/// or indirectly via Google Ad Exchange or another ad network or exchange. <p>This
		/// field is deprecated and will be removed in v201808.</p> <p>Compatible with any
		/// of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		VERIFIED_ADVERTISER_NAME = 68,
		/// <summary>Status of the ad unit. Not available as a dimension to report on, but exists as
		/// a dimension in order to filter on it using PQL. Valid values correspond to <a
		/// href='InventoryStatus'>InventoryStatus</a>. <p>Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, CREATIVE_QOS.</p>
		/// </summary>
		AD_UNIT_STATUS = 144,
		/// <summary>Breaks down reporting data by <a href='Creative#id'>Creative#id</a>. This
		/// includes regular creatives, and master and companions in case of creative sets.
		/// <p>Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		MASTER_COMPANION_CREATIVE_ID = 69,
		/// <summary>Breaks down reporting data by creative. This includes regular creatives, and
		/// master and companions in case of creative sets. <p>Corresponds to "Master and
		/// Companion creative" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, REACH.</p>
		/// </summary>
		MASTER_COMPANION_CREATIVE_NAME = 70,
		/// <summary>Breaks down reporting data by <a
		/// href='ProposalLineItem#id'>ProposalLineItem#id</a>. Can be used to filter by <a
		/// href='ProposalLineItem#id'>ProposalLineItem#id</a>. <p>Compatible with any of
		/// the following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_ID = 71,
		/// <summary>Breaks down reporting data by <a
		/// href='ProposalLineItem#name'>ProposalLineItem#name</a>. Can be used to filter by
		/// <a href='ProposalLineItem#name'>ProposalLineItem#name</a>. <p>Corresponds to
		/// "Proposal line item" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_NAME = 72,
		/// <summary>Breaks down reporting data by <a href='Proposal#id'>Proposal#id</a>. Can be used
		/// to filter by <a href='Proposal#id'>Proposal#id</a>. <p>Compatible with any of
		/// the following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_ID = 73,
		/// <summary>Breaks down reporting data by <a href='Proposal#name'>Proposal#name</a>. Can be
		/// used to filter by <a href='Proposal#name'>Proposal#name</a>. <p>Corresponds to
		/// "Proposal" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_NAME = 74,
		/// <summary>Breaks down reporting data by salesperson <a href='User#id'>User#id</a>,
		/// including both salesperson and secondary salespeople. Can be used to filter by
		/// all salespeople <a href='User#id'>User#id</a>. <p>Compatible with any of the
		/// following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		ALL_SALESPEOPLE_ID = 75,
		/// <summary>Breaks down reporting data by salesperson <a href='User#name'>User#name</a>,
		/// including both salesperson and secondary salespeople. Can be used to filter by
		/// all salespeople <a href='User#name'>User#name</a>. <p>Corresponds to "All
		/// salespeople" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		ALL_SALESPEOPLE_NAME = 76,
		/// <summary>Used to filter by <a href='User#id'>User#id</a> in sales team. Sales team
		/// includes salesperson, secondary salesperson, sales planners. Not available as a
		/// dimension to report on. <p>Compatible with any of the following report types:
		/// HISTORICAL, REACH, SALES.</p>
		/// </summary>
		SALES_TEAM_ID = 145,
		/// <summary>Used to filter by <a href='User#name'>User#name</a> in sales team. Sales team
		/// includes salesperson, secondary salesperson, sales planners. Not available as a
		/// dimension to report on. <p>Compatible with any of the following report types:
		/// HISTORICAL, REACH, SALES.</p>
		/// </summary>
		SALES_TEAM_NAME = 146,
		/// <summary>Breaks down reporting data by proposal agency <a
		/// href='Company#id'>Company#id</a>. Can be used to filter by proposal agency <a
		/// href='Company#id'>Company#id</a>. <p>Compatible with any of the following report
		/// types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_AGENCY_ID = 77,
		/// <summary>Breaks down reporting data by proposal agency <a
		/// href='Company#name'>Company#name</a>. Can be used to filter by proposal agency
		/// <a href='Company#name'>Company#name</a>. <p>Corresponds to "Proposal agency" in
		/// the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_AGENCY_NAME = 78,
		/// <summary>Breaks down reporting data by <a href='Product#id'>Product#id</a>. Can be used
		/// to filter by <a href='Product#id'>Product#id</a>. <p>Compatible with any of the
		/// following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_ID = 79,
		/// <summary>Breaks down reporting data by <a href='Product#name'>Product#name</a>.
		/// <p>Corresponds to "Product" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_NAME = 80,
		/// <summary>Breaks down reporting data by <a
		/// href='ProductTemplate#id'>ProductTemplate#id</a>. Can be used to filter by <a
		/// href='ProductTemplate#id'>ProductTemplate#id</a>. <p>Compatible with any of the
		/// following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_TEMPLATE_ID = 81,
		/// <summary>Breaks down reporting data by <a
		/// href='ProductTemplate#name'>ProductTemplate#name</a>. Can be used to filter by
		/// <a href='ProductTemplate#name'>ProductTemplate#name</a>. <p>Corresponds to
		/// "Product template" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_TEMPLATE_NAME = 82,
		/// <summary>Breaks down reporting data by <a href='RateCard#id'>RateCard#id</a>. Can be used
		/// to filter by <a href=''>RateCard#id</a>. <p>Compatible with any of the following
		/// report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		RATE_CARD_ID = 83,
		/// <summary>Breaks down reporting data by <a href='RateCard#name'>RateCard#name</a>. Can be
		/// used to filter by <a href=''>RateCard#name</a>. <p>Corresponds to "Rate card" in
		/// the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, REACH, SALES.</p>
		/// </summary>
		RATE_CARD_NAME = 84,
		/// <summary>Used to filter by <a href='Workflow#id'>Workflow#id</a>. Not available as a
		/// dimension to report on. <p>Compatible with any of the following report types:
		/// HISTORICAL, REACH, SALES.</p>
		/// </summary>
		WORKFLOW_ID = 85,
		/// <summary>Used to filter by <a href='Workflow#name'>Workflow#name</a>. Not available as a
		/// dimension to report on. <p>Compatible with any of the following report types:
		/// HISTORICAL, REACH, SALES.</p>
		/// </summary>
		WORKFLOW_NAME = 86,
		/// <summary>Breaks down reporting data by <a href='Package#id'>Package#id</a>. <p>Compatible
		/// with any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PACKAGE_ID = 147,
		/// <summary>Breaks down reporting data by <a href='Package#name'>Package#name</a>.
		/// <p>Corresponds to "Package" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PACKAGE_NAME = 148,
		/// <summary>Breaks down reporting data by <a href='ProductPackage#id'>ProductPackage#id</a>.
		/// Can be used to filter by <a href='ProductPackage#id'>ProductPackage#id</a>.
		/// <p>Compatible with any of the following report types: HISTORICAL, REACH,
		/// SALES.</p>
		/// </summary>
		PRODUCT_PACKAGE_ID = 149,
		/// <summary>Breaks down reporting data by <a
		/// href='ProductPackage#name'>ProductPackage#name</a>. Can be used to filter by <a
		/// href='ProductPackage#name'>ProductPackage#name</a>. <p>Corresponds to "Product
		/// package" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_PACKAGE_NAME = 150,
		/// <summary>Breaks down reporting data by billable audience segment ID. <p>Compatible with
		/// any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		AUDIENCE_SEGMENT_ID = 87,
		/// <summary>Breaks down reporting data by billable audience segment name. <p>Corresponds to
		/// "Audience segment (billable)" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, REACH.</p>
		/// </summary>
		AUDIENCE_SEGMENT_NAME = 88,
		/// <summary>Breaks down reporting data by audience segment data provider name.
		/// <p>Corresponds to "Data partner" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		AUDIENCE_SEGMENT_DATA_PROVIDER_NAME = 89,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange inventory size.
		/// <p>Corresponds to "Inventory sizes" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_INVENTORY_SIZE = 171,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange inventory size
		/// code. <p>Compatible with any of the following report types: HISTORICAL,
		/// REACH.</p>
		/// </summary>
		AD_EXCHANGE_INVENTORY_SIZE_CODE = 172,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange device category.
		/// <p>Corresponds to "Device categories" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_DEVICE_CATEGORY = 173,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange pricing rule ID.
		/// <p>Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		AD_EXCHANGE_PRICING_RULE_ID = 92,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange pricing rule.
		/// <p>Corresponds to "Pricing rules" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_PRICING_RULE_NAME = 93,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange tag.
		/// <p>Corresponds to "Tags" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_TAG_NAME = 94,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange URL.
		/// <p>Corresponds to "URLs" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_URL = 174,
		/// <summary>Breaks down data by Ad Exchange mapped web property code. <p>Compatible with any
		/// of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		AD_EXCHANGE_WEB_PROPERTY_CODE = 175,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange creative size.
		/// <p>Corresponds to "Creative sizes" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_CREATIVE_SIZES = 97,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange ad type.
		/// <p>Corresponds to "Ad Types" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_AD_TYPE = 176,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange channel.
		/// <p>Corresponds to "Channels" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_CHANNEL_NAME = 99,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange product.
		/// <p>Corresponds to "Products" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_PRODUCT_NAME = 100,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange product code.
		/// <p>Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		AD_EXCHANGE_PRODUCT_CODE = 177,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange site.
		/// <p>Corresponds to "Sites" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_SITE_NAME = 101,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange request source.
		/// <p>Corresponds to "Request sources" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_REQUEST_SOURCES = 102,
		/// <summary>Breaks down mapped Ad Exchange web property data by the Ad Exchange advertiser
		/// name that bids on ads. <p>Corresponds to "Advertisers" in the Ad Manager UI.
		/// Compatible with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_ADVERTISER_NAME = 104,
		/// <summary>Breaks down mapped Ad Exchange web property data by the Ad Exchange brand name
		/// that bids on ads. <p>Corresponds to "Brands" in the Ad Manager UI. Compatible
		/// with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_BRAND_NAME = 178,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange agency.
		/// <p>Corresponds to "Agencies" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_AGENCY = 105,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange bid type code.
		/// <p>Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		AD_EXCHANGE_BID_TYPE_CODE = 179,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange branding type
		/// code. <p>Compatible with any of the following report types: HISTORICAL,
		/// REACH.</p>
		/// </summary>
		AD_EXCHANGE_BRANDING_TYPE_CODE = 180,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange branding type.
		/// Examples: Branded, Anonymous. <p>Corresponds to "Branding types" in the Ad
		/// Manager UI. Compatible with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_BRANDING_TYPE = 107,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange ad network name.
		/// Example: Google Adwords. <p>Corresponds to "Buyer networks" in the Ad Manager
		/// UI. Compatible with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_BUYER_NETWORK_NAME = 108,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange ad network ID.
		/// <p>Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		AD_EXCHANGE_BUYER_NETWORK_ID = 181,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange custom channel
		/// code. <p>Compatible with any of the following report types: HISTORICAL,
		/// REACH.</p>
		/// </summary>
		AD_EXCHANGE_CUSTOM_CHANNEL_CODE = 182,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange custom channel
		/// ID. <p>Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		AD_EXCHANGE_CUSTOM_CHANNEL_ID = 183,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange date, in Ad
		/// Exchange timezone. <p><b>Note:</b> In v201802 and later, this dimension is
		/// compatible with the following time zone types:</p> <ul> <li><a
		/// href='TimeZoneType.AD_EXCHANGE'>TimeZoneType.AD_EXCHANGE</a></li> </ul>
		/// <p>Corresponds to "Days" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_DATE = 109,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange deal id.
		/// <p>Corresponds to "Deal IDs" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_DEAL_ID = 111,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange deal name.
		/// <p>Corresponds to "Deal names" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_DEAL_NAME = 112,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange deal/transaction
		/// type. Example: Open auction. <p>Corresponds to "Transaction types" in the Ad
		/// Manager UI. Compatible with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_TRANSACTION_TYPE = 184,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange DSP buyer
		/// network name. <p>Corresponds to "DSPs" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_DSP_BUYER_NETWORK_NAME = 114,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange expansion type.
		/// <p>Corresponds to "Expandable types" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_EXPANSION_TYPE = 115,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange country code.
		/// <p>Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		AD_EXCHANGE_COUNTRY_CODE = 116,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange country name.
		/// <p>Corresponds to "Countries" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_COUNTRY_NAME = 117,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Manager ad unit ID.
		/// <p>Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		AD_EXCHANGE_DFP_AD_UNIT_ID = 185,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Manager ad unit.
		/// <p>Corresponds to "DFP Ad Units" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_DFP_AD_UNIT = 186,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange inventory
		/// ownership. <p>Corresponds to "Inventory ownership" in the Ad Manager UI.
		/// Compatible with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_INVENTORY_OWNERSHIP = 118,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange advertiser
		/// domain. <p>Corresponds to "Advertiser domains" in the Ad Manager UI. Compatible
		/// with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_ADVERTISER_DOMAIN = 187,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange mobile app name.
		/// <p>Corresponds to "App names" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_MOBILE_APP_NAME = 120,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange mobile carrier
		/// name. <p>Corresponds to "Carrier names" in the Ad Manager UI. Compatible with
		/// the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_MOBILE_CARRIER_NAME = 121,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange mobile device
		/// name. <p>Corresponds to "Devices" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_MOBILE_DEVICE_NAME = 122,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange mobile inventory
		/// type. <p>Corresponds to "Inventory types" in the Ad Manager UI. Compatible with
		/// the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_MOBILE_INVENTORY_TYPE = 123,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange month, in Ad
		/// Exchange timezone. <p><b>Note:</b> In v201802 and later, this dimension is
		/// compatible with the following time zone types:</p> <ul> <li><a
		/// href='TimeZoneType.AD_EXCHANGE'>TimeZoneType.AD_EXCHANGE</a></li> </ul>
		/// <p>Corresponds to "Months" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_MONTH = 124,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange network partner
		/// name. <p>Corresponds to "Network partner names" in the Ad Manager UI. Compatible
		/// with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_NETWORK_PARTNER_NAME = 125,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange operating system
		/// version. <p>Corresponds to "Operating systems" in the Ad Manager UI. Compatible
		/// with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_OPERATING_SYSTEM = 188,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange tags.
		/// <p>Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		AD_EXCHANGE_TAG_CODE = 127,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange targeting type
		/// code. <p>Compatible with any of the following report types: HISTORICAL,
		/// REACH.</p>
		/// </summary>
		AD_EXCHANGE_TARGETING_TYPE_CODE = 189,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange targeting type.
		/// <p>Corresponds to "Targeting types" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_TARGETING_TYPE = 128,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange transaction type
		/// code <p>Compatible with any of the following report types: HISTORICAL,
		/// REACH.</p>
		/// </summary>
		AD_EXCHANGE_TRANSACTION_TYPE_CODE = 190,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange URL ID.
		/// <p>Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		AD_EXCHANGE_URL_ID = 191,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange user bandwidth.
		/// <p>Corresponds to "Bandwidth" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_USER_BANDWIDTH_NAME = 133,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange video ad
		/// duration. <p>Compatible with any of the following report types: HISTORICAL,
		/// REACH.</p>
		/// </summary>
		AD_EXCHANGE_VIDEO_AD_DURATION = 134,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange raw video ad
		/// duration. <p>Corresponds to "Video ad durations" in the Ad Manager UI.
		/// Compatible with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_VIDEO_AD_DURATION_RAW = 135,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange video ad type.
		/// <p>Corresponds to "Video ad types" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_VIDEO_AD_TYPE = 192,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange week, in Ad
		/// Exchange timezone. <p><b>Note:</b> In v201802 and later, this dimension is
		/// compatible with the following time zone types:</p> <ul> <li><a
		/// href='TimeZoneType.AD_EXCHANGE'>TimeZoneType.AD_EXCHANGE</a></li> </ul>
		/// <p>Corresponds to "Weeks" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_WEEK = 137,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange ad location.
		/// <p>Corresponds to "Ad locations" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_AD_LOCATION = 193,
		/// <summary>Breaks down mapped Ad Exchange web property data by Ad Exchange advertiser
		/// vertical. <p>Corresponds to "Advertiser verticals" in the Ad Manager UI.
		/// Compatible with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_ADVERTISER_VERTICAL = 194,
		/// <summary>Campaign date segment of Nielsen Digital Ad Ratings reporting. <p>Corresponds to
		/// "Nielsen Digital Ad Ratings segment" in the Ad Manager UI. Compatible with any
		/// of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		NIELSEN_SEGMENT = 151,
		/// <summary>Breaks down reporting data by gender and age group, i.e., MALE_18_TO_20,
		/// MALE_21_TO_24, MALE_25_TO_29, MALE_30_TO_35, MALE_35_TO_39, MALE_40_TO_44,
		/// MALE_45_TO_49, MALE_50_TO_54, MALE_55_TO_64, MALE_65_PLUS, FEMALE_18_TO_20,
		/// FEMALE_21_TO_24, FEMALE_25_TO_29, FEMALE_30_TO_34, FEMALE_35_TO_39,
		/// FEMALE_40_TO_44, FEMALE_45_TO_49, FEMALE_50_TO_54, FEMALE_55_TO_64,
		/// FEMALE_65_PLUS, and OTHER.
		/// </summary>
		NIELSEN_DEMOGRAPHICS = 152,
		/// <summary>Data restatement date of Nielsen Digital Ad Ratings data. <p>Corresponds to
		/// "Nielsen Digital Ad Ratings restatement date" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		NIELSEN_RESTATEMENT_DATE = 153,
		/// <summary>Breaks down reporting data by <a
		/// href='ProposalMarketplaceInfo#buyerAccountId'>ProposalMarketplaceInfo#buyerAccountId</a>.
		/// <p>Compatible with any of the following report types: HISTORICAL, REACH,
		/// SALES.</p>
		/// </summary>
		PROGRAMMATIC_BUYER_ID = 167,
		/// <summary>Breaks down reporting data by programmatic buyer name. <p>Corresponds to
		/// "Programmatic buyer" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PROGRAMMATIC_BUYER_NAME = 168,
		/// <summary>Breaks down reporting data by requested ad size(s). This can be a chain of sizes
		/// or a single size. <p>Corresponds to "Requested ad sizes" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		REQUESTED_AD_SIZES = 169,
		/// <summary>Breaks down reporting data by the creative size the ad was delivered to.
		/// <p>Corresponds to "Creative size (delivered)" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		CREATIVE_SIZE_DELIVERED = 170,
		/// <summary>Breaks down reporting data by demand channels. <p>Compatible with any of the
		/// following report types: HISTORICAL, REACH.</p>
		/// </summary>
		DEMAND_CHANNEL_ID = 202,
		/// <summary>Breaks down reporting data by demand channel name. <p>Corresponds to "Demand
		/// channel" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, REACH.</p>
		/// </summary>
		DEMAND_CHANNEL_NAME = 203,
	}


	/// <summary>A view for an ad unit report.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ReportQuery.AdUnitView", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ReportQueryAdUnitView {
		/// <summary>Only the top level ad units. Metrics include events for their descendants that
		/// are not filtered out.
		/// </summary>
		TOP_LEVEL = 0,
		/// <summary>All the ad units. Metrics do not include events for the descendants.
		/// </summary>
		FLAT = 1,
		/// <summary>Use the ad unit hierarchy. There will be as many ad unit columns as levels of ad
		/// units in the generated report: <ul> <li>The column <a
		/// href='Dimension#AD_UNIT_NAME'>Dimension#AD_UNIT_NAME</a> is replaced with
		/// columns "Ad unit 1", "Ad unit 2", ... "Ad unit n". If level is not applicable to
		/// a row, "N/A" is returned as the value.</li> <li>The column <a
		/// href='Dimension#AD_UNIT_ID'>Dimension#AD_UNIT_ID</a> is replaced with columns
		/// "Ad unit ID 1", "Ad unit ID 2", ... "Ad unit ID n". If level is not applicable
		/// to a row, "N/A" is returned as the value.</li> </ul> <p>Metrics do not include
		/// events for the descendants.</p>
		/// </summary>
		HIERARCHICAL = 2,
	}


	/// <summary><code>Column</code> provides all the trafficking statistics and revenue
	/// information available for the chosen <a href='Dimension'>Dimension</a> objects.
	/// <p>Columns with <code>INVENTORY_LEVEL</code> should not be used with dimensions
	/// relating to line items, orders, companies and creatives, such as <a
	/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a>. Columns with
	/// <code>LINE_ITEM_LEVEL</code> can only be used if you have line item-level
	/// dynamic allocation enabled on your network.</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum Column {
		/// <summary>The number of impressions delivered by the ad server. <p>Corresponds to "Ad
		/// server impressions" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		AD_SERVER_IMPRESSIONS = 0,
		/// <summary>The number of downloaded impressions delivered by the ad server. <p>Corresponds
		/// to "Ad server downloaded impressions" in the Ad Manager UI. Compatible with the
		/// HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_DOWNLOADED_IMPRESSIONS = 434,
		/// <summary>The number of impressions delivered by the ad server by explicit custom criteria
		/// targeting. <p>Corresponds to "Ad server targeted impressions" in the Ad Manager
		/// UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_TARGETED_IMPRESSIONS = 1,
		/// <summary>The number of clicks delivered by the ad server. <p>Corresponds to "Ad server
		/// clicks" in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_CLICKS = 2,
		/// <summary>The number of clicks delivered by the ad server by explicit custom criteria
		/// targeting. <p>Corresponds to "Ad server targeted clicks" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_TARGETED_CLICKS = 3,
		/// <summary>The CTR for an ad delivered by the ad server. <p>Corresponds to "Ad server CTR"
		/// in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_CTR = 4,
		/// <summary>The CPM and CPC revenue earned, calculated in publisher currency, for the ads
		/// delivered by the ad server. <p>Corresponds to "Ad server CPM and CPC revenue" in
		/// the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_CPM_AND_CPC_REVENUE = 5,
		/// <summary>The CPD revenue earned, calculated in publisher currency, for the ads delivered
		/// by the ad server. <p>Corresponds to "Ad server CPD revenue" in the Ad Manager
		/// UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_CPD_REVENUE = 6,
		/// <summary>The CPA revenue earned, calculated in publisher currency, for the ads delivered
		/// by the ad server. <p>Corresponds to "CPA revenue" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_CPA_REVENUE = 7,
		/// <summary>The CPM, CPC and CPD revenue earned, calculated in publisher currency, for the
		/// ads delivered by the ad server. <p>Can correspond to any of the following in the
		/// Ad Manager UI: Ad server CPM, CPC, CPD, and vCPM revenue, Ad server CPM, CPC and
		/// CPD revenue. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_ALL_REVENUE = 8,
		/// <summary>The average estimated cost-per-thousand-impressions earned from the CPM and CPC
		/// ads delivered by the ad server. <p>Corresponds to "Ad server average eCPM" in
		/// the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_WITHOUT_CPD_AVERAGE_ECPM = 9,
		/// <summary>The average estimated cost-per-thousand-impressions earned from the CPM, CPC and
		/// CPD ads delivered by the ad server.
		/// </summary>
		AD_SERVER_WITH_CPD_AVERAGE_ECPM = 10,
		/// <summary>The ratio of the number of impressions delivered to the total impressions
		/// delivered when no <a href='LineItem'>LineItem</a> reservation could be found by
		/// the ad server for inventory-level dynamic allocation. For Ad Manager 360
		/// networks, this includes line item-level dynamic allocation as well. Represented
		/// as a percentage. <p>Corresponds to "Ad server impressions (%)" in the Ad Manager
		/// UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_INVENTORY_LEVEL_PERCENT_IMPRESSIONS = 11,
		/// <summary>The ratio of the number of impressions delivered to the total impressions
		/// delivered by the ad server for line item-level dynamic allocation. Represented
		/// as a percentage. <p>Corresponds to "Ad server impressions (%)" in the Ad Manager
		/// UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_LINE_ITEM_LEVEL_PERCENT_IMPRESSIONS = 12,
		/// <summary>The ratio of the number of clicks delivered to the total clicks delivered when
		/// no <a href='LineItem'>LineItem</a> reservation could be found by the ad server
		/// for inventory-level dynamic allocation. For Ad Manager 360 networks, this
		/// includes line item-level dynamic allocation as well. Represented as a
		/// percentage. <p>Corresponds to "Ad server clicks (%)" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_INVENTORY_LEVEL_PERCENT_CLICKS = 13,
		/// <summary>The ratio of the number of clicks delivered to the total clicks delivered by the
		/// ad server for line item-level dynamic allocation. Represented as a percentage.
		/// <p>Corresponds to "Ad server clicks (%)" in the Ad Manager UI. Compatible with
		/// the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_LINE_ITEM_LEVEL_PERCENT_CLICKS = 14,
		/// <summary>The ratio of revenue generated by ad server to the total CPM and CPC revenue
		/// earned by ads delivered when no <a href='LineItem'>LineItem</a> reservation
		/// could be found by the ad server for inventory-level dynamic allocation. For Ad
		/// Manager 360 networks, this includes line item-level dynamic allocation as well.
		/// Represented as a percentage. <p>Corresponds to "Ad server revenue (%)" in the Ad
		/// Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_INVENTORY_LEVEL_WITHOUT_CPD_PERCENT_REVENUE = 15,
		/// <summary>The ratio of revenue generated by ad server to the total CPM, CPC and CPD
		/// revenue earned by ads delivered when no <a href='LineItem'>LineItem</a>
		/// reservation could be found by the ad server for inventory-level dynamic
		/// allocation. For Ad Manager 360 networks, this includes line item-level dynamic
		/// allocation as well. Represented as a percentage.
		/// </summary>
		AD_SERVER_INVENTORY_LEVEL_WITH_CPD_PERCENT_REVENUE = 16,
		/// <summary>The ratio of revenue generated by ad server to the total CPM and CPC revenue
		/// earned by the ads delivered for line item-level dynamic allocation. Represented
		/// as a percentage. <p>Corresponds to "Ad server revenue (%)" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_LINE_ITEM_LEVEL_WITHOUT_CPD_PERCENT_REVENUE = 17,
		/// <summary>The ratio of revenue generated by ad server to the total CPM, CPC and CPD
		/// revenue earned by the ads delivered for line item-level dynamic allocation.
		/// Represented as a percentage.
		/// </summary>
		AD_SERVER_LINE_ITEM_LEVEL_WITH_CPD_PERCENT_REVENUE = 18,
		/// <summary>The number of times that the code for an ad is served by the ad server. <p>This
		/// field is deprecated and will be removed in v201808.</p> <p>Compatible with the
		/// HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_CODE_SERVED_COUNT = 20,
		/// <summary>The number of downloaded impressions delivered by the ad server including
		/// impressions recognized as spam. <p>Corresponds to "Ad server unfiltered
		/// downloaded impressions" in the Ad Manager UI. Compatible with the HISTORICAL
		/// report type.</p>
		/// </summary>
		AD_SERVER_UNFILTERED_IMPRESSIONS = 435,
		/// <summary>The number of clicks delivered by the ad server including clicks recognized as
		/// spam. <p>Corresponds to "Ad server unfiltered clicks" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_UNFILTERED_CLICKS = 436,
		/// <summary>The number of impressions a dynamic allocation ad delivered when no <a
		/// href='LineItem'>LineItem</a> reservation could be found by the ad server for
		/// inventory-level dynamic allocation. For Ad Manager 360 networks, this includes
		/// line item-level dynamic allocation as well. <p>Can correspond to any of the
		/// following in the Ad Manager UI: AdSense / Ad Exchange impressions, AdSense
		/// impressions. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		DYNAMIC_ALLOCATION_INVENTORY_LEVEL_IMPRESSIONS = 24,
		/// <summary>The number of impressions an AdSense ad delivered for line item-level dynamic
		/// allocation. <p>Corresponds to "AdSense impressions" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		ADSENSE_LINE_ITEM_LEVEL_IMPRESSIONS = 26,
		/// <summary>The number of impressions an AdSense ad delivered for line item-level dynamic
		/// allocation by explicit custom criteria targeting. <p>Corresponds to "AdSense
		/// targeted impressions" in the Ad Manager UI. Compatible with the HISTORICAL
		/// report type.</p>
		/// </summary>
		ADSENSE_LINE_ITEM_LEVEL_TARGETED_IMPRESSIONS = 27,
		/// <summary>The number of clicks a dynamic allocation ad delivered when no <a
		/// href='LineItem'>LineItem</a> reservation could be found by the ad server for
		/// inventory-level dynamic allocation. For Ad Manager 360 networks, this includes
		/// line item-level dynamic allocation as well. <p>Can correspond to any of the
		/// following in the Ad Manager UI: AdSense / Ad Exchange clicks, AdSense clicks.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		DYNAMIC_ALLOCATION_INVENTORY_LEVEL_CLICKS = 28,
		/// <summary>The number of clicks an AdSense ad delivered for line item-level dynamic
		/// allocation. <p>Corresponds to "AdSense clicks" in the Ad Manager UI. Compatible
		/// with the HISTORICAL report type.</p>
		/// </summary>
		ADSENSE_LINE_ITEM_LEVEL_CLICKS = 29,
		/// <summary>The number of clicks an AdSense ad delivered for line item-level dynamic
		/// allocation by explicit custom criteria targeting. <p>Corresponds to "AdSense
		/// targeted clicks" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		ADSENSE_LINE_ITEM_LEVEL_TARGETED_CLICKS = 30,
		/// <summary>The ratio of clicks a dynamic allocation ad delivered to the number of
		/// impressions it delivered when no <a href='LineItem'>LineItem</a> reservation
		/// could be found by the ad server for inventory-level dynamic allocation. For Ad
		/// Manager 360 networks, this includes line item-level dynamic allocation as well.
		/// <p>Can correspond to any of the following in the Ad Manager UI: AdSense / Ad
		/// Exchange CTR, AdSense CTR. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		DYNAMIC_ALLOCATION_INVENTORY_LEVEL_CTR = 31,
		/// <summary>The ratio of clicks an AdSense reservation ad delivered to the number of
		/// impressions it delivered, including line item-level dynamic allocation.
		/// <p>Corresponds to "AdSense CTR" in the Ad Manager UI. Compatible with the
		/// HISTORICAL report type.</p>
		/// </summary>
		ADSENSE_LINE_ITEM_LEVEL_CTR = 32,
		/// <summary>Revenue generated from ads delivered for dynamic allocation when no <a
		/// href='LineItem'>LineItem</a> reservation could be found by the ad server for
		/// inventory-level dynamic allocation. For Ad Manager 360 networks, this includes
		/// line item-level dynamic allocation as well. <p>Can correspond to any of the
		/// following in the Ad Manager UI: AdSense / Ad Exchange revenue, AdSense revenue.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		DYNAMIC_ALLOCATION_INVENTORY_LEVEL_REVENUE = 33,
		/// <summary>Revenue generated from AdSense ads delivered for line item-level dynamic
		/// allocation. <p>Corresponds to "AdSense revenue" in the Ad Manager UI. Compatible
		/// with the HISTORICAL report type.</p>
		/// </summary>
		ADSENSE_LINE_ITEM_LEVEL_REVENUE = 34,
		/// <summary>The average estimated cost-per-thousand-impressions earned from dynamic
		/// allocation ads delivered when no <a href='LineItem'>LineItem</a> reservation
		/// could be found by the ad server for inventory-level dynamic allocation. For Ad
		/// Manager 360 networks, this includes line item-level dynamic allocation as well.
		/// <p>Can correspond to any of the following in the Ad Manager UI: AdSense / Ad
		/// Exchange average eCPM, AdSense average eCPM. Compatible with the HISTORICAL
		/// report type.</p>
		/// </summary>
		DYNAMIC_ALLOCATION_INVENTORY_LEVEL_AVERAGE_ECPM = 35,
		/// <summary>The average estimated cost-per-thousand-impressions earned from the ads
		/// delivered by AdSense for line item-level dynamic allocation. <p>Corresponds to
		/// "AdSense average eCPM" in the Ad Manager UI. Compatible with the HISTORICAL
		/// report type.</p>
		/// </summary>
		ADSENSE_LINE_ITEM_LEVEL_AVERAGE_ECPM = 36,
		/// <summary>The ratio of the number of impressions delivered by dynamic allocation ads to
		/// the total impressions delivered when no <a href='LineItem'>LineItem</a>
		/// reservation could be found by the ad server for inventory-level dynamic
		/// allocation. For Ad Manager 360 networks, this includes line item-level dynamic
		/// allocation as well. Represented as a percentage. <p>Can correspond to any of the
		/// following in the Ad Manager UI: AdSense / Ad Exchange impressions (%), AdSense
		/// impressions (%). Compatible with the HISTORICAL report type.</p>
		/// </summary>
		DYNAMIC_ALLOCATION_INVENTORY_LEVEL_PERCENT_IMPRESSIONS = 37,
		/// <summary>The ratio of the number of impressions delivered by AdSense reservation ads to
		/// the total impressions delivered for line item-level dynamic allocation.
		/// Represented as a percentage. <p>Corresponds to "AdSense impressions (%)" in the
		/// Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		ADSENSE_LINE_ITEM_LEVEL_PERCENT_IMPRESSIONS = 38,
		/// <summary>The ratio of the number of clicks delivered by dynamic allocation ads to the
		/// total clicks delivered when no <a href='LineItem'>LineItem</a> reservation could
		/// be found by the ad server for inventory-level dynamic allocation. For Ad Manager
		/// 360 networks, this includes line item-level dynamic allocation as well.
		/// Represented as a percentage. <p>Can correspond to any of the following in the Ad
		/// Manager UI: AdSense / Ad Exchange clicks (%), AdSense clicks (%). Compatible
		/// with the HISTORICAL report type.</p>
		/// </summary>
		DYNAMIC_ALLOCATION_INVENTORY_LEVEL_PERCENT_CLICKS = 39,
		/// <summary>The ratio of the number of clicks delivered by AdSense reservation ads to the
		/// total clicks delivered for line item-level dynamic allocation. Represented as a
		/// percentage. <p>Corresponds to "AdSense clicks (%)" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		ADSENSE_LINE_ITEM_LEVEL_PERCENT_CLICKS = 40,
		/// <summary>The ratio of revenue to the total revenue earned from the dynamic allocation CPM
		/// and CPC ads delivered when no <a href='LineItem'>LineItem</a> reservation could
		/// be found by the ad server for inventory-level dynamic allocation. For Ad Manager
		/// 360 networks, this includes line item-level dynamic allocation as well.
		/// Represented as a percentage. <p>Can correspond to any of the following in the Ad
		/// Manager UI: AdSense / Ad Exchange revenue (%), AdSense revenue (%). Compatible
		/// with the HISTORICAL report type.</p>
		/// </summary>
		DYNAMIC_ALLOCATION_INVENTORY_LEVEL_WITHOUT_CPD_PERCENT_REVENUE = 41,
		/// <summary>The ratio of revenue to the total revenue earned from the dynamic allocation
		/// CPM, CPC and CPD ads delivered when no <a href='LineItem'>LineItem</a>
		/// reservation could be found by the ad server for inventory-level dynamic
		/// allocation. For Ad Manager 360 networks, this includes line item-level dynamic
		/// allocation as well. Represented as a percentage.
		/// </summary>
		DYNAMIC_ALLOCATION_INVENTORY_LEVEL_WITH_CPD_PERCENT_REVENUE = 42,
		/// <summary>The ratio of revenue to the total revenue earned from the CPM and CPC ads
		/// delivered by AdSense for line item-level dynamic allocation. Represented as a
		/// percentage. <p>Corresponds to "AdSense revenue (%)" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		ADSENSE_LINE_ITEM_LEVEL_WITHOUT_CPD_PERCENT_REVENUE = 43,
		/// <summary>The ratio of revenue to the total revenue earned from the CPM, CPC and CPD ads
		/// delivered by AdSense for line item-level dynamic allocation. Represented as a
		/// percentage.
		/// </summary>
		ADSENSE_LINE_ITEM_LEVEL_WITH_CPD_PERCENT_REVENUE = 44,
		/// <summary>The number of impressions an Ad Exchange ad delivered for line item-level
		/// dynamic allocation. <p>Corresponds to "Ad Exchange impressions" in the Ad
		/// Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_LINE_ITEM_LEVEL_IMPRESSIONS = 45,
		/// <summary>Ad Impressions on mapped Ad Exchange properties. When multiple text ads fill a
		/// single display slot it is only counted once, when the top text ad is recognized.
		/// In these cases, the Ad Impression is attributed to the top text ad.
		/// <p>Corresponds to "Ad impressions" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_IMPRESSIONS = 46,
		/// <summary>Number of requests where a buyer was matched with the Ad request, for mapped Ad
		/// Exchange properties. <p>Corresponds to "Matched requests" in the Ad Manager UI.
		/// Compatible with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_MATCHED_REQUESTS = 440,
		/// <summary>Ad revenue per 1000 ad impressions, for mapped Ad Exchange properties.
		/// <p>Corresponds to "Ad eCPM" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_AD_ECPM = 441,
		/// <summary>The number of clicks delivered by mapped Ad Exchange properties. <p>Corresponds
		/// to "Clicks" in the Ad Manager UI. Compatible with the AD_EXCHANGE_HISTORICAL
		/// report type.</p>
		/// </summary>
		AD_EXCHANGE_CLICKS = 49,
		/// <summary>The estimated net revenue generated by mapped Ad Exchange properties.
		/// <p>Corresponds to "Estimated revenue" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_ESTIMATED_REVENUE = 50,
		/// <summary>The coverage reported by mapped Ad Exchange properties. <p>Corresponds to
		/// "Coverage" in the Ad Manager UI. Compatible with the AD_EXCHANGE_HISTORICAL
		/// report type.</p>
		/// </summary>
		AD_EXCHANGE_COVERAGE = 51,
		/// <summary>The matched queries click-through rate delivered by mapped Ad Exchange
		/// properties. <p>Corresponds to "CTR" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_CTR = 58,
		/// <summary>The total lift generated by mapped Ad Exchange properties. <p>Corresponds to
		/// "Lift" in the Ad Manager UI. Compatible with the AD_EXCHANGE_HISTORICAL report
		/// type.</p>
		/// </summary>
		AD_EXCHANGE_LIFT = 53,
		/// <summary>The cost-per-click generated by mapped Ad Exchange properties. <p>Corresponds to
		/// "CPC" in the Ad Manager UI. Compatible with the AD_EXCHANGE_HISTORICAL report
		/// type.</p>
		/// </summary>
		AD_EXCHANGE_CPC = 442,
		/// <summary>The number of ad requests issued by mapped Ad Exchange properties.
		/// <p>Corresponds to "Ad requests" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_AD_REQUESTS = 443,
		/// <summary>The average estimated cost-per-thousand-ad requests earned by mapped Ad Exchange
		/// properties. <p>Corresponds to "Ad request eCPM" in the Ad Manager UI. Compatible
		/// with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_AD_REQUEST_ECPM = 444,
		/// <summary>The click-through rate of ad requests issued by mapped Ad Exchange properties.
		/// <p>Corresponds to "Ad request CTR" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_AD_REQUEST_CTR = 445,
		/// <summary>The click-through rate of impressions issued by mapped Ad Exchange properties.
		/// <p>Corresponds to "Ad CTR" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_AD_CTR = 446,
		/// <summary>The video drop off rate for mapped Ad Exchange properties. <p>Corresponds to
		/// "Video drop-off rate" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_VIDEO_DROPOFF_RATE = 59,
		/// <summary>The video abandonment rate for mapped Ad Exchange properties. <p>Corresponds to
		/// "Video abandonment rate" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_VIDEO_ABANDONMENT_RATE = 60,
		/// <summary>The average estimated cost-per-thousand-impressions generated by mapped Ad
		/// Exchange properties. <p>Corresponds to "Matched eCPM" in the Ad Manager UI.
		/// Compatible with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_MATCHED_ECPM = 447,
		/// <summary>The estimated percentage of impressions generated by mapped Ad Exchange
		/// properties that are eligible for Active View measurement. <p>Corresponds to
		/// "Active view measurable" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_ACTIVE_VIEW_MEASURABLE = 448,
		/// <summary>The percentage of viewable impressions out of all measurable impressions
		/// generated by mapped Ad Exchange properties. <p>Corresponds to "Active view
		/// viewable" in the Ad Manager UI. Compatible with the AD_EXCHANGE_HISTORICAL
		/// report type.</p>
		/// </summary>
		AD_EXCHANGE_ACTIVE_VIEW_VIEWABLE = 449,
		/// <summary>The average time (in seconds) that an individual ad impression generated by
		/// mapped Ad Exchange properties was viewable. <p>Corresponds to "Average viewable
		/// time (secs)" in the Ad Manager UI. Compatible with the AD_EXCHANGE_HISTORICAL
		/// report type.</p>
		/// </summary>
		AD_EXCHANGE_AVERAGE_VIEWABLE_TIME = 450,
		/// <summary>Total number of impressions generated by mapped Ad Exchange properties that were
		/// eligible to measure viewability. <p>Corresponds to "Active view enabled
		/// impressions" in the Ad Manager UI. Compatible with the AD_EXCHANGE_HISTORICAL
		/// report type.</p>
		/// </summary>
		AD_EXCHANGE_ACTIVE_VIEW_ENABLED_IMPRESSIONS = 451,
		/// <summary>Total number of eligible impressions generated by mapped Ad Exchange properties
		/// that were measurable by Active View. <p>Corresponds to "Active view measured
		/// impressions" in the Ad Manager UI. Compatible with the AD_EXCHANGE_HISTORICAL
		/// report type.</p>
		/// </summary>
		AD_EXCHANGE_ACTIVE_VIEW_MEASURED_IMPRESSIONS = 452,
		/// <summary>Total number of Active View measurable impressions generated by mapped Ad
		/// Exchange properties that were viewable. <p>Corresponds to "Active view viewed
		/// impressions" in the Ad Manager UI. Compatible with the AD_EXCHANGE_HISTORICAL
		/// report type.</p>
		/// </summary>
		AD_EXCHANGE_ACTIVE_VIEW_VIEWED_IMPRESSIONS = 453,
		/// <summary>Number of responses that shows that a buyer is bidding, for mapped Ad Exchange
		/// properties. <p>Corresponds to "Deals bid responses" in the Ad Manager UI.
		/// Compatible with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_DEALS_BID_RESPONSES = 455,
		/// <summary>Deal ad requests for mapped Ad Exchange properties which were ?matched? with
		/// demand from the buyer associated with the Deal. Each ?Deals matched request?
		/// represents one opportunity for the Deal Buyer to serve their ad in the context
		/// of the Deal. <p>Corresponds to "Deals matched requests" in the Ad Manager UI.
		/// Compatible with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_DEALS_MATCHED_REQUESTS = 456,
		/// <summary>Total ad requests associated with a given Deal, for mapped Ad Exchange
		/// properties. <p>Corresponds to "Deals ad requests" in the Ad Manager UI.
		/// Compatible with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_DEALS_AD_REQUESTS = 457,
		/// <summary>Deals matched requests divided by Deals ad requests, for mapped Ad Exchange
		/// properties. <p>Corresponds to "Deals match rate" in the Ad Manager UI.
		/// Compatible with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_DEALS_MATCH_RATE = 458,
		/// <summary>A count of how many users watch the first 25% of a video ad, for mapped Ad
		/// Exchange properties.
		/// </summary>
		AD_EXCHANGE_VIDEO_QUARTILE_1 = 65,
		/// <summary>A count of how many users watch the first 75% of a video ad, for mapped Ad
		/// Exchange properties.
		/// </summary>
		AD_EXCHANGE_VIDEO_QUARTILE_3 = 66,
		/// <summary>Percentage of times a user clicked Skip, for mapped Ad Exchange properties.
		/// <p>Corresponds to "TrueView skip rate" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_VIDEO_TRUEVIEW_SKIP_RATE = 67,
		/// <summary>Number of times a video ad has been viewed to completion or watched to 30
		/// seconds, whichever happens first, for mapped Ad Exchange properties.
		/// <p>Corresponds to "TrueView views" in the Ad Manager UI. Compatible with the
		/// AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_VIDEO_TRUEVIEW_VIEWS = 459,
		/// <summary>TrueView views divided by TrueView impressions, for mapped Ad Exchange
		/// properties. <p>Corresponds to "TrueView VTR" in the Ad Manager UI. Compatible
		/// with the AD_EXCHANGE_HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_VIDEO_TRUEVIEW_VTR = 460,
		/// <summary>The third-party fill rate by Ad Exchange properties linked to Ad Manager.
		/// <p><b>This experimental column only works with Ad Exchange web properties linked
		/// with an active status.</b></p> <p>This field is deprecated and will be removed
		/// in v201805.</p> <p>Corresponds to "Mediation fill rate" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_THIRD_PARTY_FILL_RATE = 73,
		/// <summary>Impressions generated for mediation requests. This includes third-party network
		/// and Ad Exchange impressions for mediation. <p>This field is deprecated and will
		/// be removed in v201805.</p> <p>Compatible with the HISTORICAL report type.</p>
		/// </summary>
		MEDIATION_IMPRESSIONS = 428,
		/// <summary>Estimated revenue generated for mediation requests. This combines estimated
		/// revenue from third-parties along with Ad Exchange. <p>This field is deprecated
		/// and will be removed in v201805.</p> <p>Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		MEDIATION_ESTIMATED_REVENUE = 429,
		/// <summary>The average estimated cost-per-thousand-impressions earned from mediation ads.
		/// <p>This field is deprecated and will be removed in v201805.</p> <p>Compatible
		/// with the HISTORICAL report type.</p>
		/// </summary>
		MEDIATION_ECPM = 430,
		/// <summary>Mediation third-party average cost-per-thousand-impressions. <p>Compatible with
		/// the HISTORICAL report type.</p>
		/// </summary>
		MEDIATION_THIRD_PARTY_ECPM = 431,
		/// <summary>Mediation fill rate indicating how often a network fills an ad request. <p>This
		/// field is deprecated and will be removed in v201805.</p> <p>Compatible with the
		/// HISTORICAL report type.</p>
		/// </summary>
		MEDIATION_FILL_RATE = 432,
		/// <summary>Mediation passbacks recorded when a network does not fill an ad request. <p>This
		/// field is deprecated and will be removed in v201805.</p> <p>Compatible with the
		/// HISTORICAL report type.</p>
		/// </summary>
		MEDIATION_PASSBACKS = 433,
		/// <summary>The number of impressions an Ad Exchange ad delivered for line item-level
		/// dynamic allocation by explicit custom criteria targeting. <p>Corresponds to "Ad
		/// Exchange targeted impressions" in the Ad Manager UI. Compatible with the
		/// HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_LINE_ITEM_LEVEL_TARGETED_IMPRESSIONS = 77,
		/// <summary>The number of clicks an Ad Exchange ad delivered for line item-level dynamic
		/// allocation. <p>Corresponds to "Ad Exchange clicks" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_LINE_ITEM_LEVEL_CLICKS = 78,
		/// <summary>The number of clicks an Ad Exchange ad delivered for line item-level dynamic
		/// allocation by explicit custom criteria targeting. <p>Corresponds to "Ad Exchange
		/// targeted clicks" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		AD_EXCHANGE_LINE_ITEM_LEVEL_TARGETED_CLICKS = 79,
		/// <summary>The ratio of clicks an Ad Exchange ad delivered to the number of impressions it
		/// delivered for line item-level dynamic allocation. <p>Corresponds to "Ad Exchange
		/// CTR" in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_LINE_ITEM_LEVEL_CTR = 80,
		/// <summary>The ratio of the number of impressions delivered to the total impressions
		/// delivered by Ad Exchange for line item-level dynamic allocation. Represented as
		/// a percentage. <p>Corresponds to "Ad Exchange impressions (%)" in the Ad Manager
		/// UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_LINE_ITEM_LEVEL_PERCENT_IMPRESSIONS = 81,
		/// <summary>The ratio of the number of clicks delivered to the total clicks delivered by Ad
		/// Exchange for line item-level dynamic allocation. Represented as a percentage.
		/// <p>Corresponds to "Ad Exchange clicks (%)" in the Ad Manager UI. Compatible with
		/// the HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_LINE_ITEM_LEVEL_PERCENT_CLICKS = 82,
		/// <summary>Revenue generated from Ad Exchange ads delivered for line item-level dynamic
		/// allocation. Represented in publisher currency and time zone. <p>Corresponds to
		/// "Ad Exchange revenue" in the Ad Manager UI. Compatible with the HISTORICAL
		/// report type.</p>
		/// </summary>
		AD_EXCHANGE_LINE_ITEM_LEVEL_REVENUE = 83,
		/// <summary>The ratio of revenue generated by Ad Exchange to the total revenue earned by CPM
		/// and CPC ads delivered for line item-level dynamic allocation. Represented as a
		/// percentage. <p>Corresponds to "Ad Exchange revenue (%)" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_LINE_ITEM_LEVEL_WITHOUT_CPD_PERCENT_REVENUE = 84,
		/// <summary>The ratio of revenue generated by Ad Exchange to the total revenue earned by
		/// CPM, CPC and CPD ads delivered for line item-level dynamic allocation.
		/// Represented as a percentage.
		/// </summary>
		AD_EXCHANGE_LINE_ITEM_LEVEL_WITH_CPD_PERCENT_REVENUE = 85,
		/// <summary>The average estimated cost-per-thousand-impressions earned from the delivery of
		/// Ad Exchange ads for line item-level dynamic allocation. <p>Corresponds to "Ad
		/// Exchange average eCPM" in the Ad Manager UI. Compatible with the HISTORICAL
		/// report type.</p>
		/// </summary>
		AD_EXCHANGE_LINE_ITEM_LEVEL_AVERAGE_ECPM = 86,
		/// <summary>The total number of impressions delivered by the ad servers including
		/// inventory-level dynamic allocation. <p>Corresponds to "Total impressions" in the
		/// Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		TOTAL_INVENTORY_LEVEL_IMPRESSIONS = 87,
		/// <summary>The total number of impressions delivered including line item-level dynamic
		/// allocation. <p>Corresponds to "Total impressions" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		TOTAL_LINE_ITEM_LEVEL_IMPRESSIONS = 88,
		/// <summary>The total number of impressions delivered including line item-level dynamic
		/// allocation by explicit custom criteria targeting. <p>Corresponds to "Total
		/// targeted impressions" in the Ad Manager UI. Compatible with the HISTORICAL
		/// report type.</p>
		/// </summary>
		TOTAL_LINE_ITEM_LEVEL_TARGETED_IMPRESSIONS = 89,
		/// <summary>The total number of clicks delivered by the ad servers including inventory-level
		/// dynamic allocation. <p>Corresponds to "Total clicks" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		TOTAL_INVENTORY_LEVEL_CLICKS = 91,
		/// <summary>The total number of clicks delivered including line item-level dynamic
		/// allocation. <p>Corresponds to "Total clicks" in the Ad Manager UI. Compatible
		/// with the HISTORICAL report type.</p>
		/// </summary>
		TOTAL_LINE_ITEM_LEVEL_CLICKS = 92,
		/// <summary>The total number of clicks delivered including line item-level dynamic
		/// allocation by explicit custom criteria targeting <p>Corresponds to "Total
		/// targeted clicks" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		TOTAL_LINE_ITEM_LEVEL_TARGETED_CLICKS = 93,
		/// <summary>The ratio of total clicks on ads delivered by the ad servers to the total number
		/// of impressions delivered for an ad including inventory-level dynamic allocation.
		/// <p>Corresponds to "Total CTR" in the Ad Manager UI. Compatible with the
		/// HISTORICAL report type.</p>
		/// </summary>
		TOTAL_INVENTORY_LEVEL_CTR = 94,
		/// <summary>The ratio of total clicks on ads delivered by the ad servers to the total number
		/// of impressions delivered for an ad including line item-level dynamic allocation.
		/// <p>Corresponds to "Total CTR" in the Ad Manager UI. Compatible with the
		/// HISTORICAL report type.</p>
		/// </summary>
		TOTAL_LINE_ITEM_LEVEL_CTR = 95,
		/// <summary>The total CPM and CPC revenue generated by the ad servers including
		/// inventory-level dynamic allocation. <p>Corresponds to "Total CPM and CPC
		/// revenue" in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		TOTAL_INVENTORY_LEVEL_CPM_AND_CPC_REVENUE = 96,
		/// <summary>The total CPM, CPC and CPD revenue generated by the ad servers including
		/// inventory-level dynamic allocation.
		/// </summary>
		TOTAL_INVENTORY_LEVEL_ALL_REVENUE = 97,
		/// <summary>The total CPM and CPC revenue generated by the ad servers including line
		/// item-level dynamic allocation. <p>Corresponds to "Total CPM and CPC revenue" in
		/// the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		TOTAL_LINE_ITEM_LEVEL_CPM_AND_CPC_REVENUE = 98,
		/// <summary>The total CPM, CPC and CPD revenue generated by the ad servers including line
		/// item-level dynamic allocation. <p>Can correspond to any of the following in the
		/// Ad Manager UI: Total CPM, CPC, CPD, and vCPM revenue, Total CPM, CPC and CPD
		/// revenue. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		TOTAL_LINE_ITEM_LEVEL_ALL_REVENUE = 99,
		/// <summary>Estimated cost-per-thousand-impressions (eCPM) of CPM and CPC ads delivered by
		/// the ad servers including inventory-level dynamic allocation. <p>Corresponds to
		/// "Total average eCPM" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		TOTAL_INVENTORY_LEVEL_WITHOUT_CPD_AVERAGE_ECPM = 100,
		/// <summary>Estimated cost-per-thousand-impressions (eCPM) of CPM, CPC and CPD ads delivered
		/// by the ad servers including inventory-level dynamic allocation.
		/// </summary>
		TOTAL_INVENTORY_LEVEL_WITH_CPD_AVERAGE_ECPM = 101,
		/// <summary>Estimated cost-per-thousand-impressions (eCPM) of CPM and CPC ads delivered by
		/// the ad servers including line item-level dynamic allocation. <p>Corresponds to
		/// "Total average eCPM" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		TOTAL_LINE_ITEM_LEVEL_WITHOUT_CPD_AVERAGE_ECPM = 102,
		/// <summary>Estimated cost-per-thousand-impressions (eCPM) of CPM, CPC and CPD ads delivered
		/// by the ad servers including line item-level dynamic allocation.
		/// </summary>
		TOTAL_LINE_ITEM_LEVEL_WITH_CPD_AVERAGE_ECPM = 103,
		/// <summary>The total number of times that the code for an ad is served by the ad server
		/// including inventory-level dynamic allocation. <p>Corresponds to "Total code
		/// served count" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		TOTAL_CODE_SERVED_COUNT = 104,
		/// <summary>The total number of missed impressions due to the ad servers' inability to find
		/// ads to serve, including inventory-level dynamic allocation. <p>Corresponds to
		/// "Unfilled impressions" in the Ad Manager UI. Compatible with the HISTORICAL
		/// report type.</p>
		/// </summary>
		TOTAL_INVENTORY_LEVEL_UNFILLED_IMPRESSIONS = 105,
		/// <summary>The number of control (unoptimized) impressions delivered for an ad for which
		/// the optimization feature has been enabled. <p>Corresponds to "Control
		/// impressions" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		OPTIMIZATION_CONTROL_IMPRESSIONS = 107,
		/// <summary>Number of clicks resulting from the delivery of control (unoptimized)
		/// impressions for an ad for which the optimization feature has been enabled.
		/// <p>Corresponds to "Control clicks" in the Ad Manager UI. Compatible with the
		/// HISTORICAL report type.</p>
		/// </summary>
		OPTIMIZATION_CONTROL_CLICKS = 108,
		/// <summary>The CTR for control (unoptimized) impressions for an order for which the
		/// optimization feature has been enabled. <p>Corresponds to "Control CTR" in the Ad
		/// Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		OPTIMIZATION_CONTROL_CTR = 109,
		/// <summary>Number of optimized impressions delivered for an ad for which the optimization
		/// feature has been enabled. <p>Corresponds to "Optimized impressions" in the Ad
		/// Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		OPTIMIZATION_OPTIMIZED_IMPRESSIONS = 110,
		/// <summary>Number of clicks resulting from the delivery of optimized impressions for an ad
		/// for which the optimization feature has been enabled. <p>Corresponds to
		/// "Optimized clicks" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		OPTIMIZATION_OPTIMIZED_CLICKS = 111,
		/// <summary>Number of non-optimized impressions delivered for an ad for which the
		/// optimization feature has been enabled. <p>Corresponds to "Non-optimized
		/// impressions" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		OPTIMIZATION_NON_OPTIMIZED_IMPRESSIONS = 112,
		/// <summary>Number of clicks resulting from the delivery of non-optimized impressions for an
		/// ad for which the optimization feature has been enabled. <p>Corresponds to
		/// "Non-optimized clicks" in the Ad Manager UI. Compatible with the HISTORICAL
		/// report type.</p>
		/// </summary>
		OPTIMIZATION_NON_OPTIMIZED_CLICKS = 113,
		/// <summary>Number of extra clicks resulting from the delivery of optimized impressions for
		/// an ad for which the optimization feature has been enabled. <p>Corresponds to
		/// "Extra clicks" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		OPTIMIZATION_EXTRA_CLICKS = 114,
		/// <summary>The CTR for optimized impressions for an ad for which the optimization feature
		/// has been enabled. <p>Corresponds to "Optimized CTR" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		OPTIMIZATION_OPTIMIZED_CTR = 115,
		/// <summary>The percentage by which optimized CTRs are greater than the unoptimized CTRs.
		/// This is calculated as ((<a
		/// href='Column#OPTIMIZATION_OPTIMIZED_CTR'>Column#OPTIMIZATION_OPTIMIZED_CTR</a>/
		/// <a href='Column#OPTIMIZATION_CONTROL_CTR'>Column#OPTIMIZATION_CONTROL_CTR</a>) -
		/// 1) * 100 for an ad for which the optimization feature has been enabled.
		/// <p>Corresponds to "Lift" in the Ad Manager UI. Compatible with the HISTORICAL
		/// report type.</p>
		/// </summary>
		OPTIMIZATION_LIFT = 116,
		/// <summary>The line item coverage measures how often the traffic was sent for optimization.
		/// <p>Corresponds to "Percent optimized" in the Ad Manager UI. Compatible with the
		/// HISTORICAL report type.</p>
		/// </summary>
		OPTIMIZATION_COVERAGE = 117,
		/// <summary>The number of impressions that were behind schedule at the time of their
		/// delivery. <p>Corresponds to "Impressions that are behind schedule" in the Ad
		/// Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		OPTIMIZATION_BEHIND_SCHEDULE_IMPRESSIONS = 118,
		/// <summary>The number of impressions that did not have any clicks recorded in the recent
		/// past. <p>Corresponds to "Impressions with no clicks recorded" in the Ad Manager
		/// UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		OPTIMIZATION_NO_CLICKS_RECORDED_IMPRESSIONS = 119,
		/// <summary>The number of impressions that were delivered as sponsorship items.
		/// <p>Corresponds to "Sponsorship impressions" in the Ad Manager UI. Compatible
		/// with the HISTORICAL report type.</p>
		/// </summary>
		OPTIMIZATION_SPONSORSHIP_IMPRESSIONS = 120,
		/// <summary>The number of impressions that were set to deliver as fast as possible.
		/// <p>Corresponds to "Impressions serving as fast as possible" in the Ad Manager
		/// UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		OPTIMIZATION_AS_FAST_AS_POSSIBLE_IMPRESSIONS = 121,
		/// <summary>The number of impressions that have no absolute lifetime delivery goals.
		/// <p>Corresponds to "Impressions with no lifetime goal" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		OPTIMIZATION_NO_ABSOLUTE_LIFETIME_GOAL_IMPRESSIONS = 122,
		/// <summary>Total revenue resulting from the delivery of control (unoptimized) impressions
		/// for an ad for which the optimization feature has been enabled. <p>Corresponds to
		/// "Control revenue" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		OPTIMIZATION_CONTROL_REVENUE = 123,
		/// <summary>Total revenue resulting from the delivery of optimized impressions for an ad for
		/// which the optimization feature has been enabled. <p>Corresponds to "Optimized
		/// revenue" in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		OPTIMIZATION_OPTIMIZED_REVENUE = 124,
		/// <summary>Estimated cost-per-thousand-impressions (eCPM) of control (unoptimized)
		/// impressions for an ad for which the optimization feature has been enabled.
		/// <p>Corresponds to "Control eCPM" in the Ad Manager UI. Compatible with the
		/// HISTORICAL report type.</p>
		/// </summary>
		OPTIMIZATION_CONTROL_ECPM = 125,
		/// <summary>Estimated cost-per-thousand-impressions (eCPM) of optimized impressions for an
		/// ad for which the optimization feature has been enabled. <p>Corresponds to
		/// "Optimized eCPM" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		OPTIMIZATION_OPTIMIZED_ECPM = 126,
		/// <summary>Freed-up impressions as a result of optimization. <p>Corresponds to "Freed-up
		/// impressions" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		OPTIMIZATION_FREED_UP_IMPRESSIONS = 127,
		/// <summary>Relative change in eCPM as a result of optimization. <p>Corresponds to "eCPM
		/// lift" in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		OPTIMIZATION_ECPM_LIFT = 128,
		/// <summary>The average number of ads displayed to each unique visitor. <p>Corresponds to
		/// "Average impressions / visitor" in the Ad Manager UI. Compatible with the REACH
		/// report type.</p>
		/// </summary>
		REACH_FREQUENCY = 129,
		/// <summary>The average revenue earned per unique visitor. <p>Corresponds to "Average
		/// revenue / visitor" in the Ad Manager UI. Compatible with the REACH report
		/// type.</p>
		/// </summary>
		REACH_AVERAGE_REVENUE = 130,
		/// <summary>The number of unique visitors. <p>To maintain user privacy, "Unique visitors"
		/// totaling 0-99 won't be displayed in the report and will appear empty.</p>
		/// <p>Corresponds to "Unique visitors" in the Ad Manager UI. Compatible with the
		/// REACH report type.</p>
		/// </summary>
		REACH = 131,
		/// <summary>The number of people in the given demographic bucket. <p>Corresponds to
		/// "Population" in the Ad Manager UI. Compatible with the REACH report type.</p>
		/// </summary>
		GRP_POPULATION = 132,
		/// <summary>The number of unique users reached in the given demographic bucket.
		/// <p>Corresponds to "Unique viewers" in the Ad Manager UI. Compatible with the
		/// REACH report type.</p>
		/// </summary>
		GRP_UNIQUE_AUDIENCE = 133,
		/// <summary>Percentage of the number of unique users reached in the given demographic bucket
		/// (out of the number of unique users reached in all demographics). <p>Corresponds
		/// to "% Composition unique viewers" in the Ad Manager UI. Compatible with the
		/// REACH report type.</p>
		/// </summary>
		GRP_UNIQUE_AUDIENCE_SHARE = 134,
		/// <summary>The number of impressions in the given demographic bucket. <p>Corresponds to
		/// "Impressions" in the Ad Manager UI. Compatible with the REACH report type.</p>
		/// </summary>
		GRP_AUDIENCE_IMPRESSIONS = 135,
		/// <summary>Percentage of the number of impressions in the given demographic bucket (out of
		/// the number of impressions in all demographics). <p>Corresponds to "% Composition
		/// impressions" in the Ad Manager UI. Compatible with the REACH report type.</p>
		/// </summary>
		GRP_AUDIENCE_IMPRESSIONS_SHARE = 136,
		/// <summary>The audience reach calculated as <a
		/// href='#GRP_UNIQUE_AUDIENCE'>#GRP_UNIQUE_AUDIENCE</a> / <a
		/// href='#GRP_POPULATION'>#GRP_POPULATION</a>. <p>Corresponds to "% Population
		/// reach" in the Ad Manager UI. Compatible with the REACH report type.</p>
		/// </summary>
		GRP_AUDIENCE_REACH = 137,
		/// <summary>The audience average frequency calculated as <a
		/// href='#GRP_AUDIENCE_IMPRESSIONS'>#GRP_AUDIENCE_IMPRESSIONS</a> / <a
		/// href=''>#GRP_UNIQUE_AUDIENCE</a>. <p>Corresponds to "Average frequency" in the
		/// Ad Manager UI. Compatible with the REACH report type.</p>
		/// </summary>
		GRP_AUDIENCE_AVERAGE_FREQUENCY = 138,
		/// <summary>The gross rating points (GRP) calculated as <a
		/// href='#GRP_AUDIENCE_REACH'>#GRP_AUDIENCE_REACH</a> * <a
		/// href=''>#GRP_AUDIENCE_AVERAGE_FREQUENCY</a> * 100. <p>Corresponds to "Target
		/// rating points" in the Ad Manager UI. Compatible with the REACH report type.</p>
		/// </summary>
		GRP_GROSS_RATING_POINTS = 139,
		/// <summary>The number of impressions for a particular SDK mediation creative.
		/// <p>Corresponds to "SDK mediation creative impressions" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		SDK_MEDIATION_CREATIVE_IMPRESSIONS = 140,
		/// <summary>The number of clicks for a particular SDK mediation creative. <p>Corresponds to
		/// "SDK mediation creative clicks" in the Ad Manager UI. Compatible with the
		/// HISTORICAL report type.</p>
		/// </summary>
		SDK_MEDIATION_CREATIVE_CLICKS = 141,
		/// <summary>The number of forecasted impressions for future sell-through reports. <p>This
		/// metric is available for the next 90 days with a daily break down and for the
		/// next 12 months with a monthly break down.</p> <p>Corresponds to "Forecasted
		/// impressions" in the Ad Manager UI. Compatible with the SELL_THROUGH report
		/// type.</p>
		/// </summary>
		SELL_THROUGH_FORECASTED_IMPRESSIONS = 142,
		/// <summary>The number of available impressions for future sell-through reports. <p>This
		/// metric is available for the next 90 days with a daily break down and for the
		/// next 12 months with a monthly break down.</p> <p>Corresponds to "Available
		/// impressions" in the Ad Manager UI. Compatible with the SELL_THROUGH report
		/// type.</p>
		/// </summary>
		SELL_THROUGH_AVAILABLE_IMPRESSIONS = 143,
		/// <summary>The number of reserved impressions for future sell-through reports. <p>This
		/// metric is available for the next 90 days with a daily break down and for the
		/// next 12 months with a monthly break down.</p> <p>Corresponds to "Reserved
		/// impressions" in the Ad Manager UI. Compatible with the SELL_THROUGH report
		/// type.</p>
		/// </summary>
		SELL_THROUGH_RESERVED_IMPRESSIONS = 144,
		/// <summary>The sell-through rate for impressions for future sell-through reports. <p>This
		/// metric is available for the next 90 days with a daily break down and for the
		/// next 12 months with a monthly break down.</p> <p>Corresponds to "Sell-through
		/// rate" in the Ad Manager UI. Compatible with the SELL_THROUGH report type.</p>
		/// </summary>
		SELL_THROUGH_SELL_THROUGH_RATE = 145,
		/// <summary>The total number of times a backup image is served in place of a rich media ad.
		/// <p>Corresponds to "Backup image impressions" in the Ad Manager UI. Compatible
		/// with the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_BACKUP_IMAGES = 146,
		/// <summary>The amount of time(seconds) that each rich media ad is displayed to users.
		/// <p>Corresponds to "Total display time" in the Ad Manager UI. Compatible with the
		/// HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_DISPLAY_TIME = 147,
		/// <summary>The average amount of time(seconds) that each rich media ad is displayed to
		/// users. <p>Corresponds to "Average display time" in the Ad Manager UI. Compatible
		/// with the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_AVERAGE_DISPLAY_TIME = 148,
		/// <summary>The number of times an expanding ad was expanded. <p>Corresponds to "Total
		/// expansions" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		RICH_MEDIA_EXPANSIONS = 149,
		/// <summary>The average amount of time(seconds) that an expanding ad is viewed in an
		/// expanded state. <p>Corresponds to "Average expanding time" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_EXPANDING_TIME = 150,
		/// <summary>The average amount of time(seconds) that a user interacts with a rich media ad.
		/// <p>Corresponds to "Interaction time" in the Ad Manager UI. Compatible with the
		/// HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_INTERACTION_TIME = 151,
		/// <summary>The number of times that a user interacts with a rich media ad. <p>Corresponds
		/// to "Total interactions" in the Ad Manager UI. Compatible with the HISTORICAL
		/// report type.</p>
		/// </summary>
		RICH_MEDIA_INTERACTION_COUNT = 152,
		/// <summary>The ratio of rich media ad interactions to the number of times the ad was
		/// displayed. Represented as a percentage. <p>Corresponds to "Interaction rate" in
		/// the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_INTERACTION_RATE = 153,
		/// <summary>The average amount of time(seconds) that a user interacts with a rich media ad.
		/// <p>Corresponds to "Average interaction time" in the Ad Manager UI. Compatible
		/// with the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_AVERAGE_INTERACTION_TIME = 154,
		/// <summary>The number of impressions where a user interacted with a rich media ad.
		/// <p>Corresponds to "Interactive impressions" in the Ad Manager UI. Compatible
		/// with the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_INTERACTION_IMPRESSIONS = 155,
		/// <summary>The number of times that a user manually closes a floating, expanding, in-page
		/// with overlay, or in-page with floating ad. <p>Corresponds to "Manual closes" in
		/// the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_MANUAL_CLOSES = 156,
		/// <summary>A metric that measures an impression only once when a user opens an ad in full
		/// screen mode. <p>Corresponds to "Full-screen impressions" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_FULL_SCREEN_IMPRESSIONS = 157,
		/// <summary>The number of times a user clicked on the graphical controls of a video player.
		/// <p>Corresponds to "Total video interactions" in the Ad Manager UI. Compatible
		/// with the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_VIDEO_INTERACTIONS = 158,
		/// <summary>The ratio of video interactions to video plays. Represented as a percentage.
		/// <p>Corresponds to "Video interaction rate" in the Ad Manager UI. Compatible with
		/// the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_VIDEO_INTERACTION_RATE = 159,
		/// <summary>The number of times a rich media video was muted. <p>Corresponds to "Mute" in
		/// the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_VIDEO_MUTES = 160,
		/// <summary>The number of times a rich media video was paused. <p>Corresponds to "Pause" in
		/// the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_VIDEO_PAUSES = 161,
		/// <summary>The number of times a rich media video was played. <p>Corresponds to "Plays" in
		/// the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_VIDEO_PLAYES = 162,
		/// <summary>The number of times a rich media video was played upto midpoint. <p>Corresponds
		/// to "Midpoint" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		RICH_MEDIA_VIDEO_MIDPOINTS = 163,
		/// <summary>The number of times a rich media video was fully played. <p>Corresponds to
		/// "Complete" in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_VIDEO_COMPLETES = 164,
		/// <summary>The number of times a rich media video was restarted. <p>Corresponds to
		/// "Replays" in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_VIDEO_REPLAYS = 165,
		/// <summary>The number of times a rich media video was stopped. <p>Corresponds to "Stops" in
		/// the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_VIDEO_STOPS = 166,
		/// <summary>The number of times a rich media video was unmuted. <p>Corresponds to "Unmute"
		/// in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_VIDEO_UNMUTES = 167,
		/// <summary>The average amount of time(seconds) that a rich media video was viewed per view.
		/// <p>Corresponds to "Average view time" in the Ad Manager UI. Compatible with the
		/// HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_VIDEO_VIEW_TIME = 168,
		/// <summary>The percentage of a video watched by a user. <p>Corresponds to "View rate" in
		/// the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_VIDEO_VIEW_RATE = 169,
		/// <summary>The amount of time (seconds) that a user interacts with a rich media ad.
		/// <p>Corresponds to "Custom event - time" in the Ad Manager UI. Compatible with
		/// the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_CUSTOM_EVENT_TIME = 170,
		/// <summary>The number of times a user views and interacts with a specified part of a rich
		/// media ad. <p>Corresponds to "Custom event - count" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		RICH_MEDIA_CUSTOM_EVENT_COUNT = 171,
		/// <summary>The number of impressions where the video was played. <p>Corresponds to "Start"
		/// in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_VIEWERSHIP_START = 172,
		/// <summary>The number of times the video played to 25% of its length. <p>Corresponds to
		/// "First quartile" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_VIEWERSHIP_FIRST_QUARTILE = 173,
		/// <summary>The number of times the video reached its midpoint during play. <p>Corresponds
		/// to "Midpoint" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_VIEWERSHIP_MIDPOINT = 174,
		/// <summary>The number of times the video played to 75% of its length. <p>Corresponds to
		/// "Third quartile" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_VIEWERSHIP_THIRD_QUARTILE = 175,
		/// <summary>The number of times the video played to completion. <p>Corresponds to "Complete"
		/// in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_VIEWERSHIP_COMPLETE = 176,
		/// <summary>Average percentage of the video watched by users. <p>Corresponds to "Average
		/// view rate" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_VIEWERSHIP_AVERAGE_VIEW_RATE = 177,
		/// <summary>Average time(seconds) users watched the video. <p>Corresponds to "Average view
		/// time" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_VIEWERSHIP_AVERAGE_VIEW_TIME = 178,
		/// <summary>Percentage of times the video played to the end. <p>Corresponds to "Completion
		/// rate" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_VIEWERSHIP_COMPLETION_RATE = 179,
		/// <summary>The number of times an error occurred, such as a VAST redirect error, a video
		/// playback error, or an invalid response error. <p>Corresponds to "Total error
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_VIEWERSHIP_TOTAL_ERROR_COUNT = 180,
		/// <summary>Duration of the video creative. <p>Corresponds to "Video length" in the Ad
		/// Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_VIEWERSHIP_VIDEO_LENGTH = 181,
		/// <summary>The number of times a skip button is shown in video. <p>Corresponds to "Skip
		/// button shown" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_VIEWERSHIP_SKIP_BUTTON_SHOWN = 182,
		/// <summary>The number of engaged views i.e. ad is viewed to completion or for 30s,
		/// whichever comes first. <p>Corresponds to "Engaged view" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_VIEWERSHIP_ENGAGED_VIEW = 183,
		/// <summary>View-through rate represented as a percentage. <p>Corresponds to "View-through
		/// rate" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_VIEWERSHIP_VIEW_THROUGH_RATE = 184,
		/// <summary>Number of times that the publisher specified a video ad played automatically.
		/// <p>Corresponds to "Auto-plays" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_VIEWERSHIP_AUTO_PLAYS = 185,
		/// <summary>Number of times that the publisher specified a video ad was clicked to play.
		/// <p>Corresponds to "Click-to-plays" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_VIEWERSHIP_CLICK_TO_PLAYS = 186,
		/// <summary>Error rate is the percentage of video error count from (error count + total
		/// impressions). <p>Corresponds to "Total error rate" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		VIDEO_VIEWERSHIP_TOTAL_ERROR_RATE = 187,
		/// <summary>Number of VAST video errors of type 100. <p>Corresponds to "VAST error 100
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_100_COUNT = 461,
		/// <summary>Number of VAST video errors of type 101. <p>Corresponds to "VAST error 101
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_101_COUNT = 462,
		/// <summary>Number of VAST video errors of type 102. <p>Corresponds to "VAST error 102
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_102_COUNT = 463,
		/// <summary>Number of VAST video errors of type 200. <p>Corresponds to "VAST error 200
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_200_COUNT = 464,
		/// <summary>Number of VAST video errors of type 201. <p>Corresponds to "VAST error 201
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_201_COUNT = 465,
		/// <summary>Number of VAST video errors of type 202. <p>Corresponds to "VAST error 202
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_202_COUNT = 466,
		/// <summary>Number of VAST video errors of type 203. <p>Corresponds to "VAST error 203
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_203_COUNT = 467,
		/// <summary>Number of VAST video errors of type 300. <p>Corresponds to "VAST error 300
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_300_COUNT = 468,
		/// <summary>Number of VAST video errors of type 301. <p>Corresponds to "VAST error 301
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_301_COUNT = 469,
		/// <summary>Number of VAST video errors of type 302. <p>Corresponds to "VAST error 302
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_302_COUNT = 470,
		/// <summary>Number of VAST video errors of type 303. <p>Corresponds to "VAST error 303
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_303_COUNT = 471,
		/// <summary>Number of VAST video errors of type 400. <p>Corresponds to "VAST error 400
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_400_COUNT = 472,
		/// <summary>Number of VAST video errors of type 401. <p>Corresponds to "VAST error 401
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_401_COUNT = 473,
		/// <summary>Number of VAST video errors of type 402. <p>Corresponds to "VAST error 402
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_402_COUNT = 474,
		/// <summary>Number of VAST video errors of type 403. <p>Corresponds to "VAST error 403
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_403_COUNT = 475,
		/// <summary>Number of VAST video errors of type 405. <p>Corresponds to "VAST error 405
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_405_COUNT = 476,
		/// <summary>Number of VAST video errors of type 500. <p>Corresponds to "VAST error 500
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_500_COUNT = 477,
		/// <summary>Number of VAST video errors of type 501. <p>Corresponds to "VAST error 501
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_501_COUNT = 478,
		/// <summary>Number of VAST video errors of type 502. <p>Corresponds to "VAST error 502
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_502_COUNT = 479,
		/// <summary>Number of VAST video errors of type 503. <p>Corresponds to "VAST error 503
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_503_COUNT = 480,
		/// <summary>Number of VAST video errors of type 600. <p>Corresponds to "VAST error 600
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_600_COUNT = 481,
		/// <summary>Number of VAST video errors of type 601. <p>Corresponds to "VAST error 601
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_601_COUNT = 482,
		/// <summary>Number of VAST video errors of type 602. <p>Corresponds to "VAST error 602
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_602_COUNT = 483,
		/// <summary>Number of VAST video errors of type 603. <p>Corresponds to "VAST error 603
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_603_COUNT = 484,
		/// <summary>Number of VAST video errors of type 604. <p>Corresponds to "VAST error 604
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_604_COUNT = 485,
		/// <summary>Number of VAST video errors of type 900. <p>Corresponds to "VAST error 900
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_900_COUNT = 486,
		/// <summary>Number of VAST video errors of type 901. <p>Corresponds to "VAST error 901
		/// count" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_ERRORS_VAST_ERROR_901_COUNT = 487,
		/// <summary>Video interaction event: The number of times user paused ad clip. <p>Corresponds
		/// to "Pause" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_INTERACTION_PAUSE = 216,
		/// <summary>Video interaction event: The number of times the user unpaused the video.
		/// <p>Corresponds to "Resume" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_INTERACTION_RESUME = 217,
		/// <summary>Video interaction event: The number of times a user rewinds the video.
		/// <p>Corresponds to "Rewind" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_INTERACTION_REWIND = 218,
		/// <summary>Video interaction event: The number of times video player was in mute state
		/// during play of ad clip. <p>Corresponds to "Mute" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_INTERACTION_MUTE = 219,
		/// <summary>Video interaction event: The number of times a user unmutes the video.
		/// <p>Corresponds to "Unmute" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_INTERACTION_UNMUTE = 220,
		/// <summary>Video interaction event: The number of times a user collapses a video, either to
		/// its original size or to a different size. <p>Corresponds to "Collapse" in the Ad
		/// Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_INTERACTION_COLLAPSE = 221,
		/// <summary>Video interaction event: The number of times a user expands a video.
		/// <p>Corresponds to "Expand" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_INTERACTION_EXPAND = 222,
		/// <summary>Video interaction event: The number of times ad clip played in full screen mode.
		/// <p>Corresponds to "Full screen" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_INTERACTION_FULL_SCREEN = 223,
		/// <summary>Video interaction event: The number of user interactions with a video, on
		/// average, such as pause, full screen, mute, etc. <p>Corresponds to "Average
		/// interaction rate" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_INTERACTION_AVERAGE_INTERACTION_RATE = 224,
		/// <summary>Video interaction event: The number of times a skippable video is skipped.
		/// <p>Corresponds to "Video skipped" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, CREATIVE_QOS.</p>
		/// </summary>
		VIDEO_INTERACTION_VIDEO_SKIPS = 225,
		/// <summary>The number of control starts. <p>Corresponds to "Control starts" in the Ad
		/// Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		VIDEO_OPTIMIZATION_CONTROL_STARTS = 226,
		/// <summary>The number of optimized starts. <p>Corresponds to "Optimized starts" in the Ad
		/// Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		VIDEO_OPTIMIZATION_OPTIMIZED_STARTS = 227,
		/// <summary>The number of control completes. <p>Corresponds to "Control completes" in the Ad
		/// Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		VIDEO_OPTIMIZATION_CONTROL_COMPLETES = 228,
		/// <summary>The number of optimized completes. <p>Corresponds to "Optimized completes" in
		/// the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		VIDEO_OPTIMIZATION_OPTIMIZED_COMPLETES = 229,
		/// <summary>The rate of control completions. <p>Corresponds to "Control completion rate" in
		/// the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		VIDEO_OPTIMIZATION_CONTROL_COMPLETION_RATE = 230,
		/// <summary>The rate of optimized completions. <p>Corresponds to "Optimized completion rate"
		/// in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		VIDEO_OPTIMIZATION_OPTIMIZED_COMPLETION_RATE = 231,
		/// <summary>The percentage by which optimized completion rate is greater than the
		/// unoptimized completion rate. This is calculated as (( <a
		/// href='Column#VIDEO_OPTIMIZATION_OPTIMIZED_COMPLETION_RATE'>Column#VIDEO_OPTIMIZATION_OPTIMIZED_COMPLETION_RATE</a>/
		/// <a
		/// href='Column#VIDEO_OPTIMIZATION_CONTROL_COMPLETION_RATE'>Column#VIDEO_OPTIMIZATION_CONTROL_COMPLETION_RATE</a>)
		/// - 1) * 100 for an ad for which the optimization feature has been enabled.
		/// <p>Corresponds to "Completion rate lift" in the Ad Manager UI. Compatible with
		/// the HISTORICAL report type.</p>
		/// </summary>
		VIDEO_OPTIMIZATION_COMPLETION_RATE_LIFT = 232,
		/// <summary>The number of control skip buttons shown. <p>Corresponds to "Control skip button
		/// shown" in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		VIDEO_OPTIMIZATION_CONTROL_SKIP_BUTTON_SHOWN = 233,
		/// <summary>The number of optimized skip buttons shown. <p>Corresponds to "Optimized skip
		/// button shown" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		VIDEO_OPTIMIZATION_OPTIMIZED_SKIP_BUTTON_SHOWN = 234,
		/// <summary>The number of control engaged views. <p>Corresponds to "Control engaged view" in
		/// the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		VIDEO_OPTIMIZATION_CONTROL_ENGAGED_VIEW = 235,
		/// <summary>The number of optimized engaged views. <p>Corresponds to "Optimized engaged
		/// view" in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		VIDEO_OPTIMIZATION_OPTIMIZED_ENGAGED_VIEW = 236,
		/// <summary>The control view-through rate. <p>Corresponds to "Control view-through rate" in
		/// the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		VIDEO_OPTIMIZATION_CONTROL_VIEW_THROUGH_RATE = 237,
		/// <summary>The optimized view-through rate. <p>Corresponds to "Optimized view-through rate"
		/// in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		VIDEO_OPTIMIZATION_OPTIMIZED_VIEW_THROUGH_RATE = 238,
		/// <summary>The percentage by which optimized view-through rate is greater than the
		/// unoptimized view-through rate. This is calculated as (( <a
		/// href=''>Column#VIDEO_OPTIMIZATION_OPTIMIZED_VIEW_THROUGH_RATE</a>/ <a
		/// href=''>Column#VIDEO_OPTIMIZATION_CONTROL_VIEW_THROUGH_RATE</a>) - 1) * 100 for
		/// an ad for which the optimization feature has been enabled. <p>Corresponds to
		/// "View-through rate lift" in the Ad Manager UI. Compatible with the HISTORICAL
		/// report type.</p>
		/// </summary>
		VIDEO_OPTIMIZATION_VIEW_THROUGH_RATE_LIFT = 239,
		/// <summary>The total number of impressions viewed on the user's screen. <p>Corresponds to
		/// "Total Active View viewable impressions" in the Ad Manager UI. Compatible with
		/// the HISTORICAL report type.</p>
		/// </summary>
		TOTAL_ACTIVE_VIEW_VIEWABLE_IMPRESSIONS = 240,
		/// <summary>The total number of impressions that were sampled and measured by active view.
		/// <p>Corresponds to "Total Active View measurable impressions" in the Ad Manager
		/// UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		TOTAL_ACTIVE_VIEW_MEASURABLE_IMPRESSIONS = 241,
		/// <summary>The percentage of total impressions viewed on the user's screen (out of the
		/// total impressions measurable by active view).
		/// </summary>
		TOTAL_ACTIVE_VIEW_VIEWABLE_IMPRESSIONS_RATE = 242,
		/// <summary>Total number of impressions that were eligible to measure viewability.
		/// <p>Corresponds to "Total Active View eligible impressions" in the Ad Manager UI.
		/// Compatible with the HISTORICAL report type.</p>
		/// </summary>
		TOTAL_ACTIVE_VIEW_ELIGIBLE_IMPRESSIONS = 243,
		/// <summary>The percentage of total impressions that were measurable by active view (out of
		/// all the total impressions sampled for active view). <p>Corresponds to "Total
		/// Active View % measurable impressions" in the Ad Manager UI. Compatible with the
		/// HISTORICAL report type.</p>
		/// </summary>
		TOTAL_ACTIVE_VIEW_MEASURABLE_IMPRESSIONS_RATE = 244,
		/// <summary>Active View total average time in seconds that specific impressions are reported
		/// as being viewable. <p>Corresponds to "Total Active View Average Viewable Time
		/// (seconds)" in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		TOTAL_ACTIVE_VIEW_AVERAGE_VIEWABLE_TIME = 488,
		/// <summary>The number of impressions delivered by the ad server viewed on the user's
		/// screen. <p>Corresponds to "Ad server Active View viewable impressions" in the Ad
		/// Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_ACTIVE_VIEW_VIEWABLE_IMPRESSIONS = 245,
		/// <summary>The number of impressions delivered by the ad server that were sampled, and
		/// measurable by active view. <p>Corresponds to "Ad server Active View measurable
		/// impressions" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		AD_SERVER_ACTIVE_VIEW_MEASURABLE_IMPRESSIONS = 246,
		/// <summary>The percentage of impressions delivered by the ad server viewed on the user's
		/// screen (out of the ad server impressions measurable by active view).
		/// <p>Corresponds to "Ad server Active View % viewable impressions" in the Ad
		/// Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_ACTIVE_VIEW_VIEWABLE_IMPRESSIONS_RATE = 247,
		/// <summary>Total number of impressions delivered by the ad server that were eligible to
		/// measure viewability. <p>Corresponds to "Ad server Active View eligible
		/// impressions" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		AD_SERVER_ACTIVE_VIEW_ELIGIBLE_IMPRESSIONS = 248,
		/// <summary>The percentage of impressions delivered by the ad server that were measurable by
		/// active view ( out of all the ad server impressions sampled for active view).
		/// <p>Corresponds to "Ad server Active View % measurable impressions" in the Ad
		/// Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_ACTIVE_VIEW_MEASURABLE_IMPRESSIONS_RATE = 249,
		/// <summary>Active View ad server revenue. <p>Corresponds to "Ad Server Active View Revenue"
		/// in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_SERVER_ACTIVE_VIEW_REVENUE = 422,
		/// <summary>Active View ad server average time in seconds that specific impressions are
		/// reported as being viewable. <p>Corresponds to "Ad Server Active View Average
		/// Viewable Time (seconds)" in the Ad Manager UI. Compatible with the HISTORICAL
		/// report type.</p>
		/// </summary>
		AD_SERVER_ACTIVE_VIEW_AVERAGE_VIEWABLE_TIME = 489,
		/// <summary>The number of impressions delivered by AdSense viewed on the user's screen,
		/// <p>Corresponds to "AdSense Active View viewable impressions" in the Ad Manager
		/// UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		ADSENSE_ACTIVE_VIEW_VIEWABLE_IMPRESSIONS = 250,
		/// <summary>The number of impressions delivered by AdSense that were sampled, and measurable
		/// by active view. <p>Corresponds to "AdSense Active View measurable impressions"
		/// in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		ADSENSE_ACTIVE_VIEW_MEASURABLE_IMPRESSIONS = 251,
		/// <summary>The percentage of impressions delivered by AdSense viewed on the user's screen
		/// (out of AdSense impressions measurable by active view). <p>Corresponds to
		/// "AdSense Active View % viewable impressions" in the Ad Manager UI. Compatible
		/// with the HISTORICAL report type.</p>
		/// </summary>
		ADSENSE_ACTIVE_VIEW_VIEWABLE_IMPRESSIONS_RATE = 252,
		/// <summary>Total number of impressions delivered by AdSense that were eligible to measure
		/// viewability. <p>Corresponds to "AdSense Active View eligible impressions" in the
		/// Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		ADSENSE_ACTIVE_VIEW_ELIGIBLE_IMPRESSIONS = 253,
		/// <summary>The percentage of impressions delivered by AdSense that were measurable by
		/// active view ( out of all AdSense impressions sampled for active view).
		/// <p>Corresponds to "AdSense Active View % measurable impressions" in the Ad
		/// Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		ADSENSE_ACTIVE_VIEW_MEASURABLE_IMPRESSIONS_RATE = 254,
		/// <summary>Active View AdSense revenue. <p>Corresponds to "AdSense Active View Revenue" in
		/// the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		ADSENSE_ACTIVE_VIEW_REVENUE = 423,
		/// <summary>Active View AdSense average time in seconds that specific impressions are
		/// reported as being viewable. <p>Corresponds to "AdSense Active View Average
		/// Viewable Time (seconds)" in the Ad Manager UI. Compatible with the HISTORICAL
		/// report type.</p>
		/// </summary>
		ADSENSE_ACTIVE_VIEW_AVERAGE_VIEWABLE_TIME = 490,
		/// <summary>The number of impressions delivered by Ad Exchange viewed on the user's screen,
		/// <p>Corresponds to "Ad Exchange Active View viewable impressions" in the Ad
		/// Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_ACTIVE_VIEW_VIEWABLE_IMPRESSIONS = 255,
		/// <summary>The number of impressions delivered by Ad Exchange that were sampled, and
		/// measurable by active view. <p>Corresponds to "Ad Exchange Active View measurable
		/// impressions" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		AD_EXCHANGE_ACTIVE_VIEW_MEASURABLE_IMPRESSIONS = 256,
		/// <summary>The percentage of impressions delivered by Ad Exchange viewed on the user's
		/// screen (out of Ad Exchange impressions measurable by active view).
		/// <p>Corresponds to "Ad Exchange Active View % viewable impressions" in the Ad
		/// Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_ACTIVE_VIEW_VIEWABLE_IMPRESSIONS_RATE = 257,
		/// <summary>Total number of impressions delivered by Ad Exchange that were eligible to
		/// measure viewability. <p>Corresponds to "Ad Exchange Active View eligible
		/// impressions" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		AD_EXCHANGE_ACTIVE_VIEW_ELIGIBLE_IMPRESSIONS = 258,
		/// <summary>The percentage of impressions delivered by Ad Exchange that were measurable by
		/// active view ( out of all Ad Exchange impressions sampled for active view).
		/// <p>Corresponds to "Ad Exchange Active View % measurable impressions" in the Ad
		/// Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_ACTIVE_VIEW_MEASURABLE_IMPRESSIONS_RATE = 259,
		/// <summary>Active View AdExchange revenue. <p>Corresponds to "Ad Exchange Active View
		/// Revenue" in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AD_EXCHANGE_ACTIVE_VIEW_REVENUE = 424,
		/// <summary>Active View AdExchange average time in seconds that specific impressions are
		/// reported as being viewable. <p>Corresponds to "Ad Exchange Active View Average
		/// Viewable Time (seconds)" in the Ad Manager UI. Compatible with the HISTORICAL
		/// report type.</p>
		/// </summary>
		AD_EXCHANGE_ACTIVE_VIEW_AVERAGE_VIEWABLE_TIME = 491,
		/// <summary>Active View total revenue. <p>Corresponds to "Total Active View Revenue" in the
		/// Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		TOTAL_ACTIVE_VIEW_REVENUE = 425,
		/// <summary>Cost for audience extension ie. cost the publisher had to pay in order to buy
		/// the inventory. <p>This field is deprecated and will be removed in v201805.</p>
		/// <p>Compatible with the HISTORICAL report type.</p>
		/// </summary>
		AUDIENCE_EXTENSION_COST = 492,
		/// <summary>Number of view-through conversions.
		/// </summary>
		VIEW_THROUGH_CONVERSIONS = 260,
		/// <summary>Number of view-through conversions per thousand impressions. <p>Corresponds to
		/// "Conversions per thousand impressions" in the Ad Manager UI. Compatible with the
		/// HISTORICAL report type.</p>
		/// </summary>
		CONVERSIONS_PER_THOUSAND_IMPRESSIONS = 261,
		/// <summary>Number of click-through conversions. <p>Corresponds to "Click-through
		/// conversions" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		CLICK_THROUGH_CONVERSIONS = 262,
		/// <summary>Number of click-through conversions per click. <p>Corresponds to "Conversions
		/// per click" in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		CONVERSIONS_PER_CLICK = 263,
		/// <summary>Revenue for view-through conversions. <p>Corresponds to "Advertiser view-through
		/// sales" in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		VIEW_THROUGH_REVENUE = 264,
		/// <summary>Revenue for click-through conversions. <p>Corresponds to "Advertiser
		/// click-through sales" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		CLICK_THROUGH_REVENUE = 265,
		/// <summary>Total number of conversions. <p>Corresponds to "Total conversions" in the Ad
		/// Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		TOTAL_CONVERSIONS = 266,
		/// <summary>Total revenue for conversions. <p>Corresponds to "Total advertiser sales" in the
		/// Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		TOTAL_CONVERSION_REVENUE = 267,
		/// <summary>The number of impressions sent to Ad Exchange / AdSense, regardless of whether
		/// they won or lost (total number of dynamic allocation impressions).
		/// <p>Corresponds to "Impressions competing" in the Ad Manager UI. Compatible with
		/// the HISTORICAL report type.</p>
		/// </summary>
		DYNAMIC_ALLOCATION_OPPORTUNITY_IMPRESSIONS_COMPETING_TOTAL = 268,
		/// <summary>The number of unfilled queries that attempted dynamic allocation by Ad Exchange
		/// / AdSense. <p>Corresponds to "Unfilled competing impressions" in the Ad Manager
		/// UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		DYNAMIC_ALLOCATION_OPPORTUNITY_UNFILLED_IMPRESSIONS_COMPETING = 269,
		/// <summary>The number of Ad Exchange / AdSense and Ad Manager impressions. <p>Corresponds
		/// to "Eligible impressions" in the Ad Manager UI. Compatible with the HISTORICAL
		/// report type.</p>
		/// </summary>
		DYNAMIC_ALLOCATION_OPPORTUNITY_ELIGIBLE_IMPRESSIONS_TOTAL = 270,
		/// <summary>The difference between eligible impressions and competing impressions in dynamic
		/// allocation.
		/// </summary>
		DYNAMIC_ALLOCATION_OPPORTUNITY_IMPRESSIONS_NOT_COMPETING_TOTAL = 271,
		/// <summary>The percentage of eligible impressions that are not competing in dynamic
		/// allocation. <p>Corresponds to "Impressions not competing (%)" in the Ad Manager
		/// UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		DYNAMIC_ALLOCATION_OPPORTUNITY_IMPRESSIONS_NOT_COMPETING_PERCENT_TOTAL = 272,
		/// <summary>The percent of eligible impressions participating in dynamic allocation.
		/// </summary>
		DYNAMIC_ALLOCATION_OPPORTUNITY_SATURATION_RATE_TOTAL = 273,
		/// <summary>The percent of total dynamic allocation queries that won. <p>Corresponds to
		/// "Dynamic allocation match rate" in the Ad Manager UI. Compatible with the
		/// HISTORICAL report type.</p>
		/// </summary>
		DYNAMIC_ALLOCATION_OPPORTUNITY_MATCH_RATE_TOTAL = 274,
		/// <summary>The contracted net revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. <p>Corresponds to "Contracted
		/// revenue (net)" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, SALES.</p>
		/// </summary>
		CONTRACTED_REVENUE_CONTRACTED_NET_REVENUE = 275,
		/// <summary>The contracted net revenue in the local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. See <a
		/// href='#CONTRACTED_REVENUE_CONTRACTED_NET_REVENUE'>#CONTRACTED_REVENUE_CONTRACTED_NET_REVENUE</a>
		/// <p>Can correspond to any of the following in the Ad Manager UI: Contracted
		/// revenue (local), Contracted revenue (net) (local). Compatible with any of the
		/// following report types: HISTORICAL, SALES.</p>
		/// </summary>
		CONTRACTED_REVENUE_LOCAL_CONTRACTED_NET_REVENUE = 276,
		/// <summary>The contracted gross revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>, including agency commission.
		/// <p>Corresponds to "Contracted revenue (gross)" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		CONTRACTED_REVENUE_CONTRACTED_GROSS_REVENUE = 277,
		/// <summary>The contracted gross revenue in the local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>, including agency commission. See
		/// <a
		/// href='#CONTRACTED_REVENUE_CONTRACTED_GROSS_REVENUE'>#CONTRACTED_REVENUE_CONTRACTED_GROSS_REVENUE</a>
		/// <p>Corresponds to "Contracted revenue (gross) (local)" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		CONTRACTED_REVENUE_LOCAL_CONTRACTED_GROSS_REVENUE = 278,
		/// <summary>The value added tax on contracted net revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> or <a href='Proposal'>Proposal</a>.
		/// <p>Corresponds to "Contracted VAT" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		CONTRACTED_REVENUE_CONTRACTED_VAT = 279,
		/// <summary>The value added tax on contracted net revenue in the local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> or <a href='Proposal'>Proposal</a>.
		/// See <a
		/// href='#CONTRACTED_REVENUE_CONTRACTED_VAT'>#CONTRACTED_REVENUE_CONTRACTED_VAT</a>
		/// <p>Corresponds to "Contracted VAT (local)" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		CONTRACTED_REVENUE_LOCAL_CONTRACTED_VAT = 280,
		/// <summary>The contracted agency commission of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> or <a href='Proposal'>Proposal</a>.
		/// <p>Corresponds to "Contracted agency commission" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		CONTRACTED_REVENUE_CONTRACTED_AGENCY_COMMISSION = 281,
		/// <summary>The contracted agency commission in the local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> or <a href='Proposal'>Proposal</a>.
		/// See <a
		/// href='#CONTRACTED_REVENUE_CONTRACTED_AGENCY_COMMISSION'>#CONTRACTED_REVENUE_CONTRACTED_AGENCY_COMMISSION</a>
		/// <p>Corresponds to "Contracted agency commission (local)" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		CONTRACTED_REVENUE_LOCAL_CONTRACTED_AGENCY_COMMISSION = 282,
		/// <summary>The contracted impressions of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. <p>Corresponds to "Contracted
		/// impressions" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, SALES.</p>
		/// </summary>
		SALES_CONTRACT_CONTRACTED_IMPRESSIONS = 283,
		/// <summary>The contracted clicks of the <a href='ProposalLineItem'>ProposalLineItem</a>.
		/// <p>Corresponds to "Contracted clicks" in the Ad Manager UI. Compatible with any
		/// of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		SALES_CONTRACT_CONTRACTED_CLICKS = 284,
		/// <summary>The contracted volume of the <a href='ProposalLineItem'>ProposalLineItem</a>.
		/// Volume represents impressions for rate type CPM, clicks for CPC, and days for
		/// CPD. <p>Corresponds to "Contracted volume" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		SALES_CONTRACT_CONTRACTED_VOLUME = 285,
		/// <summary>The budget of the <a href='Proposal'>Proposal</a>. <p>Corresponds to "Budget" in
		/// the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, SALES.</p>
		/// </summary>
		SALES_CONTRACT_BUDGET = 286,
		/// <summary>The remaining budget of the <a href='Proposal'>Proposal</a>. It is calculated by
		/// subtracting the contracted net revenue from the budget. <p>Corresponds to
		/// "Remaining budget" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SALES.</p>
		/// </summary>
		SALES_CONTRACT_REMAINING_BUDGET = 287,
		/// <summary>The buffered impressions of the <a href='ProposalLineItem'>ProposalLineItem</a>.
		/// <p>Corresponds to "Buffered impressions" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		SALES_CONTRACT_BUFFERED_IMPRESSIONS = 288,
		/// <summary>The buffered clicks of the <a href='ProposalLineItem'>ProposalLineItem</a>.
		/// <p>Corresponds to "Buffered clicks" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		SALES_CONTRACT_BUFFERED_CLICKS = 289,
		/// <summary>The scheduled impressions of a <a href='ProposalLineItem'>ProposalLineItem</a>.
		/// It is the sum of <a
		/// href='#SALES_CONTRACT_CONTRACTED_IMPRESSIONS'>#SALES_CONTRACT_CONTRACTED_IMPRESSIONS</a>
		/// and <a
		/// href='#SALES_CONTRACT_BUFFERED_IMPRESSIONS'>#SALES_CONTRACT_BUFFERED_IMPRESSIONS</a>.
		/// <p>Corresponds to "Scheduled impressions" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		SCHEDULED_SCHEDULED_IMPRESSIONS = 290,
		/// <summary>The scheduled clicks of a <a href='ProposalLineItem'>ProposalLineItem</a>. It is
		/// the sum of <a
		/// href='#SALES_CONTRACT_CONTRACTED_CLICKS'>#SALES_CONTRACT_CONTRACTED_CLICKS</a>
		/// and <a
		/// href='#SALES_CONTRACT_BUFFERED_CLICKS'>#SALES_CONTRACT_BUFFERED_CLICKS</a>.
		/// <p>Corresponds to "Scheduled clicks" in the Ad Manager UI. Compatible with any
		/// of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		SCHEDULED_SCHEDULED_CLICKS = 291,
		/// <summary>The scheduled volume of a <a href='ProposalLineItem'>ProposalLineItem</a>. It is
		/// the sum of <a
		/// href='#SALES_CONTRACT_CONTRACTED_VOLUME'>#SALES_CONTRACT_CONTRACTED_VOLUME</a>
		/// and buffered volume. <p>Corresponds to "Scheduled volume" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		SCHEDULED_SCHEDULED_VOLUME = 292,
		/// <summary>The scheduled net revenue of a <a href='ProposalLineItem'>ProposalLineItem</a>.
		/// <p>Corresponds to "Scheduled revenue (net)" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		SCHEDULED_SCHEDULED_NET_REVENUE = 293,
		/// <summary>The scheduled net revenue in the local currency of a <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. <p>Corresponds to "Scheduled
		/// revenue (net) (local)" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SALES.</p>
		/// </summary>
		SCHEDULED_LOCAL_SCHEDULED_NET_REVENUE = 294,
		/// <summary>The scheduled gross revenue of a <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. <p>Corresponds to "Scheduled
		/// revenue (gross)" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SALES.</p>
		/// </summary>
		SCHEDULED_SCHEDULED_GROSS_REVENUE = 295,
		/// <summary>The scheduled gross revenue in the local currency of a <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. <p>Corresponds to "Scheduled
		/// revenue (gross) (local)" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SALES.</p>
		/// </summary>
		SCHEDULED_LOCAL_SCHEDULED_GROSS_REVENUE = 296,
		/// <summary>The total budget of the <a href='Proposal'>Proposal</a>. It differs from <a
		/// href='#SALES_CONTRACT_BUDGET'>#SALES_CONTRACT_BUDGET</a> since it always
		/// contains the total budget, not the prorated budget. <p>Corresponds to "Total
		/// budget" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, SALES.</p>
		/// </summary>
		SALES_TOTAL_TOTAL_BUDGET = 297,
		/// <summary>The total remaining budget of the <a href='Proposal'>Proposal</a>. It differs
		/// from <a href=''>#SALES_CONTRACT_REMAINING_BUDGET</a> since it always contains
		/// the total remaining budget, not the prorated remaining budget. <p>Corresponds to
		/// "Total remaining budget" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SALES.</p>
		/// </summary>
		SALES_TOTAL_TOTAL_REMAINING_BUDGET = 298,
		/// <summary>The total contracted volume of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It differs from <a
		/// href=''>#SALES_CONTRACT_CONTRACTED_VOLUME</a> that the volume is not prorated
		/// with regard to the date range. <p>Corresponds to "Total contracted volume" in
		/// the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, SALES.</p>
		/// </summary>
		SALES_TOTAL_TOTAL_CONTRACTED_VOLUME = 299,
		/// <summary>The total contracted net revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It differs from <a
		/// href=''>#CONTRACTED_REVENUE_CONTRACTED_NET_REVENUE</a> that the revenue is not
		/// prorated with regard to the date range. <p>Corresponds to "Total contracted
		/// revenue (net)" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, SALES.</p>
		/// </summary>
		SALES_TOTAL_TOTAL_CONTRACTED_NET_REVENUE = 300,
		/// <summary>The total contracted net revenue in the local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It differs from <a
		/// href='#CONTRACTED_REVENUE_LOCAL_CONTRACTED_NET_REVENUE'>#CONTRACTED_REVENUE_LOCAL_CONTRACTED_NET_REVENUE</a>
		/// that the revenue is not prorated with regard to the date range. <p>See <a
		/// href='#SALES_TOTAL_TOTAL_CONTRACTED_NET_REVENUE'>#SALES_TOTAL_TOTAL_CONTRACTED_NET_REVENUE</a></p>
		/// <p>Corresponds to "Total contracted revenue (net) (local)" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		SALES_TOTAL_LOCAL_TOTAL_CONTRACTED_NET_REVENUE = 301,
		/// <summary>The total contracted gross revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It differs from <a
		/// href=''>#CONTRACTED_REVENUE_CONTRACTED_GROSS_REVENUE</a> that the revenue is not
		/// prorated with regard to the date range. <p>Corresponds to "Total contracted
		/// revenue (gross)" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SALES.</p>
		/// </summary>
		SALES_TOTAL_TOTAL_CONTRACTED_GROSS_REVENUE = 302,
		/// <summary>The total contracted gross revenue in the local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It differs from <a
		/// href='#CONTRACTED_REVENUE_LOCAL_CONTRACTED_GROSS_REVENUE'>#CONTRACTED_REVENUE_LOCAL_CONTRACTED_GROSS_REVENUE</a>
		/// that the revenue is not prorated with regard to the date range. <p>See <a
		/// href='#SALES_TOTAL_TOTAL_CONTRACTED_GROSS_REVENUE'>#SALES_TOTAL_TOTAL_CONTRACTED_GROSS_REVENUE</a></p>
		/// <p>Corresponds to "Total contracted revenue (gross) (local)" in the Ad Manager
		/// UI. Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		SALES_TOTAL_LOCAL_TOTAL_CONTRACTED_GROSS_REVENUE = 303,
		/// <summary>The total contracted agency commission of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It differs from <a
		/// href=''>#CONTRACTED_REVENUE_CONTRACTED_AGENCY_COMMISSION</a> that the revenue is
		/// not prorated with regard to the date range. <p>Corresponds to "Total contracted
		/// agency commission" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SALES.</p>
		/// </summary>
		SALES_TOTAL_TOTAL_CONTRACTED_AGENCY_COMMISSION = 304,
		/// <summary>The total contracted agency commission in the local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It differs from <a
		/// href='#CONTRACTED_REVENUE_LOCAL_CONTRACTED_AGENCY_COMMISSION'>#CONTRACTED_REVENUE_LOCAL_CONTRACTED_AGENCY_COMMISSION</a>
		/// that the revenue is not prorated with regard to the date range. <p>See <a
		/// href='#SALES_TOTAL_TOTAL_CONTRACTED_AGENCY_COMMISSION'>#SALES_TOTAL_TOTAL_CONTRACTED_AGENCY_COMMISSION</a></p>
		/// <p>Corresponds to "Total contracted agency commission (local)" in the Ad Manager
		/// UI. Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		SALES_TOTAL_LOCAL_TOTAL_CONTRACTED_AGENCY_COMMISSION = 305,
		/// <summary>The total net revenue plus its value added tax of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. The revenue is not prorated with
		/// regard to the date range. <p>Corresponds to "Total contracted revenue with VAT
		/// (net)" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, SALES.</p>
		/// </summary>
		SALES_TOTAL_TOTAL_CONTRACTED_NET_REVENUE_WITH_VAT = 306,
		/// <summary>The total net revenue plus its value added tax in the local currency of the <a
		/// href=''>ProposalLineItem</a>. The revenue is not prorated with regard to the
		/// date range. <p>See <a
		/// href='#SALES_TOTAL_TOTAL_CONTRACTED_WITH_VAT'>#SALES_TOTAL_TOTAL_CONTRACTED_WITH_VAT</a></p>
		/// <p>Corresponds to "Total contracted revenue with VAT (net) (local)" in the Ad
		/// Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// SALES.</p>
		/// </summary>
		SALES_TOTAL_LOCAL_TOTAL_CONTRACTED_NET_REVENUE_WITH_VAT = 307,
		/// <summary>The total scheduled volume of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It differs from <a
		/// href=''>#SCHEDULED_SCHEDULED_VOLUME</a> that the volume is not prorated with
		/// regard to the date range. <p>Corresponds to "Total scheduled volume" in the Ad
		/// Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// SALES.</p>
		/// </summary>
		SALES_TOTAL_TOTAL_SCHEDULED_VOLUME = 308,
		/// <summary>The total scheduled net revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It differs from <a
		/// href=''>#SCHEDULED_SCHEDULED_NET_REVENUE</a> that the revenue is not prorated
		/// with regard to the date range. <p>Corresponds to "Total scheduled revenue (net)"
		/// in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, SALES.</p>
		/// </summary>
		SALES_TOTAL_TOTAL_SCHEDULED_NET_REVENUE = 309,
		/// <summary>The total scheduled net revenue in the local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It differs from <a
		/// href='#SCHEDULED_LOCAL_SCHEDULED_NET_REVENUE'>#SCHEDULED_LOCAL_SCHEDULED_NET_REVENUE</a>
		/// that the revenue is not prorated with regard to the date range. <p>See <a
		/// href='#SALES_TOTAL_TOTAL_SCHEDULED_NET_REVENUE'>#SALES_TOTAL_TOTAL_SCHEDULED_NET_REVENUE</a></p>
		/// <p>Corresponds to "Total scheduled revenue (net) (local)" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		SALES_TOTAL_LOCAL_TOTAL_SCHEDULED_NET_REVENUE = 310,
		/// <summary>The total scheduled gross revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It differs from <a
		/// href=''>#SCHEDULED_SCHEDULED_GROSS_REVENUE</a> that the revenue is not prorated
		/// with regard to the date range. <p>Corresponds to "Total scheduled revenue
		/// (gross)" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, SALES.</p>
		/// </summary>
		SALES_TOTAL_TOTAL_SCHEDULED_GROSS_REVENUE = 311,
		/// <summary>The total scheduled gross revenue in the local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It differs from <a
		/// href='#SCHEDULED_LOCAL_SCHEDULED_GROSS_REVENUE'>#SCHEDULED_LOCAL_SCHEDULED_GROSS_REVENUE</a>
		/// that the revenue is not prorated with regard to the date range. <p>See <a
		/// href='#SALES_TOTAL_TOTAL_SCHEDULED_GROSS_REVENUE'>#SALES_TOTAL_TOTAL_SCHEDULED_GROSS_REVENUE</a></p>
		/// <p>Corresponds to "Total scheduled revenue (gross) (local)" in the Ad Manager
		/// UI. Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		SALES_TOTAL_LOCAL_TOTAL_SCHEDULED_GROSS_REVENUE = 312,
		/// <summary>The unreconciled net revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It is the portion of <a
		/// href=''>#UNIFIED_REVENUE_UNIFIED_NET_REVENUE</a> coming from unreconciled Ad
		/// Manager volume. <p>Corresponds to "Unreconciled revenue (net)" in the Ad Manager
		/// UI. Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		UNIFIED_REVENUE_UNRECONCILED_NET_REVENUE = 313,
		/// <summary>The unreconciled net revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> in local currency. It is the
		/// portion of <a
		/// href='#UNIFIED_REVENUE_LOCAL_UNIFIED_NET_REVENUE'>#UNIFIED_REVENUE_LOCAL_UNIFIED_NET_REVENUE</a>
		/// coming from unreconciled Ad Manager volume. <p>See <a
		/// href='#UNIFIED_REVENUE_UNRECONCILED_NET_REVENUE'>#UNIFIED_REVENUE_UNRECONCILED_NET_REVENUE</a></p>
		/// <p>Corresponds to "Unreconciled revenue (net) (local)" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		UNIFIED_REVENUE_LOCAL_UNRECONCILED_NET_REVENUE = 314,
		/// <summary>The unreconciled gross revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It is the portion of <a
		/// href=''>#UNIFIED_REVENUE_UNIFIED_GROSS_REVENUE</a> coming from unreconciled Ad
		/// Manager volume. <p>Corresponds to "Unreconciled revenue (gross)" in the Ad
		/// Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// SALES.</p>
		/// </summary>
		UNIFIED_REVENUE_UNRECONCILED_GROSS_REVENUE = 315,
		/// <summary>The unreconciled gross revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> in local currency. It is the
		/// portion of <a
		/// href='#UNIFIED_REVENUE_LOCAL_UNIFIED_GROSS_REVENUE'>#UNIFIED_REVENUE_LOCAL_UNIFIED_GROSS_REVENUE</a>
		/// coming from unreconciled Ad manager volume. <p>See <a
		/// href='#UNIFIED_REVENUE_UNRECONCILED_GROSS_REVENUE'>#UNIFIED_REVENUE_UNRECONCILED_GROSS_REVENUE</a></p>
		/// <p>Corresponds to "Unreconciled revenue (gross) (local)" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		UNIFIED_REVENUE_LOCAL_UNRECONCILED_GROSS_REVENUE = 316,
		/// <summary>The forecasted net revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It is the portion of <a
		/// href=''>#UNIFIED_REVENUE_UNIFIED_NET_REVENUE</a> coming from forecasted Ad
		/// Manager volume. <p>Corresponds to "Forecasted revenue (net)" in the Ad Manager
		/// UI. Compatible with the SALES report type.</p>
		/// </summary>
		UNIFIED_REVENUE_FORECASTED_NET_REVENUE = 317,
		/// <summary>The forecasted net revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> in local currency. It is the
		/// portion of <a
		/// href='#UNIFIED_REVENUE_LOCAL_UNIFIED_NET_REVENUE'>#UNIFIED_REVENUE_LOCAL_UNIFIED_NET_REVENUE</a>
		/// coming from forecasted Ad Manager volume. <p>See <a
		/// href='#UNIFIED_REVENUE_FORECASTED_NET_REVENUE'>#UNIFIED_REVENUE_FORECASTED_NET_REVENUE</a></p>
		/// <p>Corresponds to "Forecasted revenue (net) (local)" in the Ad Manager UI.
		/// Compatible with the SALES report type.</p>
		/// </summary>
		UNIFIED_REVENUE_LOCAL_FORECASTED_NET_REVENUE = 318,
		/// <summary>The forecasted gross revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It is the portion of <a
		/// href=''>#UNIFIED_REVENUE_UNIFIED_GROSS_REVENUE</a> coming from forecasted Ad
		/// Manager volume. <p>Corresponds to "Forecasted revenue (gross)" in the Ad Manager
		/// UI. Compatible with the SALES report type.</p>
		/// </summary>
		UNIFIED_REVENUE_FORECASTED_GROSS_REVENUE = 319,
		/// <summary>The forecasted gross revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> in local currency. It is the
		/// portion of <a
		/// href='#UNIFIED_REVENUE_LOCAL_UNIFIED_GROSS_REVENUE'>#UNIFIED_REVENUE_LOCAL_UNIFIED_GROSS_REVENUE</a>
		/// coming from forecasted Ad Manager volume. <p>See <a
		/// href='#UNIFIED_REVENUE_FORECASTED_GROSS_REVENUE'>#UNIFIED_REVENUE_FORECASTED_GROSS_REVENUE</a></p>
		/// <p>Corresponds to "Forecasted revenue (gross) (local)" in the Ad Manager UI.
		/// Compatible with the SALES report type.</p>
		/// </summary>
		UNIFIED_REVENUE_LOCAL_FORECASTED_GROSS_REVENUE = 320,
		/// <summary>The unified net revenue of the <a href='ProposalLineItem'>ProposalLineItem</a>.
		/// It is a combination of <a href=''>#UNIFIED_REVENUE_UNRECONCILED_NET_REVENUE</a>,
		/// <a href='#BILLING_BILLABLE_NET_REVENUE'>#BILLING_BILLABLE_NET_REVENUE</a>, and
		/// <a href=''>#UNIFIED_REVENUE_FORECASTED_NET_REVENUE</a> when query date range
		/// spans historical delivery and forecasted delivery. <p>Corresponds to "Unified
		/// revenue (net)" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, SALES.</p>
		/// </summary>
		UNIFIED_REVENUE_UNIFIED_NET_REVENUE = 321,
		/// <summary>The unified net revenue of the <a href='ProposalLineItem'>ProposalLineItem</a>
		/// in local currency. It is a combination of <a
		/// href='#UNIFIED_REVENUE_LOCAL_UNRECONCILED_NET_REVENUE'>#UNIFIED_REVENUE_LOCAL_UNRECONCILED_NET_REVENUE</a>,
		/// <a
		/// href='#BILLING_LOCAL_BILLABLE_NET_REVENUE'>#BILLING_LOCAL_BILLABLE_NET_REVENUE</a>,
		/// and <a
		/// href='#UNIFIED_REVENUE_LOCAL_FORECASTED_NET_REVENUE'>#UNIFIED_REVENUE_LOCAL_FORECASTED_NET_REVENUE</a>
		/// when query date range spans historical delivery and forecasted delivery. See <a
		/// href='#UNIFIED_REVENUE_UNIFIED_NET_REVENUE'>#UNIFIED_REVENUE_UNIFIED_NET_REVENUE</a>
		/// <p>Corresponds to "Unified revenue (net) (local)" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		UNIFIED_REVENUE_LOCAL_UNIFIED_NET_REVENUE = 322,
		/// <summary>The unified net revenue of the <a href='ProposalLineItem'>ProposalLineItem</a>.
		/// It is a combination of <a
		/// href='#UNIFIED_REVENUE_UNRECONCILED_GROSS_REVENUE'>#UNIFIED_REVENUE_UNRECONCILED_GROSS_REVENUE</a>,
		/// <a href='#BILLING_BILLABLE_GROSS_REVENUE'>#BILLING_BILLABLE_GROSS_REVENUE</a>,
		/// and <a
		/// href='#UNIFIED_REVENUE_FORECASTED_GROSS_REVENUE'>#UNIFIED_REVENUE_FORECASTED_GROSS_REVENUE</a>
		/// when query date range spans historical delivery and forecasted delivery.
		/// <p>Corresponds to "Unified revenue (gross)" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		UNIFIED_REVENUE_UNIFIED_GROSS_REVENUE = 323,
		/// <summary>The unified gross revenue of the <a href='ProposalLineItem'>ProposalLineItem</a>
		/// in local currency. It is a combination of <a
		/// href='#UNIFIED_REVENUE_LOCAL_UNRECONCILED_GROSS_REVENUE'>#UNIFIED_REVENUE_LOCAL_UNRECONCILED_GROSS_REVENUE</a>,
		/// <a
		/// href='#BILLING_LOCAL_BILLABLE_GROSS_REVENUE'>#BILLING_LOCAL_BILLABLE_GROSS_REVENUE</a>,
		/// and <a
		/// href='#UNIFIED_REVENUE_LOCAL_FORECASTED_GROSS_REVENUE'>#UNIFIED_REVENUE_LOCAL_FORECASTED_GROSS_REVENUE</a>
		/// when query date range spans historical delivery and forecasted delivery. See <a
		/// href='#UNIFIED_REVENUE_UNIFIED_GROSS_REVENUE'>#UNIFIED_REVENUE_UNIFIED_GROSS_REVENUE</a>
		/// <p>Corresponds to "Unified revenue (gross) (local)" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		UNIFIED_REVENUE_LOCAL_UNIFIED_GROSS_REVENUE = 324,
		/// <summary>The unified agency commission of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It is a combination of the
		/// unreconciled agency commission, the <a
		/// href='#BILLING_BILLABLE_AGENCY_COMMISSION'>#BILLING_BILLABLE_AGENCY_COMMISSION</a>,
		/// and the forecasted agency commission when query date range spans historical
		/// delivery and forecasted delivery. <p>Corresponds to "Unified agency commission"
		/// in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, SALES.</p>
		/// </summary>
		UNIFIED_REVENUE_UNIFIED_AGENCY_COMMISSION = 325,
		/// <summary>The unified agency commission of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> in local currency. It is a
		/// combination of the unreconciled agency commission, the <a
		/// href='#BILLING_BILLABLE_AGENCY_COMMISSION'>#BILLING_BILLABLE_AGENCY_COMMISSION</a>,
		/// and the forecasted agency commission when query date range spans historical
		/// delivery and forecasted delivery. See <a
		/// href='#UNIFIED_REVENUE_UNIFIED_AGENCY_COMMISSION'>#UNIFIED_REVENUE_UNIFIED_AGENCY_COMMISSION</a>
		/// <p>Corresponds to "Unified agency commission (local)" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		UNIFIED_REVENUE_LOCAL_UNIFIED_AGENCY_COMMISSION = 326,
		/// <summary>The unreconciled volume of the <a href='ProposalLineItem'>ProposalLineItem</a>
		/// for each cycle. Volume represents impressions for rate type CPM, clicks for CPC
		/// and days for CPD. This fact can only be run in proposal or proposal line item
		/// time zone. <p>Corresponds to "Unreconciled volume" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		UNIFIED_REVENUE_UNRECONCILED_VOLUME = 437,
		/// <summary>The forecasted volume of the <a href='ProposalLineItem'>ProposalLineItem</a> for
		/// each cycle. Volume represents impressions for rate type CPM, clicks for CPC and
		/// days for CPD. This fact can only be run in proposal or proposal line item time
		/// zone. <p>Corresponds to "Forecasted volume" in the Ad Manager UI. Compatible
		/// with the SALES report type.</p>
		/// </summary>
		UNIFIED_REVENUE_FORECASTED_VOLUME = 438,
		/// <summary>The unified volume of the <a href='ProposalLineItem'>ProposalLineItem</a> for
		/// each cycle. Volume represents impressions for rate type CPM, clicks for CPC and
		/// days for CPD. This fact can only be run in proposal or proposal line item time
		/// zone. <p>Corresponds to "Unified volume" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		UNIFIED_REVENUE_UNIFIED_VOLUME = 439,
		/// <summary>The expected revenue of the <a href='ProposalLineItem'>ProposalLineItem</a>. It
		/// is equivalent to <a
		/// href='#UNIFIED_REVENUE_UNIFIED_NET_REVENUE'>#UNIFIED_REVENUE_UNIFIED_NET_REVENUE</a>
		/// when the <a href='ProposalLineItem'>ProposalLineItem</a> is sold and <a
		/// href='#SALES_PIPELINE_PIPELINE_NET_REVENUE'>#SALES_PIPELINE_PIPELINE_NET_REVENUE</a>
		/// otherwise. <p>Corresponds to "Expected revenue (net)" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		EXPECTED_REVENUE_EXPECTED_NET_REVENUE = 327,
		/// <summary>The expected revenue of the <a href='ProposalLineItem'>ProposalLineItem</a> in
		/// local currency. It is equivalent to <a
		/// href='#UNIFIED_REVENUE_LOCAL_UNIFIED_NET_REVENUE'>#UNIFIED_REVENUE_LOCAL_UNIFIED_NET_REVENUE</a>
		/// when the <a href='ProposalLineItem'>ProposalLineItem</a> is sold and <a
		/// href='#SALES_PIPELINE_LOCAL_PIPELINE_NET_REVENUE'>#SALES_PIPELINE_LOCAL_PIPELINE_NET_REVENUE</a>
		/// otherwise. <p>See <a
		/// href='#EXPECTED_REVENUE_EXPECTED_NET_REVENUE'>#EXPECTED_REVENUE_EXPECTED_NET_REVENUE</a></p>
		/// <p>Corresponds to "Expected revenue (net) (local)" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		EXPECTED_REVENUE_LOCAL_EXPECTED_NET_REVENUE = 328,
		/// <summary>The expected gross revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It is equivalent to <a
		/// href=''>#UNIFIED_REVENUE_UNIFIED_GROSS_REVENUE</a> when the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> is sold and <a
		/// href=''>#SALES_PIPELINE_PIPELINE_GROSS_REVENUE</a> otherwise. <p>Corresponds to
		/// "Expected revenue (gross)" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SALES.</p>
		/// </summary>
		EXPECTED_REVENUE_EXPECTED_GROSS_REVENUE = 329,
		/// <summary>The expected gross revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> in local currency. It is equivalent
		/// to <a
		/// href='#UNIFIED_REVENUE_LOCAL_UNIFIED_GROSS_REVENUE'>#UNIFIED_REVENUE_LOCAL_UNIFIED_GROSS_REVENUE</a>
		/// when the <a href='ProposalLineItem'>ProposalLineItem</a> is sold and <a
		/// href='#SALES_PIPELINE_LOCAL_PIPELINE_GROSS_REVENUE'>#SALES_PIPELINE_LOCAL_PIPELINE_GROSS_REVENUE</a>
		/// otherwise. <p>See <a
		/// href='#EXPECTED_REVENUE_EXPECTED_GROSS_REVENUE'>#EXPECTED_REVENUE_EXPECTED_GROSS_REVENUE</a></p>
		/// <p>Corresponds to "Expected revenue (gross) (local)" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		EXPECTED_REVENUE_LOCAL_EXPECTED_GROSS_REVENUE = 330,
		/// <summary>The pipeline net revenue of the <a href='ProposalLineItem'>ProposalLineItem</a>.
		/// There is no revenue for sold <a href=''>ProposalLineItem proposal line
		/// items</a>. For unsold <a href='ProposalLineItem'>proposal line items</a>, it is
		/// calculated by multiplying <a
		/// href='Proposal#probabilityOfClose'>Proposal#probabilityOfClose</a> by the
		/// contracted revenue when inventory is not reserved; otherwise it is calcualted by
		/// multiplying <a href=''>Proposal#probabilityOfClose</a> by the forecasted
		/// revenue. <p>Corresponds to "Pipeline revenue (net)" in the Ad Manager UI.
		/// Compatible with the SALES report type.</p>
		/// </summary>
		SALES_PIPELINE_PIPELINE_NET_REVENUE = 331,
		/// <summary>The pipeline net revenue in the local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. There is no revenue for sold <a
		/// href='ProposalLineItem'>proposal line items</a>. For unsold <a
		/// href='ProposalLineItem'>proposal line items</a>, it is calculated by multiplying
		/// <a href='Proposal#probabilityOfClose'>Proposal#probabilityOfClose</a> by the
		/// contracted revenue when inventory is not reserved; otherwise it is calcualted by
		/// multiplying <a
		/// href='Proposal#probabilityOfClose'>Proposal#probabilityOfClose</a> by the
		/// forecasted revenue. See <a
		/// href='#SALES_PIPELINE_PIPELINE_NET_REVENUE'>#SALES_PIPELINE_PIPELINE_NET_REVENUE</a>
		/// <p>Corresponds to "Pipeline revenue (net) (local)" in the Ad Manager UI.
		/// Compatible with the SALES report type.</p>
		/// </summary>
		SALES_PIPELINE_LOCAL_PIPELINE_NET_REVENUE = 332,
		/// <summary>The pipeline gross revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. There is no revenue for sold <a
		/// href='ProposalLineItem'>proposal line items</a>. For unsold <a
		/// href='ProposalLineItem'>proposal line items</a>, it is calculated by multiplying
		/// <a href='Proposal#probabilityOfClose'>Proposal#probabilityOfClose</a> by the
		/// contracted revenue including agency commission when inventory is not reserved;
		/// otherwise it is calcualted by multiplying <a
		/// href='Proposal#probabilityOfClose'>Proposal#probabilityOfClose</a> by the
		/// forecasted revenue including agency commission. <p>Corresponds to "Pipeline
		/// revenue (gross)" in the Ad Manager UI. Compatible with the SALES report
		/// type.</p>
		/// </summary>
		SALES_PIPELINE_PIPELINE_GROSS_REVENUE = 333,
		/// <summary>The pipeline gross revenue in the local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. There is no revenue for sold <a
		/// href='ProposalLineItem'>proposal line items</a>. For unsold <a
		/// href='ProposalLineItem'>proposal line items</a>, it is calculated by multiplying
		/// <a href='Proposal#probabilityOfClose'>Proposal#probabilityOfClose</a> by the
		/// contracted revenue including agency commission when inventory is not reserved;
		/// otherwise it is calcualted by multiplying <a
		/// href='Proposal#probabilityOfClose'>Proposal#probabilityOfClose</a> by the
		/// forecasted revenue including agency commission. See <a
		/// href='#SALES_PIPELINE_PIPELINE_GROSS_REVENUE'>#SALES_PIPELINE_PIPELINE_GROSS_REVENUE</a>
		/// <p>Corresponds to "Pipeline revenue (gross) (local)" in the Ad Manager UI.
		/// Compatible with the SALES report type.</p>
		/// </summary>
		SALES_PIPELINE_LOCAL_PIPELINE_GROSS_REVENUE = 334,
		/// <summary>The pipeline agency commission of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. There is no revenue for sold <a
		/// href='ProposalLineItem'>proposal line items</a>. For unsold <a
		/// href='ProposalLineItem'>proposal line items</a>, it is calculated against gross
		/// pipeline revenue. <p>Corresponds to "Pipeline agency commission" in the Ad
		/// Manager UI. Compatible with the SALES report type.</p>
		/// </summary>
		SALES_PIPELINE_PIPELINE_AGENCY_COMMISSION = 335,
		/// <summary>The pipeline agency commission in the local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. There is no revenue for sold <a
		/// href='ProposalLineItem'>proposal line items</a>. For unsold <a
		/// href='ProposalLineItem'>proposal line items</a>, it is calculated against gross
		/// pipeline revenue in local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. See <a
		/// href='#SALES_PIPELINE_PIPELINE_AGENCY_COMMISSION'>#SALES_PIPELINE_PIPELINE_AGENCY_COMMISSION</a>
		/// <p>Corresponds to "Pipeline agency commission (local)" in the Ad Manager UI.
		/// Compatible with the SALES report type.</p>
		/// </summary>
		SALES_PIPELINE_LOCAL_PIPELINE_AGENCY_COMMISSION = 336,
		/// <summary>The Ad Manager volume of the <a href='ProposalLineItem'>ProposalLineItem</a>,
		/// which is used for reconciliation. Volume represents impressions for rate type
		/// CPM, clicks for CPC and days for CPD. <p>Corresponds to "DFP volume" in the Ad
		/// Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// SALES.</p>
		/// </summary>
		RECONCILIATION_DFP_VOLUME = 339,
		/// <summary>The third party volume of the <a href='ProposalLineItem'>ProposalLineItem</a>,
		/// which is used for reconciliation. Volume represents impressions for rate type
		/// CPM, clicks for CPC and days for CPD. <p>Corresponds to "Third-party volume" in
		/// the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, SALES.</p>
		/// </summary>
		RECONCILIATION_THIRD_PARTY_VOLUME = 340,
		/// <summary>The reconciled volume of the <a href='ProposalLineItem'>ProposalLineItem</a>,
		/// which is used for reconciliation. Volume represents impressions for rate type
		/// CPM, clicks for CPC and days for CPD. <p>Corresponds to "Reconciled volume" in
		/// the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, SALES.</p>
		/// </summary>
		RECONCILIATION_RECONCILED_VOLUME = 341,
		/// <summary>The discrepancy percentage between Ad Manager volume and third party volume.
		/// <p>Corresponds to "Discrepancy (%)" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		RECONCILIATION_DISCREPANCY_PERCENTAGE = 426,
		/// <summary>The reconciled revenue of the <a href='LineItem'>LineItem</a>. <p>Corresponds to
		/// "Reconciled revenue" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SALES.</p>
		/// </summary>
		RECONCILIATION_RECONCILED_REVENUE = 343,
		/// <summary>The discrepancy between Ad Manager impressions and third party impressions.
		/// <p>Corresponds to "Impression discrepancy" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		RECONCILIATION_IMPRESSION_DISCREPANCY = 344,
		/// <summary>The discrepancy between Ad Manager clicks and third party clicks. <p>Corresponds
		/// to "Click discrepancy" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SALES.</p>
		/// </summary>
		RECONCILIATION_CLICK_DISCREPANCY = 345,
		/// <summary>The discrepancy between Ad Manager revenue and third party revenue.
		/// <p>Corresponds to "Revenue discrepancy" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		RECONCILIATION_REVENUE_DISCREPANCY = 346,
		/// <summary>The billable net revenue of the <a href='ProposalLineItem'>ProposalLineItem</a>.
		/// It is calculated from reconciled volume and rate, with cap applied.
		/// <p>Corresponds to "Billable revenue (net)" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		BILLING_BILLABLE_NET_REVENUE = 347,
		/// <summary>The billable net revenue in the local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It is calculated from reconciled
		/// volume and rate, with cap applied. See <a
		/// href='#BILLING_BILLABLE_NET_REVENUE'>#BILLING_BILLABLE_NET_REVENUE</a>
		/// <p>Corresponds to "Billable revenue (net) (local)" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		BILLING_LOCAL_BILLABLE_NET_REVENUE = 348,
		/// <summary>The billable gross revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It is calculated from reconciled
		/// volume and rate, with cap applied, and including agency commission.
		/// <p>Corresponds to "Billable revenue (gross)" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		BILLING_BILLABLE_GROSS_REVENUE = 349,
		/// <summary>The billable gross revenue in the local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. It is calculated from reconciled
		/// volume and rate, with cap applied, and including agency commission. See <a
		/// href='#BILLING_BILLABLE_GROSS_REVENUE'>#BILLING_BILLABLE_GROSS_REVENUE</a>
		/// <p>Corresponds to "Billable revenue (gross) (local)" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		BILLING_LOCAL_BILLABLE_GROSS_REVENUE = 350,
		/// <summary>The billable net revenue of the <a href='ProposalLineItem'>ProposalLineItem</a>
		/// before manual adjustment. It is calculated from reconciled volume and rate, with
		/// cap applied, before manual adjustment. <p>Corresponds to "Billable revenue
		/// before manual adjustment (net)" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SALES.</p>
		/// </summary>
		BILLING_BILLABLE_NET_REVENUE_BEFORE_MANUAL_ADJUSTMENT = 351,
		/// <summary>The billable net revenue in local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> before manual adjustment. It is
		/// calculated from reconciled volume and rate, with cap applied, before manual
		/// adjustment. <p>See <a
		/// href='#BILLING_BILLABLE_NET_REVENUE_BEFORE_MANUAL_ADJUSTMENT'>#BILLING_BILLABLE_NET_REVENUE_BEFORE_MANUAL_ADJUSTMENT</a></p>
		/// <p>Corresponds to "Billable revenue before manual adjustment (net) (local)" in
		/// the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, SALES.</p>
		/// </summary>
		BILLING_LOCAL_BILLABLE_NET_REVENUE_BEFORE_MANUAL_ADJUSTMENT = 352,
		/// <summary>The billable gross revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> before manual adjustment. It is
		/// calculated from reconciled volume and rate, with cap applied, before manual
		/// adjustment. <p>Corresponds to "Billable revenue before manual adjustment
		/// (gross)" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, SALES.</p>
		/// </summary>
		BILLING_BILLABLE_GROSS_REVENUE_BEFORE_MANUAL_ADJUSTMENT = 353,
		/// <summary>The billable net revenue in local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> before manual adjustment. It is
		/// calculated from reconciled volume and rate, with cap applied, before manual
		/// adjustment. <p>See <a
		/// href='#BILLING_BILLABLE_GROSS_REVENUE_BEFORE_MANUAL_ADJUSTMENT'>#BILLING_BILLABLE_GROSS_REVENUE_BEFORE_MANUAL_ADJUSTMENT</a></p>
		/// <p>Corresponds to "Billable revenue before manual adjustment (gross) (local)" in
		/// the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, SALES.</p>
		/// </summary>
		BILLING_LOCAL_BILLABLE_GROSS_REVENUE_BEFORE_MANUAL_ADJUSTMENT = 354,
		/// <summary>The value added tax on billable net revenue of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> or <a href=''>Proposal</a>.
		/// <p>Corresponds to "Billable VAT" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		BILLING_BILLABLE_VAT = 355,
		/// <summary>The value added tax on billable net revenue in the local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> or <a href='Proposal'>Proposal</a>.
		/// See <a href='#BILLING_BILLABLE_VAT'>#BILLING_BILLABLE_VAT</a> <p>Corresponds to
		/// "Billable VAT (local)" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SALES.</p>
		/// </summary>
		BILLING_LOCAL_BILLABLE_VAT = 356,
		/// <summary>The billable agency commission of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> or <a href='Proposal'>Proposal</a>.
		/// <p>Corresponds to "Billable agency commission" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		BILLING_BILLABLE_AGENCY_COMMISSION = 357,
		/// <summary>The billable agency commission in the local currency of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> or <a href='Proposal'>Proposal</a>.
		/// See <a
		/// href='#BILLING_BILLABLE_AGENCY_COMMISSION'>#BILLING_BILLABLE_AGENCY_COMMISSION</a>
		/// <p>Corresponds to "Billable agency commission (local)" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		BILLING_LOCAL_BILLABLE_AGENCY_COMMISSION = 358,
		/// <summary>The cap quantity of the <a href='ProposalLineItem'>ProposalLineItem</a> for each
		/// cycle. Quantity represents impressions for rate type CPM, clicks for CPC and
		/// days for CPD. <p>Corresponds to "Cap quantity" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		BILLING_CAP_QUANTITY = 359,
		/// <summary>The billable volume of the <a href='ProposalLineItem'>ProposalLineItem</a> for
		/// each cycle. Billable volumes are calculated by applying cap quantity to
		/// reconciled volumes. Volume represents impressions for rate type CPM, clicks for
		/// CPC and days for CPD. <p>Corresponds to "Billable volume" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		BILLING_BILLABLE_VOLUME = 360,
		/// <summary>The delivery rollover volume of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> from previous cycle. Volume
		/// represents impressions for rate type CPM, clicks for CPC and days for CPD.
		/// <p>Corresponds to "Delivery rollover" in the Ad Manager UI. Compatible with any
		/// of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		BILLING_DELIVERY_ROLLOVER = 427,
		/// <summary>The CPM calcuated by <a
		/// href='#BILLING_BILLABLE_NET_REVENUE'>#BILLING_BILLABLE_NET_REVENUE</a> and <a
		/// href='#AD_SERVER_IMPRESSIONS'>#AD_SERVER_IMPRESSIONS</a>. <p>Corresponds to
		/// "Realized CPM" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, SALES.</p>
		/// </summary>
		BILLING_REALIZED_CPM = 362,
		/// <summary>The rate calcuated by <a
		/// href='#BILLING_BILLABLE_NET_REVENUE'>#BILLING_BILLABLE_NET_REVENUE</a> and Ad
		/// Manager volume. <p>Corresponds to "Realized rate" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SALES.</p>
		/// </summary>
		BILLING_REALIZED_RATE = 363,
		/// <summary>The contracted net overall discount of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. <p>Corresponds to "Contracted
		/// overall discount (net)" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SALES.</p>
		/// </summary>
		DISCOUNTS_BREAKDOWN_CONTRACTED_NET_OVERALL_DISCOUNT = 364,
		/// <summary>The billable net overall discount of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. <p>Corresponds to "Billable
		/// overall discount (net)" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SALES.</p>
		/// </summary>
		DISCOUNTS_BREAKDOWN_BILLABLE_NET_OVERALL_DISCOUNT = 365,
		/// <summary>The contracted non-billable (net) of the <a
		/// href='ProposalLineItem'>ProposalLineItem</a>. The non-billable means revenue
		/// that marked as make good, added value or barter. <p>Corresponds to "Contracted
		/// non-billable (net)" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SALES.</p>
		/// </summary>
		DISCOUNTS_BREAKDOWN_CONTRACTED_NET_NON_BILLABLE = 374,
		/// <summary>The number of invoiced impressions. <p>Corresponds to "Invoiced impressions" in
		/// the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		INVOICED_IMPRESSIONS = 379,
		/// <summary>The number of invoiced unfilled impressions. <p>Corresponds to "Invoiced
		/// unfilled impressions" in the Ad Manager UI. Compatible with the HISTORICAL
		/// report type.</p>
		/// </summary>
		INVOICED_UNFILLED_IMPRESSIONS = 380,
		/// <summary>The total number of impressions tracked for Nielsen Digital Ad Ratings
		/// measurement. <p>Corresponds to "Impressions" in the Ad Manager UI. Compatible
		/// with the REACH report type.</p>
		/// </summary>
		NIELSEN_IMPRESSIONS = 400,
		/// <summary>The total number of impressions for in-target demographic tracked for Nielsen
		/// Digital Ad Ratings measurement. <p>Corresponds to "In-target impressions" in the
		/// Ad Manager UI. Compatible with the REACH report type.</p>
		/// </summary>
		NIELSEN_IN_TARGET_IMPRESSIONS = 411,
		/// <summary>The population in the demographic. <p>Corresponds to "Population base" in the Ad
		/// Manager UI. Compatible with the REACH report type.</p>
		/// </summary>
		NIELSEN_POPULATION_BASE = 401,
		/// <summary>The total population for all in-target demographics. <p>Compatible with the
		/// REACH report type.</p>
		/// </summary>
		NIELSEN_IN_TARGET_POPULATION_BASE = 412,
		/// <summary>The total number of different people within the selected demographic who were
		/// reached. <p>Corresponds to "Unique audience" in the Ad Manager UI. Compatible
		/// with the REACH report type.</p>
		/// </summary>
		NIELSEN_UNIQUE_AUDIENCE = 402,
		/// <summary>The total number of different people within all in-target demographics who were
		/// reached. <p>Compatible with the REACH report type.</p>
		/// </summary>
		NIELSEN_IN_TARGET_UNIQUE_AUDIENCE = 413,
		/// <summary>The unique audience reached as a percentage of the population base.
		/// <p>Corresponds to "% audience reach" in the Ad Manager UI. Compatible with the
		/// REACH report type.</p>
		/// </summary>
		NIELSEN_PERCENT_AUDIENCE_REACH = 403,
		/// <summary>The unique audience reached as a percentage of the population base for all
		/// in-target demographics. <p>Compatible with the REACH report type.</p>
		/// </summary>
		NIELSEN_IN_TARGET_PERCENT_AUDIENCE_REACH = 414,
		/// <summary>The average number of times that a person within the target audience sees an
		/// advertisement. <p>Corresponds to "Average frequency" in the Ad Manager UI.
		/// Compatible with the REACH report type.</p>
		/// </summary>
		NIELSEN_AVERAGE_FREQUENCY = 404,
		/// <summary>The average number of times that a person within the target audience sees an
		/// advertisement for all in-target demographics. <p>Compatible with the REACH
		/// report type.</p>
		/// </summary>
		NIELSEN_IN_TARGET_AVERAGE_FREQUENCY = 415,
		/// <summary>The unit of audience volume, which is based on the percentage of the reached
		/// target audience population multiplied by the average frequency. <p>Corresponds
		/// to "Gross rating points" in the Ad Manager UI. Compatible with the REACH report
		/// type.</p>
		/// </summary>
		NIELSEN_GROSS_RATING_POINTS = 405,
		/// <summary>The unit of audience volume, which is based on the percentage of the reached
		/// target audience population multiplied by the average frequency, for all
		/// in-target demographics. <p>Compatible with the REACH report type.</p>
		/// </summary>
		NIELSEN_IN_TARGET_GROSS_RATING_POINTS = 416,
		/// <summary>The share of impressions that reached the target demographic. <p>Corresponds to
		/// "% impression share" in the Ad Manager UI. Compatible with the REACH report
		/// type.</p>
		/// </summary>
		NIELSEN_PERCENT_IMPRESSIONS_SHARE = 406,
		/// <summary>The share of impressions that reached all in-target demographics. <p>Corresponds
		/// to "In-target % impression share" in the Ad Manager UI. Compatible with the
		/// REACH report type.</p>
		/// </summary>
		NIELSEN_IN_TARGET_PERCENT_IMPRESSIONS_SHARE = 417,
		/// <summary>The share of the total population represented by the population base.
		/// <p>Corresponds to "% population share" in the Ad Manager UI. Compatible with the
		/// REACH report type.</p>
		/// </summary>
		NIELSEN_PERCENT_POPULATION_SHARE = 407,
		/// <summary>The share of the total population for all in-target demographics represented by
		/// the population base. <p>Compatible with the REACH report type.</p>
		/// </summary>
		NIELSEN_IN_TARGET_PERCENT_POPULATION_SHARE = 418,
		/// <summary>The share of the unique audience in the demographic. <p>Corresponds to "%
		/// audience share" in the Ad Manager UI. Compatible with the REACH report type.</p>
		/// </summary>
		NIELSEN_PERCENT_AUDIENCE_SHARE = 408,
		/// <summary>The share of the unique audience for all in-target demographics. <p>Compatible
		/// with the REACH report type.</p>
		/// </summary>
		NIELSEN_IN_TARGET_PERCENT_AUDIENCE_SHARE = 419,
		/// <summary>The relative unique audience in the demographic compared with its share of the
		/// overall population. <p>Corresponds to "Audience index" in the Ad Manager UI.
		/// Compatible with the REACH report type.</p>
		/// </summary>
		NIELSEN_AUDIENCE_INDEX = 409,
		/// <summary>The relative unique audience for all in-target demographics compared with its
		/// share of the overall population. <p>Compatible with the REACH report type.</p>
		/// </summary>
		NIELSEN_IN_TARGET_AUDIENCE_INDEX = 420,
		/// <summary>The relative impressions per person in the demographic compared with the
		/// impressions per person for the overall population. <p>Corresponds to
		/// "Impressions index" in the Ad Manager UI. Compatible with the REACH report
		/// type.</p>
		/// </summary>
		NIELSEN_IMPRESSIONS_INDEX = 410,
		/// <summary>The relative impressions per person for all in-target demographics compared with
		/// the impressions per person for the overall population. <p>Compatible with the
		/// REACH report type.</p>
		/// </summary>
		NIELSEN_IN_TARGET_IMPRESSIONS_INDEX = 421,
		/// <summary>The host impressions in the partner management. <p>Corresponds to "Host
		/// impressions" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		PARTNER_MANAGEMENT_HOST_IMPRESSIONS = 392,
		/// <summary>The host clicks in the partner management. <p>Corresponds to "Host clicks" in
		/// the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		PARTNER_MANAGEMENT_HOST_CLICKS = 393,
		/// <summary>The host CTR in the partner management. <p>Corresponds to "Host CTR" in the Ad
		/// Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		PARTNER_MANAGEMENT_HOST_CTR = 394,
		/// <summary>The unfilled impressions in the partner management. <p>Corresponds to "Unfilled
		/// impressions" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, PARTNER_FINANCE.</p>
		/// </summary>
		PARTNER_MANAGEMENT_UNFILLED_IMPRESSIONS = 399,
		/// <summary>The partner impressions in the partner management. <p>Corresponds to "Partner
		/// impressions" in the Ad Manager UI. Compatible with the HISTORICAL report
		/// type.</p>
		/// </summary>
		PARTNER_MANAGEMENT_PARTNER_IMPRESSIONS = 493,
		/// <summary>The partner clicks in the partner management. <p>Corresponds to "Partner clicks"
		/// in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		PARTNER_MANAGEMENT_PARTNER_CLICKS = 494,
		/// <summary>The partner CTR in the partner management. <p>Corresponds to "Partner CTR" in
		/// the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		PARTNER_MANAGEMENT_PARTNER_CTR = 495,
		/// <summary>The gross revenue in the partner management. <p>Corresponds to "Gross revenue"
		/// in the Ad Manager UI. Compatible with the HISTORICAL report type.</p>
		/// </summary>
		PARTNER_MANAGEMENT_GROSS_REVENUE = 496,
		/// <summary>Monthly host impressions for partner finance reports. <p>Corresponds to "Host
		/// impressions" in the Ad Manager UI. Compatible with the PARTNER_FINANCE report
		/// type.</p>
		/// </summary>
		PARTNER_FINANCE_HOST_IMPRESSIONS = 497,
		/// <summary>Monthly host revenue for partner finance reports. <p>Corresponds to "Host
		/// revenue" in the Ad Manager UI. Compatible with the PARTNER_FINANCE report
		/// type.</p>
		/// </summary>
		PARTNER_FINANCE_HOST_REVENUE = 498,
		/// <summary>Monthly host eCPM for partner finance reports. <p>Corresponds to "Host eCPM" in
		/// the Ad Manager UI. Compatible with the PARTNER_FINANCE report type.</p>
		/// </summary>
		PARTNER_FINANCE_HOST_ECPM = 499,
		/// <summary>Monthly partner revenue for partner finance reports. <p>Corresponds to "Partner
		/// revenue" in the Ad Manager UI. Compatible with the PARTNER_FINANCE report
		/// type.</p>
		/// </summary>
		PARTNER_FINANCE_PARTNER_REVENUE = 500,
		/// <summary>Monthly partner eCPM for partner finance reports. <p>Corresponds to "Partner
		/// eCPM" in the Ad Manager UI. Compatible with the PARTNER_FINANCE report type.</p>
		/// </summary>
		PARTNER_FINANCE_PARTNER_ECPM = 501,
		/// <summary>Monthly gross revenue for partner finance reports. <p>Corresponds to "Gross
		/// revenue" in the Ad Manager UI. Compatible with the PARTNER_FINANCE report
		/// type.</p>
		/// </summary>
		PARTNER_FINANCE_GROSS_REVENUE = 502,
	}


	/// <summary><code>DimensionAttribute</code> provides additional fields associated with a <a
	/// href='Dimension'>Dimension</a>. It can only be selected with its corresponding
	/// <a href='Dimension'>Dimension</a>. For example, <a
	/// href='DimensionAttribute#ORDER_PO_NUMBER'>DimensionAttribute#ORDER_PO_NUMBER</a>
	/// can only be used if the <a
	/// href='ReportQuery#dimensions'>ReportQuery#dimensions</a> contains <a
	/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum DimensionAttribute {
		/// <summary>Represents <a
		/// href='LineItem#effectiveAppliedLabels'>LineItem#effectiveAppliedLabels</a> as a
		/// comma separated list of <a href='Label#name'>Label#name</a> for <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a>. <p>Corresponds to
		/// "Line item labels" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		LINE_ITEM_LABELS = 0,
		/// <summary>Represents <a
		/// href='LineItem#effectiveAppliedLabels'>LineItem#effectiveAppliedLabels</a> as a
		/// comma separated list of <a href='Label#id'>Label#id</a> for <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a>. <p>Compatible with
		/// any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		LINE_ITEM_LABEL_IDS = 1,
		/// <summary>Generated as <code>true</code> for <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a> which is eligible
		/// for optimization, <code>false</code> otherwise. Can be used for filtering.
		/// <p>Corresponds to "Optimizable" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		LINE_ITEM_OPTIMIZABLE = 2,
		/// <summary>Indicates the progress made for the delivery of the <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a>. <table> <tr> <th
		/// scope="col">Progress</th> <th scope="col">Definition</th> </tr> <tr>
		/// <td>100%</td> <td>The <a href='LineItem'>LineItem</a> is on track to deliver in
		/// full as per <a href='LineItem#unitsBought'>LineItem#unitsBought</a>.</td> </tr>
		/// <tr> <td>&gt; 100%</td> <td>The <a href='LineItem'>LineItem</a> is on track to
		/// overdeliver.</td> </tr> <tr> <td>&lt; 100%</td> <td>The <a
		/// href='LineItem'>LineItem</a> is on track to underdeliver.</td> </tr> <tr>
		/// <td>N/A</td> <td>The <a href='LineItem'>LineItem</a> does not have any quantity
		/// goals, or there is insufficient information about the <a
		/// href='LineItem'>LineItem</a>.</td> </tr> </table> <p>Corresponds to "Delivery
		/// Indicator" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		LINE_ITEM_DELIVERY_INDICATOR = 139,
		/// <summary>Represents <a href='LineItem#deliveryRateType'>LineItem#deliveryRateType</a> for
		/// <a href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a>. <p>Corresponds
		/// to "Delivery pacing" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH, SALES, DATA_LEAKAGE,
		/// CREATIVE_QOS.</p>
		/// </summary>
		LINE_ITEM_DELIVERY_PACING = 3,
		/// <summary>Represents <a href='LineItem#frequencyCaps'>LineItem#frequencyCaps</a> as a
		/// comma separated list of "<a
		/// href='FrequencyCap#maxImpressions'>FrequencyCap#maxImpressions</a> impressions
		/// per/every <a href='FrequencyCap#numTimeUnits'>FrequencyCap#numTimeUnits</a> <a
		/// href='FrequencyCap#timeUnit'>FrequencyCap#timeUnit</a>" (e.g. "10 impressions
		/// every day,500 impressions per lifetime") for <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a>. <p>Corresponds to
		/// "Frequency cap" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		LINE_ITEM_FREQUENCY_CAP = 4,
		/// <summary>Represents the monthly reconciliation status of the line item for <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a> and <a
		/// href='Dimension#MONTH_YEAR'>Dimension#MONTH_YEAR</a>. <p>Corresponds to "Line
		/// item reconciliation status" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		LINE_ITEM_RECONCILIATION_STATUS = 119,
		/// <summary>Represents the monthly last reconciliation date time of the line item for <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a> and <a
		/// href='Dimension#MONTH_YEAR'>Dimension#MONTH_YEAR</a>. <p>Corresponds to "Line
		/// item last reconciliation time" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		LINE_ITEM_LAST_RECONCILIATION_DATE_TIME = 120,
		/// <summary>Represents <a href='Company#externalId'>Company#externalId</a> for <a
		/// href='Dimension#ADVERTISER_NAME'>Dimension#ADVERTISER_NAME</a>. <p>Corresponds
		/// to "External advertiser ID" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		ADVERTISER_EXTERNAL_ID = 5,
		/// <summary>Represents <a href='Company#type'>Company#type</a> for <a
		/// href='Dimension#ADVERTISER_NAME'>Dimension#ADVERTISER_NAME</a>. Can be used for
		/// filtering. <p>Corresponds to "Advertiser type" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, SELL_THROUGH, REACH, SALES,
		/// DATA_LEAKAGE, CREATIVE_QOS.</p>
		/// </summary>
		ADVERTISER_TYPE = 121,
		/// <summary>Represents <a href='Company#creditStatus'>Company#creditStatus</a> for <a
		/// href='Dimension#ADVERTISER_NAME'>Dimension#ADVERTISER_NAME</a>. Can be used for
		/// filtering. <p>Corresponds to "Advertiser credit status" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SELL_THROUGH,
		/// REACH, SALES, DATA_LEAKAGE, CREATIVE_QOS.</p>
		/// </summary>
		ADVERTISER_CREDIT_STATUS = 122,
		/// <summary>Represents name and email address in the form of name(email) of primary contact
		/// for <a href=''>Dimension#ADVERTISER_NAME</a>. <p>Corresponds to "Advertiser
		/// primary contact" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		ADVERTISER_PRIMARY_CONTACT = 6,
		/// <summary>Represents the start date (in YYYY-MM-DD format) for <a
		/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a>. Can be used for filtering.
		/// <p>Corresponds to "Order start date" in the Ad Manager UI. Compatible with any
		/// of the following report types: HISTORICAL, SELL_THROUGH, REACH, SALES,
		/// DATA_LEAKAGE, CREATIVE_QOS.</p>
		/// </summary>
		ORDER_START_DATE_TIME = 7,
		/// <summary>Represents the end date (in YYYY-MM-DD format) for <a
		/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a>. Can be used for filtering.
		/// <p>Corresponds to "Order end date" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, SELL_THROUGH, REACH, SALES,
		/// DATA_LEAKAGE, CREATIVE_QOS.</p>
		/// </summary>
		ORDER_END_DATE_TIME = 8,
		/// <summary>Represents <a href='Order#externalOrderId'>Order#externalOrderId</a> for <a
		/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a>. <p>Corresponds to
		/// "External order ID" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		ORDER_EXTERNAL_ID = 9,
		/// <summary>Represents <a href='Order#poNumber'>Order#poNumber</a> for <a
		/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a>. Can be used for filtering.
		/// <p>Corresponds to "Order PO number" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, SELL_THROUGH, REACH, SALES,
		/// DATA_LEAKAGE, CREATIVE_QOS.</p>
		/// </summary>
		ORDER_PO_NUMBER = 10,
		/// <summary>Represents <a href='Order#orderIsProgrammatic'>Order#orderIsProgrammatic</a> for
		/// <a href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a>. Can be used for
		/// filtering. <p>Corresponds to "Programmatic order" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		ORDER_IS_PROGRAMMATIC = 11,
		/// <summary>Represents the name of <a href='Order#agencyId'>Order#agencyId</a> for <a
		/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a>. <p>Corresponds to "Agency"
		/// in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, REACH, SALES.</p>
		/// </summary>
		ORDER_AGENCY = 12,
		/// <summary>Represents <a href='Order#agencyId'>Order#agencyId</a> for <a
		/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a>. Can be used for filtering.
		/// <p>Corresponds to "Agency ID" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		ORDER_AGENCY_ID = 13,
		/// <summary>Represents <a
		/// href='Order#effectiveAppliedLabels'>Order#effectiveAppliedLabels</a> as a comma
		/// separated list of <a href='Label#name'>Label#name</a> for <a
		/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a>. <p>Corresponds to "Order
		/// labels" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, REACH, SALES.</p>
		/// </summary>
		ORDER_LABELS = 14,
		/// <summary>Represents <a
		/// href='Order#effectiveAppliedLabels'>Order#effectiveAppliedLabels</a> as a comma
		/// separated list of <a href='Label#id'>Label#id</a> for <a
		/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a>. <p>Compatible with any of
		/// the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		ORDER_LABEL_IDS = 15,
		/// <summary>The name and email address in the form of name(email) of the trafficker for <a
		/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a> <p>Corresponds to
		/// "Trafficker" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		ORDER_TRAFFICKER = 16,
		/// <summary>Represents <a href='Order#traffickerId'>Order#traffickerId</a> for <a
		/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a>. Can be used for filtering.
		/// <p>Compatible with any of the following report types: HISTORICAL, REACH,
		/// SALES.</p>
		/// </summary>
		ORDER_TRAFFICKER_ID = 17,
		/// <summary>The names and email addresses as a comma separated list of name(email) of the <a
		/// href='Order#secondaryTraffickerIds'>Order#secondaryTraffickerIds</a> for <a
		/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a>. <p>Corresponds to
		/// "Secondary traffickers" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		ORDER_SECONDARY_TRAFFICKERS = 18,
		/// <summary>The name and email address in the form of name(email) of the <a
		/// href='Order#salespersonId'>Order#salespersonId</a> for <a
		/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a>. <p>Corresponds to
		/// "Salesperson" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		ORDER_SALESPERSON = 19,
		/// <summary>The names and email addresses as a comma separated list of name(email) of the <a
		/// href='Order#secondarySalespersonIds'>Order#secondarySalespersonIds</a> for <a
		/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a>. <p>Corresponds to
		/// "Secondary salespeople" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		ORDER_SECONDARY_SALESPEOPLE = 20,
		/// <summary>The total number of impressions delivered over the lifetime of an <a
		/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a>. <p>Corresponds to "Order
		/// lifetime impressions" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH, SALES, DATA_LEAKAGE,
		/// CREATIVE_QOS.</p>
		/// </summary>
		ORDER_LIFETIME_IMPRESSIONS = 21,
		/// <summary>The total number of clicks delivered over the lifetime of an <a
		/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a>. <p>Corresponds to "Order
		/// lifetime clicks" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH, SALES, DATA_LEAKAGE,
		/// CREATIVE_QOS.</p>
		/// </summary>
		ORDER_LIFETIME_CLICKS = 22,
		/// <summary>The cost of booking all the CPM ads for <a
		/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a>. <p>Corresponds to "Booked
		/// CPM" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, REACH, SALES.</p>
		/// </summary>
		ORDER_BOOKED_CPM = 23,
		/// <summary>The cost of booking all the CPC ads for <a
		/// href='Dimension#ORDER_NAME'>Dimension#ORDER_NAME</a>. <p>Corresponds to "Booked
		/// CPC" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, REACH, SALES.</p>
		/// </summary>
		ORDER_BOOKED_CPC = 24,
		/// <summary>Represents the start date (in YYYY-MM-DD format) for <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a>. Can be used for
		/// filtering. <p>Corresponds to "Line item start date" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SELL_THROUGH,
		/// REACH, SALES, DATA_LEAKAGE, CREATIVE_QOS.</p>
		/// </summary>
		LINE_ITEM_START_DATE_TIME = 25,
		/// <summary>Represents the end date (in YYYY-MM-DD format) for <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a>. Can be used for
		/// filtering. <p>Corresponds to "Line item end date" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SELL_THROUGH,
		/// REACH, SALES, DATA_LEAKAGE, CREATIVE_QOS.</p>
		/// </summary>
		LINE_ITEM_END_DATE_TIME = 26,
		/// <summary>Represents <a href='LineItem#externalId'>LineItem#externalId</a> for <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a>. Can be used for
		/// filtering. <p>Corresponds to "External Line Item ID" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		LINE_ITEM_EXTERNAL_ID = 27,
		/// <summary>Represents <a href='LineItem#costType'>LineItem#costType</a> for <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a>. Can be used for
		/// filtering. <p>Corresponds to "Cost type" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, SELL_THROUGH, REACH, SALES,
		/// DATA_LEAKAGE, CREATIVE_QOS.</p>
		/// </summary>
		LINE_ITEM_COST_TYPE = 28,
		/// <summary>Represents <a href='LineItem#costPerUnit'>LineItem#costPerUnit</a> for <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a>. <p>Corresponds to
		/// "Rate" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, SELL_THROUGH, REACH, SALES, DATA_LEAKAGE, CREATIVE_QOS.</p>
		/// </summary>
		LINE_ITEM_COST_PER_UNIT = 29,
		/// <summary>Represents the 3 letter currency code for <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a>. <p>Corresponds to
		/// "Currency code" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH, SALES, DATA_LEAKAGE,
		/// CREATIVE_QOS.</p>
		/// </summary>
		LINE_ITEM_CURRENCY_CODE = 30,
		/// <summary>The total number of impressions, clicks or days that is reserved for <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a>. <p>Corresponds to
		/// "Goal quantity" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH, SALES, DATA_LEAKAGE,
		/// CREATIVE_QOS.</p>
		/// </summary>
		LINE_ITEM_GOAL_QUANTITY = 31,
		/// <summary>The ratio between the goal quantity for <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a> of <a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a> and the <a
		/// href='#LINE_ITEM_GOAL_QUANTITY'>#LINE_ITEM_GOAL_QUANTITY</a>. Represented as a
		/// number between 0..100. <p>Corresponds to "Sponsorship goal (%)" in the Ad
		/// Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// REACH, SALES.</p>
		/// </summary>
		LINE_ITEM_SPONSORSHIP_GOAL_PERCENTAGE = 32,
		/// <summary>The total number of impressions delivered over the lifetime of a <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a>. <p>Corresponds to
		/// "Line item lifetime impressions" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, SELL_THROUGH, REACH, SALES,
		/// DATA_LEAKAGE, CREATIVE_QOS.</p>
		/// </summary>
		LINE_ITEM_LIFETIME_IMPRESSIONS = 33,
		/// <summary>The total number of clicks delivered over the lifetime of a <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a>. <p>Corresponds to
		/// "Line item lifetime clicks" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES, DATA_LEAKAGE,
		/// CREATIVE_QOS.</p>
		/// </summary>
		LINE_ITEM_LIFETIME_CLICKS = 34,
		/// <summary>Represents <a href='LineItem#priority'>LineItem#priority</a> for <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a> as a value between
		/// 1 and 16. Can be used for filtering. <p>Corresponds to "Line item priority" in
		/// the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, SELL_THROUGH, REACH, SALES, DATA_LEAKAGE, CREATIVE_QOS.</p>
		/// </summary>
		LINE_ITEM_PRIORITY = 35,
		/// <summary>Indicates if a creative is a regular creative or creative set. Values will be
		/// 'Creative' or 'Creative set' <p>Compatible with any of the following report
		/// types: HISTORICAL, REACH.</p>
		/// </summary>
		CREATIVE_OR_CREATIVE_SET = 36,
		/// <summary>The type of creative in a creative set - master or companion. <p>Corresponds to
		/// "Master or Companion" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, REACH.</p>
		/// </summary>
		MASTER_COMPANION_TYPE = 37,
		/// <summary>Represents the <a
		/// href='LineItem#contractedUnitsBought'>LineItem#contractedUnitsBought</a>
		/// quantity for <a href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a>.
		/// <p>Corresponds to "Contracted quantity" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		LINE_ITEM_CONTRACTED_QUANTITY = 38,
		/// <summary>Represents the <a href='LineItem#discount'>LineItem#discount</a> for <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a>. The number is
		/// either a percentage or an absolute value depending on <a
		/// href='LineItem#discountType'>LineItem#discountType</a>. <p>Corresponds to
		/// "Discount" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		LINE_ITEM_DISCOUNT = 39,
		/// <summary>The cost of booking for a non-CPD <a
		/// href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a>. <p>Corresponds to
		/// "Booked revenue (exclude CPD)" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		LINE_ITEM_NON_CPD_BOOKED_REVENUE = 40,
		/// <summary>Represents <a href='Company#appliedLabels'>Company#appliedLabels</a> as a comma
		/// separated list of <a href='Label#name'>Label#name</a> for <a
		/// href='Dimension#ADVERTISER_NAME'>Dimension#ADVERTISER_NAME</a>. <p>Corresponds
		/// to "Advertiser labels" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		ADVERTISER_LABELS = 41,
		/// <summary>Represents <a href='Company#appliedLabels'>Company#appliedLabels</a> as a comma
		/// separated list of <a href='Label#id'>Label#id</a> for <a
		/// href='Dimension#ADVERTISER_NAME'>Dimension#ADVERTISER_NAME</a>. <p>Compatible
		/// with any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		ADVERTISER_LABEL_IDS = 42,
		/// <summary>Represents the click-through URL for <a
		/// href='Dimension#CREATIVE_NAME'>Dimension#CREATIVE_NAME</a>. <p>Corresponds to
		/// "Click-through URL" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, REACH.</p>
		/// </summary>
		CREATIVE_CLICK_THROUGH_URL = 43,
		/// <summary>Represents whether a creative is SSL-compliant. <p>Corresponds to "Creative SSL
		/// scan result" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, REACH.</p>
		/// </summary>
		CREATIVE_SSL_SCAN_RESULT = 44,
		/// <summary>Represents whether a creative's SSL status was overridden. <p>Corresponds to
		/// "Creative SSL compliance override" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		CREATIVE_SSL_COMPLIANCE_OVERRIDE = 45,
		/// <summary>Represents a <a
		/// href='LineItemCreativeAssociation#startDateTime'>LineItemCreativeAssociation#startDateTime</a>
		/// for a <a href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a> and a <a
		/// href='Dimension#CREATIVE_NAME'>Dimension#CREATIVE_NAME</a>. Includes the date
		/// without the time. <p>Corresponds to "Creative start date" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		LINE_ITEM_CREATIVE_START_DATE = 46,
		/// <summary>Represents a <a
		/// href='LineItemCreativeAssociation#endDateTime'>LineItemCreativeAssociation#endDateTime</a>
		/// for a <a href='Dimension#LINE_ITEM_NAME'>Dimension#LINE_ITEM_NAME</a> and a <a
		/// href='Dimension#CREATIVE_NAME'>Dimension#CREATIVE_NAME</a>. Includes the date
		/// without the time. <p>Corresponds to "Creative end date" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		LINE_ITEM_CREATIVE_END_DATE = 47,
		/// <summary>Represents <a href='Proposal#startDateTime'>Proposal#startDateTime</a> for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Proposal start time" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_START_DATE_TIME = 48,
		/// <summary>Represents <a href='Proposal#endDateTime'>Proposal#endDateTime</a> for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Proposal end time" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_END_DATE_TIME = 49,
		/// <summary>Represents <a href='Proposal#creationDateTime'>Proposal#creationDateTime</a> for
		/// <a href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. Can be used for
		/// filtering. <p>Corresponds to "Creation time" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, SELL_THROUGH, REACH,
		/// SALES.</p>
		/// </summary>
		PROPOSAL_CREATION_DATE_TIME = 50,
		/// <summary>Represents the sold time for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Sold time" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_SOLD_DATE_TIME = 51,
		/// <summary>Represents <a href='Proposal#isSold'>Proposal#isSold</a> for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. Can be used for
		/// filtering. <p>Corresponds to "Sold" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_IS_SOLD = 52,
		/// <summary>Represents <a href='Proposal#probabilityOfClose'>Proposal#probabilityOfClose</a>
		/// for <a href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>.
		/// <p>Corresponds to "Probability of close" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_PROBABILITY_OF_CLOSE = 135,
		/// <summary>Represents <a href='Proposal#status'>Proposal#status</a> for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. This attribute
		/// includes post-sold statuses, e.g. DRAFT(SOLD) until v201611. Starting from
		/// v201702, it will not include post-sold statuses. Can be used for filtering.
		/// <p>Compatible with any of the following report types: HISTORICAL, SELL_THROUGH,
		/// REACH, SALES.</p>
		/// </summary>
		PROPOSAL_STATUS = 54,
		/// <summary>Represents archival status for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>, the values are
		/// ARCHIVED and NOT_ARCHIVED. Can be used for filtering. <p>Corresponds to
		/// "Proposal archival status" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_ARCHIVAL_STATUS = 55,
		/// <summary>Represents <a href='Proposal#currency'>Proposal#currency</a> for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Currency" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_CURRENCY = 56,
		/// <summary>Represents <a href='Proposal#exchangeRate'>Proposal#exchangeRate</a> for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Exchange rate" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_EXCHANGE_RATE = 57,
		/// <summary>Represents <a href='Proposal#agencyCommission'>Proposal#agencyCommission</a> for
		/// <a href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Agency commission rate" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_AGENCY_COMMISSION_RATE = 58,
		/// <summary>Represents <a href='Proposal#valueAddedTax'>Proposal#valueAddedTax</a> for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "VAT rate" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_VAT_RATE = 59,
		/// <summary>Represents <a href='Proposal#proposalDiscount'>Proposal#proposalDiscount</a> for
		/// <a href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Proposal discount" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_DISCOUNT = 60,
		/// <summary>Represents <a href='Proposal#advertiserDiscount'>Proposal#advertiserDiscount</a>
		/// for <a href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>.
		/// <p>Corresponds to "Advertiser discount" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_ADVERTISER_DISCOUNT = 61,
		/// <summary>Represents the advertiser name of <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Advertiser" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_ADVERTISER = 62,
		/// <summary>Represents the advertiser id of <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Advertiser ID" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_ADVERTISER_ID = 63,
		/// <summary>Represents the agency names as a comma separated string for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Agencies" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_AGENCIES = 64,
		/// <summary>Represents the agency ids as a comma separated string for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Agency IDs" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_AGENCY_IDS = 65,
		/// <summary>Represents <a href='Proposal#poNumber'>Proposal#poNumber</a> for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "PO number" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_PO_NUMBER = 66,
		/// <summary>Represents name and email address in the form of name(email) of primary
		/// salesperson for <a href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>.
		/// <p>Corresponds to "Salesperson" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_PRIMARY_SALESPERSON = 67,
		/// <summary>Represents name and email addresses in the form of name(email) of secondary
		/// salespeople as a comma separated string for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Secondary salespeople" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_SECONDARY_SALESPEOPLE = 68,
		/// <summary>Represents name and email address in the form of name(email) of creator for <a
		/// href=''>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to "Creator" in the Ad
		/// Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_CREATOR = 69,
		/// <summary>Represents name and email addresses in the form of name(email) of <a
		/// href=''>Proposal#salesPlannerIds</a> as a comma separated list string for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Sales planners" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_SALES_PLANNERS = 70,
		/// <summary>Represents <a href='Proposal#pricingModel'>Proposal#pricingModel</a> for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Pricing model" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_PRICING_MODEL = 71,
		/// <summary>Represents <a href='Proposal#billingSource'>Proposal#billingSource</a> for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Proposal billing source" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_BILLING_SOURCE = 72,
		/// <summary>Represents <a href='Proposal#billingCap'>Proposal#billingCap</a> for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Proposal caps and rollovers" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_BILLING_CAP = 73,
		/// <summary>Represents <a href='Proposal#billingSchedule'>Proposal#billingSchedule</a> for
		/// <a href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Proposal billing schedule" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_BILLING_SCHEDULE = 74,
		/// <summary>Represents <a href='Proposal#appliedTeamIds'>Proposal#appliedTeamIds</a> as a
		/// comma separated list of <a href='Team#name'>Team#name</a>s for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Teams" in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_APPLIED_TEAM_NAMES = 75,
		/// <summary>Represents the approval stage for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Approval stage" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_APPROVAL_STAGE = 76,
		/// <summary>Represents the inventory release date time for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Inventory release time" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_INVENTORY_RELEASE_DATE_TIME = 77,
		/// <summary>Represents <a href='Proposal#budget'>Proposal#budget</a> in local currency for
		/// <a href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Budget (local)" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LOCAL_BUDGET = 78,
		/// <summary>Represents the remaining budget in local currency for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. <p>Corresponds to
		/// "Remaining budget (local)" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LOCAL_REMAINING_BUDGET = 79,
		/// <summary>Represents whether the <a href='Proposal#billingBase'>Proposal#billingBase</a>
		/// is <a href='BillingBase#REVENUE'>BillingBase#REVENUE</a>. <p>Corresponds to
		/// "Proposal flat fee" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_FLAT_FEE = 133,
		/// <summary>Represents <a href='Proposal#isProgrammatic'>Proposal#isProgrammatic</a> for <a
		/// href='Dimension#PROPOSAL_NAME'>Dimension#PROPOSAL_NAME</a>. Not available as an
		/// attribute to report on, but exists as an attribute for filtering using PQL.
		/// <p>Compatible with any of the following report types: HISTORICAL, SELL_THROUGH,
		/// REACH, SALES.</p>
		/// </summary>
		PROPOSAL_IS_PROGRAMMATIC = 140,
		/// <summary>Represents <a
		/// href='ProposalLineItem#startDateTime'>ProposalLineItem#startDateTime</a> for <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>.
		/// <p>Corresponds to "Proposal line item start time" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SELL_THROUGH,
		/// REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_START_DATE_TIME = 80,
		/// <summary>Represents <a
		/// href='ProposalLineItem#endDateTime'>ProposalLineItem#endDateTime</a> for <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>.
		/// <p>Corresponds to "Proposal line item end time" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, SELL_THROUGH, REACH,
		/// SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_END_DATE_TIME = 81,
		/// <summary>Represents <a href='ProposalLineItem#rateType'>ProposalLineItem#rateType</a> for
		/// <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>.
		/// Can be used for filtering. <p>Corresponds to "Proposal line item rate type" in
		/// the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_RATE_TYPE = 82,
		/// <summary>Represents the reservation status of <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>.
		/// Can be used for filtering. <p>Corresponds to "Reservation status" in the Ad
		/// Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_RESERVATION_STATUS = 123,
		/// <summary>Represents <a
		/// href='ProposalLineItem#costPerUnit'>ProposalLineItem#costPerUnit</a> for <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>.
		/// <p>Corresponds to "Rate (net)" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_COST_PER_UNIT = 83,
		/// <summary>Represents <a
		/// href='ProposalLineItem#costPerUnit'>ProposalLineItem#costPerUnit</a> in local
		/// currency for <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>.
		/// See <a
		/// href='#PROPOSAL_LINE_ITEM_COST_PER_UNIT'>#PROPOSAL_LINE_ITEM_COST_PER_UNIT</a>
		/// <p>Can correspond to any of the following in the Ad Manager UI: Rate (local),
		/// Rate (net) (local). Compatible with any of the following report types:
		/// HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_LOCAL_COST_PER_UNIT = 84,
		/// <summary>Represents gross cost per unit for <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>.
		/// <p>Corresponds to "Rate (gross)" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_COST_PER_UNIT_GROSS = 85,
		/// <summary>Represents gross cost per unit in local currency for <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>.
		/// See <a
		/// href='#PROPOSAL_LINE_ITEM_COST_PER_UNIT_GROSS'>#PROPOSAL_LINE_ITEM_COST_PER_UNIT_GROSS</a>
		/// <p>Corresponds to "Rate (gross) (local)" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_LOCAL_COST_PER_UNIT_GROSS = 86,
		/// <summary>Represents line item type (if applicable) and line item priority (if applicable)
		/// for <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>.
		/// <p>Corresponds to "Proposal line item type / priority" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SELL_THROUGH,
		/// REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_TYPE_AND_PRIORITY = 87,
		/// <summary>Represents the size of <a
		/// href='ProposalLineItem#creativePlaceholders'>ProposalLineItem#creativePlaceholders</a>
		/// for <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>.
		/// <p>Corresponds to "Sizes" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_SIZE = 88,
		/// <summary>Represents archival status for <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>,
		/// the values are ARCHIVED and NOT_ARCHIVED. Can be used for filtering.
		/// <p>Corresponds to "Proposal line item archival status" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SELL_THROUGH,
		/// REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_ARCHIVAL_STATUS = 89,
		/// <summary>Represents the product adjustment of <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>.
		/// <p>Corresponds to "Product adjustment" in the Ad Manager UI. Compatible with any
		/// of the following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_PRODUCT_ADJUSTMENT = 90,
		/// <summary>Represents <a
		/// href='ProposalLineItem#contractedQuantityBuffer'>ProposalLineItem#contractedQuantityBuffer</a>
		/// for <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>.
		/// <p>Corresponds to "Buffer (%)" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_BUFFER = 91,
		/// <summary>Represents the listing rate (net) of <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>.
		/// <p>Corresponds to "Listing rate (net)" in the Ad Manager UI. Compatible with any
		/// of the following report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_LISTING_RATE_NET = 136,
		/// <summary>Represents <a
		/// href='ProposalLineItem#billingSource'>ProposalLineItem#billingSource</a> for <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>.
		/// <p>Corresponds to "Proposal line item billing source" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SELL_THROUGH,
		/// REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_BILLING_SOURCE = 93,
		/// <summary>Represents <a href='ProposalLineItem#billingCap'>ProposalLineItem#billingCap</a>
		/// for <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>.
		/// <p>Corresponds to "Proposal line item caps and rollovers" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SELL_THROUGH,
		/// REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_BILLING_CAP = 94,
		/// <summary>Represents <a
		/// href='ProposalLineItem#billingSchedule'>ProposalLineItem#billingSchedule</a> for
		/// <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>.
		/// <p>Corresponds to "Proposal line item billing schedule" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, SELL_THROUGH,
		/// REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_BILLING_SCHEDULE = 95,
		/// <summary>Represents <a href='Goal#units'>Goal#units</a> of <a
		/// href='ProposalLineItem#goal'>ProposalLineItem#goal</a> for <a
		/// href=''>Dimension#PROPOSAL_LINE_ITEM_NAME</a> The attribute is available only if
		/// <a href=''>ProposalLineItem#lineItemType</a> is of type <a
		/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a>, <a
		/// href=''>LineItemType#HOUSE</a>, <a
		/// href='LineItemType#NETWORK'>LineItemType#NETWORK</a>, or <a
		/// href='LineItemType#BUMPER'>LineItemType#BUMPER</a>. <p>Corresponds to "Goal (%)"
		/// in the Ad Manager UI. Compatible with any of the following report types:
		/// HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_GOAL_PERCENTAGE = 96,
		/// <summary>Represents <a
		/// href='ProposalLineItem#costAdjustment'>ProposalLineItem#costAdjustment</a> for
		/// <a href=''>Dimension#PROPOSAL_LINE_ITEM_NAME</a>. <p>Corresponds to "Cost
		/// adjustment" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_COST_ADJUSTMENT = 97,
		/// <summary>Represents the <a href='ProposalLineItem#notes'>comments</a> for <a
		/// href=''>Dimension#PROPOSAL_LINE_ITEM_NAME</a>. <p>Corresponds to "Proposal line
		/// item comments" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_COMMENTS = 98,
		/// <summary>Represents the monthly reconciliation status of the proposal line item for <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>
		/// and <a href='Dimension#MONTH_YEAR'>Dimension#MONTH_YEAR</a>. <p>Corresponds to
		/// "Proposal line item reconciliation status" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_RECONCILIATION_STATUS = 124,
		/// <summary>Represents the monthly last reconciliation date time of the proposal line item
		/// for <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>
		/// and <a href='Dimension#MONTH_YEAR'>Dimension#MONTH_YEAR</a>. <p>Corresponds to
		/// "Proposal line item last reconciliation time" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_LAST_RECONCILIATION_DATE_TIME = 125,
		/// <summary>Represents whether the <a
		/// href='ProposalLineItem#billingBase'>ProposalLineItem#billingBase</a> is <a
		/// href='BillingBase#REVENUE'>BillingBase#REVENUE</a>. <p>Corresponds to "Proposal
		/// line item flat fee" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_FLAT_FEE = 134,
		/// <summary>Represents the corresponding product package item's archival status of <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>.
		/// Not available as an attribute to report on, but exists as an attribute for
		/// filtering using PQL. <p>Compatible with any of the following report types:
		/// HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_PACKAGE_ITEM_ARCHIVAL_STATUS = 126,
		/// <summary>Represents the <a
		/// href='ProposalLineItem#lineItemType'>ProposalLineItem#lineItemType</a> of <a
		/// href='Dimension#PROPOSAL_LINE_ITEM_NAME'>Dimension#PROPOSAL_LINE_ITEM_NAME</a>.
		/// Only used for filtering. <p>Compatible with any of the following report types:
		/// HISTORICAL, SELL_THROUGH, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_LINE_ITEM_TYPE = 142,
		/// <summary>Represents <a href='ProductTemplate#rateType'>ProductTemplate#rateType</a> for
		/// <a href='Dimension#PRODUCT_TEMPLATE_NAME'>Dimension#PRODUCT_TEMPLATE_NAME</a>.
		/// <p>Corresponds to "Product template rate type" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_TEMPLATE_RATE_TYPE = 99,
		/// <summary>Represents <a href='ProductTemplate#status'>ProductTemplate#status</a> for <a
		/// href='Dimension#PRODUCT_TEMPLATE_NAME'>Dimension#PRODUCT_TEMPLATE_NAME</a>.
		/// <p>Corresponds to "Product template status" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_TEMPLATE_STATUS = 100,
		/// <summary>Represents the line item type (if applicable) and line item priority (if
		/// applicable) of <a
		/// href='Dimension#PRODUCT_TEMPLATE_NAME'>Dimension#PRODUCT_TEMPLATE_NAME</a>.
		/// <p>Corresponds to "Product template type / priority" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_TEMPLATE_TYPE_AND_PRIORITY = 101,
		/// <summary>Represents <a href='ProductTemplate#productType'>ProductTemplate#productType</a>
		/// for <a
		/// href='Dimension#PRODUCT_TEMPLATE_NAME'>Dimension#PRODUCT_TEMPLATE_NAME</a>.
		/// <p>Corresponds to "Product template product type" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_TEMPLATE_PRODUCT_TYPE = 102,
		/// <summary>Represents <a href='ProductTemplate#description'>ProductTemplate#description</a>
		/// for <a
		/// href='Dimension#PRODUCT_TEMPLATE_NAME'>Dimension#PRODUCT_TEMPLATE_NAME</a>.
		/// <p>Corresponds to "Description" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_TEMPLATE_DESCRIPTION = 103,
		/// <summary>Represents the product template's name of <a
		/// href='Dimension#PRODUCT_NAME'>Dimension#PRODUCT_NAME</a>. <p>Corresponds to
		/// "Product template name" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_PRODUCT_TEMPLATE_NAME = 104,
		/// <summary>Represents <a href='Product#rateType'>Product#rateType</a> for <a
		/// href='Dimension#PRODUCT_NAME'>Dimension#PRODUCT_NAME</a>. <p>Corresponds to
		/// "Product rate type" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_RATE_TYPE = 105,
		/// <summary>Represents <a href='Product#status'>Product#status</a> for <a
		/// href='Dimension#PRODUCT_NAME'>Dimension#PRODUCT_NAME</a>. <p>Corresponds to
		/// "Product status" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_STATUS = 106,
		/// <summary>Represents the line item type (if applicable) and line item priority (if
		/// applicable) of <a href='Dimension#PRODUCT_NAME'>Dimension#PRODUCT_NAME</a>.
		/// <p>Corresponds to "Product type / priority" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_TYPE_AND_PRIORITY = 107,
		/// <summary>Represents the product type of <a
		/// href='Dimension#PRODUCT_NAME'>Dimension#PRODUCT_NAME</a>. <p>Corresponds to
		/// "Product product type" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_PRODUCT_TYPE = 108,
		/// <summary>Represents <a href='Product#notes'>Product#notes</a> for <a
		/// href='Dimension#PRODUCT_NAME'>Dimension#PRODUCT_NAME</a>. <p>Corresponds to
		/// "Product notes" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_NOTES = 109,
		/// <summary>Represents <a
		/// href='Product#creativePlaceholders'>Product#creativePlaceholders</a> for <a
		/// href='Dimension#PRODUCT_NAME'>Dimension#PRODUCT_NAME</a>. <p>Corresponds to
		/// "Inventory sizes" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_INVENTORY_SIZES = 141,
		/// <summary>Represents the <a href='Dimension#PRODUCT_NAME'>Dimension#PRODUCT_NAME</a>'s
		/// rate in a <a href='Dimension#RATE_CARD_NAME'>Dimension#RATE_CARD_NAME</a>.
		/// <p>Corresponds to "Product rate" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_RATE = 137,
		/// <summary>Represents the <a href='Dimension#PRODUCT_NAME'>Dimension#PRODUCT_NAME</a>'s
		/// rate in a <a href='Dimension#RATE_CARD_NAME'>Dimension#RATE_CARD_NAME</a> and <a
		/// href='Dimension#PRODUCT_PACKAGE_NAME'>Dimension#PRODUCT_PACKAGE_NAME</a>.
		/// <p>Corresponds to "Packaged product rate" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PACKAGED_PRODUCT_RATE = 138,
		/// <summary>Represents the <a href='Company#type'>Company#type</a> of <a
		/// href='Dimension#PROPOSAL_AGENCY_NAME'>Dimension#PROPOSAL_AGENCY_NAME</a>.
		/// <p>Corresponds to "Proposal agency type" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_AGENCY_TYPE = 110,
		/// <summary>Represents the <a href='Company#creditStatus'>Company#creditStatus</a> of <a
		/// href='Dimension#PROPOSAL_AGENCY_NAME'>Dimension#PROPOSAL_AGENCY_NAME</a>.
		/// <p>Corresponds to "Proposal agency credit status" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_AGENCY_CREDIT_STATUS = 111,
		/// <summary>Represents <a href='Company#externalId'>Company#externalId</a> for <a
		/// href='Dimension#PROPOSAL_AGENCY_NAME'>Dimension#PROPOSAL_AGENCY_NAME</a>.
		/// <p>Corresponds to "External agency ID" in the Ad Manager UI. Compatible with any
		/// of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_AGENCY_EXTERNAL_ID = 112,
		/// <summary>Represents <a href='Company#comment'>Company#comment</a> for <a
		/// href='Dimension#PROPOSAL_AGENCY_NAME'>Dimension#PROPOSAL_AGENCY_NAME</a>.
		/// <p>Corresponds to "Proposal agency comment" in the Ad Manager UI. Compatible
		/// with any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PROPOSAL_AGENCY_COMMENT = 113,
		/// <summary>Represents the <a
		/// href='Dimension#ALL_SALESPEOPLE_NAME'>Dimension#ALL_SALESPEOPLE_NAME</a>'s
		/// contribution to a <a href=''>Dimension#PROPOSAL_NAME</a>. This is different from
		/// <a
		/// href='#SALESPERSON_PROPOSAL_CONTRIBUTION'>#SALESPERSON_PROPOSAL_CONTRIBUTION</a>
		/// as this will include both primary and secondary salespeople. <p>Corresponds to
		/// "Salespeople proposal contribution" in the Ad Manager UI. Compatible with any of
		/// the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		SALESPEOPLE_PROPOSAL_CONTRIBUTION = 114,
		/// <summary>Represents the <a
		/// href='Dimension#SALESPERSON_NAME'>Dimension#SALESPERSON_NAME</a>'s contribution
		/// to a <a href=''>Dimension#PROPOSAL_NAME</a>. <p>See <a
		/// href='#SALESPERSON_PROPOSAL_CONTRIBUTION'>#SALESPERSON_PROPOSAL_CONTRIBUTION</a>.</p>
		/// <p>Corresponds to "Salesperson proposal contribution" in the Ad Manager UI.
		/// Compatible with any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		SALESPERSON_PROPOSAL_CONTRIBUTION = 115,
		/// <summary>Represents <a href='ProductPackage#notes'>ProductPackage#notes</a> for <a
		/// href='Dimension#PRODUCT_PACKAGE_NAME'>Dimension#PRODUCT_PACKAGE_NAME</a>.
		/// <p>Corresponds to "Product package notes" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_PACKAGE_NOTES = 127,
		/// <summary>Represents the products as a comma separated list of name for <a
		/// href='Dimension#PRODUCT_PACKAGE_NAME'>Dimension#PRODUCT_PACKAGE_NAME</a>.
		/// <p>Corresponds to "Product package items" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_PACKAGE_ITEMS = 128,
		/// <summary>Represents <a href='ProductPackage#status'>ProductPackage#status</a> for <a
		/// href='Dimension#PRODUCT_PACKAGE_NAME'>Dimension#PRODUCT_PACKAGE_NAME</a>.
		/// <p>Corresponds to "Product package status" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PRODUCT_PACKAGE_STATUS = 129,
		/// <summary>Represents <a href='Package#comments'>Package#comments</a> for <a
		/// href='Dimension#PACKAGE_NAME'>Dimension#PACKAGE_NAME</a>. <p>Corresponds to
		/// "Package comments" in the Ad Manager UI. Compatible with any of the following
		/// report types: HISTORICAL, REACH, SALES.</p>
		/// </summary>
		PACKAGE_COMMENTS = 130,
		/// <summary>Represents <a href='Package#startDateTime'>Package#startDateTime</a> for
		/// {@Dimension#PACKAGE_NAME}. <p>Corresponds to "Package start time" in the Ad
		/// Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// REACH, SALES.</p>
		/// </summary>
		PACKAGE_START_DATE_TIME = 131,
		/// <summary>Represents <a href='Package#endDateTime'>Package#endDateTime</a> for
		/// {@Dimension#PACKAGE_NAME}. <p>Corresponds to "Package end time" in the Ad
		/// Manager UI. Compatible with any of the following report types: HISTORICAL,
		/// REACH, SALES.</p>
		/// </summary>
		PACKAGE_END_DATE_TIME = 132,
		/// <summary>Represents the <a href='CmsContent#displayName'>CmsContent#displayName</a>
		/// within the first element of <a href='Content#cmsContent'>Content#cmsContent</a>
		/// for <a href='Dimension#CONTENT_NAME'>Dimension#CONTENT_NAME</a>. <p>Corresponds
		/// to "Content source name" in the Ad Manager UI. Compatible with any of the
		/// following report types: HISTORICAL, REACH.</p>
		/// </summary>
		CONTENT_CMS_NAME = 116,
		/// <summary>Represents the <a href='CmsContent#cmsContentId'>CmsContent#cmsContentId</a>
		/// within the first element of <a href='Content#cmsContent'>Content#cmsContent</a>
		/// for <a href='Dimension#CONTENT_NAME'>Dimension#CONTENT_NAME</a>. <p>Corresponds
		/// to "ID of the video in the content source" in the Ad Manager UI. Compatible with
		/// any of the following report types: HISTORICAL, REACH.</p>
		/// </summary>
		CONTENT_CMS_VIDEO_ID = 117,
		/// <summary>Represents <a href='AdUnit#adUnitCode'>AdUnit#adUnitCode</a> for <a
		/// href='Dimension#AD_UNIT_NAME'>Dimension#AD_UNIT_NAME</a>. <p>Corresponds to "Ad
		/// unit code" in the Ad Manager UI. Compatible with any of the following report
		/// types: HISTORICAL, SELL_THROUGH, REACH, SALES, CREATIVE_QOS.</p>
		/// </summary>
		AD_UNIT_CODE = 118,
	}


	/// <summary>Represents a period of time.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum DateRangeType {
		/// <summary>The current day.
		/// </summary>
		TODAY = 0,
		/// <summary>The previous day.
		/// </summary>
		YESTERDAY = 1,
		/// <summary>The last week, from monday to sunday.
		/// </summary>
		LAST_WEEK = 2,
		/// <summary>The previous month.
		/// </summary>
		LAST_MONTH = 3,
		/// <summary>The last 3 full months. For example, if today is May 5, 2017, then LAST_3_MONTHS
		/// would go from February 1 to April 30.
		/// </summary>
		LAST_3_MONTHS = 14,
		/// <summary>The last 63 days. This date range is only usable for the columns <a
		/// href='Column#REACH_FREQUENCY'>Column#REACH_FREQUENCY</a>, <a
		/// href='Column#REACH_AVERAGE_REVENUE'>Column#REACH_AVERAGE_REVENUE</a> and <a
		/// href='Column#REACH'>Column#REACH</a>.
		/// </summary>
		REACH_LIFETIME = 4,
		/// <summary>Specifying this value will enable the user to specify <a
		/// href='ReportQuery#startDate'>ReportQuery#startDate</a> and <a
		/// href='ReportQuery#endDate'>ReportQuery#endDate</a>.
		/// </summary>
		CUSTOM_DATE = 5,
		/// <summary>The next day.
		/// </summary>
		NEXT_DAY = 6,
		/// <summary>The next ninety days.
		/// </summary>
		NEXT_90_DAYS = 7,
		/// <summary>The next week, from monday to sunday.
		/// </summary>
		NEXT_WEEK = 8,
		/// <summary>The next month.
		/// </summary>
		NEXT_MONTH = 9,
		/// <summary>Beginning of the next day until the end of the next month.
		/// </summary>
		CURRENT_AND_NEXT_MONTH = 10,
		/// <summary>The next quarter.
		/// </summary>
		NEXT_QUARTER = 11,
		/// <summary>The next three months.
		/// </summary>
		NEXT_3_MONTHS = 12,
		/// <summary>The next twelve months.
		/// </summary>
		NEXT_12_MONTHS = 13,
	}


	/// <summary>Enumerates all allowed time zones that can be used in reports. Note that some
	/// time zones are only compatible with specific fields.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum TimeZoneType {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		/// <summary>Use the proposal or proposal line item time zone. This time zone is only
		/// compatible with sales metrics and attributes. <p>For example, if <a
		/// href='com.google.ads.publisher.api.service.reports.Column#SALES_CONTRACT_CONTRACTED_CLICKS'>
		/// com.google.ads.publisher.api.service.reports.Column#SALES_CONTRACT_CONTRACTED_CLICKS</a>
		/// is included in a report with this flag set to <code>true</code>, then it will be
		/// calculated using the <a
		/// href='ProposalLineItem#timeZoneId'>ProposalLineItem#timeZoneId</a> of the
		/// proposal line item the metric is for. If <a
		/// href='com.google.ads.publisher.api.service.reports.DimensionAttribute#PROPOSAL_CREATION_DATE_TIME'>
		/// com.google.ads.publisher.api.service.reports.DimensionAttribute#PROPOSAL_CREATION_DATE_TIME</a>
		/// is included in a report with this flag set to <code>true</code>, then a
		/// proposal's creation date time will be formatted in <a
		/// href='Proposal#timeZoneId'>Proposal#timeZoneId</a> of that proposal.</p>
		/// </summary>
		PROPOSAL_LOCAL = 1,
		/// <summary>Use the publisher's time zone. For Ad Manager reports, this time zone is
		/// compatible with all metrics. For Ad Exchange reports, this time zone is not
		/// compatible with "Bids" and "Deals" metrics. <p><b>Note:</b> if your report
		/// includes "time unit" dimensions, only the Ad Manager "time unit" dimensions are
		/// compatible with this timezone, e.g.:</p> <ul> <li><a
		/// href='com.google.ads.publisher.api.service.reports.Dimension.DATE'>com.google.ads.publisher.api.service.reports.Dimension.DATE</a></li>
		/// <li><a
		/// href='com.google.ads.publisher.api.service.reports.Dimension.WEEK'>com.google.ads.publisher.api.service.reports.Dimension.WEEK</a></li>
		/// <li><a
		/// href='com.google.ads.publisher.api.service.reports.Dimension.MONTH_AND_YEAR'>
		/// com.google.ads.publisher.api.service.reports.Dimension.MONTH_AND_YEAR</a></li>
		/// </ul>
		/// </summary>
		PUBLISHER = 2,
		/// <summary>Use the Ad Exchange time zone (Pacific Time Zone). This time zone is only
		/// compatible with Ad Exchange metrics. <p><b>Note:</b> if your report includes
		/// "time unit" dimensions, only the Ad Exchange "time unit" dimensions are
		/// compatible with this timezone, e.g.:</p> <ul> <li><a
		/// href='com.google.ads.publisher.api.service.reports.Dimension.AD_EXCHANGE_DATE'>
		/// com.google.ads.publisher.api.service.reports.Dimension.AD_EXCHANGE_DATE</a></li>
		/// <li><a
		/// href='com.google.ads.publisher.api.service.reports.Dimension.AD_EXCHANGE_WEEK'>
		/// com.google.ads.publisher.api.service.reports.Dimension.AD_EXCHANGE_WEEK</a></li>
		/// <li><a
		/// href='com.google.ads.publisher.api.service.reports.Dimension.AD_EXCHANGE_MONTH'>
		/// com.google.ads.publisher.api.service.reports.Dimension.AD_EXCHANGE_MONTH</a></li>
		/// </ul>
		/// </summary>
		AD_EXCHANGE = 3,
	}


	/// <summary>Represents a report job that will be run to retrieve performance and statistics
	/// information about ad campaigns, networks, inventory and sales.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ReportJob {
		private long idField;

		private bool idFieldSpecified;

		private ReportQuery reportQueryField;

		/// <summary>The unique ID of the <code>ReportJob</code>. This value is read-only and is
		/// assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>Holds the filtering criteria.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public ReportQuery reportQuery {
			get {
				return this.reportQueryField;
			}
			set {
				this.reportQueryField = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ReportServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ReportServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for executing a <a href='ReportJob'>ReportJob</a> and
	/// retrieving performance and statistics about ad campaigns, networks, inventory
	/// and sales. <p>Follow the steps outlined below:</p> <p> <ul> <li>Create the
	/// <code>ReportJob</code> object by invoking <a
	/// href='ReportService#runReportJob'>ReportService#runReportJob</a>.</li> <li>Poll
	/// the <code>ReportJob</code> object using <a
	/// href='ReportService#getReportJob'>ReportService#getReportJob</a>.</li>
	/// <li>Continue to poll the <code>ReportJob</code> object until the <a
	/// href='ReportJob#reportJobStatus'>ReportJob#reportJobStatus</a> field is equal to
	/// <a href='ReportJobStatus#COMPLETED'>ReportJobStatus#COMPLETED</a> or <a
	/// href='ReportJobStatus#FAILED'>ReportJobStatus#FAILED</a>.</li> <li>If
	/// successful, fetch the URL for downloading the report by invoking <a
	/// href='ReportService#getReportDownloadURL'>ReportService#getReportDownloadURL</a>.</li>
	/// </ul> <br /> <br /> <h4>Test network behavior</h4> </p><p>The networks created
	/// using <a
	/// href='NetworkService#makeTestNetwork'>NetworkService#makeTestNetwork</a> are
	/// unable to provide reports that would be comparable to the production environment
	/// because reports require traffic history. In the test networks, reports will
	/// consistently return no data for all reports.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ReportService : AdManagerSoapClient<IReportService>, IReportService {
		/// <summary> Creates a new instance of the <see cref="ReportService"/> class.
		/// </summary>
		public ReportService() {
		}

		/// <summary> Creates a new instance of the <see cref="ReportService"/> class.
		/// </summary>
		public ReportService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="ReportService"/> class.
		/// </summary>
		public ReportService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ReportService"/> class.
		/// </summary>
		public ReportService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ReportService"/> class.
		/// </summary>
		public ReportService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		/// <summary>Returns the URL at which the report file can be downloaded. <p>The report will
		/// be generated as a gzip archive, containing the report file itself. </p>
		/// </summary><param name='reportJobId'>the ID of the <a
		/// href='ReportJob'>ReportJob</a></param>
		/// <param name='exportFormat'>the <a href='ExportFormat'>ExportFormat</a> for the
		/// report file</param>
		/// <returns>the URL for report file download</returns>
		public virtual string getReportDownloadURL(long reportJobId, Google.Api.Ads.AdManager.v201802.ExportFormat exportFormat) {
			return base.Channel.getReportDownloadURL(reportJobId, exportFormat);
		}

		public virtual System.Threading.Tasks.Task<string> getReportDownloadURLAsync(long reportJobId, Google.Api.Ads.AdManager.v201802.ExportFormat exportFormat) {
			return base.Channel.getReportDownloadURLAsync(reportJobId, exportFormat);
		}

		/// <summary>Returns the URL at which the report file can be downloaded, and allows for
		/// customization of the downloaded report. <p>By default, the report will be
		/// generated as a gzip archive, containing the report file itself. This can be
		/// changed by setting <a
		/// href='ReportDownloadOptions#useGzipCompression'>ReportDownloadOptions#useGzipCompression</a>
		/// to false. </p>
		/// </summary><param name='reportJobId'>the ID of the <a
		/// href='ReportJob'>ReportJob</a></param>
		/// <param name='reportDownloadOptions'>the <a
		/// href='ReportDownloadOptions'>ReportDownloadOptions</a> for the request</param>
		/// <returns>the URL for report file download</returns>
		public virtual string getReportDownloadUrlWithOptions(long reportJobId, Google.Api.Ads.AdManager.v201802.ReportDownloadOptions reportDownloadOptions) {
			return base.Channel.getReportDownloadUrlWithOptions(reportJobId, reportDownloadOptions);
		}

		public virtual System.Threading.Tasks.Task<string> getReportDownloadUrlWithOptionsAsync(long reportJobId, Google.Api.Ads.AdManager.v201802.ReportDownloadOptions reportDownloadOptions) {
			return base.Channel.getReportDownloadUrlWithOptionsAsync(reportJobId, reportDownloadOptions);
		}

		/// <summary>Returns the <a href='ReportJobStatus'>ReportJobStatus</a> of the report job with
		/// the specified ID.
		/// </summary>
		public virtual Google.Api.Ads.AdManager.v201802.ReportJobStatus getReportJobStatus(long reportJobId) {
			return base.Channel.getReportJobStatus(reportJobId);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReportJobStatus> getReportJobStatusAsync(long reportJobId) {
			return base.Channel.getReportJobStatusAsync(reportJobId);
		}

		/// <summary>Retrieves a page of the saved queries either created by or shared with the
		/// current user. Each <a href='SavedQuery'>SavedQuery</a> in the page, if it is
		/// compatible with the current API version, will contain a <a
		/// href='ReportQuery'>ReportQuery</a> object which can be optionally modified and
		/// used to create a <a href='ReportJob'>ReportJob</a>. This can then be passed to
		/// <a href='ReportService#runReportJob'>ReportService#runReportJob</a>. The
		/// following fields are supported for filtering: <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>id</code></td> <td><a href='SavedQuery#id'>SavedQuery#id</a></td>
		/// </tr> <tr> <td><code>name</code></td> <td><a
		/// href='SavedQuery#name'>SavedQuery#name</a></td> </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter which saved queries should be returned.</param>
		/// <returns>a <a href='SavedQueryPage'>SavedQueryPage</a> that contains all <a
		/// href='SavedQuery'>SavedQuery</a> instances which satisfy the given
		/// statement.</returns>
		public virtual Google.Api.Ads.AdManager.v201802.SavedQueryPage getSavedQueriesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getSavedQueriesByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.SavedQueryPage> getSavedQueriesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getSavedQueriesByStatementAsync(filterStatement);
		}

		/// <summary>Initiates the execution of a <a href='ReportQuery'>ReportQuery</a> on the
		/// server. <p>The following fields are required:</p> <ul> <li><a
		/// href='ReportJob#reportQuery'>ReportJob#reportQuery</a></li> </ul>
		/// </summary><param name='reportJob'>the report job to run</param>
		/// <returns>the report job with its ID filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ReportJob runReportJob(Google.Api.Ads.AdManager.v201802.ReportJob reportJob) {
			return base.Channel.runReportJob(reportJob);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReportJob> runReportJobAsync(Google.Api.Ads.AdManager.v201802.ReportJob reportJob) {
			return base.Channel.runReportJobAsync(reportJob);
		}
	}
	namespace Wrappers.SuggestedAdUnitService
	{
	}
	/// <summary>A <code>SuggestedAdUnit</code> represents a suggestion for a new ad unit, based
	/// on an ad tag that has been served at least ten times in the past week, but which
	/// does not correspond to a defined ad unit. This type is read-only.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SuggestedAdUnit {
		private string idField;

		private long numRequestsField;

		private bool numRequestsFieldSpecified;

		private string[] pathField;

		private AdUnitParent[] parentPathField;

		private AdUnitTargetWindow targetWindowField;

		private bool targetWindowFieldSpecified;

		private TargetPlatform targetPlatformField;

		private bool targetPlatformFieldSpecified;

		private AdUnitSize[] suggestedAdUnitSizesField;

		/// <summary>The unique ID of the suggested ad unit. After API version 201311 this field will
		/// be a numerical ID. Earlier versions will return a string value which is the
		/// complete path to the suggested ad unit with path elements separated by '/'
		/// characters. This attribute is read-only and is populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
			}
		}

		/// <summary>Returns the number of times the ad tag corresponding to this suggested ad unit
		/// has been served in the previous week. Suggested ad units are only created when
		/// they have been served at least ten times in that period. This attribute is
		/// read-only and is populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long numRequests {
			get {
				return this.numRequestsField;
			}
			set {
				this.numRequestsField = value;
				this.numRequestsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="numRequests"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool numRequestsSpecified {
			get {
				return this.numRequestsFieldSpecified;
			}
			set {
				this.numRequestsFieldSpecified = value;
			}
		}

		/// <summary>The hierarchical path from the <a href='#parentPath'>last existing ad unit</a>
		/// after this and all suggested parent ad units have been created. Each path
		/// element is a separate ad unit code in the returned list. This attribute is
		/// read-only and is populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("path", Order = 2)]
		public string[] path {
			get {
				return this.pathField;
			}
			set {
				this.pathField = value;
			}
		}

		/// <summary>The existing hierarchical path leading up to, and including, the parent of the
		/// first suggested ad unit in the ad unit hierarchy. The <code>parentPath</code>
		/// and the <code>path</code> make up the full path of the suggested ad unit after
		/// it is approved. This attribute is read-only and is populated by Google.
		/// <p><strong>Note:</strong> The ad unit code for each of the parent ad units will
		/// not be provided.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("parentPath", Order = 3)]
		public AdUnitParent[] parentPath {
			get {
				return this.parentPathField;
			}
			set {
				this.parentPathField = value;
			}
		}

		/// <summary>The <code>target</code> attribute of the underlying ad tag, as defined in the <a
		/// href='AdUnit'>AdUnit</a>. This attribute is read-only and is populated by
		/// Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public AdUnitTargetWindow targetWindow {
			get {
				return this.targetWindowField;
			}
			set {
				this.targetWindowField = value;
				this.targetWindowSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="targetWindow" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool targetWindowSpecified {
			get {
				return this.targetWindowFieldSpecified;
			}
			set {
				this.targetWindowFieldSpecified = value;
			}
		}

		/// <summary>The target platform for the browser that clicked the underlying ad tag. This
		/// attribute is read-only and is populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public TargetPlatform targetPlatform {
			get {
				return this.targetPlatformField;
			}
			set {
				this.targetPlatformField = value;
				this.targetPlatformSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="targetPlatform" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool targetPlatformSpecified {
			get {
				return this.targetPlatformFieldSpecified;
			}
			set {
				this.targetPlatformFieldSpecified = value;
			}
		}

		/// <summary>The target sizes associated with this <code>SuggestedAdUnit</code>. This
		/// attribute is read-only and is populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("suggestedAdUnitSizes", Order = 6)]
		public AdUnitSize[] suggestedAdUnitSizes {
			get {
				return this.suggestedAdUnitSizesField;
			}
			set {
				this.suggestedAdUnitSizesField = value;
			}
		}
	}


	/// <summary>Indicates the target platform.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum TargetPlatform {
		/// <summary>The desktop web.
		/// </summary>
		WEB = 0,
		/// <summary>Mobile devices.
		/// </summary>
		MOBILE = 1,
		/// <summary>An universal target platform that combines mobile and desktop features.
		/// </summary>
		ANY = 2,
	}


	/// <summary>Contains a page of <a href='SuggestedAdUnit'>SuggestedAdUnit</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SuggestedAdUnitPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private SuggestedAdUnit[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of suggested ad units contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public SuggestedAdUnit[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.SuggestedAdUnitServiceInterface")]
	public interface SuggestedAdUnitServiceInterface
	{
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.SuggestedAdUnitPage getSuggestedAdUnitsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.SuggestedAdUnitPage> getSuggestedAdUnitsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.SuggestedAdUnitUpdateResult performSuggestedAdUnitAction(Google.Api.Ads.AdManager.v201802.SuggestedAdUnitAction suggestedAdUnitAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.SuggestedAdUnitUpdateResult> performSuggestedAdUnitActionAsync(Google.Api.Ads.AdManager.v201802.SuggestedAdUnitAction suggestedAdUnitAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);
	}


	/// <summary>Represents the actions that can be performed on <a
	/// href='SuggestedAdUnit'>SuggestedAdUnit</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ApproveSuggestedAdUnits))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class SuggestedAdUnitAction {
	}


	/// <summary>Action to approve <a href='SuggestedAdUnit'>SuggestedAdUnit</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ApproveSuggestedAdUnits : SuggestedAdUnitAction {
	}


	/// <summary>Represents the result of performing an action on <a
	/// href='SuggestedAdUnit'>SuggestedAdUnit</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SuggestedAdUnitUpdateResult {
		private string[] newAdUnitIdsField;

		private int numChangesField;

		private bool numChangesFieldSpecified;

		/// <summary>The ids of the <a href='AdUnit'>AdUnit</a> objects that were created in response
		/// to a performSuggestedAdUnitAction call.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("newAdUnitIds", Order = 0)]
		public string[] newAdUnitIds {
			get {
				return this.newAdUnitIdsField;
			}
			set {
				this.newAdUnitIdsField = value;
			}
		}

		/// <summary>The number of objects that were changed as a result of performing the action.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int numChanges {
			get {
				return this.numChangesField;
			}
			set {
				this.numChangesField = value;
				this.numChangesSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="numChanges"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool numChangesSpecified {
			get {
				return this.numChangesFieldSpecified;
			}
			set {
				this.numChangesFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface SuggestedAdUnitServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.SuggestedAdUnitServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>This service provides operations for retrieving and approving <a
	/// href='SuggestedAdUnit'>SuggestedAdUnit</a> objects. <p>Publishers may create ad
	/// tags that lack a corresponding ad unit defined in DFP, in order to gather
	/// information about potential ads without needing to create dummy ad units and
	/// make them available for targeting in line items. Any undefined ad unit to
	/// receive more than ten serving requests in the past week is treated as a
	/// 'suggested ad unit'. These can be queried by the client and selectively
	/// approved. Approval causes a new ad unit to be created based on the suggested ad
	/// unit. Unapproved suggested ad units cease to exist whenever their corresponding
	/// ad tag has been served fewer than ten times in the past seven days.</p> <p>This
	/// service is only available to Premium publishers. Before use, suggested ad units
	/// must be enabled for the client's network. This can be done in the UI: in the
	/// Inventory tab, click "Network settings" in the left-hand panel, then enable the
	/// checkbox "Get suggestions for new ad units." If suggested ad units are not
	/// enabled, then <a
	/// href='#getSuggestedAdUnitsByStatement'>#getSuggestedAdUnitsByStatement</a> will
	/// always return an empty page.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class SuggestedAdUnitService : AdManagerSoapClient<ISuggestedAdUnitService>, ISuggestedAdUnitService {
		/// <summary> Creates a new instance of the <see cref="SuggestedAdUnitService"/>
		/// class. </summary>
		public SuggestedAdUnitService() {
		}

		/// <summary> Creates a new instance of the <see cref="SuggestedAdUnitService"/>
		/// class. </summary>
		public SuggestedAdUnitService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="SuggestedAdUnitService"/>
		/// class. </summary>
		public SuggestedAdUnitService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="SuggestedAdUnitService"/>
		/// class. </summary>
		public SuggestedAdUnitService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="SuggestedAdUnitService"/>
		/// class. </summary>
		public SuggestedAdUnitService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		/// <summary>Gets a <a href='SuggestedAdUnitPage'>SuggestedAdUnitPage</a> of <a
		/// href='SuggestedAdUnit'>SuggestedAdUnit</a> objects that satisfy the filter
		/// query. There is a system-enforced limit of 1000 on the number of suggested ad
		/// units that are suggested at any one time. <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>id</code></td> <td><a
		/// href='SuggestedAdUnit#id'>SuggestedAdUnit#id</a></td> </tr> <tr>
		/// <td><code>numRequests</code></td> <td><a
		/// href='SuggestedAdUnit#numRequests'>SuggestedAdUnit#numRequests</a></td> </tr>
		/// </table> <p><strong>Note:</strong> After API version 201311, the <code>id</code>
		/// field will only be numerical. </p>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of suggested ad units</param>
		/// <returns>the suggested ad units that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.SuggestedAdUnitPage getSuggestedAdUnitsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getSuggestedAdUnitsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.SuggestedAdUnitPage> getSuggestedAdUnitsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getSuggestedAdUnitsByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='SuggestedAdUnit'>SuggestedAdUnit</a> objects that
		/// match the given <a href='Statement#query'>Statement#query</a>. The following
		/// fields are supported for filtering: <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>id</code></td> <td><a
		/// href='SuggestedAdUnit#id'>SuggestedAdUnit#id</a></td> </tr> <tr>
		/// <td><code>numRequests</code></td> <td><a
		/// href='SuggestedAdUnit#numRequests'>SuggestedAdUnit#numRequests</a></td> </tr>
		/// </table>
		/// </summary><param name='suggestedAdUnitAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of suggested ad units</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.SuggestedAdUnitUpdateResult performSuggestedAdUnitAction(Google.Api.Ads.AdManager.v201802.SuggestedAdUnitAction suggestedAdUnitAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performSuggestedAdUnitAction(suggestedAdUnitAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.SuggestedAdUnitUpdateResult> performSuggestedAdUnitActionAsync(Google.Api.Ads.AdManager.v201802.SuggestedAdUnitAction suggestedAdUnitAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performSuggestedAdUnitActionAsync(suggestedAdUnitAction, filterStatement);
		}
	}
	namespace Wrappers.TeamService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createTeams", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createTeamsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("teams")]
			public Google.Api.Ads.AdManager.v201802.Team[] teams;

			/// <summary> Creates a new instance of the <see cref="createTeamsRequest"/> class.
			/// </summary>
			public createTeamsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createTeamsRequest"/> class.
			/// </summary>
			public createTeamsRequest(Google.Api.Ads.AdManager.v201802.Team[] teams) {
				this.teams = teams;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createTeamsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createTeamsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Team[] rval;

			/// <summary> Creates a new instance of the <see cref="createTeamsResponse"/> class.
			/// </summary>
			public createTeamsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createTeamsResponse"/> class.
			/// </summary>
			public createTeamsResponse(Google.Api.Ads.AdManager.v201802.Team[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateTeams", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateTeamsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("teams")]
			public Google.Api.Ads.AdManager.v201802.Team[] teams;

			/// <summary> Creates a new instance of the <see cref="updateTeamsRequest"/> class.
			/// </summary>
			public updateTeamsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updateTeamsRequest"/> class.
			/// </summary>
			public updateTeamsRequest(Google.Api.Ads.AdManager.v201802.Team[] teams) {
				this.teams = teams;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateTeamsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateTeamsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Team[] rval;

			/// <summary> Creates a new instance of the <see cref="updateTeamsResponse"/> class.
			/// </summary>
			public updateTeamsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updateTeamsResponse"/> class.
			/// </summary>
			public updateTeamsResponse(Google.Api.Ads.AdManager.v201802.Team[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>A <code>Team</code> defines a grouping of users and what entities they have
	/// access to. Users are added to teams with <a
	/// href='UserTeamAssociation'>UserTeamAssociation</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Team {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private string descriptionField;

		private TeamStatus statusField;

		private bool statusFieldSpecified;

		private bool hasAllCompaniesField;

		private bool hasAllCompaniesFieldSpecified;

		private bool hasAllInventoryField;

		private bool hasAllInventoryFieldSpecified;

		private TeamAccessType teamAccessTypeField;

		private bool teamAccessTypeFieldSpecified;

		/// <summary>The unique ID of the <code>Team</code>. This value is readonly and is assigned
		/// by Google. Teams that are created by Google will have negative IDs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the <code>Team</code>. This value is required to create a team and
		/// has a maximum length of 106 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The description of the <code>Team</code>. This value is optional and has a
		/// maximum length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string description {
			get {
				return this.descriptionField;
			}
			set {
				this.descriptionField = value;
			}
		}

		/// <summary>The status of the <a href='Team'>Team</a>. This value can be <a
		/// href='TeamStatus#ACTIVE'>TeamStatus#ACTIVE</a> (default) or <a
		/// href='TeamStatus#INACTIVE'>TeamStatus#INACTIVE</a> and determines the visibility
		/// of the team in the UI.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public TeamStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>Whether or not users on this team have access to all companies. If this value is
		/// true, then <a href='#companyIds'>#companyIds</a> must be empty.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public bool hasAllCompanies {
			get {
				return this.hasAllCompaniesField;
			}
			set {
				this.hasAllCompaniesField = value;
				this.hasAllCompaniesSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="hasAllCompanies" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool hasAllCompaniesSpecified {
			get {
				return this.hasAllCompaniesFieldSpecified;
			}
			set {
				this.hasAllCompaniesFieldSpecified = value;
			}
		}

		/// <summary>Whether or not users on this team have access to all inventory. If this value is
		/// true, then <a href='#adUnitIds'>#adUnitIds</a> must be empty.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public bool hasAllInventory {
			get {
				return this.hasAllInventoryField;
			}
			set {
				this.hasAllInventoryField = value;
				this.hasAllInventorySpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="hasAllInventory" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool hasAllInventorySpecified {
			get {
				return this.hasAllInventoryFieldSpecified;
			}
			set {
				this.hasAllInventoryFieldSpecified = value;
			}
		}

		/// <summary>The default access to orders, for users on this team.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public TeamAccessType teamAccessType {
			get {
				return this.teamAccessTypeField;
			}
			set {
				this.teamAccessTypeField = value;
				this.teamAccessTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="teamAccessType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool teamAccessTypeSpecified {
			get {
				return this.teamAccessTypeFieldSpecified;
			}
			set {
				this.teamAccessTypeFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents the status of a team, whether it is active or inactive.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum TeamStatus {
		/// <summary>The status of an active team. (i.e. visible in the UI)
		/// </summary>
		ACTIVE = 0,
		/// <summary>The status of an inactive team. (i.e. hidden in the UI)
		/// </summary>
		INACTIVE = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Represents the types of team access supported for orders.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum TeamAccessType {
		/// <summary>The level of access in which team members cannot view or edit a team's orders.
		/// </summary>
		NONE = 0,
		/// <summary>The level of access in which team members can only view a team's orders.
		/// </summary>
		READ_ONLY = 1,
		/// <summary>The level of access in which team members can view and edit a team's orders.
		/// </summary>
		READ_WRITE = 2,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.TeamServiceInterface")]
	public interface TeamServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.TeamService.createTeamsResponse createTeams(Wrappers.TeamService.createTeamsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.TeamService.createTeamsResponse> createTeamsAsync(Wrappers.TeamService.createTeamsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.TeamPage getTeamsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.TeamPage> getTeamsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performTeamAction(Google.Api.Ads.AdManager.v201802.TeamAction teamAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performTeamActionAsync(Google.Api.Ads.AdManager.v201802.TeamAction teamAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.TeamService.updateTeamsResponse updateTeams(Wrappers.TeamService.updateTeamsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.TeamService.updateTeamsResponse> updateTeamsAsync(Wrappers.TeamService.updateTeamsRequest request);
	}


	/// <summary>Captures a page of <a href='Team'>Team</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class TeamPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private Team[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of teams contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public Team[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a href='Team'>Team</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeactivateTeams))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateTeams))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class TeamAction {
	}


	/// <summary>The action used for deactivating <a href='Team'>Team</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeactivateTeams : TeamAction {
	}


	/// <summary>The action used for activating <a href='Team'>Team</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateTeams : TeamAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface TeamServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.TeamServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating, updating, and retrieving <a href='Team'>Team</a>
	/// objects. <p>Teams are used to group users in order to define access to entities
	/// such as companies, inventory and orders.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class TeamService : AdManagerSoapClient<ITeamService>, ITeamService {
		/// <summary> Creates a new instance of the <see cref="TeamService"/> class.
		/// </summary>
		public TeamService() {
		}

		/// <summary> Creates a new instance of the <see cref="TeamService"/> class.
		/// </summary>
		public TeamService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="TeamService"/> class.
		/// </summary>
		public TeamService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="TeamService"/> class.
		/// </summary>
		public TeamService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="TeamService"/> class.
		/// </summary>
		public TeamService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.TeamService.createTeamsResponse Google.Api.Ads.AdManager.v201802.TeamServiceInterface.createTeams(Wrappers.TeamService.createTeamsRequest request) {
			return base.Channel.createTeams(request);
		}

		/// <summary>Creates new <a href='Team'>Team</a> objects. The following fields are required:
		/// <ul> <li><a href='Team#name'>Team#name</a></li> </ul>
		/// </summary><param name='teams'>the teams to create</param>
		/// <returns>the created teams with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Team[] createTeams(Google.Api.Ads.AdManager.v201802.Team[] teams) {
			Wrappers.TeamService.createTeamsRequest inValue = new Wrappers.TeamService.createTeamsRequest();
			inValue.teams = teams;
			Wrappers.TeamService.createTeamsResponse retVal = ((Google.Api.Ads.AdManager.v201802.TeamServiceInterface)(this)).createTeams(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.TeamService.createTeamsResponse> Google.Api.Ads.AdManager.v201802.TeamServiceInterface.createTeamsAsync(Wrappers.TeamService.createTeamsRequest request) {
			return base.Channel.createTeamsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Team[]> createTeamsAsync(Google.Api.Ads.AdManager.v201802.Team[] teams) {
			Wrappers.TeamService.createTeamsRequest inValue = new Wrappers.TeamService.createTeamsRequest();
			inValue.teams = teams;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Team[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.TeamServiceInterface)(this)).createTeamsAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <code>TeamPage</code> of <code>Team</code> objects that satisfy the given
		/// <a href='Statement#query'>Statement#query</a>. The following fields are
		/// supported for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='Team#id'>Team#id</a></td> </tr> <tr> <td><code>name</code></td> <td><a
		/// href='Team#name'>Team#name</a></td> </tr> <tr> <td><code>description</code></td>
		/// <td><a href='Team#description'>Team#description</a></td> </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of teams.</param>
		/// <returns>the teams that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.TeamPage getTeamsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getTeamsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.TeamPage> getTeamsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getTeamsByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='Team'>Team</a> objects that match the given <a
		/// href='Statement#query'>Statement#query</a>.
		/// </summary><param name='teamAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of teams</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performTeamAction(Google.Api.Ads.AdManager.v201802.TeamAction teamAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performTeamAction(teamAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performTeamActionAsync(Google.Api.Ads.AdManager.v201802.TeamAction teamAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performTeamActionAsync(teamAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.TeamService.updateTeamsResponse Google.Api.Ads.AdManager.v201802.TeamServiceInterface.updateTeams(Wrappers.TeamService.updateTeamsRequest request) {
			return base.Channel.updateTeams(request);
		}

		/// <summary>Updates the specified <a href='Team'>Team</a> objects.
		/// </summary><param name='teams'>the teams to update</param>
		/// <returns>the updated teams</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Team[] updateTeams(Google.Api.Ads.AdManager.v201802.Team[] teams) {
			Wrappers.TeamService.updateTeamsRequest inValue = new Wrappers.TeamService.updateTeamsRequest();
			inValue.teams = teams;
			Wrappers.TeamService.updateTeamsResponse retVal = ((Google.Api.Ads.AdManager.v201802.TeamServiceInterface)(this)).updateTeams(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.TeamService.updateTeamsResponse> Google.Api.Ads.AdManager.v201802.TeamServiceInterface.updateTeamsAsync(Wrappers.TeamService.updateTeamsRequest request) {
			return base.Channel.updateTeamsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Team[]> updateTeamsAsync(Google.Api.Ads.AdManager.v201802.Team[] teams) {
			Wrappers.TeamService.updateTeamsRequest inValue = new Wrappers.TeamService.updateTeamsRequest();
			inValue.teams = teams;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Team[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.TeamServiceInterface)(this)).updateTeamsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.UserService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createUsers", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createUsersRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("users")]
			public Google.Api.Ads.AdManager.v201802.User[] users;

			/// <summary> Creates a new instance of the <see cref="createUsersRequest"/> class.
			/// </summary>
			public createUsersRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createUsersRequest"/> class.
			/// </summary>
			public createUsersRequest(Google.Api.Ads.AdManager.v201802.User[] users) {
				this.users = users;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createUsersResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createUsersResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.User[] rval;

			/// <summary> Creates a new instance of the <see cref="createUsersResponse"/> class.
			/// </summary>
			public createUsersResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createUsersResponse"/> class.
			/// </summary>
			public createUsersResponse(Google.Api.Ads.AdManager.v201802.User[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "getAllRoles", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class getAllRolesRequest {
			/// <summary> Creates a new instance of the <see cref="getAllRolesRequest"/> class.
			/// </summary>
			public getAllRolesRequest() {
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "getAllRolesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class getAllRolesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Role[] rval;

			/// <summary> Creates a new instance of the <see cref="getAllRolesResponse"/> class.
			/// </summary>
			public getAllRolesResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="getAllRolesResponse"/> class.
			/// </summary>
			public getAllRolesResponse(Google.Api.Ads.AdManager.v201802.Role[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateUsers", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateUsersRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("users")]
			public Google.Api.Ads.AdManager.v201802.User[] users;

			/// <summary> Creates a new instance of the <see cref="updateUsersRequest"/> class.
			/// </summary>
			public updateUsersRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updateUsersRequest"/> class.
			/// </summary>
			public updateUsersRequest(Google.Api.Ads.AdManager.v201802.User[] users) {
				this.users = users;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateUsersResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateUsersResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.User[] rval;

			/// <summary> Creates a new instance of the <see cref="updateUsersResponse"/> class.
			/// </summary>
			public updateUsersResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updateUsersResponse"/> class.
			/// </summary>
			public updateUsersResponse(Google.Api.Ads.AdManager.v201802.User[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>The <code>UserRecord</code> represents the base class from which a
	/// <code>User</code> is derived.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(User))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UserRecord {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private string emailField;

		private long roleIdField;

		private bool roleIdFieldSpecified;

		private string roleNameField;

		/// <summary>The unique ID of the <code>User</code>. This attribute is readonly and is
		/// assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the <code>User</code>. It has a maximum length of 128 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The email or login of the <code>User</code>. In order to create a new user, you
		/// must already have a <a
		/// href="https://www.google.com/accounts/ManageAccount">Google Account</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string email {
			get {
				return this.emailField;
			}
			set {
				this.emailField = value;
			}
		}

		/// <summary>The unique role ID of the <code>User</code>. Roles that are created by Google
		/// will have negative IDs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public long roleId {
			get {
				return this.roleIdField;
			}
			set {
				this.roleIdField = value;
				this.roleIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="roleId" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool roleIdSpecified {
			get {
				return this.roleIdFieldSpecified;
			}
			set {
				this.roleIdFieldSpecified = value;
			}
		}

		/// <summary>The name of the role assigned to the <code>User</code>. This attribute is
		/// readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string roleName {
			get {
				return this.roleNameField;
			}
			set {
				this.roleNameField = value;
			}
		}
	}


	/// <summary>Represents a user of the system. <p>Users may be assigned at most one <a
	/// href='Role'>Role</a> per network. Each role provides a user with permissions to
	/// perform specific operations. Without a role, they will not be able to perform
	/// any actions.</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class User : UserRecord {
		private bool isActiveField;

		private bool isActiveFieldSpecified;

		private bool isEmailNotificationAllowedField;

		private bool isEmailNotificationAllowedFieldSpecified;

		private string externalIdField;

		private bool isServiceAccountField;

		private bool isServiceAccountFieldSpecified;

		private string ordersUiLocalTimeZoneIdField;

		/// <summary>Specifies whether or not the <code>User</code> is active. An inactive user
		/// cannot log in to the system or perform any operations. This attribute is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public bool isActive {
			get {
				return this.isActiveField;
			}
			set {
				this.isActiveField = value;
				this.isActiveSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isActive"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isActiveSpecified {
			get {
				return this.isActiveFieldSpecified;
			}
			set {
				this.isActiveFieldSpecified = value;
			}
		}

		/// <summary>Specifies whether or not the <code>User</code> wants to permit the Publisher
		/// Display Ads system to send email notifications to his or her email address. This
		/// attribute is optional and defaults to <code>true</code>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public bool isEmailNotificationAllowed {
			get {
				return this.isEmailNotificationAllowedField;
			}
			set {
				this.isEmailNotificationAllowedField = value;
				this.isEmailNotificationAllowedSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isEmailNotificationAllowed" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isEmailNotificationAllowedSpecified {
			get {
				return this.isEmailNotificationAllowedFieldSpecified;
			}
			set {
				this.isEmailNotificationAllowedFieldSpecified = value;
			}
		}

		/// <summary>An identifier for the <code>User</code> that is meaningful to the publisher.
		/// This attribute is optional and has a maximum length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string externalId {
			get {
				return this.externalIdField;
			}
			set {
				this.externalIdField = value;
			}
		}

		/// <summary>Whether the user is an OAuth2 service account user. This attribute is read-only.
		/// Service account users can only be added through the UI.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public bool isServiceAccount {
			get {
				return this.isServiceAccountField;
			}
			set {
				this.isServiceAccountField = value;
				this.isServiceAccountSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="isServiceAccount" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isServiceAccountSpecified {
			get {
				return this.isServiceAccountFieldSpecified;
			}
			set {
				this.isServiceAccountFieldSpecified = value;
			}
		}

		/// <summary>The long format timezone id (e.g. "America/Los_Angeles") used in the orders and
		/// line items UI for this <code>User</code>. Set this to <code>null</code> to
		/// indicate that no such value is defined for the <code>User</code> - UI then
		/// defaults to using the Network's timezone. This setting only affects the UI for
		/// this user and does not in particular affect the timezone of any dates and times
		/// returned in API responses.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string ordersUiLocalTimeZoneId {
			get {
				return this.ordersUiLocalTimeZoneIdField;
			}
			set {
				this.ordersUiLocalTimeZoneIdField = value;
			}
		}
	}


	/// <summary>An error for an exception that occurred when using a token.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class TokenError : ApiError {
		private TokenErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public TokenErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "TokenError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum TokenErrorReason {
		INVALID = 0,
		EXPIRED = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.UserServiceInterface")]
	public interface UserServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(UserRecord))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.UserService.createUsersResponse createUsers(Wrappers.UserService.createUsersRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.UserService.createUsersResponse> createUsersAsync(Wrappers.UserService.createUsersRequest request);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(UserRecord))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.UserService.getAllRolesResponse getAllRoles(Wrappers.UserService.getAllRolesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.UserService.getAllRolesResponse> getAllRolesAsync(Wrappers.UserService.getAllRolesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(UserRecord))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.User getCurrentUser();

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.User> getCurrentUserAsync();

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(UserRecord))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UserPage getUsersByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UserPage> getUsersByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(UserRecord))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performUserAction(Google.Api.Ads.AdManager.v201802.UserAction userAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performUserActionAsync(Google.Api.Ads.AdManager.v201802.UserAction userAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(UserRecord))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.UserService.updateUsersResponse updateUsers(Wrappers.UserService.updateUsersRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.UserService.updateUsersResponse> updateUsersAsync(Wrappers.UserService.updateUsersRequest request);
	}


	/// <summary>Each <code>Role</code> provides a user with permissions to perform specific
	/// operations in the system.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Role {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private string descriptionField;

		private RoleStatus statusField;

		private bool statusFieldSpecified;

		/// <summary>The unique ID of the role. This value is readonly and is assigned by Google.
		/// Roles that are created by Google will have negative IDs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the role. This value is readonly and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The description of the role. This value is readonly and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string description {
			get {
				return this.descriptionField;
			}
			set {
				this.descriptionField = value;
			}
		}

		/// <summary>The status of the <a href='Role'>Role</a>. This field is read-only and can have
		/// the values <a href='RoleStatus#ACTIVE'>RoleStatus#ACTIVE</a> (default) or <a
		/// href='RoleStatus#INACTIVE'>RoleStatus#INACTIVE</a>, which determines the
		/// visibility of the role in the UI.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public RoleStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents the status of the role, weather the role is active or inactive.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum RoleStatus {
		/// <summary>The status of an active role. (i.e. visible in the UI)
		/// </summary>
		ACTIVE = 0,
		/// <summary>The status of an inactive role. (i.e. hidden in the UI)
		/// </summary>
		INACTIVE = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Captures a page of <a href='User'>User</a> objects
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UserPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private User[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of users contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public User[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a href='User'>User</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeactivateUsers))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateUsers))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class UserAction {
	}


	/// <summary>The action used for deactivating <a href='User'>User</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeactivateUsers : UserAction {
	}


	/// <summary>The action used for activating <a href='User'>User</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateUsers : UserAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface UserServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.UserServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides operations for creating, updating and retrieving <a
	/// href='User'>User</a> objects. <p>A user is assigned one of several different
	/// roles. Each <a href='Role'>Role</a> type has a unique ID that is used to
	/// identify that role in an organization. Role types and their IDs can be retrieved
	/// by invoking <a href='#getAllRoles'>#getAllRoles</a>.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class UserService : AdManagerSoapClient<IUserService>, IUserService {
		/// <summary> Creates a new instance of the <see cref="UserService"/> class.
		/// </summary>
		public UserService() {
		}

		/// <summary> Creates a new instance of the <see cref="UserService"/> class.
		/// </summary>
		public UserService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="UserService"/> class.
		/// </summary>
		public UserService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="UserService"/> class.
		/// </summary>
		public UserService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="UserService"/> class.
		/// </summary>
		public UserService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.UserService.createUsersResponse Google.Api.Ads.AdManager.v201802.UserServiceInterface.createUsers(Wrappers.UserService.createUsersRequest request) {
			return base.Channel.createUsers(request);
		}

		/// <summary>Creates new <a href='User'>User</a> objects.
		/// </summary><param name='users'>the users to create</param>
		/// <returns>the created users with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.User[] createUsers(Google.Api.Ads.AdManager.v201802.User[] users) {
			Wrappers.UserService.createUsersRequest inValue = new Wrappers.UserService.createUsersRequest();
			inValue.users = users;
			Wrappers.UserService.createUsersResponse retVal = ((Google.Api.Ads.AdManager.v201802.UserServiceInterface)(this)).createUsers(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.UserService.createUsersResponse> Google.Api.Ads.AdManager.v201802.UserServiceInterface.createUsersAsync(Wrappers.UserService.createUsersRequest request) {
			return base.Channel.createUsersAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.User[]> createUsersAsync(Google.Api.Ads.AdManager.v201802.User[] users) {
			Wrappers.UserService.createUsersRequest inValue = new Wrappers.UserService.createUsersRequest();
			inValue.users = users;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.User[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.UserServiceInterface)(this)).createUsersAsync(inValue)).Result.rval);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.UserService.getAllRolesResponse Google.Api.Ads.AdManager.v201802.UserServiceInterface.getAllRoles(Wrappers.UserService.getAllRolesRequest request) {
			return base.Channel.getAllRoles(request);
		}

		/// <summary>Returns the <a href='Role'>Role</a> objects that are defined for the users of
		/// the network.
		/// </summary><returns>the roles defined for the user's network</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Role[] getAllRoles() {
			Wrappers.UserService.getAllRolesRequest inValue = new Wrappers.UserService.getAllRolesRequest();
			Wrappers.UserService.getAllRolesResponse retVal = ((Google.Api.Ads.AdManager.v201802.UserServiceInterface)(this)).getAllRoles(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.UserService.getAllRolesResponse> Google.Api.Ads.AdManager.v201802.UserServiceInterface.getAllRolesAsync(Wrappers.UserService.getAllRolesRequest request) {
			return base.Channel.getAllRolesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Role[]> getAllRolesAsync() {
			Wrappers.UserService.getAllRolesRequest inValue = new Wrappers.UserService.getAllRolesRequest();
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Role[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.UserServiceInterface)(this)).getAllRolesAsync(inValue)).Result.rval);
		}

		/// <summary>Returns the current <a href='User'>User</a>.
		/// </summary><returns>the current user</returns>
		public virtual Google.Api.Ads.AdManager.v201802.User getCurrentUser() {
			return base.Channel.getCurrentUser();
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.User> getCurrentUserAsync() {
			return base.Channel.getCurrentUserAsync();
		}

		/// <summary>Gets a <a href='UserPage'>UserPage</a> of <a href='User'>User</a> objects that
		/// satisfy the given <a href='Statement#query'>Statement#query</a>. The following
		/// fields are supported for filtering: <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>email</code></td> <td><a href='User#email'>User#email</a></td> </tr>
		/// <tr> <td><code>id</code></td> <td><a href='User#id'>User#id</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a href='User#name'>User#name</a></td> </tr> <tr>
		/// <td><code>roleId</code></td> <td><a href='User#roleId'>User#roleId</a> </td>
		/// </tr> <tr> <td><code>rolename</code></td> <td><a
		/// href='User#roleName'>User#roleName</a> </td> </tr> <tr>
		/// <td><code>status</code></td> <td><code>ACTIVE</code> if <a
		/// href='User#isActive'>User#isActive</a> is true; <code>INACTIVE</code>
		/// otherwise</td> </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of users</param>
		/// <returns>the users that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UserPage getUsersByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getUsersByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UserPage> getUsersByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getUsersByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='User'>User</a> objects that match the given <a
		/// href='Statement#query'>Statement#query</a>.
		/// </summary><param name='userAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of users</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performUserAction(Google.Api.Ads.AdManager.v201802.UserAction userAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performUserAction(userAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performUserActionAsync(Google.Api.Ads.AdManager.v201802.UserAction userAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performUserActionAsync(userAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.UserService.updateUsersResponse Google.Api.Ads.AdManager.v201802.UserServiceInterface.updateUsers(Wrappers.UserService.updateUsersRequest request) {
			return base.Channel.updateUsers(request);
		}

		/// <summary>Updates the specified <a href='User'>User</a> objects.
		/// </summary><param name='users'>the users to update</param>
		/// <returns>the updated users</returns>
		public virtual Google.Api.Ads.AdManager.v201802.User[] updateUsers(Google.Api.Ads.AdManager.v201802.User[] users) {
			Wrappers.UserService.updateUsersRequest inValue = new Wrappers.UserService.updateUsersRequest();
			inValue.users = users;
			Wrappers.UserService.updateUsersResponse retVal = ((Google.Api.Ads.AdManager.v201802.UserServiceInterface)(this)).updateUsers(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.UserService.updateUsersResponse> Google.Api.Ads.AdManager.v201802.UserServiceInterface.updateUsersAsync(Wrappers.UserService.updateUsersRequest request) {
			return base.Channel.updateUsersAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.User[]> updateUsersAsync(Google.Api.Ads.AdManager.v201802.User[] users) {
			Wrappers.UserService.updateUsersRequest inValue = new Wrappers.UserService.updateUsersRequest();
			inValue.users = users;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.User[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.UserServiceInterface)(this)).updateUsersAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.UserTeamAssociationService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createUserTeamAssociations", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createUserTeamAssociationsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("userTeamAssociations")]
			public Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] userTeamAssociations;

			/// <summary> Creates a new instance of the <see
			/// cref="createUserTeamAssociationsRequest"/> class. </summary>
			public createUserTeamAssociationsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createUserTeamAssociationsRequest"/> class. </summary>
			public createUserTeamAssociationsRequest(Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] userTeamAssociations) {
				this.userTeamAssociations = userTeamAssociations;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createUserTeamAssociationsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createUserTeamAssociationsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createUserTeamAssociationsResponse"/> class. </summary>
			public createUserTeamAssociationsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createUserTeamAssociationsResponse"/> class. </summary>
			public createUserTeamAssociationsResponse(Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateUserTeamAssociations", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateUserTeamAssociationsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("userTeamAssociations")]
			public Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] userTeamAssociations;

			/// <summary> Creates a new instance of the <see
			/// cref="updateUserTeamAssociationsRequest"/> class. </summary>
			public updateUserTeamAssociationsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateUserTeamAssociationsRequest"/> class. </summary>
			public updateUserTeamAssociationsRequest(Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] userTeamAssociations) {
				this.userTeamAssociations = userTeamAssociations;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateUserTeamAssociationsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateUserTeamAssociationsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateUserTeamAssociationsResponse"/> class. </summary>
			public updateUserTeamAssociationsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateUserTeamAssociationsResponse"/> class. </summary>
			public updateUserTeamAssociationsResponse(Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary><code>UserRecordTeamAssociation</code> represents the association between a <a
	/// href='UserRecord'>UserRecord</a> and a <a href='Team'>Team</a>.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UserTeamAssociation))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class UserRecordTeamAssociation {
		private long teamIdField;

		private bool teamIdFieldSpecified;

		private TeamAccessType overriddenTeamAccessTypeField;

		private bool overriddenTeamAccessTypeFieldSpecified;

		private TeamAccessType defaultTeamAccessTypeField;

		private bool defaultTeamAccessTypeFieldSpecified;

		/// <summary>The <a href='Team#id'>Team#id</a> of the team.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long teamId {
			get {
				return this.teamIdField;
			}
			set {
				this.teamIdField = value;
				this.teamIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="teamId" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool teamIdSpecified {
			get {
				return this.teamIdFieldSpecified;
			}
			set {
				this.teamIdFieldSpecified = value;
			}
		}

		/// <summary>The overridden team access type. This field is <code>null</code> if team access
		/// type is not overridden.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public TeamAccessType overriddenTeamAccessType {
			get {
				return this.overriddenTeamAccessTypeField;
			}
			set {
				this.overriddenTeamAccessTypeField = value;
				this.overriddenTeamAccessTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="overriddenTeamAccessType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool overriddenTeamAccessTypeSpecified {
			get {
				return this.overriddenTeamAccessTypeFieldSpecified;
			}
			set {
				this.overriddenTeamAccessTypeFieldSpecified = value;
			}
		}

		/// <summary>The default team access type <a
		/// href='Team#teamAccessType'>Team#teamAccessType</a>. This field is read-only and
		/// is populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public TeamAccessType defaultTeamAccessType {
			get {
				return this.defaultTeamAccessTypeField;
			}
			set {
				this.defaultTeamAccessTypeField = value;
				this.defaultTeamAccessTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="defaultTeamAccessType" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool defaultTeamAccessTypeSpecified {
			get {
				return this.defaultTeamAccessTypeFieldSpecified;
			}
			set {
				this.defaultTeamAccessTypeFieldSpecified = value;
			}
		}
	}


	/// <summary><code>UserTeamAssociation</code> associates a <a href='User'>User</a> with a <a
	/// href='Team'>Team</a> to provide the user access to the entities that belong to
	/// the team.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UserTeamAssociation : UserRecordTeamAssociation {
		private long userIdField;

		private bool userIdFieldSpecified;

		/// <summary>Refers to the <a href='User#id'>User#id</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long userId {
			get {
				return this.userIdField;
			}
			set {
				this.userIdField = value;
				this.userIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="userId" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool userIdSpecified {
			get {
				return this.userIdFieldSpecified;
			}
			set {
				this.userIdFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.UserTeamAssociationServiceInterface")]
	public interface UserTeamAssociationServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(UserRecordTeamAssociation))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.UserTeamAssociationService.createUserTeamAssociationsResponse createUserTeamAssociations(Wrappers.UserTeamAssociationService.createUserTeamAssociationsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.UserTeamAssociationService.createUserTeamAssociationsResponse> createUserTeamAssociationsAsync(Wrappers.UserTeamAssociationService.createUserTeamAssociationsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(UserRecordTeamAssociation))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UserTeamAssociationPage getUserTeamAssociationsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UserTeamAssociationPage> getUserTeamAssociationsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(UserRecordTeamAssociation))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performUserTeamAssociationAction(Google.Api.Ads.AdManager.v201802.UserTeamAssociationAction userTeamAssociationAction, Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performUserTeamAssociationActionAsync(Google.Api.Ads.AdManager.v201802.UserTeamAssociationAction userTeamAssociationAction, Google.Api.Ads.AdManager.v201802.Statement statement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(UserRecordTeamAssociation))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.UserTeamAssociationService.updateUserTeamAssociationsResponse updateUserTeamAssociations(Wrappers.UserTeamAssociationService.updateUserTeamAssociationsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.UserTeamAssociationService.updateUserTeamAssociationsResponse> updateUserTeamAssociationsAsync(Wrappers.UserTeamAssociationService.updateUserTeamAssociationsRequest request);
	}


	/// <summary>Captures a page of <a href='UserTeamAssociation'>UserTeamAssociation</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UserTeamAssociationPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private UserTeamAssociation[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of user team associations contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public UserTeamAssociation[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a
	/// href='UserTeamAssociation'>UserTeamAssociation</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeleteUserTeamAssociations))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class UserTeamAssociationAction {
	}


	/// <summary>Action to delete the association between a <a href='User'>User</a> and a <a
	/// href='Team'>Team</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeleteUserTeamAssociations : UserTeamAssociationAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface UserTeamAssociationServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.UserTeamAssociationServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating, updating, and retrieving <a
	/// href='UserTeamAssociation'>UserTeamAssociation</a> objects.
	/// <p>UserTeamAssociation objects are used to add users to teams in order to define
	/// access to entities such as companies, inventory and orders and to override the
	/// team's access type to orders for a user.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class UserTeamAssociationService : AdManagerSoapClient<IUserTeamAssociationService>, IUserTeamAssociationService {
		/// <summary> Creates a new instance of the <see cref="UserTeamAssociationService"/>
		/// class. </summary>
		public UserTeamAssociationService() {
		}

		/// <summary> Creates a new instance of the <see cref="UserTeamAssociationService"/>
		/// class. </summary>
		public UserTeamAssociationService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="UserTeamAssociationService"/>
		/// class. </summary>
		public UserTeamAssociationService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="UserTeamAssociationService"/>
		/// class. </summary>
		public UserTeamAssociationService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="UserTeamAssociationService"/>
		/// class. </summary>
		public UserTeamAssociationService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.UserTeamAssociationService.createUserTeamAssociationsResponse Google.Api.Ads.AdManager.v201802.UserTeamAssociationServiceInterface.createUserTeamAssociations(Wrappers.UserTeamAssociationService.createUserTeamAssociationsRequest request) {
			return base.Channel.createUserTeamAssociations(request);
		}

		/// <summary>Creates new <a href='UserTeamAssociation'>UserTeamAssociation</a> objects.
		/// </summary><param name='userTeamAssociations'>the user team associations to create</param>
		/// <returns>the created user team associations with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] createUserTeamAssociations(Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] userTeamAssociations) {
			Wrappers.UserTeamAssociationService.createUserTeamAssociationsRequest inValue = new Wrappers.UserTeamAssociationService.createUserTeamAssociationsRequest();
			inValue.userTeamAssociations = userTeamAssociations;
			Wrappers.UserTeamAssociationService.createUserTeamAssociationsResponse retVal = ((Google.Api.Ads.AdManager.v201802.UserTeamAssociationServiceInterface)(this)).createUserTeamAssociations(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.UserTeamAssociationService.createUserTeamAssociationsResponse> Google.Api.Ads.AdManager.v201802.UserTeamAssociationServiceInterface.createUserTeamAssociationsAsync(Wrappers.UserTeamAssociationService.createUserTeamAssociationsRequest request) {
			return base.Channel.createUserTeamAssociationsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UserTeamAssociation[]> createUserTeamAssociationsAsync(Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] userTeamAssociations) {
			Wrappers.UserTeamAssociationService.createUserTeamAssociationsRequest inValue = new Wrappers.UserTeamAssociationService.createUserTeamAssociationsRequest();
			inValue.userTeamAssociations = userTeamAssociations;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UserTeamAssociation[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.UserTeamAssociationServiceInterface)(this)).createUserTeamAssociationsAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='UserTeamAssociationPage'>UserTeamAssociationPage</a> of <a
		/// href='UserTeamAssociation'>UserTeamAssociation</a> objects that satisfy the
		/// given <a href='Statement#query'>Statement#query</a>. The following fields are
		/// supported for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>userId</code></td> <td><a
		/// href='UserTeamAssociation#userId'>UserTeamAssociation#userId</a></td> </tr> <tr>
		/// <td><code>teamId</code></td> <td><a
		/// href='UserTeamAssociation#teamId'>UserTeamAssociation#teamId</a></td> </tr>
		/// </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of user team associations</param>
		/// <returns>the user team associations that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UserTeamAssociationPage getUserTeamAssociationsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getUserTeamAssociationsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UserTeamAssociationPage> getUserTeamAssociationsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getUserTeamAssociationsByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='UserTeamAssociation'>UserTeamAssociation</a>
		/// objects that match the given <a href='Statement#query'>Statement#query</a>.
		/// </summary><param name='userTeamAssociationAction'>the action to perform</param>
		/// <param name='statement'>a Publisher Query Language statement used to filter a
		/// set of user team associations</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performUserTeamAssociationAction(Google.Api.Ads.AdManager.v201802.UserTeamAssociationAction userTeamAssociationAction, Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.performUserTeamAssociationAction(userTeamAssociationAction, statement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performUserTeamAssociationActionAsync(Google.Api.Ads.AdManager.v201802.UserTeamAssociationAction userTeamAssociationAction, Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.performUserTeamAssociationActionAsync(userTeamAssociationAction, statement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.UserTeamAssociationService.updateUserTeamAssociationsResponse Google.Api.Ads.AdManager.v201802.UserTeamAssociationServiceInterface.updateUserTeamAssociations(Wrappers.UserTeamAssociationService.updateUserTeamAssociationsRequest request) {
			return base.Channel.updateUserTeamAssociations(request);
		}

		/// <summary>Updates the specified <a href='UserTeamAssociation'>UserTeamAssociation</a>
		/// objects.
		/// </summary><param name='userTeamAssociations'>the user team associations to update</param>
		/// <returns>the updated user team associations</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] updateUserTeamAssociations(Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] userTeamAssociations) {
			Wrappers.UserTeamAssociationService.updateUserTeamAssociationsRequest inValue = new Wrappers.UserTeamAssociationService.updateUserTeamAssociationsRequest();
			inValue.userTeamAssociations = userTeamAssociations;
			Wrappers.UserTeamAssociationService.updateUserTeamAssociationsResponse retVal = ((Google.Api.Ads.AdManager.v201802.UserTeamAssociationServiceInterface)(this)).updateUserTeamAssociations(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.UserTeamAssociationService.updateUserTeamAssociationsResponse> Google.Api.Ads.AdManager.v201802.UserTeamAssociationServiceInterface.updateUserTeamAssociationsAsync(Wrappers.UserTeamAssociationService.updateUserTeamAssociationsRequest request) {
			return base.Channel.updateUserTeamAssociationsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UserTeamAssociation[]> updateUserTeamAssociationsAsync(Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] userTeamAssociations) {
			Wrappers.UserTeamAssociationService.updateUserTeamAssociationsRequest inValue = new Wrappers.UserTeamAssociationService.updateUserTeamAssociationsRequest();
			inValue.userTeamAssociations = userTeamAssociations;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UserTeamAssociation[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.UserTeamAssociationServiceInterface)(this)).updateUserTeamAssociationsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.WorkflowRequestService
	{
	}
	/// <summary>A <code>WorkflowRequest</code> represents a workflow action unit that requires
	/// external or manual interference.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(WorkflowExternalConditionRequest))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(WorkflowApprovalRequest))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class WorkflowRequest {
		private long idField;

		private bool idFieldSpecified;

		private string workflowRuleNameField;

		private long entityIdField;

		private bool entityIdFieldSpecified;

		private WorkflowEntityType entityTypeField;

		private bool entityTypeFieldSpecified;

		private WorkflowRequestType typeField;

		private bool typeFieldSpecified;

		/// <summary>The unique ID of the workflow request. This attribute is readonly and is
		/// assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the workflow rule that generated the request. This attribute is
		/// readonly and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string workflowRuleName {
			get {
				return this.workflowRuleNameField;
			}
			set {
				this.workflowRuleNameField = value;
			}
		}

		/// <summary>The ID of entity associated to this workflow request.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public long entityId {
			get {
				return this.entityIdField;
			}
			set {
				this.entityIdField = value;
				this.entityIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="entityId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool entityIdSpecified {
			get {
				return this.entityIdFieldSpecified;
			}
			set {
				this.entityIdFieldSpecified = value;
			}
		}

		/// <summary>The <a href='WorkflowEntityType'>WorkflowEntityType</a> associated to this
		/// workflow request.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public WorkflowEntityType entityType {
			get {
				return this.entityTypeField;
			}
			set {
				this.entityTypeField = value;
				this.entityTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="entityType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool entityTypeSpecified {
			get {
				return this.entityTypeFieldSpecified;
			}
			set {
				this.entityTypeFieldSpecified = value;
			}
		}

		/// <summary>The <a href='WorkflowRequestType'>WorkflowRequestType</a> of this workflow
		/// request. This attribute is readonly and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public WorkflowRequestType type {
			get {
				return this.typeField;
			}
			set {
				this.typeField = value;
				this.typeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="type" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool typeSpecified {
			get {
				return this.typeFieldSpecified;
			}
			set {
				this.typeFieldSpecified = value;
			}
		}
	}


	/// <summary>The entity types that workflows can be applied to.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum WorkflowEntityType {
		/// <summary>Represents a <a href='Proposal'>Proposal</a>.
		/// </summary>
		PROPOSAL = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	/// <summary>Types of a workflow request.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum WorkflowRequestType {
		/// <summary>This is a request for an approval action. Either by a frontend user or an API
		/// request.
		/// </summary>
		WORKFLOW_APPROVAL_REQUEST = 0,
		/// <summary>This is an external condition request. It is pending an external system to
		/// determine whether an action should trigger or not.
		/// </summary>
		WORKFLOW_EXTERNAL_CONDITION_REQUEST = 1,
		UNKNOWN = 2,
	}


	/// <summary>A <code>WorkflowExternalConditionRequest</code> represents a workflow condition
	/// that requires external system to determine the result.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class WorkflowExternalConditionRequest : WorkflowRequest {
		private WorkflowEvaluationStatus statusField;

		private bool statusFieldSpecified;

		/// <summary>The status of the <code>WorkflowExternalConditionRequest</code>. This attribute
		/// is readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public WorkflowEvaluationStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}
	}


	/// <summary>A <code>WorkflowApprovalRequest</code> represents a workflow action unit that
	/// requires user approval.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class WorkflowApprovalRequest : WorkflowRequest {
		private WorkflowApprovalRequestStatus statusField;

		private bool statusFieldSpecified;

		/// <summary>The status of the <code>WorkflowApprovalRequest</code>. This attribute is
		/// readonly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public WorkflowApprovalRequestStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}
	}


	/// <summary>Captures a page of <a href='WorkflowRequest'>WorkflowRequest</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class WorkflowRequestPage {
		private WorkflowRequest[] resultsField;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		/// <summary>The collection of workflow requests contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 0)]
		public WorkflowRequest[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}
	}


	/// <summary>Lists errors associated with <a href='WorkflowRequest'>workflow requests</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class WorkflowRequestError : ApiError {
		private WorkflowRequestErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public WorkflowRequestErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "WorkflowRequestError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum WorkflowRequestErrorReason {
		/// <summary>The request has already been processed.
		/// </summary>
		REQUEST_ALREADY_PROCESSED = 0,
		/// <summary>The workflow is not in progress.
		/// </summary>
		WORKFLOW_NOT_IN_PROGRESS = 1,
		/// <summary>The request ID is invalid.
		/// </summary>
		INVALID_REQUEST_ID = 2,
		/// <summary>The action could not be performed on a request of that type.
		/// </summary>
		INVALID_ACTION = 3,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 5,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.WorkflowRequestServiceInterface")]
	public interface WorkflowRequestServiceInterface
	{
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.WorkflowRequestPage getWorkflowRequestsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.WorkflowRequestPage> getWorkflowRequestsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performWorkflowRequestAction(Google.Api.Ads.AdManager.v201802.WorkflowRequestAction action, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performWorkflowRequestActionAsync(Google.Api.Ads.AdManager.v201802.WorkflowRequestAction action, Google.Api.Ads.AdManager.v201802.Statement filterStatement);
	}


	/// <summary>Represents the actions that can be performed on <a
	/// href='WorkflowRequest'>WorkflowRequest</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RejectWorkflowApprovalRequests))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(TriggerWorkflowExternalConditionRequests))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SkipWorkflowExternalConditionRequests))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ApproveWorkflowApprovalRequests))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class WorkflowRequestAction {
	}


	/// <summary>The action used to reject <a href='WorkflowApprovalRequest'>workflow approval
	/// requests</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RejectWorkflowApprovalRequests : WorkflowRequestAction {
		private string commentField;

		/// <summary>The comment of the <a
		/// href='RejectWorkflowApprovalRequests'>RejectWorkflowApprovalRequests</a> action.
		/// This field is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string comment {
			get {
				return this.commentField;
			}
			set {
				this.commentField = value;
			}
		}
	}


	/// <summary>The action to trigger <a href='WorkflowExternalConditionRequest'>workflow
	/// external condition requests</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class TriggerWorkflowExternalConditionRequests : WorkflowRequestAction {
	}


	/// <summary>The action to skip <a href='WorkflowExternalConditionRequest'>workflow external
	/// condition requests</a>. Doing so means that the rule did not trigger.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SkipWorkflowExternalConditionRequests : WorkflowRequestAction {
	}


	/// <summary>The action used to approve <a href='WorkflowApprovalRequest'>workflow approval
	/// requests</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ApproveWorkflowApprovalRequests : WorkflowRequestAction {
		private string commentField;

		/// <summary>The comment of the <a
		/// href='ApproveWorkflowApprovalRequests'>ApproveWorkflowApprovalRequests</a>
		/// action. This field is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string comment {
			get {
				return this.commentField;
			}
			set {
				this.commentField = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface WorkflowRequestServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.WorkflowRequestServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods to retrieve and perform actions on <a
	/// href='WorkflowRequest'>WorkflowRequest</a> objects <p>To use this service, you
	/// need to have the new sales management solution enabled on your network. If you
	/// do not see a "Sales" tab in <a href="https://www.google.com/dfp">DoubleClick for
	/// Publishers (DFP)</a>, you will not be able to use this service.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class WorkflowRequestService : AdManagerSoapClient<IWorkflowRequestService>, IWorkflowRequestService {
		/// <summary> Creates a new instance of the <see cref="WorkflowRequestService"/>
		/// class. </summary>
		public WorkflowRequestService() {
		}

		/// <summary> Creates a new instance of the <see cref="WorkflowRequestService"/>
		/// class. </summary>
		public WorkflowRequestService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="WorkflowRequestService"/>
		/// class. </summary>
		public WorkflowRequestService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="WorkflowRequestService"/>
		/// class. </summary>
		public WorkflowRequestService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="WorkflowRequestService"/>
		/// class. </summary>
		public WorkflowRequestService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		/// <summary>Gets a list of <a href='WorkflowRequest'>WorkflowRequest</a> objects that
		/// satisfy the given <a href='Statement#query'>Statement#query</a>. The following
		/// fields are supported for filtering: <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>id</code></td> <td><a
		/// href='WorkflowRequest#id'>WorkflowRequest#id</a></td> </tr> <tr>
		/// <td><code>workflowRuleName</code></td> <td><a
		/// href='WorkflowRequest#workflowRuleName'>WorkflowRequest#workflowRuleName</a></td>
		/// </tr> <tr> <td><code>entityType</code></td> <td><a
		/// href='WorkflowRequest#entityType'>WorkflowRequest#entityType</a></td> </tr> <tr>
		/// <td><code>entityId</code></td> <td><a
		/// href='WorkflowRequest#entityId'>WorkflowRequest#entityId</a></td> </tr> <tr>
		/// <td><code>approvalStatus</code></td> <td><a
		/// href='WorkflowApprovalRequest#status'>WorkflowApprovalRequest#status</a></td>
		/// </tr> <tr> <td><code>conditionStatus</code></td> <td><a
		/// href='WorkflowExternalConditionRequest#status'>WorkflowExternalConditionRequest#status</a></td>
		/// </tr> <tr> <td><code>type</code></td> <td><a
		/// href='WorkflowRequest#type'>WorkflowRequest#type</a></td> </tr> </table> <p>The
		/// <code>type</code> filter is required in v201705 and earlier. </p>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of workflow requests belonging to an entity</param>
		/// <returns>the workflow requests that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.WorkflowRequestPage getWorkflowRequestsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getWorkflowRequestsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.WorkflowRequestPage> getWorkflowRequestsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getWorkflowRequestsByStatementAsync(filterStatement);
		}

		/// <summary>Perform actions on <a href='WorkflowRequest'>WorkflowRequest</a> objects that
		/// match the given <a href='Statement#query'>Statement#query</a>.
		/// </summary><param name='action'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of workflow requests</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performWorkflowRequestAction(Google.Api.Ads.AdManager.v201802.WorkflowRequestAction action, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performWorkflowRequestAction(action, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performWorkflowRequestActionAsync(Google.Api.Ads.AdManager.v201802.WorkflowRequestAction action, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performWorkflowRequestActionAsync(action, filterStatement);
		}
	}
	namespace Wrappers.PackageService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createPackages", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createPackagesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("packages")]
			public Google.Api.Ads.AdManager.v201802.Package[] packages;

			/// <summary> Creates a new instance of the <see cref="createPackagesRequest"/>
			/// class. </summary>
			public createPackagesRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createPackagesRequest"/>
			/// class. </summary>
			public createPackagesRequest(Google.Api.Ads.AdManager.v201802.Package[] packages) {
				this.packages = packages;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createPackagesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createPackagesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Package[] rval;

			/// <summary> Creates a new instance of the <see cref="createPackagesResponse"/>
			/// class. </summary>
			public createPackagesResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createPackagesResponse"/>
			/// class. </summary>
			public createPackagesResponse(Google.Api.Ads.AdManager.v201802.Package[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updatePackages", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updatePackagesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("packages")]
			public Google.Api.Ads.AdManager.v201802.Package[] packages;

			/// <summary> Creates a new instance of the <see cref="updatePackagesRequest"/>
			/// class. </summary>
			public updatePackagesRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updatePackagesRequest"/>
			/// class. </summary>
			public updatePackagesRequest(Google.Api.Ads.AdManager.v201802.Package[] packages) {
				this.packages = packages;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updatePackagesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updatePackagesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Package[] rval;

			/// <summary> Creates a new instance of the <see cref="updatePackagesResponse"/>
			/// class. </summary>
			public updatePackagesResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updatePackagesResponse"/>
			/// class. </summary>
			public updatePackagesResponse(Google.Api.Ads.AdManager.v201802.Package[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>A <code>Package</code> represents a group of proposal line items which will be
	/// sold together.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Package {
		private long idField;

		private bool idFieldSpecified;

		private long proposalIdField;

		private bool proposalIdFieldSpecified;

		private long productPackageIdField;

		private bool productPackageIdFieldSpecified;

		private long rateCardIdField;

		private bool rateCardIdFieldSpecified;

		private string nameField;

		private string commentsField;

		private PackageStatus statusField;

		private bool statusFieldSpecified;

		private DateTime startDateTimeField;

		private DateTime endDateTimeField;

		private DateTime lastModifiedDateTimeField;

		/// <summary>The unique ID of the <code>Package</code>. <p>This attribute is read-only and is
		/// assigned by Google.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The unique ID of the <a href='Proposal'>Proposal</a>, to which the
		/// <code>Package</code> belongs. <p>This attribute is required for creation and
		/// then is read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long proposalId {
			get {
				return this.proposalIdField;
			}
			set {
				this.proposalIdField = value;
				this.proposalIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="proposalId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool proposalIdSpecified {
			get {
				return this.proposalIdFieldSpecified;
			}
			set {
				this.proposalIdFieldSpecified = value;
			}
		}

		/// <summary>The unique ID of the <a href='ProductPackage'>ProductPackage</a>, from which the
		/// <code>Package</code> is created. <p>This attribute is required for creation and
		/// then is read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public long productPackageId {
			get {
				return this.productPackageIdField;
			}
			set {
				this.productPackageIdField = value;
				this.productPackageIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="productPackageId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool productPackageIdSpecified {
			get {
				return this.productPackageIdFieldSpecified;
			}
			set {
				this.productPackageIdFieldSpecified = value;
			}
		}

		/// <summary>The unique ID of the <a href='RateCard'>RateCard</a>, based on which the
		/// <code>ProposalLineItem</code> objects in the <code>Package</code> are priced.
		/// <p>This attribute is required for creation of associated <code></code> objects
		/// and then is read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public long rateCardId {
			get {
				return this.rateCardIdField;
			}
			set {
				this.rateCardIdField = value;
				this.rateCardIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="rateCardId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool rateCardIdSpecified {
			get {
				return this.rateCardIdFieldSpecified;
			}
			set {
				this.rateCardIdFieldSpecified = value;
			}
		}

		/// <summary>The name of the <code>Package</code> which should be unique under the same <a
		/// href='Proposal'>Proposal</a>. <p>This attribute is required and has a maximum
		/// length of 255 characters.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>Provides any additional comments that may annotate the <code></code>. <p>This
		/// attribute is optional and has a maximum length of 65,535 characters.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public string comments {
			get {
				return this.commentsField;
			}
			set {
				this.commentsField = value;
			}
		}

		/// <summary>This field specifies the status of the <code>Package</code>, whether the <a
		/// href='ProposalLineItem'>ProposalLineItem</a> objects belonging to the
		/// <code>Package</code> have been created. <p>This attribute is read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public PackageStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>The date and time at which the order and line items associated with the
		/// <code>Package</code> are eligible to begin serving. <p>This attribute is
		/// read-only and is derived from the earliest <a
		/// href='ProposalLineItem#startDateTime'>ProposalLineItem#startDateTime</a> of <a
		/// href='ProposalLineItem'>ProposalLineItem</a> objects belonging to this
		/// package.</p> <p>This attribute will be null, if this package has no related line
		/// items, or none of its line items have a start time.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public DateTime startDateTime {
			get {
				return this.startDateTimeField;
			}
			set {
				this.startDateTimeField = value;
			}
		}

		/// <summary>The date and time at which the order and line items associated with the
		/// <code>Package</code> stop being served. <p>This attribute is read-only and is
		/// derived from the latest <a
		/// href='ProposalLineItem#endDateTime'>ProposalLineItem#endDateTime</a> of <a
		/// href='ProposalLineItem'>ProposalLineItem</a> objects belonging to this
		/// package.</p> <p>This attribute will be null, if this package has no related line
		/// items, or none of its line items have an end time.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public DateTime endDateTime {
			get {
				return this.endDateTimeField;
			}
			set {
				this.endDateTimeField = value;
			}
		}

		/// <summary>The date and time this <code>Package</code> was last modified. <p>This attribute
		/// is read-only and is assigned by Google when a <code>Package</code> is
		/// updated.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public DateTime lastModifiedDateTime {
			get {
				return this.lastModifiedDateTimeField;
			}
			set {
				this.lastModifiedDateTimeField = value;
			}
		}
	}


	/// <summary>Describes the different statuses for <a href='Package'>Package</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum PackageStatus {
		/// <summary>Indicates that the proposal line items under the <a href='Package'>Package</a>
		/// have not been created.
		/// </summary>
		IN_PROGRESS = 0,
		/// <summary>Indicates that the proposal line items under the <a href='Package'>Package</a>
		/// have been created.
		/// </summary>
		COMPLETED = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.PackageServiceInterface")]
	public interface PackageServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.PackageService.createPackagesResponse createPackages(Wrappers.PackageService.createPackagesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.PackageService.createPackagesResponse> createPackagesAsync(Wrappers.PackageService.createPackagesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.PackagePage getPackagesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.PackagePage> getPackagesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performPackageAction(Google.Api.Ads.AdManager.v201802.PackageAction packageAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performPackageActionAsync(Google.Api.Ads.AdManager.v201802.PackageAction packageAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.PackageService.updatePackagesResponse updatePackages(Wrappers.PackageService.updatePackagesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.PackageService.updatePackagesResponse> updatePackagesAsync(Wrappers.PackageService.updatePackagesRequest request);
	}


	/// <summary>Captures a page of <a href='Package'>Package</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PackagePage {
		private Package[] resultsField;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		/// <summary>The collection of packages contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 0)]
		public Package[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a href='Package'>Package</a>
	/// objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(CreateProposalLineItemsFromPackages))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class PackageAction {
	}


	/// <summary>The action used for creating proposal line items from <a
	/// href='Package'>Package</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CreateProposalLineItemsFromPackages : PackageAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface PackageServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.PackageServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='Package'>Package</a> objects. <p>To use this service, you need to have the
	/// new sales management solution enabled on your network. If you do not see a
	/// "Sales" tab in <a href="https://www.google.com/dfp">DoubleClick for Publishers
	/// (DFP)</a>, you will not be able to use this service.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class PackageService : AdManagerSoapClient<IPackageService>, IPackageService {
		/// <summary> Creates a new instance of the <see cref="PackageService"/> class.
		/// </summary>
		public PackageService() {
		}

		/// <summary> Creates a new instance of the <see cref="PackageService"/> class.
		/// </summary>
		public PackageService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="PackageService"/> class.
		/// </summary>
		public PackageService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="PackageService"/> class.
		/// </summary>
		public PackageService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="PackageService"/> class.
		/// </summary>
		public PackageService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.PackageService.createPackagesResponse Google.Api.Ads.AdManager.v201802.PackageServiceInterface.createPackages(Wrappers.PackageService.createPackagesRequest request) {
			return base.Channel.createPackages(request);
		}

		/// <summary>Creates new <a href='Package'>Package</a> objects. For each package, the
		/// following fields are required: <ul> <li><a
		/// href='Package#proposalId'>Package#proposalId</a></li> <li><a
		/// href='Package#productPackageId'>Package#productPackageId</a></li> <li><a
		/// href='Package#name'>Package#name</a></li> </ul>
		/// </summary><param name='packages'>the packages to create</param>
		/// <returns>the created packages with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Package[] createPackages(Google.Api.Ads.AdManager.v201802.Package[] packages) {
			Wrappers.PackageService.createPackagesRequest inValue = new Wrappers.PackageService.createPackagesRequest();
			inValue.packages = packages;
			Wrappers.PackageService.createPackagesResponse retVal = ((Google.Api.Ads.AdManager.v201802.PackageServiceInterface)(this)).createPackages(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.PackageService.createPackagesResponse> Google.Api.Ads.AdManager.v201802.PackageServiceInterface.createPackagesAsync(Wrappers.PackageService.createPackagesRequest request) {
			return base.Channel.createPackagesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Package[]> createPackagesAsync(Google.Api.Ads.AdManager.v201802.Package[] packages) {
			Wrappers.PackageService.createPackagesRequest inValue = new Wrappers.PackageService.createPackagesRequest();
			inValue.packages = packages;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Package[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.PackageServiceInterface)(this)).createPackagesAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='PackagePage'>PackagePage</a> of <a href='Package'>Package</a>
		/// objects that satisfy the given <a href='Statement#query'>Statement#query</a>.
		/// The following fields are supported for filtering: <table> <tr> <th
		/// scope="col">PQL Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>id</code></td> <td><a href='Package#id'>Package#id</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a href='Package#name'>Package#name</a></td>
		/// </tr> <tr> <td><code>proposalId</code></td> <td><a
		/// href='Package#proposalId'>Package#proposalId</a></td> </tr> <tr>
		/// <td><code>productPackageId</code></td> <td><a
		/// href='Package#productPackageId'>Package#productPackageId</a></td> </tr> <tr>
		/// <td><code>isArchived</code></td> <td><a
		/// href='Package#isArchived'>Package#isArchived</a></td> </tr> <tr>
		/// <td><code>lastModifiedDateTime</code></td> <td><a
		/// href='Package#lastModifiedDateTime'>Package#lastModifiedDateTime</a></td> </tr>
		/// </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of packages</param>
		/// <returns>the packages that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.PackagePage getPackagesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getPackagesByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.PackagePage> getPackagesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getPackagesByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='Package'>Package</a> objects that match the given
		/// <a href='Statement'>Statement</a>.
		/// </summary><param name='packageAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of packages</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performPackageAction(Google.Api.Ads.AdManager.v201802.PackageAction packageAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performPackageAction(packageAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performPackageActionAsync(Google.Api.Ads.AdManager.v201802.PackageAction packageAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performPackageActionAsync(packageAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.PackageService.updatePackagesResponse Google.Api.Ads.AdManager.v201802.PackageServiceInterface.updatePackages(Wrappers.PackageService.updatePackagesRequest request) {
			return base.Channel.updatePackages(request);
		}

		/// <summary>Updates the specified <a href='Package'>Package</a> objects.
		/// </summary><param name='packages'>the packages to update</param>
		/// <returns>the updated packages</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Package[] updatePackages(Google.Api.Ads.AdManager.v201802.Package[] packages) {
			Wrappers.PackageService.updatePackagesRequest inValue = new Wrappers.PackageService.updatePackagesRequest();
			inValue.packages = packages;
			Wrappers.PackageService.updatePackagesResponse retVal = ((Google.Api.Ads.AdManager.v201802.PackageServiceInterface)(this)).updatePackages(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.PackageService.updatePackagesResponse> Google.Api.Ads.AdManager.v201802.PackageServiceInterface.updatePackagesAsync(Wrappers.PackageService.updatePackagesRequest request) {
			return base.Channel.updatePackagesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Package[]> updatePackagesAsync(Google.Api.Ads.AdManager.v201802.Package[] packages) {
			Wrappers.PackageService.updatePackagesRequest inValue = new Wrappers.PackageService.updatePackagesRequest();
			inValue.packages = packages;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Package[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.PackageServiceInterface)(this)).updatePackagesAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.ProductPackageService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createProductPackages", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createProductPackagesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("productPackages")]
			public Google.Api.Ads.AdManager.v201802.ProductPackage[] productPackages;

			/// <summary> Creates a new instance of the <see
			/// cref="createProductPackagesRequest"/> class. </summary>
			public createProductPackagesRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createProductPackagesRequest"/> class. </summary>
			public createProductPackagesRequest(Google.Api.Ads.AdManager.v201802.ProductPackage[] productPackages) {
				this.productPackages = productPackages;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createProductPackagesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createProductPackagesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ProductPackage[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createProductPackagesResponse"/> class. </summary>
			public createProductPackagesResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createProductPackagesResponse"/> class. </summary>
			public createProductPackagesResponse(Google.Api.Ads.AdManager.v201802.ProductPackage[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateProductPackages", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateProductPackagesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("productPackages")]
			public Google.Api.Ads.AdManager.v201802.ProductPackage[] productPackages;

			/// <summary> Creates a new instance of the <see
			/// cref="updateProductPackagesRequest"/> class. </summary>
			public updateProductPackagesRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateProductPackagesRequest"/> class. </summary>
			public updateProductPackagesRequest(Google.Api.Ads.AdManager.v201802.ProductPackage[] productPackages) {
				this.productPackages = productPackages;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateProductPackagesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateProductPackagesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ProductPackage[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateProductPackagesResponse"/> class. </summary>
			public updateProductPackagesResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateProductPackagesResponse"/> class. </summary>
			public updateProductPackagesResponse(Google.Api.Ads.AdManager.v201802.ProductPackage[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>A <code>ProductPackage</code> represents a group of products which will be sold
	/// together.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductPackage {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private string notesField;

		private ProductPackageStatus statusField;

		private bool statusFieldSpecified;

		private bool isArchivedField;

		private bool isArchivedFieldSpecified;

		private long[] rateCardIdsField;

		private BaseCustomFieldValue[] customFieldValuesField;

		private DateTime lastModifiedDateTimeField;

		/// <summary>Uniquely identifies the <code>ProductPackage</code>. <p>This attribute is
		/// read-only and is assigned by Google when a <code>ProductPackage</code> is
		/// created.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the <code>ProductPackage</code>. <p>This attribute is required and
		/// has maximum length of 255 characters.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The notes of the <code>ProductPackage</code>. <p>This attribute has maximum
		/// length of 511 characters.</p> <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string notes {
			get {
				return this.notesField;
			}
			set {
				this.notesField = value;
			}
		}

		/// <summary>The status of the <code>ProductPackage</code>. <p>This attribute is read-only
		/// and is assigned by Google.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public ProductPackageStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>The archival status of the <code>ProductPackage</code>. <p>This attribute is
		/// read-only and is assigned by Google.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public bool isArchived {
			get {
				return this.isArchivedField;
			}
			set {
				this.isArchivedField = value;
				this.isArchivedSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isArchived"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isArchivedSpecified {
			get {
				return this.isArchivedFieldSpecified;
			}
			set {
				this.isArchivedFieldSpecified = value;
			}
		}

		/// <summary><a href='RateCard'>RateCard</a> IDs associated with the <code></code>. <p>This
		/// attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("rateCardIds", Order = 5)]
		public long[] rateCardIds {
			get {
				return this.rateCardIdsField;
			}
			set {
				this.rateCardIdsField = value;
			}
		}

		/// <summary>The <a href='CustomFieldValue'>CustomFieldValue</a> objects associated with this
		/// <code>ProductPackage</code>. <p>This attribute is optional.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("customFieldValues", Order = 6)]
		public BaseCustomFieldValue[] customFieldValues {
			get {
				return this.customFieldValuesField;
			}
			set {
				this.customFieldValuesField = value;
			}
		}

		/// <summary>The date and time this <code>ProductPackage</code> was last modified. <p>This
		/// attribute is read-only and is assigned by Google when a
		/// <code>ProductPackage</code> is updated.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public DateTime lastModifiedDateTime {
			get {
				return this.lastModifiedDateTimeField;
			}
			set {
				this.lastModifiedDateTimeField = value;
			}
		}
	}


	/// <summary>Describes the different statuses for <code>ProductPackage</code>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProductPackageStatus {
		ACTIVE = 0,
		INACTIVE = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Lists all errors associated with product packages rate card associations.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductPackageRateCardAssociationError : ApiError {
		private ProductPackageRateCardAssociationErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ProductPackageRateCardAssociationErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the <a href='ProductPackageError'>ProductPackageError</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ProductPackageRateCardAssociationError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProductPackageRateCardAssociationErrorReason {
		/// <summary>The id of associated rate card is invalid or invisible to user.
		/// </summary>
		INVALID_RATE_CARD_ID = 0,
		/// <summary>The id of associated package is invalid.
		/// </summary>
		INVALID_PRODUCT_PACKAGE_ID = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Lists all errors associated with product package items.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductPackageItemError : ApiError {
		private ProductPackageItemErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ProductPackageItemErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the <a
	/// href='ProductPackageItemError'>ProductPackageItemError</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ProductPackageItemError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProductPackageItemErrorReason {
		/// <summary>Add a archived product to product package is not allowed.
		/// </summary>
		ARCHIVED_PRODUCT_NOT_ALLOWED = 0,
		/// <summary>Inactive mandatory product is not allowed in active product package.
		/// </summary>
		INACTIVE_MANDATORY_PRODUCT_NOT_ALLOWED = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Lists all errors for executing operations on product packages.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductPackageActionError : ApiError {
		private ProductPackageActionErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ProductPackageActionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the <a
	/// href='ProductPackageActionError'>ProductPackageActionError</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ProductPackageActionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProductPackageActionErrorReason {
		/// <summary>The activate operation is not applicable if there's any inactive mandatory
		/// product.
		/// </summary>
		ACTIVATE_WITH_INACTIVE_MANDATORY_PRODUCT = 0,
		/// <summary>The operation is not applicable to the current state.
		/// </summary>
		NOT_APPLICABLE = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ProductPackageServiceInterface")]
	public interface ProductPackageServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ProductPackageService.createProductPackagesResponse createProductPackages(Wrappers.ProductPackageService.createProductPackagesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ProductPackageService.createProductPackagesResponse> createProductPackagesAsync(Wrappers.ProductPackageService.createProductPackagesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ProductPackagePage getProductPackagesByStatement(Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductPackagePage> getProductPackagesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performProductPackageAction(Google.Api.Ads.AdManager.v201802.ProductPackageAction action, Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performProductPackageActionAsync(Google.Api.Ads.AdManager.v201802.ProductPackageAction action, Google.Api.Ads.AdManager.v201802.Statement statement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ProductPackageService.updateProductPackagesResponse updateProductPackages(Wrappers.ProductPackageService.updateProductPackagesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ProductPackageService.updateProductPackagesResponse> updateProductPackagesAsync(Wrappers.ProductPackageService.updateProductPackagesRequest request);
	}


	/// <summary>Captures a page of <a href='ProductPackageDto'>ProductPackageDto</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductPackagePage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private ProductPackage[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of product packages contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public ProductPackage[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on product packages.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UnarchiveProductPackages))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeactivateProductPackages))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ArchiveProductPackages))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateProductPackages))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class ProductPackageAction {
	}


	/// <summary>The action used to un-archive product packages.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UnarchiveProductPackages : ProductPackageAction {
	}


	/// <summary>The action used to de-activate product packages.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeactivateProductPackages : ProductPackageAction {
	}


	/// <summary>The action used to archive product packages.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ArchiveProductPackages : ProductPackageAction {
	}


	/// <summary>The action used to activate product packages.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateProductPackages : ProductPackageAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ProductPackageServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ProductPackageServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for updating and retrieving <a
	/// href='ProductPackage'>ProductPackage</a> objects. <p>A <a
	/// href='ProductPackage'>ProductPackage</a> represents a group of products which
	/// will be sold together.</p> <p>To use this service, you need to have the new
	/// sales management solution enabled on your network. If you do not see a "Sales"
	/// tab in <a href="https://www.google.com/dfp">DoubleClick for Publishers
	/// (DFP)</a>, you will not be able to use this service.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ProductPackageService : AdManagerSoapClient<IProductPackageService>, IProductPackageService {
		/// <summary> Creates a new instance of the <see cref="ProductPackageService"/>
		/// class. </summary>
		public ProductPackageService() {
		}

		/// <summary> Creates a new instance of the <see cref="ProductPackageService"/>
		/// class. </summary>
		public ProductPackageService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="ProductPackageService"/>
		/// class. </summary>
		public ProductPackageService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ProductPackageService"/>
		/// class. </summary>
		public ProductPackageService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ProductPackageService"/>
		/// class. </summary>
		public ProductPackageService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ProductPackageService.createProductPackagesResponse Google.Api.Ads.AdManager.v201802.ProductPackageServiceInterface.createProductPackages(Wrappers.ProductPackageService.createProductPackagesRequest request) {
			return base.Channel.createProductPackages(request);
		}

		/// <summary>Creates new <a href='ProductPackage'>ProductPackage</a> objects.
		/// </summary><param name='productPackages'>the product packages to create</param>
		/// <returns>the persisted product packages with their ID filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ProductPackage[] createProductPackages(Google.Api.Ads.AdManager.v201802.ProductPackage[] productPackages) {
			Wrappers.ProductPackageService.createProductPackagesRequest inValue = new Wrappers.ProductPackageService.createProductPackagesRequest();
			inValue.productPackages = productPackages;
			Wrappers.ProductPackageService.createProductPackagesResponse retVal = ((Google.Api.Ads.AdManager.v201802.ProductPackageServiceInterface)(this)).createProductPackages(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ProductPackageService.createProductPackagesResponse> Google.Api.Ads.AdManager.v201802.ProductPackageServiceInterface.createProductPackagesAsync(Wrappers.ProductPackageService.createProductPackagesRequest request) {
			return base.Channel.createProductPackagesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductPackage[]> createProductPackagesAsync(Google.Api.Ads.AdManager.v201802.ProductPackage[] productPackages) {
			Wrappers.ProductPackageService.createProductPackagesRequest inValue = new Wrappers.ProductPackageService.createProductPackagesRequest();
			inValue.productPackages = productPackages;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductPackage[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ProductPackageServiceInterface)(this)).createProductPackagesAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='ProductPackagePage'>ProductPackagePage</a> of <a
		/// href='ProductPackage'>ProductPackage</a> objects that satisfy the filtering
		/// criteria specified by given <a href='Statement#query'>Statement#query</a>. The
		/// following fields are supported for filtering: <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>id</code></td> <td><a
		/// href='ProductPackage#id'>ProductPackage#id</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a
		/// href='ProductPackage#name'>ProductPackage#name</a></td> </tr> <tr>
		/// <td><code>notes</code></td> <td><a
		/// href='ProductPackage#notes'>ProductPackage#notes</a></td> </tr> <tr>
		/// <td><code>status</code></td> <td><a
		/// href='ProductPackage#status'>ProductPackage#status</a></td> </tr> <tr>
		/// <td><code>isArchived</code></td> <td><a
		/// href='ProductPackage#isArchived'>ProductPackage#isArchived</a></td> </tr> <tr>
		/// <td><code>lastModifiedDateTime</code></td> <td><a
		/// href='ProductPackage#lastModifiedDateTime'>ProductPackage#lastModifiedDateTime</a></td>
		/// </tr> </table>
		/// </summary><param name='statement'>a Publisher Query Language statement which specifies the
		/// filtering criteria over product packages</param>
		/// <returns>the product packages that match the given statement</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ProductPackagePage getProductPackagesByStatement(Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.getProductPackagesByStatement(statement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductPackagePage> getProductPackagesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.getProductPackagesByStatementAsync(statement);
		}

		/// <summary>Performs actions on <a href='ProductPackage'>ProductPackage</a> objects that
		/// match the given <a href=''>Statement#query</a>.
		/// </summary><param name='action'>the action to perform</param>
		/// <param name='statement'>a Publisher Query Language statement used to filter a
		/// set of product packages</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performProductPackageAction(Google.Api.Ads.AdManager.v201802.ProductPackageAction action, Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.performProductPackageAction(action, statement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performProductPackageActionAsync(Google.Api.Ads.AdManager.v201802.ProductPackageAction action, Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.performProductPackageActionAsync(action, statement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ProductPackageService.updateProductPackagesResponse Google.Api.Ads.AdManager.v201802.ProductPackageServiceInterface.updateProductPackages(Wrappers.ProductPackageService.updateProductPackagesRequest request) {
			return base.Channel.updateProductPackages(request);
		}

		/// <summary>Updates the specified <a href='ProductPackage'>ProductPackage</a> objects.
		/// </summary><param name='productPackages'>the product packages to update</param>
		/// <returns>the updated product packages</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ProductPackage[] updateProductPackages(Google.Api.Ads.AdManager.v201802.ProductPackage[] productPackages) {
			Wrappers.ProductPackageService.updateProductPackagesRequest inValue = new Wrappers.ProductPackageService.updateProductPackagesRequest();
			inValue.productPackages = productPackages;
			Wrappers.ProductPackageService.updateProductPackagesResponse retVal = ((Google.Api.Ads.AdManager.v201802.ProductPackageServiceInterface)(this)).updateProductPackages(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ProductPackageService.updateProductPackagesResponse> Google.Api.Ads.AdManager.v201802.ProductPackageServiceInterface.updateProductPackagesAsync(Wrappers.ProductPackageService.updateProductPackagesRequest request) {
			return base.Channel.updateProductPackagesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductPackage[]> updateProductPackagesAsync(Google.Api.Ads.AdManager.v201802.ProductPackage[] productPackages) {
			Wrappers.ProductPackageService.updateProductPackagesRequest inValue = new Wrappers.ProductPackageService.updateProductPackagesRequest();
			inValue.productPackages = productPackages;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductPackage[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ProductPackageServiceInterface)(this)).updateProductPackagesAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.ProductPackageItemService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createProductPackageItems", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createProductPackageItemsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("productPackageItems")]
			public Google.Api.Ads.AdManager.v201802.ProductPackageItem[] productPackageItems;

			/// <summary> Creates a new instance of the <see
			/// cref="createProductPackageItemsRequest"/> class. </summary>
			public createProductPackageItemsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createProductPackageItemsRequest"/> class. </summary>
			public createProductPackageItemsRequest(Google.Api.Ads.AdManager.v201802.ProductPackageItem[] productPackageItems) {
				this.productPackageItems = productPackageItems;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createProductPackageItemsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createProductPackageItemsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ProductPackageItem[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createProductPackageItemsResponse"/> class. </summary>
			public createProductPackageItemsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createProductPackageItemsResponse"/> class. </summary>
			public createProductPackageItemsResponse(Google.Api.Ads.AdManager.v201802.ProductPackageItem[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateProductPackageItems", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateProductPackageItemsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("productPackageItems")]
			public Google.Api.Ads.AdManager.v201802.ProductPackageItem[] productPackageItems;

			/// <summary> Creates a new instance of the <see
			/// cref="updateProductPackageItemsRequest"/> class. </summary>
			public updateProductPackageItemsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateProductPackageItemsRequest"/> class. </summary>
			public updateProductPackageItemsRequest(Google.Api.Ads.AdManager.v201802.ProductPackageItem[] productPackageItems) {
				this.productPackageItems = productPackageItems;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateProductPackageItemsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateProductPackageItemsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ProductPackageItem[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateProductPackageItemsResponse"/> class. </summary>
			public updateProductPackageItemsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateProductPackageItemsResponse"/> class. </summary>
			public updateProductPackageItemsResponse(Google.Api.Ads.AdManager.v201802.ProductPackageItem[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>A <code>ProductPackageItem</code> represents a product item in a package.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductPackageItem {
		private long idField;

		private bool idFieldSpecified;

		private long productIdField;

		private bool productIdFieldSpecified;

		private long productPackageIdField;

		private bool productPackageIdFieldSpecified;

		private bool isMandatoryField;

		private bool isMandatoryFieldSpecified;

		private ArchiveStatus archiveStatusField;

		private bool archiveStatusFieldSpecified;

		/// <summary>The unique ID of the <a href='ProductPackageItem'>ProductPackageItem</a>.
		/// <p>This attribute is read-only and is assigned by Google when a <a
		/// href='ProductPackageItem'>ProductPackageItem</a> is created.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The unique ID of the <a href='Product'>Product</a>, to which the <a
		/// href='ProductPackageItem'>ProductPackageItem</a> comes from. <p>This attribute
		/// is required for creation and then is read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long productId {
			get {
				return this.productIdField;
			}
			set {
				this.productIdField = value;
				this.productIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="productId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool productIdSpecified {
			get {
				return this.productIdFieldSpecified;
			}
			set {
				this.productIdFieldSpecified = value;
			}
		}

		/// <summary>The unique ID of the <a href='ProductPackage'>ProductPackage</a>, to which the
		/// <a href='ProductPackageItem'>ProductPackageItem</a> belongs. <p>This attribute
		/// is required for creation and then is read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public long productPackageId {
			get {
				return this.productPackageIdField;
			}
			set {
				this.productPackageIdField = value;
				this.productPackageIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="productPackageId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool productPackageIdSpecified {
			get {
				return this.productPackageIdFieldSpecified;
			}
			set {
				this.productPackageIdFieldSpecified = value;
			}
		}

		/// <summary>Indicates whether the <a href='ProductPackageItem'>ProductPackageItem</a> must
		/// be included to complete the <a href='ProductPackage'>ProductPackage</a>.
		/// <p>Deactivating a mandatory <a href='ProductPackageItem'>ProductPackageItem</a>
		/// will make the <a href='ProductPackage'>ProductPackage</a> unsellable.</p>
		/// <p>This attribute is required.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public bool isMandatory {
			get {
				return this.isMandatoryField;
			}
			set {
				this.isMandatoryField = value;
				this.isMandatorySpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isMandatory"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isMandatorySpecified {
			get {
				return this.isMandatoryFieldSpecified;
			}
			set {
				this.isMandatoryFieldSpecified = value;
			}
		}

		/// <summary>The archival status of the <a href='ProductPackageItem'>ProductPackageItem</a>.
		/// <p>This attribute is read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public ArchiveStatus archiveStatus {
			get {
				return this.archiveStatusField;
			}
			set {
				this.archiveStatusField = value;
				this.archiveStatusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="archiveStatus" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool archiveStatusSpecified {
			get {
				return this.archiveStatusFieldSpecified;
			}
			set {
				this.archiveStatusFieldSpecified = value;
			}
		}
	}


	/// <summary>Archive status of product package item.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ArchiveStatus {
		/// <summary>Product package item is archived
		/// </summary>
		ARCHIVED = 0,
		/// <summary>Product package item is not archived
		/// </summary>
		NOT_ARCHIVED = 1,
		/// <summary>The corresponding product template of this product package item is archived.
		/// </summary>
		PRODUCT_TEMPLATE_ARCHIVED = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Lists all errors for executing operations on product package items.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductPackageItemActionError : ApiError {
		private ProductPackageItemActionErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ProductPackageItemActionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the <a
	/// href='ProductPackageItemActionError'>ProductPackageItemActionError</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ProductPackageItemActionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ProductPackageItemActionErrorReason {
		/// <summary>The operation is not applicable to the current state.
		/// </summary>
		NOT_APPLICABLE = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ProductPackageItemServiceInterface")]
	public interface ProductPackageItemServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ProductPackageItemService.createProductPackageItemsResponse createProductPackageItems(Wrappers.ProductPackageItemService.createProductPackageItemsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ProductPackageItemService.createProductPackageItemsResponse> createProductPackageItemsAsync(Wrappers.ProductPackageItemService.createProductPackageItemsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ProductPackageItemPage getProductPackageItemsByStatement(Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductPackageItemPage> getProductPackageItemsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performProductPackageItemAction(Google.Api.Ads.AdManager.v201802.ProductPackageItemAction productPackageItemAction, Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performProductPackageItemActionAsync(Google.Api.Ads.AdManager.v201802.ProductPackageItemAction productPackageItemAction, Google.Api.Ads.AdManager.v201802.Statement statement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ProductPackageItemService.updateProductPackageItemsResponse updateProductPackageItems(Wrappers.ProductPackageItemService.updateProductPackageItemsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ProductPackageItemService.updateProductPackageItemsResponse> updateProductPackageItemsAsync(Wrappers.ProductPackageItemService.updateProductPackageItemsRequest request);
	}


	/// <summary>Captures a page of <a href='ProductPackageItemDto'>ProductPackageItemDto</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductPackageItemPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private ProductPackageItem[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of product package item dtos contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public ProductPackageItem[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on product package items.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UnArchiveProductPackageItems))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ArchiveProductPackageItems))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class ProductPackageItemAction {
	}


	/// <summary>The action used to un-archive product package items.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UnArchiveProductPackageItems : ProductPackageItemAction {
	}


	/// <summary>The action used to archive product package items.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ArchiveProductPackageItems : ProductPackageItemAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ProductPackageItemServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ProductPackageItemServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating and retrieving <a
	/// href='ProductPackageItem'>ProductPackageItem</a> objects. <p>A <a
	/// href='ProductPackageItem'>ProductPackageItem</a> represents a product which will
	/// be associated with a <a href=''>ProductPackage</a>.</p> <p>To use this service,
	/// you need to have the new sales management solution enabled on your network. If
	/// you do not see a "Sales" tab in <a href="https://www.google.com/dfp">DoubleClick
	/// for Publishers (DFP)</a>, you will not be able to use this service.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ProductPackageItemService : AdManagerSoapClient<IProductPackageItemService>, IProductPackageItemService {
		/// <summary> Creates a new instance of the <see cref="ProductPackageItemService"/>
		/// class. </summary>
		public ProductPackageItemService() {
		}

		/// <summary> Creates a new instance of the <see cref="ProductPackageItemService"/>
		/// class. </summary>
		public ProductPackageItemService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="ProductPackageItemService"/>
		/// class. </summary>
		public ProductPackageItemService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ProductPackageItemService"/>
		/// class. </summary>
		public ProductPackageItemService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ProductPackageItemService"/>
		/// class. </summary>
		public ProductPackageItemService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ProductPackageItemService.createProductPackageItemsResponse Google.Api.Ads.AdManager.v201802.ProductPackageItemServiceInterface.createProductPackageItems(Wrappers.ProductPackageItemService.createProductPackageItemsRequest request) {
			return base.Channel.createProductPackageItems(request);
		}

		/// <summary>Creates new <a href='ProductPackageItem'>ProductPackageItem</a> objects.
		/// </summary><param name='productPackageItems'>the product package items to create</param>
		/// <returns>the created product package items with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ProductPackageItem[] createProductPackageItems(Google.Api.Ads.AdManager.v201802.ProductPackageItem[] productPackageItems) {
			Wrappers.ProductPackageItemService.createProductPackageItemsRequest inValue = new Wrappers.ProductPackageItemService.createProductPackageItemsRequest();
			inValue.productPackageItems = productPackageItems;
			Wrappers.ProductPackageItemService.createProductPackageItemsResponse retVal = ((Google.Api.Ads.AdManager.v201802.ProductPackageItemServiceInterface)(this)).createProductPackageItems(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ProductPackageItemService.createProductPackageItemsResponse> Google.Api.Ads.AdManager.v201802.ProductPackageItemServiceInterface.createProductPackageItemsAsync(Wrappers.ProductPackageItemService.createProductPackageItemsRequest request) {
			return base.Channel.createProductPackageItemsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductPackageItem[]> createProductPackageItemsAsync(Google.Api.Ads.AdManager.v201802.ProductPackageItem[] productPackageItems) {
			Wrappers.ProductPackageItemService.createProductPackageItemsRequest inValue = new Wrappers.ProductPackageItemService.createProductPackageItemsRequest();
			inValue.productPackageItems = productPackageItems;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductPackageItem[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ProductPackageItemServiceInterface)(this)).createProductPackageItemsAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='ProductPackageItemPage'>ProductPackageItemPage</a> of
		/// <code>ProductPackageItem</code> objects that satisfy the filtering criteria
		/// specified by given <a href='Statement#query'>Statement#query</a>. The following
		/// fields are supported for filtering: <table> <tr> <th scope="col">PQL
		/// Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>id</code></td> <td><a
		/// href='ProductPackageItem#id'>ProductPackageItem#id</a></td> </tr> <tr>
		/// <td><code>productPackageId</code></td> <td><a
		/// href='ProductPackageItem#productPackageId'>ProductPackageItem#productPackageId</a></td>
		/// </tr> <tr> <td><code>productId</code></td> <td><a
		/// href='ProductPackageItem#productId'>ProductPackageItem#productId</a></td> </tr>
		/// <tr> <td><code>productTemplateId</code></td> <td><a
		/// href='ProductPackageItem#productTemplateId'>ProductPackageItem#productTemplateId</a></td>
		/// </tr> <tr> <td><code>mandatory</code></td> <td><a
		/// href='ProductPackageItem#mandatory'>ProductPackageItem#mandatory</a></td> </tr>
		/// <tr> <td><code>archived</code></td> <td><a
		/// href='ProductPackageItem#archived'>ProductPackageItem#archived</a></td> </tr>
		/// </table>
		/// </summary><param name='statement'>a Publisher Query Language statement which specifies the
		/// filtering criteria over product packages</param>
		/// <returns>the product package items that match the given statement</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ProductPackageItemPage getProductPackageItemsByStatement(Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.getProductPackageItemsByStatement(statement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductPackageItemPage> getProductPackageItemsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.getProductPackageItemsByStatementAsync(statement);
		}

		/// <summary>Performs actions on <a href='ProductPackageItem'>ProductPackageItem</a> objects
		/// that satisfy the given <a href='Statement#query'>Statement#query</a>.
		/// </summary><param name='productPackageItemAction'>the action to perform</param>
		/// <param name='statement'>a Publisher Query Language statement used to filter a
		/// set of product package items</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performProductPackageItemAction(Google.Api.Ads.AdManager.v201802.ProductPackageItemAction productPackageItemAction, Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.performProductPackageItemAction(productPackageItemAction, statement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performProductPackageItemActionAsync(Google.Api.Ads.AdManager.v201802.ProductPackageItemAction productPackageItemAction, Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.performProductPackageItemActionAsync(productPackageItemAction, statement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ProductPackageItemService.updateProductPackageItemsResponse Google.Api.Ads.AdManager.v201802.ProductPackageItemServiceInterface.updateProductPackageItems(Wrappers.ProductPackageItemService.updateProductPackageItemsRequest request) {
			return base.Channel.updateProductPackageItems(request);
		}

		/// <summary>Updates the specified <a href='ProductPackageItem'>ProductPackageItem</a>
		/// objects.
		/// </summary><param name='productPackageItems'>the product package items to update</param>
		/// <returns>the updated product package items</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ProductPackageItem[] updateProductPackageItems(Google.Api.Ads.AdManager.v201802.ProductPackageItem[] productPackageItems) {
			Wrappers.ProductPackageItemService.updateProductPackageItemsRequest inValue = new Wrappers.ProductPackageItemService.updateProductPackageItemsRequest();
			inValue.productPackageItems = productPackageItems;
			Wrappers.ProductPackageItemService.updateProductPackageItemsResponse retVal = ((Google.Api.Ads.AdManager.v201802.ProductPackageItemServiceInterface)(this)).updateProductPackageItems(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ProductPackageItemService.updateProductPackageItemsResponse> Google.Api.Ads.AdManager.v201802.ProductPackageItemServiceInterface.updateProductPackageItemsAsync(Wrappers.ProductPackageItemService.updateProductPackageItemsRequest request) {
			return base.Channel.updateProductPackageItemsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductPackageItem[]> updateProductPackageItemsAsync(Google.Api.Ads.AdManager.v201802.ProductPackageItem[] productPackageItems) {
			Wrappers.ProductPackageItemService.updateProductPackageItemsRequest inValue = new Wrappers.ProductPackageItemService.updateProductPackageItemsRequest();
			inValue.productPackageItems = productPackageItems;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductPackageItem[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ProductPackageItemServiceInterface)(this)).updateProductPackageItemsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.ContactService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createContacts", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createContactsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("contacts")]
			public Google.Api.Ads.AdManager.v201802.Contact[] contacts;

			/// <summary> Creates a new instance of the <see cref="createContactsRequest"/>
			/// class. </summary>
			public createContactsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createContactsRequest"/>
			/// class. </summary>
			public createContactsRequest(Google.Api.Ads.AdManager.v201802.Contact[] contacts) {
				this.contacts = contacts;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createContactsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createContactsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Contact[] rval;

			/// <summary> Creates a new instance of the <see cref="createContactsResponse"/>
			/// class. </summary>
			public createContactsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createContactsResponse"/>
			/// class. </summary>
			public createContactsResponse(Google.Api.Ads.AdManager.v201802.Contact[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateContacts", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateContactsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("contacts")]
			public Google.Api.Ads.AdManager.v201802.Contact[] contacts;

			/// <summary> Creates a new instance of the <see cref="updateContactsRequest"/>
			/// class. </summary>
			public updateContactsRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updateContactsRequest"/>
			/// class. </summary>
			public updateContactsRequest(Google.Api.Ads.AdManager.v201802.Contact[] contacts) {
				this.contacts = contacts;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateContactsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateContactsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Contact[] rval;

			/// <summary> Creates a new instance of the <see cref="updateContactsResponse"/>
			/// class. </summary>
			public updateContactsResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updateContactsResponse"/>
			/// class. </summary>
			public updateContactsResponse(Google.Api.Ads.AdManager.v201802.Contact[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>Base class for a <a href='Contact'>Contact</a>.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(Contact))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class BaseContact {
	}


	/// <summary>A <code>Contact</code> represents a person who is affiliated with a single <a
	/// href='Company'>Company</a>. A contact can have a variety of contact information
	/// associated to it, and can be invited to view their company's orders, line items,
	/// creatives, and reports.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Contact : BaseContact {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private long companyIdField;

		private bool companyIdFieldSpecified;

		private ContactStatus statusField;

		private bool statusFieldSpecified;

		private string addressField;

		private string cellPhoneField;

		private string commentField;

		private string emailField;

		private string faxPhoneField;

		private string titleField;

		private string workPhoneField;

		/// <summary>The unique ID of the <code>Contact</code>. This value is readonly and is
		/// assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the contact. This attribute is required and has a maximum length of
		/// 127 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The ID of the <a href='Company'>Company</a> that this contact is associated
		/// with. This attribute is required and immutable.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public long companyId {
			get {
				return this.companyIdField;
			}
			set {
				this.companyIdField = value;
				this.companyIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="companyId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool companyIdSpecified {
			get {
				return this.companyIdFieldSpecified;
			}
			set {
				this.companyIdFieldSpecified = value;
			}
		}

		/// <summary>The status of the contact. This attribute is readonly and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public ContactStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>The address of the contact. This attribute is optional and has a maximum length
		/// of 1024 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string address {
			get {
				return this.addressField;
			}
			set {
				this.addressField = value;
			}
		}

		/// <summary>The cell phone number where the contact can be reached. This attribute is
		/// optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public string cellPhone {
			get {
				return this.cellPhoneField;
			}
			set {
				this.cellPhoneField = value;
			}
		}

		/// <summary>A free-form text comment for the contact. This attribute is optional and has a
		/// maximum length of 1024 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public string comment {
			get {
				return this.commentField;
			}
			set {
				this.commentField = value;
			}
		}

		/// <summary>The e-mail address where the contact can be reached. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public string email {
			get {
				return this.emailField;
			}
			set {
				this.emailField = value;
			}
		}

		/// <summary>The fax number where the contact can be reached. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public string faxPhone {
			get {
				return this.faxPhoneField;
			}
			set {
				this.faxPhoneField = value;
			}
		}

		/// <summary>The job title of the contact. This attribute is optional and has a maximum
		/// length of 1024 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public string title {
			get {
				return this.titleField;
			}
			set {
				this.titleField = value;
			}
		}

		/// <summary>The work phone number where the contact can be reached. This attribute is
		/// optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public string workPhone {
			get {
				return this.workPhoneField;
			}
			set {
				this.workPhoneField = value;
			}
		}
	}


	/// <summary>Describes the contact statuses.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "Contact.Status", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ContactStatus {
		/// <summary>The contact has not been invited to see their orders.
		/// </summary>
		UNINVITED = 0,
		/// <summary>The contact has been invited to see their orders, but has not yet accepted the
		/// invitation.
		/// </summary>
		INVITE_PENDNG = 1,
		/// <summary>The contact has been invited to see their orders, but the invitation has already
		/// expired.
		/// </summary>
		INVITE_EXPIRED = 2,
		/// <summary>The contact was invited to see their orders, but the invitation was cancelled.
		/// </summary>
		INVITE_CANCELED = 3,
		/// <summary>The contact has access to login and view their orders.
		/// </summary>
		USER_ACTIVE = 4,
		/// <summary>The contact accepted an invitation to see their orders, but their access was
		/// later revoked.
		/// </summary>
		USER_DISABLED = 5,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 6,
	}


	/// <summary>Errors associated with <code>Contact</code>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ContactError : ApiError {
		private ContactErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ContactErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ContactError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ContactErrorReason {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ContactServiceInterface")]
	public interface ContactServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(BaseContact))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ContactService.createContactsResponse createContacts(Wrappers.ContactService.createContactsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ContactService.createContactsResponse> createContactsAsync(Wrappers.ContactService.createContactsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(BaseContact))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ContactPage getContactsByStatement(Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContactPage> getContactsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement statement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(BaseContact))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ContactService.updateContactsResponse updateContacts(Wrappers.ContactService.updateContactsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ContactService.updateContactsResponse> updateContactsAsync(Wrappers.ContactService.updateContactsRequest request);
	}


	/// <summary>Captures a page of <a href='Contact'>Contact</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ContactPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private Contact[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of contacts contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public Contact[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ContactServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ContactServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='Contact'>Contact</a> objects.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ContactService : AdManagerSoapClient<IContactService>, IContactService {
		/// <summary> Creates a new instance of the <see cref="ContactService"/> class.
		/// </summary>
		public ContactService() {
		}

		/// <summary> Creates a new instance of the <see cref="ContactService"/> class.
		/// </summary>
		public ContactService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="ContactService"/> class.
		/// </summary>
		public ContactService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ContactService"/> class.
		/// </summary>
		public ContactService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ContactService"/> class.
		/// </summary>
		public ContactService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ContactService.createContactsResponse Google.Api.Ads.AdManager.v201802.ContactServiceInterface.createContacts(Wrappers.ContactService.createContactsRequest request) {
			return base.Channel.createContacts(request);
		}

		/// <summary>Creates new <a href='Contact'>Contact</a> objects.
		/// </summary><param name='contacts'>the contacts to create</param>
		/// <returns>the created contacts with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Contact[] createContacts(Google.Api.Ads.AdManager.v201802.Contact[] contacts) {
			Wrappers.ContactService.createContactsRequest inValue = new Wrappers.ContactService.createContactsRequest();
			inValue.contacts = contacts;
			Wrappers.ContactService.createContactsResponse retVal = ((Google.Api.Ads.AdManager.v201802.ContactServiceInterface)(this)).createContacts(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ContactService.createContactsResponse> Google.Api.Ads.AdManager.v201802.ContactServiceInterface.createContactsAsync(Wrappers.ContactService.createContactsRequest request) {
			return base.Channel.createContactsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Contact[]> createContactsAsync(Google.Api.Ads.AdManager.v201802.Contact[] contacts) {
			Wrappers.ContactService.createContactsRequest inValue = new Wrappers.ContactService.createContactsRequest();
			inValue.contacts = contacts;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Contact[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ContactServiceInterface)(this)).createContactsAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='ContactPage'>ContactPage</a> of <a href='Contact'>Contact</a>
		/// objects that satisfy the given <a href='Statement#query'>Statement#query</a>.
		/// The following fields are supported for filtering: <table> <tr> <th
		/// scope="col">PQL Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>name</code></td> <td><a href='Contact#name'>Contact#name</a></td>
		/// </tr> <tr> <td><code>email</code></td> <td><a
		/// href='Contact#email'>Contact#email</a></td> </tr> <tr> <td><code>id</code></td>
		/// <td><a href='Contact#id'>Contact#id</a></td> </tr> <tr>
		/// <td><code>comment</code></td> <td><a
		/// href='Contact#comment'>Contact#comment</a></td> </tr> <tr>
		/// <td><code>companyId</code></td> <td><a
		/// href='Contact#companyId'>Contact#companyId</a></td> </tr> <tr>
		/// <td><code>title</code></td> <td><a href='Contact#title'>Contact#title</a></td>
		/// </tr> <tr> <td><code>cellPhone</code></td> <td><a
		/// href='Contact#cellPhone'>Contact#cellPhone</a></td> </tr> <tr>
		/// <td><code>workPhone</code></td> <td><a
		/// href='Contact#workPhone'>Contact#workPhone</a></td> </tr> <tr>
		/// <td><code>faxPhone</code></td> <td><a
		/// href='Contact#faxPhone'>Contact#faxPhone</a></td> </tr> <tr>
		/// <td><code>status</code></td> <td><a
		/// href='Contact#status'>Contact#status</a></td> </tr> </table>
		/// </summary><param name='statement'>a Publisher Query Language statement used to filter a
		/// set of contacts</param>
		/// <returns>the contacts that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ContactPage getContactsByStatement(Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.getContactsByStatement(statement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContactPage> getContactsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.getContactsByStatementAsync(statement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ContactService.updateContactsResponse Google.Api.Ads.AdManager.v201802.ContactServiceInterface.updateContacts(Wrappers.ContactService.updateContactsRequest request) {
			return base.Channel.updateContacts(request);
		}

		/// <summary>Updates the specified <a href='Contact'>Contact</a> objects.
		/// </summary><param name='contacts'>the contacts to update</param>
		/// <returns>the updated contacts</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Contact[] updateContacts(Google.Api.Ads.AdManager.v201802.Contact[] contacts) {
			Wrappers.ContactService.updateContactsRequest inValue = new Wrappers.ContactService.updateContactsRequest();
			inValue.contacts = contacts;
			Wrappers.ContactService.updateContactsResponse retVal = ((Google.Api.Ads.AdManager.v201802.ContactServiceInterface)(this)).updateContacts(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ContactService.updateContactsResponse> Google.Api.Ads.AdManager.v201802.ContactServiceInterface.updateContactsAsync(Wrappers.ContactService.updateContactsRequest request) {
			return base.Channel.updateContactsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Contact[]> updateContactsAsync(Google.Api.Ads.AdManager.v201802.Contact[] contacts) {
			Wrappers.ContactService.updateContactsRequest inValue = new Wrappers.ContactService.updateContactsRequest();
			inValue.contacts = contacts;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Contact[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ContactServiceInterface)(this)).updateContactsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.NativeStyleService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createNativeStyles", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createNativeStylesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("nativeStyles")]
			public Google.Api.Ads.AdManager.v201802.NativeStyle[] nativeStyles;

			/// <summary> Creates a new instance of the <see cref="createNativeStylesRequest"/>
			/// class. </summary>
			public createNativeStylesRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createNativeStylesRequest"/>
			/// class. </summary>
			public createNativeStylesRequest(Google.Api.Ads.AdManager.v201802.NativeStyle[] nativeStyles) {
				this.nativeStyles = nativeStyles;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createNativeStylesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createNativeStylesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.NativeStyle[] rval;

			/// <summary> Creates a new instance of the <see cref="createNativeStylesResponse"/>
			/// class. </summary>
			public createNativeStylesResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createNativeStylesResponse"/>
			/// class. </summary>
			public createNativeStylesResponse(Google.Api.Ads.AdManager.v201802.NativeStyle[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateNativeStyles", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateNativeStylesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("nativeStyles")]
			public Google.Api.Ads.AdManager.v201802.NativeStyle[] nativeStyles;

			/// <summary> Creates a new instance of the <see cref="updateNativeStylesRequest"/>
			/// class. </summary>
			public updateNativeStylesRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updateNativeStylesRequest"/>
			/// class. </summary>
			public updateNativeStylesRequest(Google.Api.Ads.AdManager.v201802.NativeStyle[] nativeStyles) {
				this.nativeStyles = nativeStyles;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateNativeStylesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateNativeStylesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.NativeStyle[] rval;

			/// <summary> Creates a new instance of the <see cref="updateNativeStylesResponse"/>
			/// class. </summary>
			public updateNativeStylesResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updateNativeStylesResponse"/>
			/// class. </summary>
			public updateNativeStylesResponse(Google.Api.Ads.AdManager.v201802.NativeStyle[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>Used to define the look and feel of native ads, for both web and apps. Native
	/// styles determine how native creatives look for a segment of inventory.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class NativeStyle {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private string htmlSnippetField;

		private string cssSnippetField;

		private long creativeTemplateIdField;

		private bool creativeTemplateIdFieldSpecified;

		private bool isFluidField;

		private bool isFluidFieldSpecified;

		private Targeting targetingField;

		private NativeStyleStatus statusField;

		private bool statusFieldSpecified;

		private Size sizeField;

		/// <summary>Uniquely identifies the <code>NativeStyle</code>. This attribute is read-only
		/// and is assigned by Google when a native style is created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the native style. This attribute is required and has a maximum
		/// length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The HTML snippet of the native style with placeholders for the associated
		/// variables. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public string htmlSnippet {
			get {
				return this.htmlSnippetField;
			}
			set {
				this.htmlSnippetField = value;
			}
		}

		/// <summary>The CSS snippet of the native style, with placeholders for the associated
		/// variables. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string cssSnippet {
			get {
				return this.cssSnippetField;
			}
			set {
				this.cssSnippetField = value;
			}
		}

		/// <summary>The creative template ID this native style associated with. This attribute is
		/// required on creation and is read-only afterwards.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public long creativeTemplateId {
			get {
				return this.creativeTemplateIdField;
			}
			set {
				this.creativeTemplateIdField = value;
				this.creativeTemplateIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="creativeTemplateId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool creativeTemplateIdSpecified {
			get {
				return this.creativeTemplateIdFieldSpecified;
			}
			set {
				this.creativeTemplateIdFieldSpecified = value;
			}
		}

		/// <summary>Whether this is a fluid size native style. If <code>true</code>, this must be
		/// used with 1x1 size.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public bool isFluid {
			get {
				return this.isFluidField;
			}
			set {
				this.isFluidField = value;
				this.isFluidSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="isFluid" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool isFluidSpecified {
			get {
				return this.isFluidFieldSpecified;
			}
			set {
				this.isFluidFieldSpecified = value;
			}
		}

		/// <summary>The targeting criteria for this native style. Only ad unit and key-value
		/// targeting are supported at this time.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public Targeting targeting {
			get {
				return this.targetingField;
			}
			set {
				this.targetingField = value;
			}
		}

		/// <summary>The status of the native style. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public NativeStyleStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>The size of the native style. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public Size size {
			get {
				return this.sizeField;
			}
			set {
				this.sizeField = value;
			}
		}
	}


	/// <summary>Describes status of the native style.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum NativeStyleStatus {
		/// <summary>The native style is active. Active native styles are used in ad serving.
		/// </summary>
		ACTIVE = 0,
		/// <summary>The native style is archived. Archived native styles are not visible in the UI
		/// and not used in ad serving.
		/// </summary>
		ARCHIVED = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>Errors for native styles.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class NativeStyleError : ApiError {
		private NativeStyleErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public NativeStyleErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "NativeStyleError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum NativeStyleErrorReason {
		/// <summary>The snippet of the native style contains a placeholder which is not defined as a
		/// variable on the creative template of this native style.
		/// </summary>
		UNRECOGNIZED_PLACEHOLDER = 0,
		/// <summary>Native styles can only be created under native creative templates.
		/// </summary>
		NATIVE_CREATIVE_TEMPLATE_REQUIRED = 1,
		/// <summary>Native styles can only be created under active creative templates.
		/// </summary>
		ACTIVE_CREATIVE_TEMPLATE_REQUIRED = 2,
		/// <summary>Native styles must have an HTML snippet.
		/// </summary>
		UNIQUE_SNIPPET_REQUIRED = 3,
		/// <summary>Targeting expressions on the NativeStyle can only have custom criteria targeting
		/// with <a
		/// href='CustomTargetingValue.MatchType#EXACT'>CustomTargetingValue.MatchType#EXACT</a>.
		/// </summary>
		INVALID_CUSTOM_TARGETING_MATCH_TYPE = 4,
		/// <summary>Targeting expressions on native styles can have a maximum of 20 key-value pairs.
		/// </summary>
		TOO_MANY_CUSTOM_TARGETING_KEY_VALUES = 9,
		/// <summary>Targeting expressions on the native style can only have inventory targeting
		/// and/or custom targeting.
		/// </summary>
		INVALID_TARGETING_TYPE = 5,
		/// <summary>Native styles only allows inclusion of inventory units.
		/// </summary>
		INVALID_INVENTORY_TARTGETING_TYPE = 6,
		/// <summary>The macro referenced in the snippet is not valid.
		/// </summary>
		UNRECOGNIZED_MACRO = 7,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 8,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.NativeStyleServiceInterface")]
	public interface NativeStyleServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.NativeStyleService.createNativeStylesResponse createNativeStyles(Wrappers.NativeStyleService.createNativeStylesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.NativeStyleService.createNativeStylesResponse> createNativeStylesAsync(Wrappers.NativeStyleService.createNativeStylesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.NativeStylePage getNativeStylesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.NativeStylePage> getNativeStylesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performNativeStyleAction(Google.Api.Ads.AdManager.v201802.NativeStyleAction nativeStyleAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performNativeStyleActionAsync(Google.Api.Ads.AdManager.v201802.NativeStyleAction nativeStyleAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.NativeStyleService.updateNativeStylesResponse updateNativeStyles(Wrappers.NativeStyleService.updateNativeStylesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.NativeStyleService.updateNativeStylesResponse> updateNativeStylesAsync(Wrappers.NativeStyleService.updateNativeStylesRequest request);
	}


	/// <summary>Captures a page of <a href='NativeStyle'>NativeStyle</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class NativeStylePage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private NativeStyle[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of native styles contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public NativeStyle[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents an action that can be performed on native styles.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ArchiveNativeStyles))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class NativeStyleAction {
	}


	/// <summary>Action to archive native styles.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ArchiveNativeStyles : NativeStyleAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface NativeStyleServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.NativeStyleServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating and retrieving <a
	/// href='NativeStyle'>NativeStyle</a> objects.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class NativeStyleService : AdManagerSoapClient<INativeStyleService>, INativeStyleService {
		/// <summary> Creates a new instance of the <see cref="NativeStyleService"/> class.
		/// </summary>
		public NativeStyleService() {
		}

		/// <summary> Creates a new instance of the <see cref="NativeStyleService"/> class.
		/// </summary>
		public NativeStyleService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="NativeStyleService"/> class.
		/// </summary>
		public NativeStyleService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="NativeStyleService"/> class.
		/// </summary>
		public NativeStyleService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="NativeStyleService"/> class.
		/// </summary>
		public NativeStyleService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.NativeStyleService.createNativeStylesResponse Google.Api.Ads.AdManager.v201802.NativeStyleServiceInterface.createNativeStyles(Wrappers.NativeStyleService.createNativeStylesRequest request) {
			return base.Channel.createNativeStyles(request);
		}

		/// <summary>Creates new <a href='NativeStyle'>NativeStyle</a> objects.
		/// </summary><param name='nativeStyles'>the native styles to create</param>
		/// <returns>the created native styles with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.NativeStyle[] createNativeStyles(Google.Api.Ads.AdManager.v201802.NativeStyle[] nativeStyles) {
			Wrappers.NativeStyleService.createNativeStylesRequest inValue = new Wrappers.NativeStyleService.createNativeStylesRequest();
			inValue.nativeStyles = nativeStyles;
			Wrappers.NativeStyleService.createNativeStylesResponse retVal = ((Google.Api.Ads.AdManager.v201802.NativeStyleServiceInterface)(this)).createNativeStyles(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.NativeStyleService.createNativeStylesResponse> Google.Api.Ads.AdManager.v201802.NativeStyleServiceInterface.createNativeStylesAsync(Wrappers.NativeStyleService.createNativeStylesRequest request) {
			return base.Channel.createNativeStylesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.NativeStyle[]> createNativeStylesAsync(Google.Api.Ads.AdManager.v201802.NativeStyle[] nativeStyles) {
			Wrappers.NativeStyleService.createNativeStylesRequest inValue = new Wrappers.NativeStyleService.createNativeStylesRequest();
			inValue.nativeStyles = nativeStyles;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.NativeStyle[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.NativeStyleServiceInterface)(this)).createNativeStylesAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='NativeStylePage'>NativeStylePage</a> of <a
		/// href='NativeStyle'>NativeStyle</a> objects that satisfy the given <a
		/// href='Statement'>Statement</a>. The following fields are supported for
		/// filtering: <table> <tr> <th scope="col">PQL Property</th> <th scope="col">Object
		/// Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='NativeStyle#id'>NativeStyle#id</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a
		/// href='NativeStyle#name'>NativeStyle#name</a></td> </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of native styles.</param>
		/// <returns>the native styles that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.NativeStylePage getNativeStylesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getNativeStylesByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.NativeStylePage> getNativeStylesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getNativeStylesByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='NativeStyle'>native styles</a> that match the given
		/// <a href='Statement'>Statement</a>.
		/// </summary><param name='nativeStyleAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement to filter a
		/// set of native styles</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performNativeStyleAction(Google.Api.Ads.AdManager.v201802.NativeStyleAction nativeStyleAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performNativeStyleAction(nativeStyleAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performNativeStyleActionAsync(Google.Api.Ads.AdManager.v201802.NativeStyleAction nativeStyleAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performNativeStyleActionAsync(nativeStyleAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.NativeStyleService.updateNativeStylesResponse Google.Api.Ads.AdManager.v201802.NativeStyleServiceInterface.updateNativeStyles(Wrappers.NativeStyleService.updateNativeStylesRequest request) {
			return base.Channel.updateNativeStyles(request);
		}

		/// <summary>Updates the specified <a href='NativeStyle'>NativeStyle</a> objects.
		/// </summary><param name='nativeStyles'>the native styles to be updated</param>
		/// <returns>the updated native styles</returns>
		public virtual Google.Api.Ads.AdManager.v201802.NativeStyle[] updateNativeStyles(Google.Api.Ads.AdManager.v201802.NativeStyle[] nativeStyles) {
			Wrappers.NativeStyleService.updateNativeStylesRequest inValue = new Wrappers.NativeStyleService.updateNativeStylesRequest();
			inValue.nativeStyles = nativeStyles;
			Wrappers.NativeStyleService.updateNativeStylesResponse retVal = ((Google.Api.Ads.AdManager.v201802.NativeStyleServiceInterface)(this)).updateNativeStyles(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.NativeStyleService.updateNativeStylesResponse> Google.Api.Ads.AdManager.v201802.NativeStyleServiceInterface.updateNativeStylesAsync(Wrappers.NativeStyleService.updateNativeStylesRequest request) {
			return base.Channel.updateNativeStylesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.NativeStyle[]> updateNativeStylesAsync(Google.Api.Ads.AdManager.v201802.NativeStyle[] nativeStyles) {
			Wrappers.NativeStyleService.updateNativeStylesRequest inValue = new Wrappers.NativeStyleService.updateNativeStylesRequest();
			inValue.nativeStyles = nativeStyles;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.NativeStyle[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.NativeStyleServiceInterface)(this)).updateNativeStylesAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.AudienceSegmentService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createAudienceSegments", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createAudienceSegmentsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("segments")]
			public Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] segments;

			/// <summary> Creates a new instance of the <see
			/// cref="createAudienceSegmentsRequest"/> class. </summary>
			public createAudienceSegmentsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createAudienceSegmentsRequest"/> class. </summary>
			public createAudienceSegmentsRequest(Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] segments) {
				this.segments = segments;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createAudienceSegmentsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createAudienceSegmentsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createAudienceSegmentsResponse"/> class. </summary>
			public createAudienceSegmentsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createAudienceSegmentsResponse"/> class. </summary>
			public createAudienceSegmentsResponse(Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateAudienceSegments", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateAudienceSegmentsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("segments")]
			public Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] segments;

			/// <summary> Creates a new instance of the <see
			/// cref="updateAudienceSegmentsRequest"/> class. </summary>
			public updateAudienceSegmentsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateAudienceSegmentsRequest"/> class. </summary>
			public updateAudienceSegmentsRequest(Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] segments) {
				this.segments = segments;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateAudienceSegmentsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateAudienceSegmentsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateAudienceSegmentsResponse"/> class. </summary>
			public updateAudienceSegmentsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateAudienceSegmentsResponse"/> class. </summary>
			public updateAudienceSegmentsResponse(Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>Rule of a <a href='FirstPartyAudienceSegment'>FirstPartyAudienceSegment</a> that
	/// defines user's eligibility criteria to be part of a segment.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class FirstPartyAudienceSegmentRule {
		private InventoryTargeting inventoryRuleField;

		private CustomCriteriaSet customCriteriaRuleField;

		/// <summary>Specifies the inventory (i.e. ad units and placements) that are part of the rule
		/// of a <a href='FirstPartyAudienceSegment'>FirstPartyAudienceSegment</a>. This
		/// attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public InventoryTargeting inventoryRule {
			get {
				return this.inventoryRuleField;
			}
			set {
				this.inventoryRuleField = value;
			}
		}

		/// <summary>Specifies the collection of custom criteria that are part of the rule of a <a
		/// href='FirstPartyAudienceSegment'>FirstPartyAudienceSegment</a>. <p>Once the <a
		/// href='FirstPartyAudienceSegment'>FirstPartyAudienceSegment</a> is updated or
		/// modified with custom criteria, the server may return a normalized, but
		/// equivalent representation of the custom criteria rule.</p> <ul> <li
		/// style="list-style: none"><code>customCriteriaRule</code> will have up to three
		/// levels including itself.</li> <li>The top level <a
		/// href='CustomCriteriaSet'>CustomCriteriaSet</a> i.e. the
		/// <code>customTargeting</code> object can only contain a <a
		/// href='CustomCriteriaSet.LogicalOperator#OR'>CustomCriteriaSet.LogicalOperator#OR</a>
		/// of all its children.</li> <li>The second level of <a
		/// href='CustomCriteriaSet'>CustomCriteriaSet</a> objects can only contain <a
		/// href='CustomCriteriaSet.LogicalOperator#AND'>CustomCriteriaSet.LogicalOperator#AND</a>
		/// of all their children. If a <a href='CustomCriteria'>CustomCriteria</a> is
		/// placed on this level, the server will wrap it in a <a
		/// href='CustomCriteriaSet'>CustomCriteriaSet</a>.</li> <li>The third level can
		/// only comprise of <a href='CustomCriteria'>CustomCriteria</a> objects.</li> </ul>
		/// <p>The resulting custom criteria rule would be of the form:<br /> <img
		/// src="https://chart.apis.google.com/chart?cht=gv&amp;chl=digraph{customTargeting_LogicalOperator_OR-%3ECustomCriteriaSet_LogicalOperator_AND_1-%3ECustomCriteria_1;CustomCriteriaSet_LogicalOperator_AND_1-%3Eellipsis1;customTargeting_LogicalOperator_OR-%3Eellipsis2;ellipsis1[label=%22...%22,shape=none,fontsize=32];ellipsis2[label=%22...%22,shape=none,fontsize=32]}&amp;chs=450x200"/></p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public CustomCriteriaSet customCriteriaRule {
			get {
				return this.customCriteriaRuleField;
			}
			set {
				this.customCriteriaRuleField = value;
			}
		}
	}


	/// <summary>Data provider that owns this segment. For a <a
	/// href='FirstPartyAudienceSegment'>FirstPartyAudienceSegment</a>, it would be the
	/// publisher network. For a <a
	/// href='SharedAudienceSegment'>SharedAudienceSegment</a> or a <a
	/// href='ThirdPartyAudienceSegment'>ThirdPartyAudienceSegment</a>, it would be the
	/// entity that provides that <a href='AudienceSegment'>AudienceSegment</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AudienceSegmentDataProvider {
		private string nameField;

		/// <summary>Name of the data provider. This attribute is readonly and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}
	}


	/// <summary>An <a href='AudienceSegment'>AudienceSegment</a> represents audience segment
	/// object.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(SharedAudienceSegment))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ThirdPartyAudienceSegment))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(FirstPartyAudienceSegment))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RuleBasedFirstPartyAudienceSegmentSummary))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RuleBasedFirstPartyAudienceSegment))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(NonRuleBasedFirstPartyAudienceSegment))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AudienceSegment {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private long[] categoryIdsField;

		private string descriptionField;

		private AudienceSegmentStatus statusField;

		private bool statusFieldSpecified;

		private long sizeField;

		private bool sizeFieldSpecified;

		private long mobileWebSizeField;

		private bool mobileWebSizeFieldSpecified;

		private long idfaSizeField;

		private bool idfaSizeFieldSpecified;

		private long adIdSizeField;

		private bool adIdSizeFieldSpecified;

		private long ppidSizeField;

		private bool ppidSizeFieldSpecified;

		private AudienceSegmentDataProvider dataProviderField;

		private AudienceSegmentType typeField;

		private bool typeFieldSpecified;

		/// <summary>Id of the <a href='AudienceSegment'>AudienceSegment</a>. This attribute is
		/// readonly and is populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>Name of the <a href='AudienceSegment'>AudienceSegment</a>. This attribute is
		/// required and has a maximum length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The ids of the categories this segment belongs to. This field is optional, it
		/// may be empty.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("categoryIds", Order = 2)]
		public long[] categoryIds {
			get {
				return this.categoryIdsField;
			}
			set {
				this.categoryIdsField = value;
			}
		}

		/// <summary>Description of the <a href='AudienceSegment'>AudienceSegment</a>. This attribute
		/// is optional and has a maximum length of 8192 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string description {
			get {
				return this.descriptionField;
			}
			set {
				this.descriptionField = value;
			}
		}

		/// <summary>Status of the <a href='AudienceSegment'>AudienceSegment</a>. This controls
		/// whether the given segment is available for targeting or not. During creation
		/// this attribute is optional and defaults to <code>ACTIVE</code>. This attribute
		/// is readonly for updates.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public AudienceSegmentStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}

		/// <summary>Number of unique identifiers in the <a
		/// href='AudienceSegment'>AudienceSegment</a>. This attribute is readonly and is
		/// populated by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public long size {
			get {
				return this.sizeField;
			}
			set {
				this.sizeField = value;
				this.sizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="size" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool sizeSpecified {
			get {
				return this.sizeFieldSpecified;
			}
			set {
				this.sizeFieldSpecified = value;
			}
		}

		/// <summary>Number of unique identifiers in the <a
		/// href='AudienceSegment'>AudienceSegment</a> for mobile web. This attribute is
		/// read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public long mobileWebSize {
			get {
				return this.mobileWebSizeField;
			}
			set {
				this.mobileWebSizeField = value;
				this.mobileWebSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="mobileWebSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool mobileWebSizeSpecified {
			get {
				return this.mobileWebSizeFieldSpecified;
			}
			set {
				this.mobileWebSizeFieldSpecified = value;
			}
		}

		/// <summary>Number of unique IDFA identifiers in the <a
		/// href='AudienceSegment'>AudienceSegment</a>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public long idfaSize {
			get {
				return this.idfaSizeField;
			}
			set {
				this.idfaSizeField = value;
				this.idfaSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="idfaSize"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idfaSizeSpecified {
			get {
				return this.idfaSizeFieldSpecified;
			}
			set {
				this.idfaSizeFieldSpecified = value;
			}
		}

		/// <summary>Number of unique AdID identifiers in the <a
		/// href='AudienceSegment'>AudienceSegment</a>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public long adIdSize {
			get {
				return this.adIdSizeField;
			}
			set {
				this.adIdSizeField = value;
				this.adIdSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="adIdSize"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool adIdSizeSpecified {
			get {
				return this.adIdSizeFieldSpecified;
			}
			set {
				this.adIdSizeFieldSpecified = value;
			}
		}

		/// <summary>Number of unique PPID (publisher provided identifiers) in the <a
		/// href='AudienceSegment'>AudienceSegment</a>. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public long ppidSize {
			get {
				return this.ppidSizeField;
			}
			set {
				this.ppidSizeField = value;
				this.ppidSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="ppidSize"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool ppidSizeSpecified {
			get {
				return this.ppidSizeFieldSpecified;
			}
			set {
				this.ppidSizeFieldSpecified = value;
			}
		}

		/// <summary>Owner data provider of this segment. This attribute is readonly and is assigned
		/// by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public AudienceSegmentDataProvider dataProvider {
			get {
				return this.dataProviderField;
			}
			set {
				this.dataProviderField = value;
			}
		}

		/// <summary>Type of the segment. This attribute is readonly and is assigned by Google.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 11)]
		public AudienceSegmentType type {
			get {
				return this.typeField;
			}
			set {
				this.typeField = value;
				this.typeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="type" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool typeSpecified {
			get {
				return this.typeFieldSpecified;
			}
			set {
				this.typeFieldSpecified = value;
			}
		}
	}


	/// <summary>Specifies the statuses for <a href='AudienceSegment'>AudienceSegment</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AudienceSegment.Status", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AudienceSegmentStatus {
		/// <summary>Active status means this audience segment is available for targeting.
		/// </summary>
		ACTIVE = 0,
		/// <summary>Inactive status means this audience segment is not available for targeting.
		/// </summary>
		INACTIVE = 1,
	}


	/// <summary>Specifies types for <a href='AudienceSegment'>AudienceSegment</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "AudienceSegment.Type", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum AudienceSegmentType {
		/// <summary>First party segments created and owned by the publisher.
		/// </summary>
		FIRST_PARTY = 0,
		/// <summary>First party segments shared by other clients.
		/// </summary>
		SHARED = 1,
		/// <summary>Third party segments licensed by the publisher from data providers. This doesn't
		/// include Google-provided licensed segments.
		/// </summary>
		THIRD_PARTY = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>A <a href='SharedAudienceSegment'>SharedAudienceSegment</a> is an <a
	/// href='AudienceSegment'>AudienceSegment</a> owned by another entity and shared
	/// with the publisher network.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class SharedAudienceSegment : AudienceSegment {
	}


	/// <summary>A <a href='ThirdPartyAudienceSegment'>ThirdPartyAudienceSegment</a> is an <a
	/// href='AudienceSegment'>AudienceSegment</a> owned by a data provider and licensed
	/// to the Ad Manager publisher.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ThirdPartyAudienceSegment : AudienceSegment {
		private ThirdPartyAudienceSegmentAudienceSegmentApprovalStatus approvalStatusField;

		private bool approvalStatusFieldSpecified;

		private Money costField;

		private ThirdPartyAudienceSegmentLicenseType licenseTypeField;

		private bool licenseTypeFieldSpecified;

		private DateTime startDateTimeField;

		private DateTime endDateTimeField;

		/// <summary>Specifies if the publisher has approved or rejected the segment.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ThirdPartyAudienceSegmentAudienceSegmentApprovalStatus approvalStatus {
			get {
				return this.approvalStatusField;
			}
			set {
				this.approvalStatusField = value;
				this.approvalStatusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="approvalStatus" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool approvalStatusSpecified {
			get {
				return this.approvalStatusFieldSpecified;
			}
			set {
				this.approvalStatusFieldSpecified = value;
			}
		}

		/// <summary>Specifies CPM cost for the given segment. This attribute is readonly and is
		/// assigned by the data provider. <p>The CPM cost comes from the active pricing, if
		/// there is one; otherwise it comes from the latest pricing.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public Money cost {
			get {
				return this.costField;
			}
			set {
				this.costField = value;
			}
		}

		/// <summary>Specifies the license type of the external segment. This attribute is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public ThirdPartyAudienceSegmentLicenseType licenseType {
			get {
				return this.licenseTypeField;
			}
			set {
				this.licenseTypeField = value;
				this.licenseTypeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="licenseType"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool licenseTypeSpecified {
			get {
				return this.licenseTypeFieldSpecified;
			}
			set {
				this.licenseTypeFieldSpecified = value;
			}
		}

		/// <summary>Specifies the date and time at which this segment becomes available for use.
		/// This attribute is readonly and is assigned by the data provider.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public DateTime startDateTime {
			get {
				return this.startDateTimeField;
			}
			set {
				this.startDateTimeField = value;
			}
		}

		/// <summary>Specifies the date and time at which this segment ceases to be available for
		/// use. This attribute is readonly and is assigned by the data provider.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public DateTime endDateTime {
			get {
				return this.endDateTimeField;
			}
			set {
				this.endDateTimeField = value;
			}
		}
	}


	/// <summary>Approval status values for <a
	/// href='ThirdPartyAudienceSegment'>ThirdPartyAudienceSegment</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ThirdPartyAudienceSegment.AudienceSegmentApprovalStatus", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ThirdPartyAudienceSegmentAudienceSegmentApprovalStatus {
		/// <summary>Specifies that this segment is waiting to be approved or rejected. It cannot be
		/// targeted.
		/// </summary>
		UNAPPROVED = 0,
		/// <summary>Specifies that this segment is approved and can be targeted.
		/// </summary>
		APPROVED = 1,
		/// <summary>Specifies that this segment is rejected and cannot be targeted.
		/// </summary>
		REJECTED = 2,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 3,
	}


	/// <summary>Specifies the license type of a <a
	/// href='ThirdPartyAudienceSegment'>ThirdPartyAudienceSegment</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ThirdPartyAudienceSegment.LicenseType", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ThirdPartyAudienceSegmentLicenseType {
		/// <summary>A direct license is the result of a direct contract between the data provider
		/// and the publisher.
		/// </summary>
		DIRECT_LICENSE = 0,
		/// <summary>A global license is the result of an agreement between Google and the data
		/// provider, which agrees to license their audience segments to all the publishers
		/// and/or advertisers of the Google ecosystem.
		/// </summary>
		GLOBAL_LICENSE = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	/// <summary>A <a href='FirstPartyAudienceSegment'>FirstPartyAudienceSegment</a> is an <a
	/// href='AudienceSegment'>AudienceSegment</a> owned by the publisher network.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RuleBasedFirstPartyAudienceSegmentSummary))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RuleBasedFirstPartyAudienceSegment))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(NonRuleBasedFirstPartyAudienceSegment))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class FirstPartyAudienceSegment : AudienceSegment {
	}


	/// <summary>A <a
	/// href='RuleBasedFirstPartyAudienceSegmentSummary'>RuleBasedFirstPartyAudienceSegmentSummary</a>
	/// is a <a href='FirstPartyAudienceSegment'>FirstPartyAudienceSegment</a> owned by
	/// the publisher network.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RuleBasedFirstPartyAudienceSegment))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RuleBasedFirstPartyAudienceSegmentSummary : FirstPartyAudienceSegment {
		private int pageViewsField;

		private bool pageViewsFieldSpecified;

		private int recencyDaysField;

		private bool recencyDaysFieldSpecified;

		private int membershipExpirationDaysField;

		private bool membershipExpirationDaysFieldSpecified;

		/// <summary>Specifies the number of times a user's cookie must match the segment rule before
		/// it's associated with the audience segment. This is used in combination with <a
		/// href='FirstPartyAudienceSegment#recencyDays'>FirstPartyAudienceSegment#recencyDays</a>
		/// to determine eligibility of the association. This attribute is required and can
		/// be between 1 and 12.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int pageViews {
			get {
				return this.pageViewsField;
			}
			set {
				this.pageViewsField = value;
				this.pageViewsSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="pageViews"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool pageViewsSpecified {
			get {
				return this.pageViewsFieldSpecified;
			}
			set {
				this.pageViewsFieldSpecified = value;
			}
		}

		/// <summary>Specifies the number of days within which a user's cookie must match the segment
		/// rule before it's associated with the audience segment. This is used in
		/// combination with <a
		/// href='FirstPartyAudienceSegment#pageViews'>FirstPartyAudienceSegment#pageViews</a>
		/// to determine eligibility of the association. This attribute is required only if
		/// <a
		/// href='FirstPartyAudienceSegment#pageViews'>FirstPartyAudienceSegment#pageViews</a>
		/// is greater than 1. When required, it can be between 1 and 90.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int recencyDays {
			get {
				return this.recencyDaysField;
			}
			set {
				this.recencyDaysField = value;
				this.recencyDaysSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="recencyDays"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool recencyDaysSpecified {
			get {
				return this.recencyDaysFieldSpecified;
			}
			set {
				this.recencyDaysFieldSpecified = value;
			}
		}

		/// <summary>Specifies the number of days after which a user's cookie will be removed from
		/// the audience segment due to inactivity. This attribute is required and can be
		/// between 1 and 540.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public int membershipExpirationDays {
			get {
				return this.membershipExpirationDaysField;
			}
			set {
				this.membershipExpirationDaysField = value;
				this.membershipExpirationDaysSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="membershipExpirationDays" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool membershipExpirationDaysSpecified {
			get {
				return this.membershipExpirationDaysFieldSpecified;
			}
			set {
				this.membershipExpirationDaysFieldSpecified = value;
			}
		}
	}


	/// <summary>A <a
	/// href='RuleBasedFirstPartyAudienceSegment'>RuleBasedFirstPartyAudienceSegment</a>
	/// is a <a href='FirstPartyAudienceSegment'>FirstPartyAudienceSegment</a> owned by
	/// the publisher network. It contains a rule.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RuleBasedFirstPartyAudienceSegment : RuleBasedFirstPartyAudienceSegmentSummary {
		private FirstPartyAudienceSegmentRule ruleField;

		/// <summary>Specifies the rule of the segment which determines user's eligibility criteria
		/// to be part of the segment. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public FirstPartyAudienceSegmentRule rule {
			get {
				return this.ruleField;
			}
			set {
				this.ruleField = value;
			}
		}
	}


	/// <summary>A <a
	/// href='NonRuleBasedFirstPartyAudienceSegment'>NonRuleBasedFirstPartyAudienceSegment</a>
	/// is a <a href='FirstPartyAudienceSegment'>FirstPartyAudienceSegment</a> owned by
	/// the publisher network. It doesn't contain a rule. Cookies are usually added to
	/// this segment via cookie upload. <p>These segments are created by data management
	/// platforms or Google Analytics. They cannot be created using the Ad Manager
	/// API.</p>
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class NonRuleBasedFirstPartyAudienceSegment : FirstPartyAudienceSegment {
		private int membershipExpirationDaysField;

		private bool membershipExpirationDaysFieldSpecified;

		/// <summary>Specifies the number of days after which a user's cookie will be removed from
		/// the audience segment due to inactivity. This attribute is required and can be
		/// between 1 and 540.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int membershipExpirationDays {
			get {
				return this.membershipExpirationDaysField;
			}
			set {
				this.membershipExpirationDaysField = value;
				this.membershipExpirationDaysSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="membershipExpirationDays" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool membershipExpirationDaysSpecified {
			get {
				return this.membershipExpirationDaysFieldSpecified;
			}
			set {
				this.membershipExpirationDaysFieldSpecified = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.AudienceSegmentServiceInterface")]
	public interface AudienceSegmentServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(AudienceSegment))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.AudienceSegmentService.createAudienceSegmentsResponse createAudienceSegments(Wrappers.AudienceSegmentService.createAudienceSegmentsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.AudienceSegmentService.createAudienceSegmentsResponse> createAudienceSegmentsAsync(Wrappers.AudienceSegmentService.createAudienceSegmentsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(AudienceSegment))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.AudienceSegmentPage getAudienceSegmentsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AudienceSegmentPage> getAudienceSegmentsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(AudienceSegment))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performAudienceSegmentAction(Google.Api.Ads.AdManager.v201802.AudienceSegmentAction action, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performAudienceSegmentActionAsync(Google.Api.Ads.AdManager.v201802.AudienceSegmentAction action, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(AudienceSegment))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.AudienceSegmentService.updateAudienceSegmentsResponse updateAudienceSegments(Wrappers.AudienceSegmentService.updateAudienceSegmentsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.AudienceSegmentService.updateAudienceSegmentsResponse> updateAudienceSegmentsAsync(Wrappers.AudienceSegmentService.updateAudienceSegmentsRequest request);
	}


	/// <summary>Represents a page of <a href='AudienceSegment'>AudienceSegment</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class AudienceSegmentPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private AudienceSegment[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of audience segments contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public AudienceSegment[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Action that can be performed on <a href='AudienceSegment'>AudienceSegment</a>
	/// objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(RejectAudienceSegments))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(PopulateAudienceSegments))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeactivateAudienceSegments))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ApproveAudienceSegments))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateAudienceSegments))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class AudienceSegmentAction {
	}


	/// <summary>Action that can be performed on <a
	/// href='ThirdPartyAudienceSegment'>ThirdPartyAudienceSegment</a> objects to reject
	/// them.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class RejectAudienceSegments : AudienceSegmentAction {
	}


	/// <summary>Action that can be performed on <a
	/// href='FirstPartyAudienceSegment'>FirstPartyAudienceSegment</a> objects to
	/// populate them based on last 30 days of traffic.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class PopulateAudienceSegments : AudienceSegmentAction {
	}


	/// <summary>Action that can be performed on <a
	/// href='FirstPartyAudienceSegment'>FirstPartyAudienceSegment</a> objects to
	/// deactivate them.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeactivateAudienceSegments : AudienceSegmentAction {
	}


	/// <summary>Action that can be performed on <a
	/// href='ThirdPartyAudienceSegment'>ThirdPartyAudienceSegment</a> objects to
	/// approve them.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ApproveAudienceSegments : AudienceSegmentAction {
	}


	/// <summary>Action that can be performed on <a
	/// href='FirstPartyAudienceSegment'>FirstPartyAudienceSegment</a> objects to
	/// activate them.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateAudienceSegments : AudienceSegmentAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface AudienceSegmentServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.AudienceSegmentServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides operations for creating, updating and retrieving <a
	/// href='AudienceSegment'>AudienceSegment</a> objects.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class AudienceSegmentService : AdManagerSoapClient<IAudienceSegmentService>, IAudienceSegmentService {
		/// <summary> Creates a new instance of the <see cref="AudienceSegmentService"/>
		/// class. </summary>
		public AudienceSegmentService() {
		}

		/// <summary> Creates a new instance of the <see cref="AudienceSegmentService"/>
		/// class. </summary>
		public AudienceSegmentService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="AudienceSegmentService"/>
		/// class. </summary>
		public AudienceSegmentService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="AudienceSegmentService"/>
		/// class. </summary>
		public AudienceSegmentService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="AudienceSegmentService"/>
		/// class. </summary>
		public AudienceSegmentService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.AudienceSegmentService.createAudienceSegmentsResponse Google.Api.Ads.AdManager.v201802.AudienceSegmentServiceInterface.createAudienceSegments(Wrappers.AudienceSegmentService.createAudienceSegmentsRequest request) {
			return base.Channel.createAudienceSegments(request);
		}

		/// <summary>Creates new <a
		/// href='RuleBasedFirstPartyAudienceSegment'>RuleBasedFirstPartyAudienceSegment</a>
		/// objects.
		/// </summary><param name='segments'>first-party audience segments to create</param>
		/// <returns>created first-party audience segments</returns>
		public virtual Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] createAudienceSegments(Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] segments) {
			Wrappers.AudienceSegmentService.createAudienceSegmentsRequest inValue = new Wrappers.AudienceSegmentService.createAudienceSegmentsRequest();
			inValue.segments = segments;
			Wrappers.AudienceSegmentService.createAudienceSegmentsResponse retVal = ((Google.Api.Ads.AdManager.v201802.AudienceSegmentServiceInterface)(this)).createAudienceSegments(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.AudienceSegmentService.createAudienceSegmentsResponse> Google.Api.Ads.AdManager.v201802.AudienceSegmentServiceInterface.createAudienceSegmentsAsync(Wrappers.AudienceSegmentService.createAudienceSegmentsRequest request) {
			return base.Channel.createAudienceSegmentsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[]> createAudienceSegmentsAsync(Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] segments) {
			Wrappers.AudienceSegmentService.createAudienceSegmentsRequest inValue = new Wrappers.AudienceSegmentService.createAudienceSegmentsRequest();
			inValue.segments = segments;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.AudienceSegmentServiceInterface)(this)).createAudienceSegmentsAsync(inValue)).Result.rval);
		}

		/// <summary>Gets an <a href='AudienceSegmentPage'>AudienceSegmentPage</a> of <a
		/// href='AudienceSegment'>AudienceSegment</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='AudienceSegment#id'>AudienceSegment#id</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a
		/// href='AudienceSegment#name'>AudienceSegment#name</a></td> </tr> <tr>
		/// <td><code>status</code></td> <td><a
		/// href='AudienceSegment#status'>AudienceSegment#status</a></td> </tr> <tr>
		/// <td><code>type</code></td> <td><a
		/// href='AudienceSegment#type'>AudienceSegment#type</a></td> </tr> <tr>
		/// <td><code>size</code></td> <td><a
		/// href='AudienceSegment#size'>AudienceSegment#size</a></td> </tr> <tr>
		/// <td><code>dataProviderName</code></td> <td><a
		/// href='AudienceSegmentDataProvider#name'>AudienceSegmentDataProvider#name</a></td>
		/// </tr> <tr> <td><code>approvalStatus</code></td> <td><a
		/// href='ThirdPartyAudienceSegment#approvalStatus'>ThirdPartyAudienceSegment#approvalStatus</a></td>
		/// </tr> <tr> <td><code>cost</code></td> <td><a
		/// href='ThirdPartyAudienceSegment#cost'>ThirdPartyAudienceSegment#cost</a></td>
		/// </tr> <tr> <td><code>startDateTime</code></td> <td><a
		/// href='ThirdPartyAudienceSegment#startDateTime'>ThirdPartyAudienceSegment#startDateTime</a></td>
		/// </tr> <tr> <td><code>endDateTime</code></td> <td><a
		/// href='ThirdPartyAudienceSegment#endDateTime'>ThirdPartyAudienceSegment#endDateTime</a></td>
		/// </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of audience segments</param>
		/// <returns>the audience segments that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.AudienceSegmentPage getAudienceSegmentsByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getAudienceSegmentsByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AudienceSegmentPage> getAudienceSegmentsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getAudienceSegmentsByStatementAsync(filterStatement);
		}

		/// <summary>Performs the given <a href='AudienceSegmentAction'>AudienceSegmentAction</a> on
		/// the set of segments identified by the given statement.
		/// </summary><param name='action'><a href='AudienceSegmentAction'>AudienceSegmentAction</a>
		/// to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of audience segments</param>
		/// <returns><a href='UpdateResult'>UpdateResult</a> indicating the result</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performAudienceSegmentAction(Google.Api.Ads.AdManager.v201802.AudienceSegmentAction action, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performAudienceSegmentAction(action, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performAudienceSegmentActionAsync(Google.Api.Ads.AdManager.v201802.AudienceSegmentAction action, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performAudienceSegmentActionAsync(action, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.AudienceSegmentService.updateAudienceSegmentsResponse Google.Api.Ads.AdManager.v201802.AudienceSegmentServiceInterface.updateAudienceSegments(Wrappers.AudienceSegmentService.updateAudienceSegmentsRequest request) {
			return base.Channel.updateAudienceSegments(request);
		}

		/// <summary>Updates the given <a
		/// href='RuleBasedFirstPartyAudienceSegment'>RuleBasedFirstPartyAudienceSegment</a>
		/// objects.
		/// </summary><param name='segments'>first-party audience segments to update</param>
		/// <returns>updated first-party audience segments</returns>
		public virtual Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] updateAudienceSegments(Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] segments) {
			Wrappers.AudienceSegmentService.updateAudienceSegmentsRequest inValue = new Wrappers.AudienceSegmentService.updateAudienceSegmentsRequest();
			inValue.segments = segments;
			Wrappers.AudienceSegmentService.updateAudienceSegmentsResponse retVal = ((Google.Api.Ads.AdManager.v201802.AudienceSegmentServiceInterface)(this)).updateAudienceSegments(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.AudienceSegmentService.updateAudienceSegmentsResponse> Google.Api.Ads.AdManager.v201802.AudienceSegmentServiceInterface.updateAudienceSegmentsAsync(Wrappers.AudienceSegmentService.updateAudienceSegmentsRequest request) {
			return base.Channel.updateAudienceSegmentsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[]> updateAudienceSegmentsAsync(Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] segments) {
			Wrappers.AudienceSegmentService.updateAudienceSegmentsRequest inValue = new Wrappers.AudienceSegmentService.updateAudienceSegmentsRequest();
			inValue.segments = segments;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.AudienceSegmentServiceInterface)(this)).updateAudienceSegmentsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.BaseRateService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createBaseRates", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createBaseRatesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("baseRates")]
			public Google.Api.Ads.AdManager.v201802.BaseRate[] baseRates;

			/// <summary> Creates a new instance of the <see cref="createBaseRatesRequest"/>
			/// class. </summary>
			public createBaseRatesRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createBaseRatesRequest"/>
			/// class. </summary>
			public createBaseRatesRequest(Google.Api.Ads.AdManager.v201802.BaseRate[] baseRates) {
				this.baseRates = baseRates;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createBaseRatesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createBaseRatesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.BaseRate[] rval;

			/// <summary> Creates a new instance of the <see cref="createBaseRatesResponse"/>
			/// class. </summary>
			public createBaseRatesResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createBaseRatesResponse"/>
			/// class. </summary>
			public createBaseRatesResponse(Google.Api.Ads.AdManager.v201802.BaseRate[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateBaseRates", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateBaseRatesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("baseRates")]
			public Google.Api.Ads.AdManager.v201802.BaseRate[] baseRates;

			/// <summary> Creates a new instance of the <see cref="updateBaseRatesRequest"/>
			/// class. </summary>
			public updateBaseRatesRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updateBaseRatesRequest"/>
			/// class. </summary>
			public updateBaseRatesRequest(Google.Api.Ads.AdManager.v201802.BaseRate[] baseRates) {
				this.baseRates = baseRates;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateBaseRatesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateBaseRatesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.BaseRate[] rval;

			/// <summary> Creates a new instance of the <see cref="updateBaseRatesResponse"/>
			/// class. </summary>
			public updateBaseRatesResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updateBaseRatesResponse"/>
			/// class. </summary>
			public updateBaseRatesResponse(Google.Api.Ads.AdManager.v201802.BaseRate[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>A base rate that applies to a product template, product or product package item
	/// belonging to rate card.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(UnknownBaseRate))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProductTemplateBaseRate))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProductPackageItemBaseRate))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ProductBaseRate))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class BaseRate {
		private long rateCardIdField;

		private bool rateCardIdFieldSpecified;

		private long idField;

		private bool idFieldSpecified;

		/// <summary>The ID of the <a href='RateCard'>RateCard</a> object to which this base rate
		/// belongs. This attribute is required and cannot be changed after creation.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long rateCardId {
			get {
				return this.rateCardIdField;
			}
			set {
				this.rateCardIdField = value;
				this.rateCardIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="rateCardId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool rateCardIdSpecified {
			get {
				return this.rateCardIdFieldSpecified;
			}
			set {
				this.rateCardIdFieldSpecified = value;
			}
		}

		/// <summary>Uniquely identifies the <code>BaseRate</code> object. This attribute is
		/// read-only and is assigned by Google when a base rate is created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}
	}


	/// <summary>The <a href='BaseRate'>BaseRate</a> returned if the actual base rate type is not
	/// exposed by the requested API version.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class UnknownBaseRate : BaseRate {
	}


	/// <summary>A base rate applied to a <a href='ProductTemplate'>ProductTemplate</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductTemplateBaseRate : BaseRate {
		private long productTemplateIdField;

		private bool productTemplateIdFieldSpecified;

		private Money rateField;

		/// <summary>The ID of <a href='ProductTemplate'>ProductTemplate</a> this base rate is
		/// applied to. This attribute is required and cannot be changed after creation.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long productTemplateId {
			get {
				return this.productTemplateIdField;
			}
			set {
				this.productTemplateIdField = value;
				this.productTemplateIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="productTemplateId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool productTemplateIdSpecified {
			get {
				return this.productTemplateIdFieldSpecified;
			}
			set {
				this.productTemplateIdFieldSpecified = value;
			}
		}

		/// <summary>The rate value. This attribute is required. The currency code is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public Money rate {
			get {
				return this.rateField;
			}
			set {
				this.rateField = value;
			}
		}
	}


	/// <summary>A base rate applied to a <a href='ProductPackageItem'>ProductPackageItem</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductPackageItemBaseRate : BaseRate {
		private long productPackageItemIdField;

		private bool productPackageItemIdFieldSpecified;

		private Money rateField;

		/// <summary>The ID of <a href='ProductPackageItem'>ProductPackageItem</a> this base rate is
		/// applied to. <p>This attribute is required and cannot be changed after
		/// creation.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long productPackageItemId {
			get {
				return this.productPackageItemIdField;
			}
			set {
				this.productPackageItemIdField = value;
				this.productPackageItemIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="productPackageItemId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool productPackageItemIdSpecified {
			get {
				return this.productPackageItemIdFieldSpecified;
			}
			set {
				this.productPackageItemIdFieldSpecified = value;
			}
		}

		/// <summary>The rate value of <a href='ProductPackageItem'>ProductPackageItem</a>. <p>This
		/// attribute is required and the currency code is read-only.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public Money rate {
			get {
				return this.rateField;
			}
			set {
				this.rateField = value;
			}
		}
	}


	/// <summary>A base rate applied to a <a href='Product'>Product</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ProductBaseRate : BaseRate {
		private long productIdField;

		private bool productIdFieldSpecified;

		private Money rateField;

		/// <summary>The ID of the <a href='Product'>Product</a> this base rate is applied to. This
		/// attribute is required and cannot be changed after creation.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long productId {
			get {
				return this.productIdField;
			}
			set {
				this.productIdField = value;
				this.productIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="productId"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool productIdSpecified {
			get {
				return this.productIdFieldSpecified;
			}
			set {
				this.productIdFieldSpecified = value;
			}
		}

		/// <summary>The rate value to override the rate on the product template. This attribute is
		/// required. If <code>null</code>, the product is not associated with this rate
		/// card. The currency code is read-only.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public Money rate {
			get {
				return this.rateField;
			}
			set {
				this.rateField = value;
			}
		}
	}


	/// <summary>An error having to do with <a href='BaseRate'>BaseRate</a> when performing
	/// actions.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class BaseRateActionError : ApiError {
		private BaseRateActionErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public BaseRateActionErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the target error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "BaseRateActionError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum BaseRateActionErrorReason {
		/// <summary>Cannot delete a base rate on a product template if its products still have base
		/// rates on this rate card.
		/// </summary>
		PRODUCT_BASE_RATE_EXISTS = 0,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 1,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.BaseRateServiceInterface")]
	public interface BaseRateServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.BaseRateService.createBaseRatesResponse createBaseRates(Wrappers.BaseRateService.createBaseRatesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.BaseRateService.createBaseRatesResponse> createBaseRatesAsync(Wrappers.BaseRateService.createBaseRatesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.BaseRatePage getBaseRatesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.BaseRatePage> getBaseRatesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performBaseRateAction(Google.Api.Ads.AdManager.v201802.BaseRateAction baseRateAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performBaseRateActionAsync(Google.Api.Ads.AdManager.v201802.BaseRateAction baseRateAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.BaseRateService.updateBaseRatesResponse updateBaseRates(Wrappers.BaseRateService.updateBaseRatesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.BaseRateService.updateBaseRatesResponse> updateBaseRatesAsync(Wrappers.BaseRateService.updateBaseRatesRequest request);
	}


	/// <summary>Captures a page of <a href='BaseRate'>BaseRate</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class BaseRatePage {
		private BaseRate[] resultsField;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		/// <summary>The collection of base rates contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 0)]
		public BaseRate[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}
	}


	/// <summary>Represents the action that can be performed on <a href='BaseRate'>BaseRate</a>
	/// objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeleteBaseRates))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class BaseRateAction {
	}


	/// <summary>The action used to delete <a href='BaseRate'>BaseRate</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeleteBaseRates : BaseRateAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface BaseRateServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.BaseRateServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for managing <a href='BaseRate'>BaseRate</a> objects. <p>To use
	/// this service, you need to have the new sales management solution enabled on your
	/// network. If you do not see a "Sales" tab in <a
	/// href="https://www.google.com/dfp">DoubleClick for Publishers (DFP)</a>, you will
	/// not be able to use this service.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class BaseRateService : AdManagerSoapClient<IBaseRateService>, IBaseRateService {
		/// <summary> Creates a new instance of the <see cref="BaseRateService"/> class.
		/// </summary>
		public BaseRateService() {
		}

		/// <summary> Creates a new instance of the <see cref="BaseRateService"/> class.
		/// </summary>
		public BaseRateService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="BaseRateService"/> class.
		/// </summary>
		public BaseRateService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="BaseRateService"/> class.
		/// </summary>
		public BaseRateService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="BaseRateService"/> class.
		/// </summary>
		public BaseRateService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.BaseRateService.createBaseRatesResponse Google.Api.Ads.AdManager.v201802.BaseRateServiceInterface.createBaseRates(Wrappers.BaseRateService.createBaseRatesRequest request) {
			return base.Channel.createBaseRates(request);
		}

		/// <summary>Creates a list of new <a href='BaseRate'>BaseRate</a> objects.
		/// </summary><param name='baseRates'>the base rates to be created</param>
		/// <returns>the base rates with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.BaseRate[] createBaseRates(Google.Api.Ads.AdManager.v201802.BaseRate[] baseRates) {
			Wrappers.BaseRateService.createBaseRatesRequest inValue = new Wrappers.BaseRateService.createBaseRatesRequest();
			inValue.baseRates = baseRates;
			Wrappers.BaseRateService.createBaseRatesResponse retVal = ((Google.Api.Ads.AdManager.v201802.BaseRateServiceInterface)(this)).createBaseRates(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.BaseRateService.createBaseRatesResponse> Google.Api.Ads.AdManager.v201802.BaseRateServiceInterface.createBaseRatesAsync(Wrappers.BaseRateService.createBaseRatesRequest request) {
			return base.Channel.createBaseRatesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.BaseRate[]> createBaseRatesAsync(Google.Api.Ads.AdManager.v201802.BaseRate[] baseRates) {
			Wrappers.BaseRateService.createBaseRatesRequest inValue = new Wrappers.BaseRateService.createBaseRatesRequest();
			inValue.baseRates = baseRates;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.BaseRate[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.BaseRateServiceInterface)(this)).createBaseRatesAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='BaseRatePage'>BaseRatePage</a> of <a
		/// href='BaseRate'>BaseRate</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering:
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of base rates.</param>
		/// <returns>the page of base rates that match the given filter <table> <tr> <th
		/// scope="col">PQL Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>rateCardId</code></td> <td><a
		/// href='BaseRate#rateCardId'>BaseRate#rateCardId</a></td> </tr> <tr>
		/// <td><code>id</code></td> <td><a href='BaseRate#id'>BaseRate#id</a></td> </tr>
		/// <tr> <td><code>productTemplateId</code></td> <td><a
		/// href='ProductTemplateBaseRate#id'>ProductTemplateBaseRate#id</a><br />
		/// <b>Note:</b>#x160;Cannot be combined with <code>productId</code>.</td> </tr>
		/// <tr> <td><code>productId</code></td> <td><a
		/// href='ProductBaseRate#id'>ProductBaseRate#id</a><br /> <b>Note:</b>#x160;Cannot
		/// be combined with <code></code>.</td> </tr> </table></returns>
		public virtual Google.Api.Ads.AdManager.v201802.BaseRatePage getBaseRatesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getBaseRatesByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.BaseRatePage> getBaseRatesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getBaseRatesByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='BaseRate'>BaseRate</a> objects that satisfy the
		/// given <a href='Statement#query'>Statement#query</a>.
		/// </summary><param name='baseRateAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of base rates.</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performBaseRateAction(Google.Api.Ads.AdManager.v201802.BaseRateAction baseRateAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performBaseRateAction(baseRateAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performBaseRateActionAsync(Google.Api.Ads.AdManager.v201802.BaseRateAction baseRateAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performBaseRateActionAsync(baseRateAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.BaseRateService.updateBaseRatesResponse Google.Api.Ads.AdManager.v201802.BaseRateServiceInterface.updateBaseRates(Wrappers.BaseRateService.updateBaseRatesRequest request) {
			return base.Channel.updateBaseRates(request);
		}

		/// <summary>Updates the specified <a href='BaseRate'>BaseRate</a> objects.
		/// </summary><param name='baseRates'>the base rates to be updated</param>
		/// <returns>the updated base rates</returns>
		public virtual Google.Api.Ads.AdManager.v201802.BaseRate[] updateBaseRates(Google.Api.Ads.AdManager.v201802.BaseRate[] baseRates) {
			Wrappers.BaseRateService.updateBaseRatesRequest inValue = new Wrappers.BaseRateService.updateBaseRatesRequest();
			inValue.baseRates = baseRates;
			Wrappers.BaseRateService.updateBaseRatesResponse retVal = ((Google.Api.Ads.AdManager.v201802.BaseRateServiceInterface)(this)).updateBaseRates(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.BaseRateService.updateBaseRatesResponse> Google.Api.Ads.AdManager.v201802.BaseRateServiceInterface.updateBaseRatesAsync(Wrappers.BaseRateService.updateBaseRatesRequest request) {
			return base.Channel.updateBaseRatesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.BaseRate[]> updateBaseRatesAsync(Google.Api.Ads.AdManager.v201802.BaseRate[] baseRates) {
			Wrappers.BaseRateService.updateBaseRatesRequest inValue = new Wrappers.BaseRateService.updateBaseRatesRequest();
			inValue.baseRates = baseRates;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.BaseRate[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.BaseRateServiceInterface)(this)).updateBaseRatesAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.CdnConfigurationService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createCdnConfigurations", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createCdnConfigurationsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("cdnConfigurations")]
			public Google.Api.Ads.AdManager.v201802.CdnConfiguration[] cdnConfigurations;

			/// <summary> Creates a new instance of the <see
			/// cref="createCdnConfigurationsRequest"/> class. </summary>
			public createCdnConfigurationsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createCdnConfigurationsRequest"/> class. </summary>
			public createCdnConfigurationsRequest(Google.Api.Ads.AdManager.v201802.CdnConfiguration[] cdnConfigurations) {
				this.cdnConfigurations = cdnConfigurations;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createCdnConfigurationsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createCdnConfigurationsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.CdnConfiguration[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createCdnConfigurationsResponse"/> class. </summary>
			public createCdnConfigurationsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createCdnConfigurationsResponse"/> class. </summary>
			public createCdnConfigurationsResponse(Google.Api.Ads.AdManager.v201802.CdnConfiguration[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateCdnConfigurations", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateCdnConfigurationsRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("cdnConfigurations")]
			public Google.Api.Ads.AdManager.v201802.CdnConfiguration[] cdnConfigurations;

			/// <summary> Creates a new instance of the <see
			/// cref="updateCdnConfigurationsRequest"/> class. </summary>
			public updateCdnConfigurationsRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateCdnConfigurationsRequest"/> class. </summary>
			public updateCdnConfigurationsRequest(Google.Api.Ads.AdManager.v201802.CdnConfiguration[] cdnConfigurations) {
				this.cdnConfigurations = cdnConfigurations;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateCdnConfigurationsResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateCdnConfigurationsResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.CdnConfiguration[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateCdnConfigurationsResponse"/> class. </summary>
			public updateCdnConfigurationsResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateCdnConfigurationsResponse"/> class. </summary>
			public updateCdnConfigurationsResponse(Google.Api.Ads.AdManager.v201802.CdnConfiguration[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>Errors associated with <a href='CdnConfiguration'>CdnConfiguration</a>s.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CdnConfigurationError : ApiError {
		private CdnConfigurationErrorReason reasonField;

		private bool reasonFieldSpecified;

		/// <summary>The error reason represented by an enum.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public CdnConfigurationErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the <a href='CdnConfigurationError'>CdnConfigurationError</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "CdnConfigurationError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CdnConfigurationErrorReason {
		/// <summary>URL prefixes should not contain schemes.
		/// </summary>
		URL_SHOULD_NOT_CONTAIN_SCHEME = 0,
		/// <summary>Invalid delivery setting name. Names for new delivery settings must be null or
		/// empty. Names for existing delivery settings cannot be modified.
		/// </summary>
		INVALID_DELIVERY_LOCATION_NAMES = 1,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 2,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.CdnConfigurationServiceInterface")]
	public interface CdnConfigurationServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.CdnConfigurationService.createCdnConfigurationsResponse createCdnConfigurations(Wrappers.CdnConfigurationService.createCdnConfigurationsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.CdnConfigurationService.createCdnConfigurationsResponse> createCdnConfigurationsAsync(Wrappers.CdnConfigurationService.createCdnConfigurationsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.CdnConfigurationPage getCdnConfigurationsByStatement(Google.Api.Ads.AdManager.v201802.Statement statement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CdnConfigurationPage> getCdnConfigurationsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement statement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.CdnConfigurationService.updateCdnConfigurationsResponse updateCdnConfigurations(Wrappers.CdnConfigurationService.updateCdnConfigurationsRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.CdnConfigurationService.updateCdnConfigurationsResponse> updateCdnConfigurationsAsync(Wrappers.CdnConfigurationService.updateCdnConfigurationsRequest request);
	}


	/// <summary>Captures a page of <a href='CdnConfiguration'>CdnConfiguration</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CdnConfigurationPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private CdnConfiguration[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of CDN configurations contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public CdnConfiguration[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface CdnConfigurationServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.CdnConfigurationServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='CdnConfiguration'>CdnConfiguration</a> objects.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class CdnConfigurationService : AdManagerSoapClient<ICdnConfigurationService>, ICdnConfigurationService {
		/// <summary> Creates a new instance of the <see cref="CdnConfigurationService"/>
		/// class. </summary>
		public CdnConfigurationService() {
		}

		/// <summary> Creates a new instance of the <see cref="CdnConfigurationService"/>
		/// class. </summary>
		public CdnConfigurationService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="CdnConfigurationService"/>
		/// class. </summary>
		public CdnConfigurationService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="CdnConfigurationService"/>
		/// class. </summary>
		public CdnConfigurationService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="CdnConfigurationService"/>
		/// class. </summary>
		public CdnConfigurationService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.CdnConfigurationService.createCdnConfigurationsResponse Google.Api.Ads.AdManager.v201802.CdnConfigurationServiceInterface.createCdnConfigurations(Wrappers.CdnConfigurationService.createCdnConfigurationsRequest request) {
			return base.Channel.createCdnConfigurations(request);
		}

		/// <summary>Creates new <a href='CdnConfiguration'>CdnConfiguration</a> objects.
		/// </summary>
		public virtual Google.Api.Ads.AdManager.v201802.CdnConfiguration[] createCdnConfigurations(Google.Api.Ads.AdManager.v201802.CdnConfiguration[] cdnConfigurations) {
			Wrappers.CdnConfigurationService.createCdnConfigurationsRequest inValue = new Wrappers.CdnConfigurationService.createCdnConfigurationsRequest();
			inValue.cdnConfigurations = cdnConfigurations;
			Wrappers.CdnConfigurationService.createCdnConfigurationsResponse retVal = ((Google.Api.Ads.AdManager.v201802.CdnConfigurationServiceInterface)(this)).createCdnConfigurations(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.CdnConfigurationService.createCdnConfigurationsResponse> Google.Api.Ads.AdManager.v201802.CdnConfigurationServiceInterface.createCdnConfigurationsAsync(Wrappers.CdnConfigurationService.createCdnConfigurationsRequest request) {
			return base.Channel.createCdnConfigurationsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CdnConfiguration[]> createCdnConfigurationsAsync(Google.Api.Ads.AdManager.v201802.CdnConfiguration[] cdnConfigurations) {
			Wrappers.CdnConfigurationService.createCdnConfigurationsRequest inValue = new Wrappers.CdnConfigurationService.createCdnConfigurationsRequest();
			inValue.cdnConfigurations = cdnConfigurations;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CdnConfiguration[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.CdnConfigurationServiceInterface)(this)).createCdnConfigurationsAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='CdnConfigurationPage'>CdnConfigurationPage</a> of <a
		/// href='CdnConfiguration'>CdnConfiguration</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. Currently only CDN Configurations of
		/// type <a href=''>CdnConfigurationType#LIVE_STREAM_SOURCE_CONTENT</a> will be
		/// returned. The following fields are supported for filtering: <table> <tr> <th
		/// scope="col">PQL Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>id</code></td> <td><a
		/// href='CdnConfiguration#id'>CdnConfiguration#id</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a
		/// href='CdnConfiguration#name'>CdnConfiguration#name</a></td> </tr> </table>
		/// </summary>
		public virtual Google.Api.Ads.AdManager.v201802.CdnConfigurationPage getCdnConfigurationsByStatement(Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.getCdnConfigurationsByStatement(statement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CdnConfigurationPage> getCdnConfigurationsByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement statement) {
			return base.Channel.getCdnConfigurationsByStatementAsync(statement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.CdnConfigurationService.updateCdnConfigurationsResponse Google.Api.Ads.AdManager.v201802.CdnConfigurationServiceInterface.updateCdnConfigurations(Wrappers.CdnConfigurationService.updateCdnConfigurationsRequest request) {
			return base.Channel.updateCdnConfigurations(request);
		}

		/// <summary>Updates the specified <a href='CdnConfiguration'>CdnConfiguration</a> objects.
		/// </summary>
		public virtual Google.Api.Ads.AdManager.v201802.CdnConfiguration[] updateCdnConfigurations(Google.Api.Ads.AdManager.v201802.CdnConfiguration[] cdnConfigurations) {
			Wrappers.CdnConfigurationService.updateCdnConfigurationsRequest inValue = new Wrappers.CdnConfigurationService.updateCdnConfigurationsRequest();
			inValue.cdnConfigurations = cdnConfigurations;
			Wrappers.CdnConfigurationService.updateCdnConfigurationsResponse retVal = ((Google.Api.Ads.AdManager.v201802.CdnConfigurationServiceInterface)(this)).updateCdnConfigurations(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.CdnConfigurationService.updateCdnConfigurationsResponse> Google.Api.Ads.AdManager.v201802.CdnConfigurationServiceInterface.updateCdnConfigurationsAsync(Wrappers.CdnConfigurationService.updateCdnConfigurationsRequest request) {
			return base.Channel.updateCdnConfigurationsAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CdnConfiguration[]> updateCdnConfigurationsAsync(Google.Api.Ads.AdManager.v201802.CdnConfiguration[] cdnConfigurations) {
			Wrappers.CdnConfigurationService.updateCdnConfigurationsRequest inValue = new Wrappers.CdnConfigurationService.updateCdnConfigurationsRequest();
			inValue.cdnConfigurations = cdnConfigurations;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CdnConfiguration[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.CdnConfigurationServiceInterface)(this)).updateCdnConfigurationsAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.CompanyService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createCompanies", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createCompaniesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("companies")]
			public Google.Api.Ads.AdManager.v201802.Company[] companies;

			/// <summary> Creates a new instance of the <see cref="createCompaniesRequest"/>
			/// class. </summary>
			public createCompaniesRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="createCompaniesRequest"/>
			/// class. </summary>
			public createCompaniesRequest(Google.Api.Ads.AdManager.v201802.Company[] companies) {
				this.companies = companies;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createCompaniesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createCompaniesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Company[] rval;

			/// <summary> Creates a new instance of the <see cref="createCompaniesResponse"/>
			/// class. </summary>
			public createCompaniesResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="createCompaniesResponse"/>
			/// class. </summary>
			public createCompaniesResponse(Google.Api.Ads.AdManager.v201802.Company[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateCompanies", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateCompaniesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("companies")]
			public Google.Api.Ads.AdManager.v201802.Company[] companies;

			/// <summary> Creates a new instance of the <see cref="updateCompaniesRequest"/>
			/// class. </summary>
			public updateCompaniesRequest() {
			}

			/// <summary> Creates a new instance of the <see cref="updateCompaniesRequest"/>
			/// class. </summary>
			public updateCompaniesRequest(Google.Api.Ads.AdManager.v201802.Company[] companies) {
				this.companies = companies;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateCompaniesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateCompaniesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.Company[] rval;

			/// <summary> Creates a new instance of the <see cref="updateCompaniesResponse"/>
			/// class. </summary>
			public updateCompaniesResponse() {
			}

			/// <summary> Creates a new instance of the <see cref="updateCompaniesResponse"/>
			/// class. </summary>
			public updateCompaniesResponse(Google.Api.Ads.AdManager.v201802.Company[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>Settings for a <a href='Company'>Company</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CompanySettings {
		private BillingCap billingCapField;

		private bool billingCapFieldSpecified;

		private BillingSchedule billingScheduleField;

		private bool billingScheduleFieldSpecified;

		private BillingSource billingSourceField;

		private bool billingSourceFieldSpecified;

		private long advertiserDiscountField;

		private bool advertiserDiscountFieldSpecified;

		private long valueAddedTaxField;

		private bool valueAddedTaxFieldSpecified;

		private long agencyCommissionField;

		private bool agencyCommissionFieldSpecified;

		/// <summary>Default billing cap for <a href='Proposal'>proposals</a> created by the <a
		/// href='Company'>Company</a> of type <a
		/// href='Company.Type#ADVERTISER'>Company.Type#ADVERTISER</a> in Sales Manager.
		/// Return null if default billing setting feature is disabled or <a
		/// href='BillingSource'>BillingSource</a> is <a
		/// href='BillingSource#CONTRACTED'>BillingSource#CONTRACTED</a>. It is allowed that
		/// all of the BillingCap, BillingSchedule, BillingSource are null when the company
		/// has no setting about these values.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public BillingCap billingCap {
			get {
				return this.billingCapField;
			}
			set {
				this.billingCapField = value;
				this.billingCapSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="billingCap"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool billingCapSpecified {
			get {
				return this.billingCapFieldSpecified;
			}
			set {
				this.billingCapFieldSpecified = value;
			}
		}

		/// <summary>Default billing schedule for <a href='Proposal'>proposals</a> created by the <a
		/// href='Company'>Company</a> of type <a
		/// href='Company.Type#ADVERTISER'>Company.Type#ADVERTISER</a> in Sales Manager.
		/// Return null if default billing setting feature is disabled or <a
		/// href='BillingSource'>BillingSource</a> is not <a
		/// href='BillingSource#CONTRACTED'>BillingSource#CONTRACTED</a>. It is allowed that
		/// all of the BillingCap, BillingSchedule, BillingSource are null when the company
		/// has no setting about these values.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public BillingSchedule billingSchedule {
			get {
				return this.billingScheduleField;
			}
			set {
				this.billingScheduleField = value;
				this.billingScheduleSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="billingSchedule" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool billingScheduleSpecified {
			get {
				return this.billingScheduleFieldSpecified;
			}
			set {
				this.billingScheduleFieldSpecified = value;
			}
		}

		/// <summary>Default billing source for <a href='Proposal'>proposals</a> created by the <a
		/// href='Company'>Company</a> of type <a
		/// href='Company.Type#ADVERTISER'>Company.Type#ADVERTISER</a> in Sales Manager.
		/// Return null if default billing setting feature is disabled. It is allowed that
		/// all of the BillingCap, BillingSchedule, BillingSource are null when the company
		/// has no setting about these values.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public BillingSource billingSource {
			get {
				return this.billingSourceField;
			}
			set {
				this.billingSourceField = value;
				this.billingSourceSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="billingSource" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool billingSourceSpecified {
			get {
				return this.billingSourceFieldSpecified;
			}
			set {
				this.billingSourceFieldSpecified = value;
			}
		}

		/// <summary>Default advertiser discount for <a href='Proposal'>proposals</a> created by the
		/// <a href='Company'>Company</a> of type <a
		/// href='Company.Type#ADVERTISER'>Company.Type#ADVERTISER</a> in Sales Manager.
		/// Return null if default billing setting feature is disabled or the company has no
		/// setting on this value. It presents in millipercentage (values 0 to 100000).
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public long advertiserDiscount {
			get {
				return this.advertiserDiscountField;
			}
			set {
				this.advertiserDiscountField = value;
				this.advertiserDiscountSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="advertiserDiscount" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool advertiserDiscountSpecified {
			get {
				return this.advertiserDiscountFieldSpecified;
			}
			set {
				this.advertiserDiscountFieldSpecified = value;
			}
		}

		/// <summary>Default value added tax for <a href='Proposal'>proposals</a> created by the <a
		/// href='Company'>Company</a> of type <a
		/// href='Company.Type#ADVERTISER'>Company.Type#ADVERTISER</a> in Sales Manager.
		/// Return null if default billing setting feature is disabled or the company has no
		/// setting on this value. It presents in millipercentage (values 0 to 100000).
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public long valueAddedTax {
			get {
				return this.valueAddedTaxField;
			}
			set {
				this.valueAddedTaxField = value;
				this.valueAddedTaxSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="valueAddedTax" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool valueAddedTaxSpecified {
			get {
				return this.valueAddedTaxFieldSpecified;
			}
			set {
				this.valueAddedTaxFieldSpecified = value;
			}
		}

		/// <summary>Default agency commission for <a href='Proposal'>proposals</a> associated with
		/// the <a href='Company'>Company</a> of type <a
		/// href='Company.Type#AGENCY'>Company.Type#AGENCY</a> in Sales Manager. Return null
		/// if the default billing setting feature is disabled or the company has no setting
		/// on this value. It presents in millipercentage (values 0 to 100000).
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public long agencyCommission {
			get {
				return this.agencyCommissionField;
			}
			set {
				this.agencyCommissionField = value;
				this.agencyCommissionSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="agencyCommission" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool agencyCommissionSpecified {
			get {
				return this.agencyCommissionFieldSpecified;
			}
			set {
				this.agencyCommissionFieldSpecified = value;
			}
		}
	}


	/// <summary>A <code>Company</code> represents an agency, a single advertiser or an entire
	/// advertising network.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class Company {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private CompanyType typeField;

		private bool typeFieldSpecified;

		private string addressField;

		private string emailField;

		private string faxPhoneField;

		private string primaryPhoneField;

		private string externalIdField;

		private string commentField;

		private CompanyCreditStatus creditStatusField;

		private bool creditStatusFieldSpecified;

		private CompanySettings settingsField;

		private AppliedLabel[] appliedLabelsField;

		private long primaryContactIdField;

		private bool primaryContactIdFieldSpecified;

		private long[] appliedTeamIdsField;

		private int thirdPartyCompanyIdField;

		private bool thirdPartyCompanyIdFieldSpecified;

		private DateTime lastModifiedDateTimeField;

		/// <summary>Uniquely identifies the <code>Company</code>. This value is read-only and is
		/// assigned by Google when the company is created. This attribute is required for
		/// updates.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The full name of the company. This attribute is required and has a maximum
		/// length of 127 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>Specifies what kind of company this is. This attribute is required.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public CompanyType type {
			get {
				return this.typeField;
			}
			set {
				this.typeField = value;
				this.typeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="type" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool typeSpecified {
			get {
				return this.typeFieldSpecified;
			}
			set {
				this.typeFieldSpecified = value;
			}
		}

		/// <summary>Specifies the address of the company. This attribute is optional and has a
		/// maximum length of 65,535 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 3)]
		public string address {
			get {
				return this.addressField;
			}
			set {
				this.addressField = value;
			}
		}

		/// <summary>Specifies the email of the company. This attribute is optional and has a maximum
		/// length of 128 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 4)]
		public string email {
			get {
				return this.emailField;
			}
			set {
				this.emailField = value;
			}
		}

		/// <summary>Specifies the fax phone number of the company. This attribute is optional and
		/// has a maximum length of 63 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 5)]
		public string faxPhone {
			get {
				return this.faxPhoneField;
			}
			set {
				this.faxPhoneField = value;
			}
		}

		/// <summary>Specifies the primary phone number of the company. This attribute is optional
		/// and has a maximum length of 63 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 6)]
		public string primaryPhone {
			get {
				return this.primaryPhoneField;
			}
			set {
				this.primaryPhoneField = value;
			}
		}

		/// <summary>Specifies the external ID of the company. This attribute is optional and has a
		/// maximum length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 7)]
		public string externalId {
			get {
				return this.externalIdField;
			}
			set {
				this.externalIdField = value;
			}
		}

		/// <summary>Specifies the comment of the company. This attribute is optional and has a
		/// maximum length of 1024 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 8)]
		public string comment {
			get {
				return this.commentField;
			}
			set {
				this.commentField = value;
			}
		}

		/// <summary>Specifies the company's credit status. This attribute is optional and defaults
		/// to <a href='CreditStatus#ACTIVE'>CreditStatus#ACTIVE</a> when basic credit
		/// status settings are enabled, and <a
		/// href='CreditStatus#ON_HOLD'>CreditStatus#ON_HOLD</a> when advanced credit status
		/// settings are enabled.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 9)]
		public CompanyCreditStatus creditStatus {
			get {
				return this.creditStatusField;
			}
			set {
				this.creditStatusField = value;
				this.creditStatusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="creditStatus" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool creditStatusSpecified {
			get {
				return this.creditStatusFieldSpecified;
			}
			set {
				this.creditStatusFieldSpecified = value;
			}
		}

		/// <summary>Specifies the default billing settings of this <code>Company</code>. This
		/// attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 10)]
		public CompanySettings settings {
			get {
				return this.settingsField;
			}
			set {
				this.settingsField = value;
			}
		}

		/// <summary>The set of labels applied to this company.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("appliedLabels", Order = 11)]
		public AppliedLabel[] appliedLabels {
			get {
				return this.appliedLabelsField;
			}
			set {
				this.appliedLabelsField = value;
			}
		}

		/// <summary>The ID of the <a href='Contact'>Contact</a> who is acting as the primary contact
		/// for this company. This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 12)]
		public long primaryContactId {
			get {
				return this.primaryContactIdField;
			}
			set {
				this.primaryContactIdField = value;
				this.primaryContactIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="primaryContactId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool primaryContactIdSpecified {
			get {
				return this.primaryContactIdFieldSpecified;
			}
			set {
				this.primaryContactIdFieldSpecified = value;
			}
		}

		/// <summary>The IDs of all teams that this company is on directly.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("appliedTeamIds", Order = 13)]
		public long[] appliedTeamIds {
			get {
				return this.appliedTeamIdsField;
			}
			set {
				this.appliedTeamIdsField = value;
			}
		}

		/// <summary>Specifies the ID of the Google-recognized canonicalized form of this company.
		/// This attribute is optional.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 14)]
		public int thirdPartyCompanyId {
			get {
				return this.thirdPartyCompanyIdField;
			}
			set {
				this.thirdPartyCompanyIdField = value;
				this.thirdPartyCompanyIdSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="thirdPartyCompanyId" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool thirdPartyCompanyIdSpecified {
			get {
				return this.thirdPartyCompanyIdFieldSpecified;
			}
			set {
				this.thirdPartyCompanyIdFieldSpecified = value;
			}
		}

		/// <summary>The date and time this company was last modified.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 15)]
		public DateTime lastModifiedDateTime {
			get {
				return this.lastModifiedDateTimeField;
			}
			set {
				this.lastModifiedDateTimeField = value;
			}
		}
	}


	/// <summary>The type of the company. Once a company is created, it is not possible to change
	/// its type.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "Company.Type", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CompanyType {
		/// <summary>The publisher's own advertiser. When no outside advertiser buys its inventory,
		/// the publisher may run its own advertising campaigns.
		/// </summary>
		HOUSE_ADVERTISER = 0,
		/// <summary>The publisher's own agency.
		/// </summary>
		HOUSE_AGENCY = 1,
		/// <summary>A business entity that buys publisher inventory to run advertising campaigns. An
		/// advertiser is optionally associated with one or more agencies.
		/// </summary>
		ADVERTISER = 2,
		/// <summary>A business entity that offers services, such as advertising creation, placement,
		/// and management, to advertisers.
		/// </summary>
		AGENCY = 3,
		/// <summary>A company representing multiple advertisers and agencies.
		/// </summary>
		AD_NETWORK = 4,
		/// <summary>A company representing a partner.
		/// </summary>
		PARTNER = 8,
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 7,
	}


	/// <summary>Specifies the credit-worthiness of the company for which the publisher runs an
	/// order. By doing so, the publisher can control the running of campaigns for the
	/// company. A publisher can choose between Basic and Advanced Credit Status
	/// settings. This feature needs to be enabled in the Ad Manager web site. Also the
	/// kind of setting you need - Basic or Advanced must be configured. If Basic is
	/// enabled then, the values allowed are <code>ACTIVE</code> and <code></code>. If
	/// Advanced is chosen, then all values are allowed. Choosing an Advanced setting
	/// when only the Basic feature has been enabled, or using the Basic setting without
	/// turning the feature on will result in an error.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "Company.CreditStatus", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum CompanyCreditStatus {
		/// <summary>When the credit status is active, all line items in all orders belonging to the
		/// company will be served. This is a Basic as well as an Advanced Credit Status
		/// setting.
		/// </summary>
		ACTIVE = 0,
		/// <summary>When the credit status is on hold, the publisher cannot activate new line items
		/// of the company. However, line items that were activated before the credit status
		/// change will remain active. You can still create orders and line items for the
		/// company. This is an Advanced Credit Status setting.
		/// </summary>
		ON_HOLD = 1,
		/// <summary>When the credit status is credit stop, the publisher cannot activate new line
		/// items of the company. However, line items that were activated before the credit
		/// status change will remain active. You cannot create any new orders or line items
		/// for the company. This is an Advanced Credit Status setting.
		/// </summary>
		CREDIT_STOP = 2,
		/// <summary>When the credit status is inactive, the publisher cannot activate new line items
		/// of the company. However, line items that were activated before the credit status
		/// change will remain active. You cannot create any new orders or line items for
		/// the company. It is used to mark companies with which business is to be
		/// discontinued. Such companies are not listed in Ad Manager web site. This is a
		/// Basic as well as an Advanced Credit Status setting.
		/// </summary>
		INACTIVE = 3,
		/// <summary>When the credit status of a company is marked blocked, then all active line
		/// items belonging to the company will stop serving with immediate effect. You
		/// cannot active new line items of the company nor can you create any new orders or
		/// line items belonging to the company. This is an Advanced Credit Status setting.
		/// </summary>
		BLOCKED = 4,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.CompanyServiceInterface")]
	public interface CompanyServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.CompanyService.createCompaniesResponse createCompanies(Wrappers.CompanyService.createCompaniesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.CompanyService.createCompaniesResponse> createCompaniesAsync(Wrappers.CompanyService.createCompaniesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.CompanyPage getCompaniesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CompanyPage> getCompaniesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.CompanyService.updateCompaniesResponse updateCompanies(Wrappers.CompanyService.updateCompaniesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.CompanyService.updateCompaniesResponse> updateCompaniesAsync(Wrappers.CompanyService.updateCompaniesRequest request);
	}


	/// <summary>Captures a page of <a href='Company'>Company</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class CompanyPage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private Company[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of companies contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public Company[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface CompanyServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.CompanyServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides operations for creating, updating and retrieving <a
	/// href='Company'>Company</a> objects.
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class CompanyService : AdManagerSoapClient<ICompanyService>, ICompanyService {
		/// <summary> Creates a new instance of the <see cref="CompanyService"/> class.
		/// </summary>
		public CompanyService() {
		}

		/// <summary> Creates a new instance of the <see cref="CompanyService"/> class.
		/// </summary>
		public CompanyService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="CompanyService"/> class.
		/// </summary>
		public CompanyService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="CompanyService"/> class.
		/// </summary>
		public CompanyService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="CompanyService"/> class.
		/// </summary>
		public CompanyService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.CompanyService.createCompaniesResponse Google.Api.Ads.AdManager.v201802.CompanyServiceInterface.createCompanies(Wrappers.CompanyService.createCompaniesRequest request) {
			return base.Channel.createCompanies(request);
		}

		/// <summary>Creates new <a href='Company'>Company</a> objects.
		/// </summary><param name='companies'>the companies to create</param>
		/// <returns>the created companies with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Company[] createCompanies(Google.Api.Ads.AdManager.v201802.Company[] companies) {
			Wrappers.CompanyService.createCompaniesRequest inValue = new Wrappers.CompanyService.createCompaniesRequest();
			inValue.companies = companies;
			Wrappers.CompanyService.createCompaniesResponse retVal = ((Google.Api.Ads.AdManager.v201802.CompanyServiceInterface)(this)).createCompanies(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.CompanyService.createCompaniesResponse> Google.Api.Ads.AdManager.v201802.CompanyServiceInterface.createCompaniesAsync(Wrappers.CompanyService.createCompaniesRequest request) {
			return base.Channel.createCompaniesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Company[]> createCompaniesAsync(Google.Api.Ads.AdManager.v201802.Company[] companies) {
			Wrappers.CompanyService.createCompaniesRequest inValue = new Wrappers.CompanyService.createCompaniesRequest();
			inValue.companies = companies;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Company[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.CompanyServiceInterface)(this)).createCompaniesAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='CompanyPage'>CompanyPage</a> of <a href='Company'>Company</a>
		/// objects that satisfy the given <a href='Statement#query'>Statement#query</a>.
		/// The following fields are supported for filtering: <table> <tr> <th
		/// scope="col">PQL Property</th> <th scope="col">Object Property</th> </tr> <tr>
		/// <td><code>id</code></td> <td><a href='Company#id'>Company#id</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a href='Company#name'>Company#name</a></td>
		/// </tr> <tr> <td><code>type</code></td> <td><a
		/// href='Company#type'>Company#type</a></td> </tr> <tr>
		/// <td><code>lastModifiedDateTime</code></td> <td><a
		/// href='Company#lastModifiedDateTime'>Company#lastModifiedDateTime</a></td> </tr>
		/// </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of companies</param>
		/// <returns>the companies that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.CompanyPage getCompaniesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getCompaniesByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CompanyPage> getCompaniesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getCompaniesByStatementAsync(filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.CompanyService.updateCompaniesResponse Google.Api.Ads.AdManager.v201802.CompanyServiceInterface.updateCompanies(Wrappers.CompanyService.updateCompaniesRequest request) {
			return base.Channel.updateCompanies(request);
		}

		/// <summary>Updates the specified <a href='Company'>Company</a> objects.
		/// </summary><param name='companies'>the companies to update</param>
		/// <returns>the updated companies</returns>
		public virtual Google.Api.Ads.AdManager.v201802.Company[] updateCompanies(Google.Api.Ads.AdManager.v201802.Company[] companies) {
			Wrappers.CompanyService.updateCompaniesRequest inValue = new Wrappers.CompanyService.updateCompaniesRequest();
			inValue.companies = companies;
			Wrappers.CompanyService.updateCompaniesResponse retVal = ((Google.Api.Ads.AdManager.v201802.CompanyServiceInterface)(this)).updateCompanies(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.CompanyService.updateCompaniesResponse> Google.Api.Ads.AdManager.v201802.CompanyServiceInterface.updateCompaniesAsync(Wrappers.CompanyService.updateCompaniesRequest request) {
			return base.Channel.updateCompaniesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Company[]> updateCompaniesAsync(Google.Api.Ads.AdManager.v201802.Company[] companies) {
			Wrappers.CompanyService.updateCompaniesRequest inValue = new Wrappers.CompanyService.updateCompaniesRequest();
			inValue.companies = companies;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Company[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.CompanyServiceInterface)(this)).updateCompaniesAsync(inValue)).Result.rval);
		}
	}
	namespace Wrappers.ContentBundleService
	{
		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createContentBundles", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createContentBundlesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("contentBundles")]
			public Google.Api.Ads.AdManager.v201802.ContentBundle[] contentBundles;

			/// <summary> Creates a new instance of the <see
			/// cref="createContentBundlesRequest"/> class. </summary>
			public createContentBundlesRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createContentBundlesRequest"/> class. </summary>
			public createContentBundlesRequest(Google.Api.Ads.AdManager.v201802.ContentBundle[] contentBundles) {
				this.contentBundles = contentBundles;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "createContentBundlesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class createContentBundlesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ContentBundle[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="createContentBundlesResponse"/> class. </summary>
			public createContentBundlesResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="createContentBundlesResponse"/> class. </summary>
			public createContentBundlesResponse(Google.Api.Ads.AdManager.v201802.ContentBundle[] rval) {
				this.rval = rval;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateContentBundles", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateContentBundlesRequest {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("contentBundles")]
			public Google.Api.Ads.AdManager.v201802.ContentBundle[] contentBundles;

			/// <summary> Creates a new instance of the <see
			/// cref="updateContentBundlesRequest"/> class. </summary>
			public updateContentBundlesRequest() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateContentBundlesRequest"/> class. </summary>
			public updateContentBundlesRequest(Google.Api.Ads.AdManager.v201802.ContentBundle[] contentBundles) {
				this.contentBundles = contentBundles;
			}
		}


		[System.Diagnostics.DebuggerStepThroughAttribute()]
		[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		[System.ServiceModel.MessageContractAttribute(WrapperName = "updateContentBundlesResponse", WrapperNamespace = "https://www.google.com/apis/ads/publisher/v201802", IsWrapped = true)]
		public partial class updateContentBundlesResponse {
			[System.ServiceModel.MessageBodyMemberAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", Order = 0)]
			[System.Xml.Serialization.XmlElementAttribute("rval")]
			public Google.Api.Ads.AdManager.v201802.ContentBundle[] rval;

			/// <summary> Creates a new instance of the <see
			/// cref="updateContentBundlesResponse"/> class. </summary>
			public updateContentBundlesResponse() {
			}

			/// <summary> Creates a new instance of the <see
			/// cref="updateContentBundlesResponse"/> class. </summary>
			public updateContentBundlesResponse(Google.Api.Ads.AdManager.v201802.ContentBundle[] rval) {
				this.rval = rval;
			}
		}
	}
	/// <summary>A <code>ContentBundle</code> is a grouping of individual <a
	/// href='Content'>Content</a>. A <code>ContentBundle</code> is defined as including
	/// the <code>Content</code> that match certain filter rules, along with the option
	/// to explicitly include or exclude certain <code>Content</code> IDs.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ContentBundle {
		private long idField;

		private bool idFieldSpecified;

		private string nameField;

		private ContentBundleStatus statusField;

		private bool statusFieldSpecified;

		/// <summary>ID that uniquely identifies the <code>ContentBundle</code>. This attribute is
		/// read-only and is assigned by Google when a content bundle is created.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public long id {
			get {
				return this.idField;
			}
			set {
				this.idField = value;
				this.idSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="id" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool idSpecified {
			get {
				return this.idFieldSpecified;
			}
			set {
				this.idFieldSpecified = value;
			}
		}

		/// <summary>The name of the <code>ContentBundle</code>. This attribute is required and has a
		/// maximum length of 255 characters.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public string name {
			get {
				return this.nameField;
			}
			set {
				this.nameField = value;
			}
		}

		/// <summary>The <a href='ContentBundleStatus'>ContentBundleStatus</a> of the
		/// <code>ContentBundle</code>. This attribute is read-only and defaults to <a
		/// href='ContentBundleStatus#INACTIVE'>ContentBundleStatus#INACTIVE</a>.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 2)]
		public ContentBundleStatus status {
			get {
				return this.statusField;
			}
			set {
				this.statusField = value;
				this.statusSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="status" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool statusSpecified {
			get {
				return this.statusFieldSpecified;
			}
			set {
				this.statusFieldSpecified = value;
			}
		}
	}


	/// <summary>Status for <code>ContentBundle</code> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ContentBundleStatus {
		/// <summary>The object is active and stats are collected.
		/// </summary>
		ACTIVE = 0,
		/// <summary>The object is no longer active and no stats collected.
		/// </summary>
		INACTIVE = 1,
		/// <summary>The object has been archived.
		/// </summary>
		ARCHIVED = 2,
	}


	/// <summary>Errors associated with the incorrect creation of a <a
	/// href='Condition'>Condition</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ContentFilterError : ApiError {
		private ContentFilterErrorReason reasonField;

		private bool reasonFieldSpecified;

		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public ContentFilterErrorReason reason {
			get {
				return this.reasonField;
			}
			set {
				this.reasonField = value;
				this.reasonSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="reason" />,
		/// <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool reasonSpecified {
			get {
				return this.reasonFieldSpecified;
			}
			set {
				this.reasonFieldSpecified = value;
			}
		}
	}


	/// <summary>The reasons for the <a href='ContentFilterError'>ContentFilterError</a>.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Xml.Serialization.XmlTypeAttribute(TypeName = "ContentFilterError.Reason", Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public enum ContentFilterErrorReason {
		/// <summary>The value returned if the actual value is not exposed by the requested API
		/// version.
		/// </summary>
		UNKNOWN = 0,
		WRONG_NUMBER_OF_ARGUMENTS = 1,
		ANY_FILTER_NOT_SUPPORTED = 2,
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	[System.ServiceModel.ServiceContractAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802", ConfigurationName = "Google.Api.Ads.AdManager.v201802.ContentBundleServiceInterface")]
	public interface ContentBundleServiceInterface
	{
		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ContentBundleService.createContentBundlesResponse createContentBundles(Wrappers.ContentBundleService.createContentBundlesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ContentBundleService.createContentBundlesResponse> createContentBundlesAsync(Wrappers.ContentBundleService.createContentBundlesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.ContentBundlePage getContentBundlesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentBundlePage> getContentBundlesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Google.Api.Ads.AdManager.v201802.UpdateResult performContentBundleAction(Google.Api.Ads.AdManager.v201802.ContentBundleAction contentBundleAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performContentBundleActionAsync(Google.Api.Ads.AdManager.v201802.ContentBundleAction contentBundleAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		// CODEGEN: Parameter 'rval' requires additional schema information that cannot be captured using the parameter mode. The specific attribute is 'System.Xml.Serialization.XmlElementAttribute'.
		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		[System.ServiceModel.FaultContractAttribute(typeof(Google.Api.Ads.AdManager.v201802.ApiException), Action = "", Name = "ApiExceptionFault")]
		[System.ServiceModel.XmlSerializerFormatAttribute(SupportFaults = true)]
		[System.ServiceModel.ServiceKnownTypeAttribute(typeof(ApplicationException))]
		[return: System.ServiceModel.MessageParameterAttribute(Name = "rval")]
		Wrappers.ContentBundleService.updateContentBundlesResponse updateContentBundles(Wrappers.ContentBundleService.updateContentBundlesRequest request);

		[System.ServiceModel.OperationContractAttribute(Action = "", ReplyAction = "*")]
		System.Threading.Tasks.Task<Wrappers.ContentBundleService.updateContentBundlesResponse> updateContentBundlesAsync(Wrappers.ContentBundleService.updateContentBundlesRequest request);
	}


	/// <summary>Captures a page of <a href='ContentBundle'>ContentBundle</a> objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ContentBundlePage {
		private int totalResultSetSizeField;

		private bool totalResultSetSizeFieldSpecified;

		private int startIndexField;

		private bool startIndexFieldSpecified;

		private ContentBundle[] resultsField;

		/// <summary>The size of the total result set to which this page belongs.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public int totalResultSetSize {
			get {
				return this.totalResultSetSizeField;
			}
			set {
				this.totalResultSetSizeField = value;
				this.totalResultSetSizeSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see
		/// cref="totalResultSetSize" />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool totalResultSetSizeSpecified {
			get {
				return this.totalResultSetSizeFieldSpecified;
			}
			set {
				this.totalResultSetSizeFieldSpecified = value;
			}
		}

		/// <summary>The absolute index in the total result set on which this page begins.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 1)]
		public int startIndex {
			get {
				return this.startIndexField;
			}
			set {
				this.startIndexField = value;
				this.startIndexSpecified = true;
			}
		}

		/// <summary> <code>true</code>, if a value is specified for <see cref="startIndex"
		/// />, <code>false</code> otherwise. </summary>
		[System.Xml.Serialization.XmlIgnoreAttribute()]
		[EditorBrowsable(EditorBrowsableState.Never)]
		public bool startIndexSpecified {
			get {
				return this.startIndexFieldSpecified;
			}
			set {
				this.startIndexFieldSpecified = value;
			}
		}

		/// <summary>The collection of content bundles contained within this page.
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute("results", Order = 2)]
		public ContentBundle[] results {
			get {
				return this.resultsField;
			}
			set {
				this.resultsField = value;
			}
		}
	}


	/// <summary>Represents the actions that can be performed on <a
	/// href='ContentBundle'>ContentBundle</a> objects.
	/// </summary>
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(IncludeContentInContentBundle))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ExcludeContentFromContentBundle))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(DeactivateContentBundles))]
	[System.Xml.Serialization.XmlIncludeAttribute(typeof(ActivateContentBundles))]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public abstract partial class ContentBundleAction {
	}


	/// <summary>The action used for explicitly including specific content in a <a
	/// href='ContentBundle'>ContentBundle</a> object.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class IncludeContentInContentBundle : ContentBundleAction {
		private Statement contentStatementField;

		/// <summary>The Publisher Query Language statement specifying which <a
		/// href='Content'>Content</a> to include in the <a
		/// href='ContentBundle'>ContentBundle</a>. The statement is expressed in terms of
		/// <code>Content</code> fields such as name and status. <p>All fields supported by
		/// <a
		/// href='ContentService#getContentByStatement'>ContentService#getContentByStatement</a>
		/// are supported on this statement.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public Statement contentStatement {
			get {
				return this.contentStatementField;
			}
			set {
				this.contentStatementField = value;
			}
		}
	}


	/// <summary>The action used for explicitly excluding specific content from a <a
	/// href='ContentBundle'>ContentBundle</a> object.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ExcludeContentFromContentBundle : ContentBundleAction {
		private Statement contentStatementField;

		/// <summary>The Publisher Query Language statement specifying which <a
		/// href='Content'>Content</a> to exclude from the <a
		/// href='ContentBundle'>ContentBundle</a>. The statement is expressed in terms of
		/// <code>Content</code> fields such as name and status. <p>All fields supported by
		/// <a
		/// href='ContentService#getContentByStatement'>ContentService#getContentByStatement</a>
		/// are supported on this statement.</p>
		/// </summary>
		[System.Xml.Serialization.XmlElementAttribute(Order = 0)]
		public Statement contentStatement {
			get {
				return this.contentStatementField;
			}
			set {
				this.contentStatementField = value;
			}
		}
	}


	/// <summary>The action used for deactivating <a href='ContentBundle'>ContentBundle</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class DeactivateContentBundles : ContentBundleAction {
	}


	/// <summary>The action used for activating <a href='ContentBundle'>ContentBundle</a>
	/// objects.
	/// </summary>
	[System.CodeDom.Compiler.GeneratedCodeAttribute("svcutil", "4.6.1055.0")]
	[System.SerializableAttribute()]
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.ComponentModel.DesignerCategoryAttribute("code")]
	[System.Xml.Serialization.XmlTypeAttribute(Namespace = "https://www.google.com/apis/ads/publisher/v201802")]
	public partial class ActivateContentBundles : ContentBundleAction {
	}


	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public interface ContentBundleServiceInterfaceChannel : Google.Api.Ads.AdManager.v201802.ContentBundleServiceInterface, System.ServiceModel.IClientChannel
	{
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='ContentBundle'>ContentBundle</a> objects. <p>A <code>ContentBundle</code>
	/// is a grouping of <a href='Content'>Content</a> that match filter rules as well
	/// as taking into account explicitly included or excluded <code>Content</code>.</p>
	/// </summary>
	[System.Diagnostics.DebuggerStepThroughAttribute()]
	[System.CodeDom.Compiler.GeneratedCodeAttribute("System.ServiceModel", "4.0.0.0")]
	public partial class ContentBundleService : AdManagerSoapClient<IContentBundleService>, IContentBundleService {
		/// <summary> Creates a new instance of the <see cref="ContentBundleService"/>
		/// class. </summary>
		public ContentBundleService() {
		}

		/// <summary> Creates a new instance of the <see cref="ContentBundleService"/>
		/// class. </summary>
		public ContentBundleService(string endpointConfigurationName)
			: base(endpointConfigurationName) {
		}

		/// <summary> Creates a new instance of the <see cref="ContentBundleService"/>
		/// class. </summary>
		public ContentBundleService(string endpointConfigurationName, string remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ContentBundleService"/>
		/// class. </summary>
		public ContentBundleService(string endpointConfigurationName, System.ServiceModel.EndpointAddress remoteAddress)
			: base(endpointConfigurationName, remoteAddress) {
		}

		/// <summary> Creates a new instance of the <see cref="ContentBundleService"/>
		/// class. </summary>
		public ContentBundleService(System.ServiceModel.Channels.Binding binding, System.ServiceModel.EndpointAddress remoteAddress)
			: base(binding, remoteAddress) {
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ContentBundleService.createContentBundlesResponse Google.Api.Ads.AdManager.v201802.ContentBundleServiceInterface.createContentBundles(Wrappers.ContentBundleService.createContentBundlesRequest request) {
			return base.Channel.createContentBundles(request);
		}

		/// <summary>Creates new <a href='ContentBundle'>ContentBundle</a> objects.
		/// </summary><param name='contentBundles'>the content bundles to create</param>
		/// <returns>the created content bundles with their IDs filled in</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ContentBundle[] createContentBundles(Google.Api.Ads.AdManager.v201802.ContentBundle[] contentBundles) {
			Wrappers.ContentBundleService.createContentBundlesRequest inValue = new Wrappers.ContentBundleService.createContentBundlesRequest();
			inValue.contentBundles = contentBundles;
			Wrappers.ContentBundleService.createContentBundlesResponse retVal = ((Google.Api.Ads.AdManager.v201802.ContentBundleServiceInterface)(this)).createContentBundles(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ContentBundleService.createContentBundlesResponse> Google.Api.Ads.AdManager.v201802.ContentBundleServiceInterface.createContentBundlesAsync(Wrappers.ContentBundleService.createContentBundlesRequest request) {
			return base.Channel.createContentBundlesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentBundle[]> createContentBundlesAsync(Google.Api.Ads.AdManager.v201802.ContentBundle[] contentBundles) {
			Wrappers.ContentBundleService.createContentBundlesRequest inValue = new Wrappers.ContentBundleService.createContentBundlesRequest();
			inValue.contentBundles = contentBundles;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentBundle[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ContentBundleServiceInterface)(this)).createContentBundlesAsync(inValue)).Result.rval);
		}

		/// <summary>Gets a <a href='ContentBundlePage'>ContentBundlePage</a> of <a
		/// href='ContentBundle'>ContentBundle</a> objects that satisfy the given <a
		/// href='Statement#query'>Statement#query</a>. The following fields are supported
		/// for filtering: <table> <tr> <th scope="col">PQL Property</th> <th
		/// scope="col">Object Property</th> </tr> <tr> <td><code>id</code></td> <td><a
		/// href='ContentBundle#id'>ContentBundle#id</a></td> </tr> <tr>
		/// <td><code>name</code></td> <td><a
		/// href='ContentBundle#name'>ContentBundle#name</a></td> </tr> <tr>
		/// <td><code>status</code></td> <td><a
		/// href='ContentBundle#status'>ContentBundle#status</a></td> </tr> </table>
		/// </summary><param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of content bundles</param>
		/// <returns>the content bundles that match the given filter</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ContentBundlePage getContentBundlesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getContentBundlesByStatement(filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentBundlePage> getContentBundlesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.getContentBundlesByStatementAsync(filterStatement);
		}

		/// <summary>Performs actions on <a href='ContentBundle'>ContentBundle</a> objects that match
		/// the given <a href='Statement#query'>Statement#query</a>.
		/// </summary><param name='contentBundleAction'>the action to perform</param>
		/// <param name='filterStatement'>a Publisher Query Language statement used to
		/// filter a set of content bundles</param>
		/// <returns>the result of the action performed</returns>
		public virtual Google.Api.Ads.AdManager.v201802.UpdateResult performContentBundleAction(Google.Api.Ads.AdManager.v201802.ContentBundleAction contentBundleAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performContentBundleAction(contentBundleAction, filterStatement);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UpdateResult> performContentBundleActionAsync(Google.Api.Ads.AdManager.v201802.ContentBundleAction contentBundleAction, Google.Api.Ads.AdManager.v201802.Statement filterStatement) {
			return base.Channel.performContentBundleActionAsync(contentBundleAction, filterStatement);
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		Wrappers.ContentBundleService.updateContentBundlesResponse Google.Api.Ads.AdManager.v201802.ContentBundleServiceInterface.updateContentBundles(Wrappers.ContentBundleService.updateContentBundlesRequest request) {
			return base.Channel.updateContentBundles(request);
		}

		/// <summary>Updates the specified <a href='ContentBundle'>ContentBundle</a> objects.
		/// </summary><param name='contentBundles'>the content bundles to update</param>
		/// <returns>the updated content bundles</returns>
		public virtual Google.Api.Ads.AdManager.v201802.ContentBundle[] updateContentBundles(Google.Api.Ads.AdManager.v201802.ContentBundle[] contentBundles) {
			Wrappers.ContentBundleService.updateContentBundlesRequest inValue = new Wrappers.ContentBundleService.updateContentBundlesRequest();
			inValue.contentBundles = contentBundles;
			Wrappers.ContentBundleService.updateContentBundlesResponse retVal = ((Google.Api.Ads.AdManager.v201802.ContentBundleServiceInterface)(this)).updateContentBundles(inValue);
			return retVal.rval;
		}

		[System.ComponentModel.EditorBrowsableAttribute(System.ComponentModel.EditorBrowsableState.Advanced)]
		System.Threading.Tasks.Task<Wrappers.ContentBundleService.updateContentBundlesResponse> Google.Api.Ads.AdManager.v201802.ContentBundleServiceInterface.updateContentBundlesAsync(Wrappers.ContentBundleService.updateContentBundlesRequest request) {
			return base.Channel.updateContentBundlesAsync(request);
		}

		public virtual System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentBundle[]> updateContentBundlesAsync(Google.Api.Ads.AdManager.v201802.ContentBundle[] contentBundles) {
			Wrappers.ContentBundleService.updateContentBundlesRequest inValue = new Wrappers.ContentBundleService.updateContentBundlesRequest();
			inValue.contentBundles = contentBundles;
			return System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentBundle[]>.Factory.StartNew(() => (((Google.Api.Ads.AdManager.v201802.ContentBundleServiceInterface)(this)).updateContentBundlesAsync(inValue)).Result.rval);
		}
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='ActivityGroup'>ActivityGroup</a> objects. <p>An activity group contains <a
	/// href='Activity'>Activity</a> objects. Activities have a many-to-one relationship
	/// with activity groups, meaning each activity can belong to only one activity
	/// group, but activity groups can have multiple activities. An activity group can
	/// be used to manage the activities it contains.</p>
	/// </summary>
	public interface IActivityGroupService : ActivityGroupServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.ActivityGroup[] createActivityGroups(Google.Api.Ads.AdManager.v201802.ActivityGroup[] activityGroups);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ActivityGroup[]> createActivityGroupsAsync(Google.Api.Ads.AdManager.v201802.ActivityGroup[] activityGroups);

		Google.Api.Ads.AdManager.v201802.ActivityGroup[] updateActivityGroups(Google.Api.Ads.AdManager.v201802.ActivityGroup[] activityGroups);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ActivityGroup[]> updateActivityGroupsAsync(Google.Api.Ads.AdManager.v201802.ActivityGroup[] activityGroups);
	}


	/// <summary>Provides methods for creating, updating, and retrieving <a
	/// href='ContentMetadataKeyHierarchy'>ContentMetadataKeyHierarchy</a> objects.
	/// </summary>
	public interface IContentMetadataKeyHierarchyService : ContentMetadataKeyHierarchyServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] createContentMetadataKeyHierarchies(Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] contentMetadataKeyHierarchies);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[]> createContentMetadataKeyHierarchiesAsync(Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] contentMetadataKeyHierarchies);

		Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] updateContentMetadataKeyHierarchies(Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] contentMetadataKeyHierarchies);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[]> updateContentMetadataKeyHierarchiesAsync(Google.Api.Ads.AdManager.v201802.ContentMetadataKeyHierarchy[] contentMetadataKeyHierarchies);
	}


	/// <summary>Service for retrieving <a href='Content'>Content</a>. <p><code>Content</code>
	/// entities can be targeted in video <a href='LineItem'>LineItem</a>s.</p> <p>You
	/// can query for content that belongs to a particular category or has assigned
	/// metadata. Categories and metadata for <code></code> are stored in DFP as <a
	/// href='CustomCriteria'>CustomCriteria</a>.</p> <p>For example, to find all
	/// <code>Content</code> that is "genre=comedy", you would:</p> <ul> <li>Retrieve
	/// the custom targeting key corresponding to "genre" using <a
	/// href=''>CustomTargetingService#getCustomTargetingKeysByStatement</a></li>
	/// <li>Using the <a
	/// href='CustomTargetingService#getCustomTargetingValuesByStatement'>CustomTargetingService#getCustomTargetingValuesByStatement</a>
	/// method and a filter like "WHERE customTargetingKeyId = :genreKeyId and name =
	/// 'comedy'", retrieve the ID for the "comedy" custom targeting value.</li>
	/// <li>Call <a
	/// href='#getContentByStatementAndCustomTargetingValue'>#getContentByStatementAndCustomTargetingValue</a>
	/// with a filter like "WHERE status = 'ACTIVE'" and the ID of the custom targeting
	/// value from step 2.</li> </ul>
	/// </summary>
	public interface IContentService : ContentServiceInterface, IDisposable
	{
	}


	/// <summary>Provides methods for adding, updating and retrieving <a
	/// href='Creative'>Creative</a> objects. <p>For a creative to run, it must be
	/// associated with a <a href='LineItem'>LineItem</a> managed by the <a
	/// href='LineItemCreativeAssociationService'>LineItemCreativeAssociationService</a>.</p>
	/// <p>Read more about creatives on the <a
	/// href="https://support.google.com/dfp_premium/answer/3185155">DFP Help
	/// Center</a>.</p>
	/// </summary>
	public interface ICreativeService : CreativeServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.Creative[] createCreatives(Google.Api.Ads.AdManager.v201802.Creative[] creatives);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Creative[]> createCreativesAsync(Google.Api.Ads.AdManager.v201802.Creative[] creatives);

		Google.Api.Ads.AdManager.v201802.Creative[] updateCreatives(Google.Api.Ads.AdManager.v201802.Creative[] creatives);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Creative[]> updateCreativesAsync(Google.Api.Ads.AdManager.v201802.Creative[] creatives);
	}


	/// <summary>Provides methods for adding, updating and retrieving <a
	/// href='CreativeSet'>CreativeSet</a> objects.
	/// </summary>
	public interface ICreativeSetService : CreativeSetServiceInterface, IDisposable
	{
	}


	/// <summary>Provides methods for retrieving <a href='CreativeTemplate'>CreativeTemplate</a>
	/// objects.
	/// </summary>
	public interface ICreativeTemplateService : CreativeTemplateServiceInterface, IDisposable
	{
	}


	/// <summary>Provides methods for the creation and management of creative wrappers. <a
	/// href='CreativeWrapper'>CreativeWrappers</a> allow HTML snippets to be served
	/// along with creatives. <p>Creative wrappers must be associated with a <a
	/// href='LabelType#CREATIVE_WRAPPER'>LabelType#CREATIVE_WRAPPER</a> label and
	/// applied to ad units by <a
	/// href='AdUnit#appliedLabels'>AdUnit#appliedLabels</a>.</p>
	/// </summary>
	public interface ICreativeWrapperService : CreativeWrapperServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.CreativeWrapper[] createCreativeWrappers(Google.Api.Ads.AdManager.v201802.CreativeWrapper[] creativeWrappers);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeWrapper[]> createCreativeWrappersAsync(Google.Api.Ads.AdManager.v201802.CreativeWrapper[] creativeWrappers);

		Google.Api.Ads.AdManager.v201802.CreativeWrapper[] updateCreativeWrappers(Google.Api.Ads.AdManager.v201802.CreativeWrapper[] creativeWrappers);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeWrapper[]> updateCreativeWrappersAsync(Google.Api.Ads.AdManager.v201802.CreativeWrapper[] creativeWrappers);
	}


	/// <summary>Provides operations for creating, updating and retrieving <a
	/// href='CustomTargetingKey'>CustomTargetingKey</a> and <a
	/// href=''>CustomTargetingValue</a> objects.
	/// </summary>
	public interface ICustomTargetingService : CustomTargetingServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] createCustomTargetingKeys(Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] keys);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomTargetingKey[]> createCustomTargetingKeysAsync(Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] keys);

		Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] createCustomTargetingValues(Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] values);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomTargetingValue[]> createCustomTargetingValuesAsync(Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] values);

		Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] updateCustomTargetingKeys(Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] keys);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomTargetingKey[]> updateCustomTargetingKeysAsync(Google.Api.Ads.AdManager.v201802.CustomTargetingKey[] keys);

		Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] updateCustomTargetingValues(Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] values);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomTargetingValue[]> updateCustomTargetingValuesAsync(Google.Api.Ads.AdManager.v201802.CustomTargetingValue[] values);
	}


	/// <summary>Provides methods for the creation and management of <a
	/// href='CustomField'>CustomField</a> objects.
	/// </summary>
	public interface ICustomFieldService : CustomFieldServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.CustomFieldOption[] createCustomFieldOptions(Google.Api.Ads.AdManager.v201802.CustomFieldOption[] customFieldOptions);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomFieldOption[]> createCustomFieldOptionsAsync(Google.Api.Ads.AdManager.v201802.CustomFieldOption[] customFieldOptions);

		Google.Api.Ads.AdManager.v201802.CustomField[] createCustomFields(Google.Api.Ads.AdManager.v201802.CustomField[] customFields);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomField[]> createCustomFieldsAsync(Google.Api.Ads.AdManager.v201802.CustomField[] customFields);

		Google.Api.Ads.AdManager.v201802.CustomFieldOption[] updateCustomFieldOptions(Google.Api.Ads.AdManager.v201802.CustomFieldOption[] customFieldOptions);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomFieldOption[]> updateCustomFieldOptionsAsync(Google.Api.Ads.AdManager.v201802.CustomFieldOption[] customFieldOptions);

		Google.Api.Ads.AdManager.v201802.CustomField[] updateCustomFields(Google.Api.Ads.AdManager.v201802.CustomField[] customFields);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CustomField[]> updateCustomFieldsAsync(Google.Api.Ads.AdManager.v201802.CustomField[] customFields);
	}


	/// <summary>Provides methods for adding, updating and retrieving <a
	/// href='ExchangeRate'>ExchangeRate</a> objects.
	/// </summary>
	public interface IExchangeRateService : ExchangeRateServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.ExchangeRate[] createExchangeRates(Google.Api.Ads.AdManager.v201802.ExchangeRate[] exchangeRates);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ExchangeRate[]> createExchangeRatesAsync(Google.Api.Ads.AdManager.v201802.ExchangeRate[] exchangeRates);

		Google.Api.Ads.AdManager.v201802.ExchangeRate[] updateExchangeRates(Google.Api.Ads.AdManager.v201802.ExchangeRate[] exchangeRates);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ExchangeRate[]> updateExchangeRatesAsync(Google.Api.Ads.AdManager.v201802.ExchangeRate[] exchangeRates);
	}


	/// <summary>Provides methods for estimating traffic (clicks/impressions) for line items.
	/// Forecasts can be provided for <a href='LineItem'>LineItem</a> objects that exist
	/// in the system or which have not had an ID set yet. <h4>Test network
	/// behavior</h4> <p>Test networks are unable to provide forecasts that would be
	/// comparable to the production environment because forecasts require traffic
	/// history. For test networks, a consistent behavior can be expected for forecast
	/// requests, according to the following rules:</p> <table> <tr> <th
	/// colspan="2">Inputs<br /> (<a href='LineItem'>LineItem</a> Fields)</th> <th
	/// colspan="4">Outputs<br /> (<a href='Forecast'>Forecast</a> Fields)</th> </tr>
	/// <tr> <th><a href='LineItem#lineItemType'>lineItemType</a></th> <th><a
	/// href='LineItem#unitsBought'>unitsBought</a></th> <th><a
	/// href='Forecast#availableUnits'>availableUnits</a></th> <th><a
	/// href='Forecast#forecastUnits'>forecastUnits (matchedUnits)</a></th> <th><a
	/// href='Forecast#deliveredUnits'>deliveredUnits</a></th> <th>Exception </th> </tr>
	/// <tr> <td>Sponsorship</td> <td>13</td> <td>#x2013;#x2013;</td>
	/// <td>#x2013;#x2013;</td> <td>#x2013;#x2013;</td> <td><a
	/// href='ForecastError.Reason#NO_FORECAST_YET'>NO_FORECAST_YET</a> </td> </tr> <tr>
	/// <td>Sponsorship</td> <td>20</td> <td>#x2013;#x2013;</td> <td>#x2013;#x2013;</td>
	/// <td>#x2013;#x2013;</td> <td><a
	/// href='ForecastError.Reason#SERVER_NOT_AVAILABLE'>SERVER_NOT_AVAILABLE</a> </td>
	/// </tr> <tr> <td>Sponsorship</td> <td>50</td> <td>1,200,000</td>
	/// <td>6,000,000</td> <td>600,000<br /> For prospective: 0</td>
	/// <td>#x2013;#x2013;</td> </tr> <tr> <td>Sponsorship</td> <td>!= 20 and<br /> !=
	/// 50</td> <td>1,200,000</td> <td>1,200,000</td> <td>600,000<br /> For prospective:
	/// 0</td> <td>#x2013;#x2013;</td> </tr> <tr> <td>Not Sponsorship</td> <td>&lt;=
	/// 500,000</td> <td>3 * unitsBought / 2</td> <td>unitsBought * 6</td>
	/// <td>600,000<br /> For prospective: 0</td> <td>#x2013;#x2013;</td> </tr> <tr>
	/// <td>Not Sponsorship</td> <td>&gt; 500,000 and &lt;= 1,000,000</td>
	/// <td>unitsBought / 2</td> <td>unitsBought * 6</td> <td>600,000<br /> For
	/// prospective: 0</td> <td>#x2013;#x2013;</td> </tr> <tr> <td>Not Sponsorship</td>
	/// <td>&gt; 1,000,000 and &lt;= 1,500,000</td> <td>unitsBought / 2</td> <td>3 *
	/// unitsBought / 2</td> <td>600,000<br /> For prospective: 0</td>
	/// <td>#x2013;#x2013;</td> </tr> <tr> <td>Not Sponsorship</td> <td>&gt;
	/// 1,500,000</td> <td>unitsBought / 4</td> <td>3 * unitsBought / 2</td>
	/// <td>600,000<br /> For prospective: 0</td> <td>#x2013;#x2013;</td> </tr> </table>
	/// </summary>
	public interface IForecastService : ForecastServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.DeliveryForecast getDeliveryForecast(Google.Api.Ads.AdManager.v201802.ProspectiveLineItem[] lineItems, Google.Api.Ads.AdManager.v201802.DeliveryForecastOptions forecastOptions);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.DeliveryForecast> getDeliveryForecastAsync(Google.Api.Ads.AdManager.v201802.ProspectiveLineItem[] lineItems, Google.Api.Ads.AdManager.v201802.DeliveryForecastOptions forecastOptions);

		Google.Api.Ads.AdManager.v201802.DeliveryForecast getDeliveryForecastByIds(long[] lineItemIds, Google.Api.Ads.AdManager.v201802.DeliveryForecastOptions forecastOptions);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.DeliveryForecast> getDeliveryForecastByIdsAsync(long[] lineItemIds, Google.Api.Ads.AdManager.v201802.DeliveryForecastOptions forecastOptions);
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='Activity'>Activity</a> objects. <p>An activity group contains <a
	/// href='Activity'>Activity</a> objects. Activities have a many-to-one relationship
	/// with activity groups, meaning each activity can belong to only one activity
	/// group, but activity groups can have multiple activities. An activity group can
	/// be used to manage the activities it contains.</p>
	/// </summary>
	public interface IActivityService : ActivityServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.Activity[] createActivities(Google.Api.Ads.AdManager.v201802.Activity[] activities);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Activity[]> createActivitiesAsync(Google.Api.Ads.AdManager.v201802.Activity[] activities);

		Google.Api.Ads.AdManager.v201802.Activity[] updateActivities(Google.Api.Ads.AdManager.v201802.Activity[] activities);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Activity[]> updateActivitiesAsync(Google.Api.Ads.AdManager.v201802.Activity[] activities);
	}


	public interface IInventoryService : InventoryServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.AdUnit[] createAdUnits(Google.Api.Ads.AdManager.v201802.AdUnit[] adUnits);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdUnit[]> createAdUnitsAsync(Google.Api.Ads.AdManager.v201802.AdUnit[] adUnits);

		Google.Api.Ads.AdManager.v201802.AdUnitSize[] getAdUnitSizesByStatement(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdUnitSize[]> getAdUnitSizesByStatementAsync(Google.Api.Ads.AdManager.v201802.Statement filterStatement);

		Google.Api.Ads.AdManager.v201802.AdUnit[] updateAdUnits(Google.Api.Ads.AdManager.v201802.AdUnit[] adUnits);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdUnit[]> updateAdUnitsAsync(Google.Api.Ads.AdManager.v201802.AdUnit[] adUnits);
	}


	/// <summary>Provides methods for the creation and management of Labels.
	/// </summary>
	public interface ILabelService : LabelServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.Label[] createLabels(Google.Api.Ads.AdManager.v201802.Label[] labels);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Label[]> createLabelsAsync(Google.Api.Ads.AdManager.v201802.Label[] labels);

		Google.Api.Ads.AdManager.v201802.Label[] updateLabels(Google.Api.Ads.AdManager.v201802.Label[] labels);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Label[]> updateLabelsAsync(Google.Api.Ads.AdManager.v201802.Label[] labels);
	}


	/// <summary>Provides operations for creating, updating and retrieving <a
	/// href='LineItemCreativeAssociation'>LineItemCreativeAssociation</a> objects. <p>A
	/// line item creative association (LICA) associates a <a
	/// href='Creative'>Creative</a> with a <a href='LineItem'>LineItem</a>. When a line
	/// item is selected to serve, the LICAs specify which creatives can appear for the
	/// ad units that are targeted by the line item. In order to be associated with a
	/// line item, the creative must have a size that exists within the attribute <a
	/// href='LineItem#creativeSizes'>LineItem#creativeSizes</a>.</p> <p>Each LICA has a
	/// start and end date and time that defines when the creative should be
	/// displayed.</p> <p>To read more about associating creatives with line items, see
	/// this <a href="https://support.google.com/dfp_premium/answer/3187916">DFP Help
	/// Center</a> article.</p>
	/// </summary>
	public interface ILineItemCreativeAssociationService : LineItemCreativeAssociationServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] createLineItemCreativeAssociations(Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] lineItemCreativeAssociations);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[]> createLineItemCreativeAssociationsAsync(Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] lineItemCreativeAssociations);

		Google.Api.Ads.AdManager.v201802.CreativeNativeStylePreview[] getPreviewUrlsForNativeStyles(long lineItemId, long creativeId, string siteUrl);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CreativeNativeStylePreview[]> getPreviewUrlsForNativeStylesAsync(long lineItemId, long creativeId, string siteUrl);

		Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] updateLineItemCreativeAssociations(Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] lineItemCreativeAssociations);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[]> updateLineItemCreativeAssociationsAsync(Google.Api.Ads.AdManager.v201802.LineItemCreativeAssociation[] lineItemCreativeAssociations);
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='LineItem'>LineItem</a> objects. <p>Line items define the campaign. For
	/// example, line items define:</p> <ul> <li>a budget</li> <li>a span of time to
	/// run</li> <li>ad unit targeting</li> </ul> <p>In short, line items connect all of
	/// the elements of an ad campaign.</p> <p>Line items and creatives can be
	/// associated with each other through <a href=''>LineItemCreativeAssociation</a>
	/// objects. An ad unit will host a creative through both this association and the
	/// <a href='LineItem#targeting'>LineItem#targeting</a> to it. The delivery of a
	/// line item depends on its priority. More information on line item priorities can
	/// be found on the <a
	/// href="https://support.google.com/dfp_premium/answer/177279">DFP Help
	/// Center</a>.</p>
	/// </summary>
	public interface ILineItemService : LineItemServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.LineItem[] createLineItems(Google.Api.Ads.AdManager.v201802.LineItem[] lineItems);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LineItem[]> createLineItemsAsync(Google.Api.Ads.AdManager.v201802.LineItem[] lineItems);

		Google.Api.Ads.AdManager.v201802.LineItem[] updateLineItems(Google.Api.Ads.AdManager.v201802.LineItem[] lineItems);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LineItem[]> updateLineItemsAsync(Google.Api.Ads.AdManager.v201802.LineItem[] lineItems);
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='LineItemTemplate'>LineItemTemplate</a> objects.
	/// </summary>
	public interface ILineItemTemplateService : LineItemTemplateServiceInterface, IDisposable
	{
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='LiveStreamEvent'>LiveStreamEvent</a> objects. <p>This feature is not yet
	/// openly available for DFP Video publishers. Publishers will need to apply for
	/// access for this feature through their account managers.</p>
	/// </summary>
	public interface ILiveStreamEventService : LiveStreamEventServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] createLiveStreamEvents(Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] liveStreamEvents);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LiveStreamEvent[]> createLiveStreamEventsAsync(Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] liveStreamEvents);

		string[] registerSessionsForMonitoring(string[] sessionIds);

		System.Threading.Tasks.Task<string[]> registerSessionsForMonitoringAsync(string[] sessionIds);

		Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] updateLiveStreamEvents(Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] liveStreamEvents);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.LiveStreamEvent[]> updateLiveStreamEventsAsync(Google.Api.Ads.AdManager.v201802.LiveStreamEvent[] liveStreamEvents);
	}


	/// <summary>Provides methods for retrieving <a
	/// href='MobileApplication'>MobileApplication</a> objects.
	/// </summary>
	public interface IMobileApplicationService : MobileApplicationServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.MobileApplication[] createMobileApplications(Google.Api.Ads.AdManager.v201802.MobileApplication[] mobileApplications);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.MobileApplication[]> createMobileApplicationsAsync(Google.Api.Ads.AdManager.v201802.MobileApplication[] mobileApplications);

		Google.Api.Ads.AdManager.v201802.MobileApplication[] updateMobileApplications(Google.Api.Ads.AdManager.v201802.MobileApplication[] mobileApplications);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.MobileApplication[]> updateMobileApplicationsAsync(Google.Api.Ads.AdManager.v201802.MobileApplication[] mobileApplications);
	}


	/// <summary>Provides operations for retrieving information related to the publisher's
	/// networks. This service can be used to obtain the list of all networks that the
	/// current login has access to, or to obtain information about a specific network.
	/// </summary>
	public interface INetworkService : NetworkServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.Network[] getAllNetworks();

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Network[]> getAllNetworksAsync();
	}


	/// <summary>Provides methods for creating, updating and retrieving <a href='Order'>Order</a>
	/// objects. <p>An order is a grouping of <a href='LineItem'>LineItem</a> objects.
	/// Line items have a many-to-one relationship with orders, meaning each line item
	/// can belong to only one order, but orders can have multiple line items. An order
	/// can be used to manage the line items it contains.</p>
	/// </summary>
	public interface IOrderService : OrderServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.Order[] createOrders(Google.Api.Ads.AdManager.v201802.Order[] orders);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Order[]> createOrdersAsync(Google.Api.Ads.AdManager.v201802.Order[] orders);

		Google.Api.Ads.AdManager.v201802.Order[] updateOrders(Google.Api.Ads.AdManager.v201802.Order[] orders);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Order[]> updateOrdersAsync(Google.Api.Ads.AdManager.v201802.Order[] orders);
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='Placement'>Placement</a> objects. <p>You can use a placement to group ad
	/// units. For example, you might have a placement that focuses on sports sites,
	/// which may be spread across different branches of your inventory. You might also
	/// have a "fire sale" placement that includes ad units that have not been selling
	/// and are consequently priced very attractively.</p>
	/// </summary>
	public interface IPlacementService : PlacementServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.Placement[] createPlacements(Google.Api.Ads.AdManager.v201802.Placement[] placements);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Placement[]> createPlacementsAsync(Google.Api.Ads.AdManager.v201802.Placement[] placements);

		Google.Api.Ads.AdManager.v201802.Placement[] updatePlacements(Google.Api.Ads.AdManager.v201802.Placement[] placements);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Placement[]> updatePlacementsAsync(Google.Api.Ads.AdManager.v201802.Placement[] placements);
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='AdExclusionRule'>AdExclusionRule</a> objects. <p>An <a
	/// href='AdExclusionRule'>AdExclusionRule</a> provides a way to block specified ads
	/// from showing on portions of your site. Each rule specifies the inventory on
	/// which the rule is in effect, and the labels to block on that inventory.</p>
	/// </summary>
	public interface IAdExclusionRuleService : AdExclusionRuleServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.AdExclusionRule[] createAdExclusionRules(Google.Api.Ads.AdManager.v201802.AdExclusionRule[] adExclusionRules);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdExclusionRule[]> createAdExclusionRulesAsync(Google.Api.Ads.AdManager.v201802.AdExclusionRule[] adExclusionRules);

		Google.Api.Ads.AdManager.v201802.AdExclusionRule[] updateAdExclusionRules(Google.Api.Ads.AdManager.v201802.AdExclusionRule[] adExclusionRules);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdExclusionRule[]> updateAdExclusionRulesAsync(Google.Api.Ads.AdManager.v201802.AdExclusionRule[] adExclusionRules);
	}


	/// <summary>Provides methods for managing <a href='PremiumRate'>PremiumRate</a> objects.
	/// <p>To use this service, you need to have the new sales management solution
	/// enabled on your network. If you do not see a "Sales" tab in <a
	/// href="https://www.google.com/dfp">DoubleClick for Publishers (DFP)</a>, you will
	/// not be able to use this service.</p>
	/// </summary>
	public interface IPremiumRateService : PremiumRateServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.PremiumRate[] createPremiumRates(Google.Api.Ads.AdManager.v201802.PremiumRate[] premiumRates);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.PremiumRate[]> createPremiumRatesAsync(Google.Api.Ads.AdManager.v201802.PremiumRate[] premiumRates);

		Google.Api.Ads.AdManager.v201802.PremiumRate[] updatePremiumRates(Google.Api.Ads.AdManager.v201802.PremiumRate[] premiumRates);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.PremiumRate[]> updatePremiumRatesAsync(Google.Api.Ads.AdManager.v201802.PremiumRate[] premiumRates);
	}


	/// <summary>Provides methods for updating and retrieving <a href='Product'>Product</a>
	/// objects. <p>A <code>Product</code> represents a line item proposal. Products are
	/// generated from <a href=''>ProductTemplate product templates</a> on a periodic
	/// basis using the product template's attributes. Products are typically used by
	/// inventory managers to restrict what salespeople can sell.</p> <p>To use this
	/// service, you need to have the new sales management solution enabled on your
	/// network. If you do not see a "Sales" tab in <a
	/// href="https://www.google.com/dfp">DoubleClick for Publishers (DFP)</a>, you will
	/// not be able to use this service.</p>
	/// </summary>
	public interface IProductService : ProductServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.Product[] createProducts(Google.Api.Ads.AdManager.v201802.Product[] products);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Product[]> createProductsAsync(Google.Api.Ads.AdManager.v201802.Product[] products);

		Google.Api.Ads.AdManager.v201802.Product[] updateProducts(Google.Api.Ads.AdManager.v201802.Product[] products);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Product[]> updateProductsAsync(Google.Api.Ads.AdManager.v201802.Product[] products);
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='ProductTemplate'>ProductTemplate</a> objects. <p>A product template is
	/// used to generate a set of products. Products allow inventory managers to control
	/// what salespeople can sell.</p> <p>To use this service, you need to have the new
	/// sales management solution enabled on your network. If you do not see a "Sales"
	/// tab in <a href="https://www.google.com/dfp">DoubleClick for Publishers
	/// (DFP)</a>, you will not be able to use this service.</p>
	/// </summary>
	public interface IProductTemplateService : ProductTemplateServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.ProductTemplate[] createProductTemplates(Google.Api.Ads.AdManager.v201802.ProductTemplate[] productTemplates);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductTemplate[]> createProductTemplatesAsync(Google.Api.Ads.AdManager.v201802.ProductTemplate[] productTemplates);

		Google.Api.Ads.AdManager.v201802.ProductTemplate[] updateProductTemplates(Google.Api.Ads.AdManager.v201802.ProductTemplate[] productTemplates);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductTemplate[]> updateProductTemplatesAsync(Google.Api.Ads.AdManager.v201802.ProductTemplate[] productTemplates);
	}


	/// <summary>Provides methods for adding, updating and retrieving <a
	/// href='Proposal'>Proposal</a> objects.
	/// </summary>
	public interface IProposalService : ProposalServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.Proposal[] createProposals(Google.Api.Ads.AdManager.v201802.Proposal[] proposals);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Proposal[]> createProposalsAsync(Google.Api.Ads.AdManager.v201802.Proposal[] proposals);

		Google.Api.Ads.AdManager.v201802.Proposal[] updateProposals(Google.Api.Ads.AdManager.v201802.Proposal[] proposals);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Proposal[]> updateProposalsAsync(Google.Api.Ads.AdManager.v201802.Proposal[] proposals);
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='ProposalLineItem'>ProposalLineItem</a> objects. <p>To use this service,
	/// you need to have the new sales management solution enabled on your network. If
	/// you do not see a "Sales" tab in <a href="https://www.google.com/dfp">DoubleClick
	/// for Publishers (DFP)</a>, you will not be able to use this service.</p>
	/// </summary>
	public interface IProposalLineItemService : ProposalLineItemServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.ProposalLineItem[] createProposalLineItems(Google.Api.Ads.AdManager.v201802.ProposalLineItem[] proposalLineItems);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProposalLineItem[]> createProposalLineItemsAsync(Google.Api.Ads.AdManager.v201802.ProposalLineItem[] proposalLineItems);

		Google.Api.Ads.AdManager.v201802.ProposalLineItem[] updateProposalLineItems(Google.Api.Ads.AdManager.v201802.ProposalLineItem[] proposalLineItems);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProposalLineItem[]> updateProposalLineItemsAsync(Google.Api.Ads.AdManager.v201802.ProposalLineItem[] proposalLineItems);
	}


	/// <summary>Provides methods for executing a PQL <a href='Statement'>Statement</a> to
	/// retrieve information from the system. In order to support the selection of
	/// columns of interest from various tables, <a href='Statement'>Statement</a>
	/// objects support a "select" clause. <p>An example query text might be
	/// <code>"select CountryCode, Name from Geo_Target"</code>, where
	/// <code>CountryCode</code> and <code>Name</code> are columns of interest and
	/// <code>Geo_Target</code> is the table.</p> <p>The following tables are
	/// supported:</p> <h2>Geo_Target</h2> <table> <tr> <th scope="col">Column Name</th>
	/// <th scope="col">Description</th> </tr> <tr> <td>Id</td> <td>Unique identifier
	/// for the Geo target</td> </tr> <tr> <td>Name</td> <td>The name of the Geo
	/// target</td> </tr> <tr> <td>CanonicalParentId</td> <td>The criteria ID of the
	/// direct parent that defines the canonical name of the geo target. For example, if
	/// the current geo target is "San Francisco", its canonical name would be "San
	/// Francisco, California, United States" thus the canonicalParentId would be the
	/// criteria ID of California and the canonicalParentId of California would be the
	/// criteria ID of United states</td> </tr> <tr> <td>ParentIds</td> <td>A comma
	/// separated list of criteria IDs of all parents of the geo target ordered by
	/// ascending size</td> </tr> <tr> <td>CountryCode</td> <td>Country code as defined
	/// by ISO 3166-1 alpha-2</td> </tr> <tr> <td>Type</td> <td>Allowable values: <ul>
	/// <li>Airport</li> <li>Autonomous_Community</li> <li>Canton</li> <li>City</li>
	/// <li>Congressional_District</li> <li>Country</li> <li>County</li>
	/// <li>Department</li> <li>DMA_Region</li> <li>Governorate</li>
	/// <li>Municipality</li> <li>Neighborhood</li> <li>Postal_Code</li>
	/// <li>Prefecture</li> <li>Province</li> <li>Region</li> <li>State</li>
	/// <li>Territory</li> <li>Tv_Region</li> <li>Union_Territory</li> </ul> </td> </tr>
	/// <tr> <td>Targetable</td> <td>Indicates whether geographical targeting is
	/// allowed</td> </tr> </table> <h2>Bandwidth_Group</h2> <table> <tr> <th
	/// scope="col">Column Name</th> <th scope="col">Description</th> </tr> <tr>
	/// <td>Id</td> <td>Unique identifier for the bandwidth group</td> </tr> <tr>
	/// <td>BandwidthName</td> <td>Name of the bandwidth group</td> </tr> </table>
	/// <h2>Browser</h2> <table> <tr> <th scope="col">Column Name</th> <th
	/// scope="col">Description</th> </tr> <tr> <td>Id</td> <td>Unique identifier for
	/// the browser</td> </tr> <tr> <td>BrowserName</td> <td>Name of the browser</td>
	/// </tr> <tr> <td>MajorVersion</td> <td>Major version of the browser</td> </tr>
	/// <tr> <td>MinorVersion</td> <td>Minor version of the browser</td> </tr> </table>
	/// <h2>Browser_Language</h2> <table> <tr> <th scope="col">Column Name</th> <th
	/// scope="col">Description</th> </tr> <tr> <td>Id</td> <td>Unique identifier for
	/// the browser language</td> </tr> <tr> <td>BrowserLanguageName</td> <td>Browser's
	/// language</td> </tr> </table> <h2>Device_Capability</h2> <table> <tr> <th
	/// scope="col">Column Name</th> <th scope="col">Description</th> </tr> <tr>
	/// <td>Id</td> <td>Unique identifier for the device capability</td> </tr> <tr>
	/// <td>DeviceCapabilityName</td> <td>Name of the device capability</td> </tr>
	/// </table> <h2>Device_Category</h2> <table> <tr> <th scope="col">Column Name</th>
	/// <th scope="col">Description</th> </tr> <tr> <td>Id</td> <td>Unique identifier
	/// for the device category</td> </tr> <tr> <td>DeviceCategoryName</td> <td>Name of
	/// the device category</td> </tr> </table> <h2>Device_Manufacturer</h2> <table>
	/// <tr> <th scope="col">Column Name</th> <th scope="col">Description</th> </tr>
	/// <tr> <td>Id</td> <td>Unique identifier for the device manufacturer</td> </tr>
	/// <tr> <td>MobileDeviceManufacturerName</td> <td>Name of the device
	/// manufacturer</td> </tr> </table> <h2>Mobile_Carrier</h2> <table> <tr> <th
	/// scope="col">Column Name</th> <th scope="col">Description</th> </tr> <tr>
	/// <td>Id</td> <td>Unique identifier for the mobile carrier</td> </tr> <tr>
	/// <td>CountryCode</td> <td>The country code of the mobile carrier</td> </tr> <tr>
	/// <td>MobileCarrierName</td> <td>Name of the mobile carrier</td> </tr> </table>
	/// <h2>Mobile_Device</h2> <table> <tr> <th scope="col">Column Name</th> <th
	/// scope="col">Description</th> </tr> <tr> <td>Id</td> <td>Unique identifier for
	/// the mobile device</td> </tr> <tr> <td>MobileDeviceManufacturerId</td> <td>Id of
	/// the device manufacturer</td> </tr> <tr> <td>MobileDeviceName</td> <td>Name of
	/// the mobile device</td> </tr> </table> <h2>Mobile_Device_Submodel</h2> <table>
	/// <tr> <th scope="col">Column Name</th> <th scope="col">Description</th> </tr>
	/// <tr> <td>Id</td> <td>Unique identifier for the mobile device submodel</td> </tr>
	/// <tr> <td>MobileDeviceId</td> <td>Id of the mobile device</td> </tr> <tr>
	/// <td>MobileDeviceSubmodelName</td> <td>Name of the mobile device submodel</td>
	/// </tr> </table> <h2>Operating_System</h2> <table> <tr> <th scope="col">Column
	/// Name</th> <th scope="col">Description</th> </tr> <tr> <td>Id</td> <td>Unique
	/// identifier for the operating system</td> </tr> <tr> <td>OperatingSystemName</td>
	/// <td>Name of the operating system</td> </tr> </table>
	/// <h2>Operating_System_Version</h2> <table> <tr> <th scope="col">Column Name</th>
	/// <th scope="col">Description</th> </tr> <tr> <td>Id</td> <td>Unique identifier
	/// for the operating system version</td> </tr> <tr> <td>OperatingSystemId</td>
	/// <td>Id of the operating system</td> </tr> <tr> <td>MajorVersion</td> <td>The
	/// operating system major version</td> </tr> <tr> <td>MinorVersion</td> <td>The
	/// operating system minor version</td> </tr> <tr> <td>MicroVersion</td> <td>The
	/// operating system micro version</td> </tr> </table> <h2>Third_Party_Company</h2>
	/// <table> <tr> <th scope="col">Column Name</th> <th scope="col">Description</th>
	/// </tr> <tr> <td>Id</td> <td>Unique identifier for the third party company</td>
	/// </tr> <tr> <td>Name</td> <td>The third party company name</td> </tr> <tr>
	/// <td>Type</td> <td>The third party company type</td> </tr> <tr> <td>Status</td>
	/// <td>The status of the third party company</td> </tr> </table> <h2
	/// id="Line_Item">Line_Item</h2> <table> <tr> <th>Column name</th> <th>Type</th>
	/// <th>Description</th> </tr> <tr> <td>CostType</td> <td><code>Text</code></td>
	/// <td>The method used for billing this <code>LineItem</code>.</td> </tr> <tr>
	/// <td>CreationDateTime</td> <td><code>Datetime</code></td> <td>The date and time
	/// this <code>LineItem</code> was last created. This attribute may be null for
	/// <code>LineItem</code>s created before this feature was introduced.</td> </tr>
	/// <tr> <td>DeliveryRateType</td> <td><code>Text</code></td> <td>The strategy for
	/// delivering ads over the course of the <code></code>'s duration. This attribute
	/// is optional and defaults to <a
	/// href='DeliveryRateType#EVENLY'>DeliveryRateType#EVENLY</a>. Starting in v201306,
	/// it may default to <a
	/// href='DeliveryRateType#FRONTLOADED'>DeliveryRateType#FRONTLOADED</a> if
	/// specifically configured to on the network.</td> </tr> <tr> <td>EndDateTime</td>
	/// <td><code>Datetime</code></td> <td>The date and time on which the
	/// <code>LineItem</code> stops serving.</td> </tr> <tr> <td>ExternalId</td>
	/// <td><code>Text</code></td> <td>An identifier for the <code>LineItem</code> that
	/// is meaningful to the publisher.</td> </tr> <tr> <td>Id</td>
	/// <td><code>Number</code></td> <td>Uniquely identifies the <code>LineItem</code>.
	/// This attribute is read-only and is assigned by Google when a line item is
	/// created.</td> </tr> <tr> <td>IsMissingCreatives</td>
	/// <td><code>Boolean</code></td> <td>Indicates if a <code>LineItem</code> is
	/// missing any <a href='Creative'>creatives</a> for the
	/// <code>creativePlaceholders</code> specified.</td> </tr> <tr>
	/// <td>IsSetTopBoxEnabled</td> <td><code>Boolean</code></td> <td>Whether or not
	/// this line item is set-top box enabled.</td> </tr> <tr>
	/// <td>LastModifiedDateTime</td> <td><code>Datetime</code></td> <td>The date and
	/// time this <code>LineItem</code> was last modified.</td> </tr> <tr>
	/// <td>LineItemType</td> <td><code>Text</code></td> <td>Indicates the line item
	/// type of a <code>LineItem</code>.</td> </tr> <tr> <td>Name</td>
	/// <td><code>Text</code></td> <td>The name of the <code>LineItem</code>.</td> </tr>
	/// <tr> <td>OrderId</td> <td><code>Number</code></td> <td>The ID of the <a
	/// href='Order'>Order</a> to which the <code></code> belongs.</td> </tr> <tr>
	/// <td>StartDateTime</td> <td><code>Datetime</code></td> <td>The date and time on
	/// which the <code>LineItem</code> is enabled to begin serving.</td> </tr> <tr>
	/// <td>Status</td> <td><code>Text</code></td> <td>The status of the
	/// <code>LineItem</code>.</td> </tr> <tr> <td>Targeting</td>
	/// <td><code>Targeting</code></td> <td>The targeting criteria for the ad
	/// campaign.&lt;p&gt; &lt;b&gt;This object is experimental!
	/// &lt;code&gt;Targeting&lt;/code&gt; is an experimental, innovative, and rapidly
	/// changing new feature for DFP. Unfortunately, being on the bleeding edge means
	/// that we may make backwards-incompatible changes to
	/// &lt;code&gt;Targeting&lt;/code&gt;. We will inform the community when this
	/// feature is no longer experimental.&lt;/b&gt;</td> </tr> <tr>
	/// <td>UnitsBought</td> <td><code>Number</code></td> <td>The total number of
	/// impressions or clicks that will be reserved for the <code>LineItem</code>. If
	/// the line item is of type <a
	/// href='LineItemType#SPONSORSHIP'>LineItemType#SPONSORSHIP</a>, then it represents
	/// the percentage of available impressions reserved.</td> </tr> </table> <h2
	/// id="Ad_Unit">Ad_Unit</h2> <table> <tr> <th>Column name</th> <th>Type</th>
	/// <th>Description</th> </tr> <tr> <td>AdUnitCode</td> <td><code>Text</code></td>
	/// <td>A string used to uniquely identify the ad unit for the purposes of serving
	/// the ad. This attribute is read-only and is assigned by Google when an ad unit is
	/// created.</td> </tr> <tr> <td>ExternalSetTopBoxChannelId</td>
	/// <td><code>Text</code></td> <td>The channel ID for set-top box enabled <a
	/// href='AdUnit'>ad units</a>.</td> </tr> <tr> <td>Id</td>
	/// <td><code>Number</code></td> <td>Uniquely identifies the ad unit. This value is
	/// read-only and is assigned by Google when an ad unit is created.</td> </tr> <tr>
	/// <td>LastModifiedDateTime</td> <td><code>Datetime</code></td> <td>The date and
	/// time this ad unit was last modified.</td> </tr> <tr> <td>Name</td>
	/// <td><code>Text</code></td> <td>The name of the ad unit.</td> </tr> <tr>
	/// <td>ParentId</td> <td><code>Number</code></td> <td>The ID of the ad unit's
	/// parent. Every ad unit has a parent except for the root ad unit, which is created
	/// by Google.</td> </tr> </table> <h2 id="User">User</h2> <table> <tr> <th>Column
	/// name</th> <th>Type</th> <th>Description</th> </tr> <tr> <td>Email</td>
	/// <td><code>Text</code></td> <td>The email or login of the user.</td> </tr> <tr>
	/// <td>ExternalId</td> <td><code>Text</code></td> <td>An identifier for the user
	/// that is meaningful to the publisher.</td> </tr> <tr> <td>Id</td>
	/// <td><code>Number</code></td> <td>The unique ID of the user.</td> </tr> <tr>
	/// <td>IsServiceAccount</td> <td><code>Boolean</code></td> <td>True if this user is
	/// an OAuth2 service account user, false otherwise.</td> </tr> <tr> <td>Name</td>
	/// <td><code>Text</code></td> <td>The name of the user.</td> </tr> <tr>
	/// <td>RoleId</td> <td><code>Number</code></td> <td>The unique role ID of the user.
	/// <a href='Role'>Role</a> objects that are created by Google will have negative
	/// IDs.</td> </tr> <tr> <td>RoleName</td> <td><code>Text</code></td> <td>The name
	/// of the <a href='Role'>Role</a> assigned to the user.</td> </tr> </table> <h2
	/// id="Exchange_Rate">Exchange_Rate</h2> <table> <tr> <th>Column name</th>
	/// <th>Type</th> <th>Description</th> </tr> <tr> <td>CurrencyCode</td>
	/// <td><code>Text</code></td> <td>The currency code that the exchange rate is
	/// related to. The exchange rate is between this currency and <a
	/// href='Network#currencyCode'>the network's currency</a>. This attribute is
	/// required for creation and then is readonly.</td> </tr> <tr> <td>Direction</td>
	/// <td><code>Text</code></td> <td>The direction that the exchange rate is in. It
	/// determines whether the exchange rate is from this currency to <a
	/// href='Network#currencyCode'>the network's currency</a>, or from <a
	/// href='Network#currencyCode'>the network's currency</a> to this currency. This
	/// attribute can be updated.</td> </tr> <tr> <td>ExchangeRate</td>
	/// <td><code>Number</code></td> <td>The latest exchange rate at current refresh
	/// rate and in current direction. The value is stored as the exchange rate times
	/// 10,000,000,000 truncated to a long. Setting this attribute requires the refresh
	/// rate to be already set to <a
	/// href='ExchangeRateRefreshRate#FIXED'>ExchangeRateRefreshRate#FIXED</a>.
	/// Otherwise an exception will be thrown.</td> </tr> <tr> <td>Id</td>
	/// <td><code>Number</code></td> <td>The ID of the <code>ExchangeRate</code>. This
	/// attribute is readonly and is assigned by Google when an exchange rate is
	/// created.</td> </tr> <tr> <td>RefreshRate</td> <td><code>Text</code></td> <td>The
	/// refresh rate at which the exchange rate is updated. Setting this attribute to <a
	/// href='ExchangeRateRefreshRate#FIXED'>ExchangeRateRefreshRate#FIXED</a> without
	/// setting the exchange rate value will cause unknown exchange rate value returned
	/// in future queries.</td> </tr> </table> <h2
	/// id="Programmatic_Buyer">Programmatic_Buyer</h2> <table> <tr> <th>Column
	/// name</th> <th>Type</th> <th>Description</th> </tr> <tr> <td>BuyerAccountId</td>
	/// <td><code>Number</code></td> <td>The ID used by Adx to bill the appropriate
	/// buyer network for a programmatic order.</td> </tr> <tr>
	/// <td>EnabledForPreferredDeals</td> <td><code>Boolean</code></td> <td>Whether the
	/// buyer is allowed to negotiate Preferred Deals.</td> </tr> <tr>
	/// <td>EnabledForProgrammaticGuaranteed</td> <td><code>Boolean</code></td>
	/// <td>Whether the buyer is enabled for Programmatic Guaranteed deals.</td> </tr>
	/// <tr> <td>Name</td> <td><code>Text</code></td> <td>Display name that references
	/// the buyer.</td> </tr> <tr> <td>ParentId</td> <td><code>Number</code></td>
	/// <td>The ID of the programmatic buyer's sponsor. If the programmatic buyer has no
	/// sponsor, this field will be -1.</td> </tr> </table> <h2
	/// id="Audience_Segment_Category">Audience_Segment_Category</h2> <table> <tr>
	/// <th>Column name</th> <th>Type</th> <th>Description</th> </tr> <tr> <td>Id</td>
	/// <td><code>Number</code></td> <td>The unique identifier for the audience segment
	/// category.</td> </tr> <tr> <td>Name</td> <td><code>Text</code></td> <td>The name
	/// of the audience segment category.</td> </tr> <tr> <td>ParentId</td>
	/// <td><code>Number</code></td> <td>The unique identifier of the audience segment
	/// category's parent.</td> </tr> </table> <h2
	/// id="Audience_Segment">Audience_Segment</h2> <table> <tr> <th>Column name</th>
	/// <th>Type</th> <th>Description</th> </tr> <tr> <td>AdIdSize</td>
	/// <td><code>Number</code></td> <td>The number of AdID users in the segment.</td>
	/// </tr> <tr> <td>CategoryIds</td> <td><code>Set of number</code></td> <td>The ids
	/// of the categories that this audience segment belongs to.</td> </tr> <tr>
	/// <td>Id</td> <td><code>Number</code></td> <td>The unique identifier for the
	/// audience segment.</td> </tr> <tr> <td>IdfaSize</td> <td><code>Number</code></td>
	/// <td>The number of IDFA users in the segment.</td> </tr> <tr>
	/// <td>MobileWebSize</td> <td><code>Number</code></td> <td>The number of mobile web
	/// users in the segment.</td> </tr> <tr> <td>Name</td> <td><code>Text</code></td>
	/// <td>The name of the audience segment.</td> </tr> <tr> <td>OwnerAccountId</td>
	/// <td><code>Number</code></td> <td>The owner account id of the audience
	/// segment.</td> </tr> <tr> <td>OwnerName</td> <td><code>Text</code></td> <td>The
	/// owner name of the audience segment.</td> </tr> <tr> <td>PpidSize</td>
	/// <td><code>Number</code></td> <td>The number of PPID users in the segment.</td>
	/// </tr> <tr> <td>SegmentType</td> <td><code>Text</code></td> <td>The type of the
	/// audience segment.</td> </tr> </table> <h2
	/// id="Proposal_Retraction_Reason">Proposal_Retraction_Reason</h2> <table> <tr>
	/// <th>Column name</th> <th>Type</th> <th>Description</th> </tr> <tr> <td>Id</td>
	/// <td><code>Number</code></td> <td>The ID of the
	/// <code>ProposalRetractionReason</code>. This attribute is readonly and is
	/// assigned by Google when a proposal retraction reason is created.</td> </tr> <tr>
	/// <td>IsActive</td> <td><code>Boolean</code></td> <td>True if the
	/// <code>ProposalRetractionReason</code> is active.</td> </tr> <tr> <td>Name</td>
	/// <td><code>Text</code></td> <td>The name of the
	/// <code>ProposalRetractionReason</code>.</td> </tr> </table> <h2
	/// id="Audience_Explorer">Audience_Explorer</h2> <table> <tr> <th>Column name</th>
	/// <th>Type</th> <th>Description</th> </tr> <tr> <td>Id</td>
	/// <td><code>Number</code></td> <td>Uniquely identifies the audience segment. This
	/// table has been deprecated since December 2017, and returns empty data.</td>
	/// </tr> <tr> <td>ThirtyDayActiveSize</td> <td><code>Number</code></td> <td>The
	/// number of active unique cookies in this segment over the last 30 days. This
	/// table has been deprecated since December 2017, and returns empty data.</td>
	/// </tr> <tr> <td>ThirtyDayClicks</td> <td><code>Number</code></td> <td>The number
	/// of clicks for this segment over the last 30 days. This table has been deprecated
	/// since December 2017, and returns empty data.</td> </tr> <tr>
	/// <td>ThirtyDayImpressions</td> <td><code>Number</code></td> <td>The number of
	/// impressions for this segment over the last 30 days. This table has been
	/// deprecated since December 2017, and returns empty data.</td> </tr> </table> <h2
	/// id="Time_Zone">Time_Zone</h2> <table> <tr> <th>Column name</th> <th>Type</th>
	/// <th>Description</th> </tr> <tr> <td>Id</td> <td><code>Text</code></td> <td>The
	/// id of time zone in the form of <code></code>.</td> </tr> <tr>
	/// <td>StandardGmtOffset</td> <td><code>Text</code></td> <td>The standard GMT
	/// offset in current time in the form of <code></code> for
	/// <code>America/New_York</code>, excluding the Daylight Saving Time.</td> </tr>
	/// </table> <h2 id="Proposal_Terms_And_Conditions">
	/// Proposal_Terms_And_Conditions</h2> <table> <tr> <th>Column name</th>
	/// <th>Type</th> <th>Description</th> </tr> <tr> <td>Content</td>
	/// <td><code>Text</code></td> <td>The content of the terms and conditions.</td>
	/// </tr> <tr> <td>Id</td> <td><code>Number</code></td> <td>Uniquely identifies the
	/// terms and conditions.</td> </tr> <tr> <td>IsDefault</td>
	/// <td><code>Boolean</code></td> <td>Whether or not this set of terms and
	/// conditions are the default for a network.</td> </tr> <tr>
	/// <td>LastModifiedDateTime</td> <td><code>Datetime</code></td> <td>The date and
	/// time this terms and conditions was last modified.</td> </tr> <tr> <td>Name</td>
	/// <td><code>Text</code></td> <td>The name of the terms and conditions.</td> </tr>
	/// </table> <h2 id="Change_History">Change_History</h2> Restrictions: Only ordering
	/// by <code>ChangeDateTime</code> descending is supported. <code>OFFSET</code> is
	/// not supported. To page through results, filter on the earliest change
	/// <code>Id</code> as a continuation token. For example <code>"WHERE Id &lt;
	/// :id"</code>. On each query, both an upper bound and a lower bound for the
	/// <code>ChangeDateTime</code> are required. <table> <tr> <th>Column name</th>
	/// <th>Type</th> <th>Description</th> </tr> <tr> <td>ChangeDateTime</td>
	/// <td><code>Datetime</code></td> <td>The date and time this change happened.</td>
	/// </tr> <tr> <td>EntityId</td> <td><code>Number</code></td> <td>The ID of the
	/// entity that was changed.</td> </tr> <tr> <td>EntityType</td>
	/// <td><code>Text</code></td> <td>The <a href='ChangeHistoryEntityType'>type</a> of
	/// the entity that was changed.</td> </tr> <tr> <td>Id</td>
	/// <td><code>Text</code></td> <td>The ID of this change. IDs may only be used with
	/// <code>"&lt;"</code> operator for paging and are subject to change. Do not store
	/// IDs. Note that the <code>"&lt;"</code> here does not compare the value of the ID
	/// but the row in the change history table it represents.</td> </tr> <tr>
	/// <td>Operation</td> <td><code>Text</code></td> <td>The <a
	/// href='ChangeHistoryOperation'>operation</a> that was performed on this
	/// entity.</td> </tr> <tr> <td>UserId</td> <td><code>Number</code></td> <td>The <a
	/// href='User#id'>ID</a> of the user that made this change.</td> </tr> </table>
	/// </summary>
	public interface IPublisherQueryLanguageService : PublisherQueryLanguageServiceInterface, IDisposable
	{
	}


	/// <summary>Provides methods for managing <a href='RateCard'>RateCard</a> objects. <p>To use
	/// this service, you need to have the new sales management solution enabled on your
	/// network. If you do not see a "Sales" tab in <a
	/// href="https://www.google.com/dfp">DoubleClick for Publishers (DFP)</a>, you will
	/// not be able to use this service.</p>
	/// </summary>
	public interface IRateCardService : RateCardServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.RateCard[] createRateCards(Google.Api.Ads.AdManager.v201802.RateCard[] rateCards);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.RateCard[]> createRateCardsAsync(Google.Api.Ads.AdManager.v201802.RateCard[] rateCards);

		Google.Api.Ads.AdManager.v201802.RateCard[] updateRateCards(Google.Api.Ads.AdManager.v201802.RateCard[] rateCards);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.RateCard[]> updateRateCardsAsync(Google.Api.Ads.AdManager.v201802.RateCard[] rateCards);
	}


	/// <summary>Provides methods for retrieving, reconciling, and reverting <a
	/// href='ReconciliationOrderReport'>ReconciliationOrderReport</a> objects.
	/// </summary>
	public interface IReconciliationOrderReportService : ReconciliationOrderReportServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.ReconciliationOrderReport[] updateReconciliationOrderReports(Google.Api.Ads.AdManager.v201802.ReconciliationOrderReport[] reconciliationOrderReports);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationOrderReport[]> updateReconciliationOrderReportsAsync(Google.Api.Ads.AdManager.v201802.ReconciliationOrderReport[] reconciliationOrderReports);
	}


	/// <summary>Provides methods for retrieving and updating <a
	/// href='ReconciliationLineItemReport'>ReconciliationLineItemReport</a> objects.
	/// </summary>
	public interface IReconciliationLineItemReportService : ReconciliationLineItemReportServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReport[] updateReconciliationLineItemReports(Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReport[] reconciliationLineItemReports);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReport[]> updateReconciliationLineItemReportsAsync(Google.Api.Ads.AdManager.v201802.ReconciliationLineItemReport[] reconciliationLineItemReports);
	}


	/// <summary>Provides methods for retrieving, submitting and reverting the <a
	/// href='ReconciliationReport'>ReconciliationReport</a> objects. <p>A <a
	/// href='ReconciliationReport'>ReconciliationReport</a> is a group of <a
	/// href='ReconciliationReportRow'>ReconciliationReportRow</a> objects.</p>
	/// </summary>
	public interface IReconciliationReportService : ReconciliationReportServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.ReconciliationReport[] updateReconciliationReports(Google.Api.Ads.AdManager.v201802.ReconciliationReport[] reconciliationReports);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationReport[]> updateReconciliationReportsAsync(Google.Api.Ads.AdManager.v201802.ReconciliationReport[] reconciliationReports);
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='AdRule'>AdRule</a> objects. <p>Ad rules contain data that the ad server
	/// uses to generate a playlist of video ads.</p>
	/// </summary>
	public interface IAdRuleService : AdRuleServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.AdRule[] createAdRules(Google.Api.Ads.AdManager.v201802.AdRule[] adRules);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdRule[]> createAdRulesAsync(Google.Api.Ads.AdManager.v201802.AdRule[] adRules);

		Google.Api.Ads.AdManager.v201802.AdRule[] updateAdRules(Google.Api.Ads.AdManager.v201802.AdRule[] adRules);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.AdRule[]> updateAdRulesAsync(Google.Api.Ads.AdManager.v201802.AdRule[] adRules);
	}


	/// <summary>Provides methods for retrieving and updating the <a
	/// href='ReconciliationReportRow'>ReconciliationReportRow</a> objects.
	/// </summary>
	public interface IReconciliationReportRowService : ReconciliationReportRowServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.ReconciliationReportRow[] updateReconciliationReportRows(Google.Api.Ads.AdManager.v201802.ReconciliationReportRow[] reconciliationReportRows);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ReconciliationReportRow[]> updateReconciliationReportRowsAsync(Google.Api.Ads.AdManager.v201802.ReconciliationReportRow[] reconciliationReportRows);
	}


	/// <summary>Provides methods for executing a <a href='ReportJob'>ReportJob</a> and
	/// retrieving performance and statistics about ad campaigns, networks, inventory
	/// and sales. <p>Follow the steps outlined below:</p> <p> <ul> <li>Create the
	/// <code>ReportJob</code> object by invoking <a
	/// href='ReportService#runReportJob'>ReportService#runReportJob</a>.</li> <li>Poll
	/// the <code>ReportJob</code> object using <a
	/// href='ReportService#getReportJob'>ReportService#getReportJob</a>.</li>
	/// <li>Continue to poll the <code>ReportJob</code> object until the <a
	/// href='ReportJob#reportJobStatus'>ReportJob#reportJobStatus</a> field is equal to
	/// <a href='ReportJobStatus#COMPLETED'>ReportJobStatus#COMPLETED</a> or <a
	/// href='ReportJobStatus#FAILED'>ReportJobStatus#FAILED</a>.</li> <li>If
	/// successful, fetch the URL for downloading the report by invoking <a
	/// href='ReportService#getReportDownloadURL'>ReportService#getReportDownloadURL</a>.</li>
	/// </ul> <br /> <br /> <h4>Test network behavior</h4> </p><p>The networks created
	/// using <a
	/// href='NetworkService#makeTestNetwork'>NetworkService#makeTestNetwork</a> are
	/// unable to provide reports that would be comparable to the production environment
	/// because reports require traffic history. In the test networks, reports will
	/// consistently return no data for all reports.</p>
	/// </summary>
	public interface IReportService : ReportServiceInterface, IDisposable
	{
	}


	/// <summary>This service provides operations for retrieving and approving <a
	/// href='SuggestedAdUnit'>SuggestedAdUnit</a> objects. <p>Publishers may create ad
	/// tags that lack a corresponding ad unit defined in DFP, in order to gather
	/// information about potential ads without needing to create dummy ad units and
	/// make them available for targeting in line items. Any undefined ad unit to
	/// receive more than ten serving requests in the past week is treated as a
	/// 'suggested ad unit'. These can be queried by the client and selectively
	/// approved. Approval causes a new ad unit to be created based on the suggested ad
	/// unit. Unapproved suggested ad units cease to exist whenever their corresponding
	/// ad tag has been served fewer than ten times in the past seven days.</p> <p>This
	/// service is only available to Premium publishers. Before use, suggested ad units
	/// must be enabled for the client's network. This can be done in the UI: in the
	/// Inventory tab, click "Network settings" in the left-hand panel, then enable the
	/// checkbox "Get suggestions for new ad units." If suggested ad units are not
	/// enabled, then <a
	/// href='#getSuggestedAdUnitsByStatement'>#getSuggestedAdUnitsByStatement</a> will
	/// always return an empty page.</p>
	/// </summary>
	public interface ISuggestedAdUnitService : SuggestedAdUnitServiceInterface, IDisposable
	{
	}


	/// <summary>Provides methods for creating, updating, and retrieving <a href='Team'>Team</a>
	/// objects. <p>Teams are used to group users in order to define access to entities
	/// such as companies, inventory and orders.</p>
	/// </summary>
	public interface ITeamService : TeamServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.Team[] createTeams(Google.Api.Ads.AdManager.v201802.Team[] teams);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Team[]> createTeamsAsync(Google.Api.Ads.AdManager.v201802.Team[] teams);

		Google.Api.Ads.AdManager.v201802.Team[] updateTeams(Google.Api.Ads.AdManager.v201802.Team[] teams);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Team[]> updateTeamsAsync(Google.Api.Ads.AdManager.v201802.Team[] teams);
	}


	/// <summary>Provides operations for creating, updating and retrieving <a
	/// href='User'>User</a> objects. <p>A user is assigned one of several different
	/// roles. Each <a href='Role'>Role</a> type has a unique ID that is used to
	/// identify that role in an organization. Role types and their IDs can be retrieved
	/// by invoking <a href='#getAllRoles'>#getAllRoles</a>.</p>
	/// </summary>
	public interface IUserService : UserServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.User[] createUsers(Google.Api.Ads.AdManager.v201802.User[] users);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.User[]> createUsersAsync(Google.Api.Ads.AdManager.v201802.User[] users);

		Google.Api.Ads.AdManager.v201802.Role[] getAllRoles();

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Role[]> getAllRolesAsync();

		Google.Api.Ads.AdManager.v201802.User[] updateUsers(Google.Api.Ads.AdManager.v201802.User[] users);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.User[]> updateUsersAsync(Google.Api.Ads.AdManager.v201802.User[] users);
	}


	/// <summary>Provides methods for creating, updating, and retrieving <a
	/// href='UserTeamAssociation'>UserTeamAssociation</a> objects.
	/// <p>UserTeamAssociation objects are used to add users to teams in order to define
	/// access to entities such as companies, inventory and orders and to override the
	/// team's access type to orders for a user.</p>
	/// </summary>
	public interface IUserTeamAssociationService : UserTeamAssociationServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] createUserTeamAssociations(Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] userTeamAssociations);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UserTeamAssociation[]> createUserTeamAssociationsAsync(Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] userTeamAssociations);

		Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] updateUserTeamAssociations(Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] userTeamAssociations);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.UserTeamAssociation[]> updateUserTeamAssociationsAsync(Google.Api.Ads.AdManager.v201802.UserTeamAssociation[] userTeamAssociations);
	}


	/// <summary>Provides methods to retrieve and perform actions on <a
	/// href='WorkflowRequest'>WorkflowRequest</a> objects <p>To use this service, you
	/// need to have the new sales management solution enabled on your network. If you
	/// do not see a "Sales" tab in <a href="https://www.google.com/dfp">DoubleClick for
	/// Publishers (DFP)</a>, you will not be able to use this service.</p>
	/// </summary>
	public interface IWorkflowRequestService : WorkflowRequestServiceInterface, IDisposable
	{
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='Package'>Package</a> objects. <p>To use this service, you need to have the
	/// new sales management solution enabled on your network. If you do not see a
	/// "Sales" tab in <a href="https://www.google.com/dfp">DoubleClick for Publishers
	/// (DFP)</a>, you will not be able to use this service.</p>
	/// </summary>
	public interface IPackageService : PackageServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.Package[] createPackages(Google.Api.Ads.AdManager.v201802.Package[] packages);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Package[]> createPackagesAsync(Google.Api.Ads.AdManager.v201802.Package[] packages);

		Google.Api.Ads.AdManager.v201802.Package[] updatePackages(Google.Api.Ads.AdManager.v201802.Package[] packages);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Package[]> updatePackagesAsync(Google.Api.Ads.AdManager.v201802.Package[] packages);
	}


	/// <summary>Provides methods for updating and retrieving <a
	/// href='ProductPackage'>ProductPackage</a> objects. <p>A <a
	/// href='ProductPackage'>ProductPackage</a> represents a group of products which
	/// will be sold together.</p> <p>To use this service, you need to have the new
	/// sales management solution enabled on your network. If you do not see a "Sales"
	/// tab in <a href="https://www.google.com/dfp">DoubleClick for Publishers
	/// (DFP)</a>, you will not be able to use this service.</p>
	/// </summary>
	public interface IProductPackageService : ProductPackageServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.ProductPackage[] createProductPackages(Google.Api.Ads.AdManager.v201802.ProductPackage[] productPackages);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductPackage[]> createProductPackagesAsync(Google.Api.Ads.AdManager.v201802.ProductPackage[] productPackages);

		Google.Api.Ads.AdManager.v201802.ProductPackage[] updateProductPackages(Google.Api.Ads.AdManager.v201802.ProductPackage[] productPackages);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductPackage[]> updateProductPackagesAsync(Google.Api.Ads.AdManager.v201802.ProductPackage[] productPackages);
	}


	/// <summary>Provides methods for creating and retrieving <a
	/// href='ProductPackageItem'>ProductPackageItem</a> objects. <p>A <a
	/// href='ProductPackageItem'>ProductPackageItem</a> represents a product which will
	/// be associated with a <a href=''>ProductPackage</a>.</p> <p>To use this service,
	/// you need to have the new sales management solution enabled on your network. If
	/// you do not see a "Sales" tab in <a href="https://www.google.com/dfp">DoubleClick
	/// for Publishers (DFP)</a>, you will not be able to use this service.</p>
	/// </summary>
	public interface IProductPackageItemService : ProductPackageItemServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.ProductPackageItem[] createProductPackageItems(Google.Api.Ads.AdManager.v201802.ProductPackageItem[] productPackageItems);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductPackageItem[]> createProductPackageItemsAsync(Google.Api.Ads.AdManager.v201802.ProductPackageItem[] productPackageItems);

		Google.Api.Ads.AdManager.v201802.ProductPackageItem[] updateProductPackageItems(Google.Api.Ads.AdManager.v201802.ProductPackageItem[] productPackageItems);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ProductPackageItem[]> updateProductPackageItemsAsync(Google.Api.Ads.AdManager.v201802.ProductPackageItem[] productPackageItems);
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='Contact'>Contact</a> objects.
	/// </summary>
	public interface IContactService : ContactServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.Contact[] createContacts(Google.Api.Ads.AdManager.v201802.Contact[] contacts);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Contact[]> createContactsAsync(Google.Api.Ads.AdManager.v201802.Contact[] contacts);

		Google.Api.Ads.AdManager.v201802.Contact[] updateContacts(Google.Api.Ads.AdManager.v201802.Contact[] contacts);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Contact[]> updateContactsAsync(Google.Api.Ads.AdManager.v201802.Contact[] contacts);
	}


	/// <summary>Provides methods for creating and retrieving <a
	/// href='NativeStyle'>NativeStyle</a> objects.
	/// </summary>
	public interface INativeStyleService : NativeStyleServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.NativeStyle[] createNativeStyles(Google.Api.Ads.AdManager.v201802.NativeStyle[] nativeStyles);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.NativeStyle[]> createNativeStylesAsync(Google.Api.Ads.AdManager.v201802.NativeStyle[] nativeStyles);

		Google.Api.Ads.AdManager.v201802.NativeStyle[] updateNativeStyles(Google.Api.Ads.AdManager.v201802.NativeStyle[] nativeStyles);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.NativeStyle[]> updateNativeStylesAsync(Google.Api.Ads.AdManager.v201802.NativeStyle[] nativeStyles);
	}


	/// <summary>Provides operations for creating, updating and retrieving <a
	/// href='AudienceSegment'>AudienceSegment</a> objects.
	/// </summary>
	public interface IAudienceSegmentService : AudienceSegmentServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] createAudienceSegments(Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] segments);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[]> createAudienceSegmentsAsync(Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] segments);

		Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] updateAudienceSegments(Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] segments);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[]> updateAudienceSegmentsAsync(Google.Api.Ads.AdManager.v201802.FirstPartyAudienceSegment[] segments);
	}


	/// <summary>Provides methods for managing <a href='BaseRate'>BaseRate</a> objects. <p>To use
	/// this service, you need to have the new sales management solution enabled on your
	/// network. If you do not see a "Sales" tab in <a
	/// href="https://www.google.com/dfp">DoubleClick for Publishers (DFP)</a>, you will
	/// not be able to use this service.</p>
	/// </summary>
	public interface IBaseRateService : BaseRateServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.BaseRate[] createBaseRates(Google.Api.Ads.AdManager.v201802.BaseRate[] baseRates);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.BaseRate[]> createBaseRatesAsync(Google.Api.Ads.AdManager.v201802.BaseRate[] baseRates);

		Google.Api.Ads.AdManager.v201802.BaseRate[] updateBaseRates(Google.Api.Ads.AdManager.v201802.BaseRate[] baseRates);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.BaseRate[]> updateBaseRatesAsync(Google.Api.Ads.AdManager.v201802.BaseRate[] baseRates);
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='CdnConfiguration'>CdnConfiguration</a> objects.
	/// </summary>
	public interface ICdnConfigurationService : CdnConfigurationServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.CdnConfiguration[] createCdnConfigurations(Google.Api.Ads.AdManager.v201802.CdnConfiguration[] cdnConfigurations);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CdnConfiguration[]> createCdnConfigurationsAsync(Google.Api.Ads.AdManager.v201802.CdnConfiguration[] cdnConfigurations);

		Google.Api.Ads.AdManager.v201802.CdnConfiguration[] updateCdnConfigurations(Google.Api.Ads.AdManager.v201802.CdnConfiguration[] cdnConfigurations);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.CdnConfiguration[]> updateCdnConfigurationsAsync(Google.Api.Ads.AdManager.v201802.CdnConfiguration[] cdnConfigurations);
	}


	/// <summary>Provides operations for creating, updating and retrieving <a
	/// href='Company'>Company</a> objects.
	/// </summary>
	public interface ICompanyService : CompanyServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.Company[] createCompanies(Google.Api.Ads.AdManager.v201802.Company[] companies);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Company[]> createCompaniesAsync(Google.Api.Ads.AdManager.v201802.Company[] companies);

		Google.Api.Ads.AdManager.v201802.Company[] updateCompanies(Google.Api.Ads.AdManager.v201802.Company[] companies);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.Company[]> updateCompaniesAsync(Google.Api.Ads.AdManager.v201802.Company[] companies);
	}


	/// <summary>Provides methods for creating, updating and retrieving <a
	/// href='ContentBundle'>ContentBundle</a> objects. <p>A <code>ContentBundle</code>
	/// is a grouping of <a href='Content'>Content</a> that match filter rules as well
	/// as taking into account explicitly included or excluded <code>Content</code>.</p>
	/// </summary>
	public interface IContentBundleService : ContentBundleServiceInterface, IDisposable
	{
		Google.Api.Ads.AdManager.v201802.ContentBundle[] createContentBundles(Google.Api.Ads.AdManager.v201802.ContentBundle[] contentBundles);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentBundle[]> createContentBundlesAsync(Google.Api.Ads.AdManager.v201802.ContentBundle[] contentBundles);

		Google.Api.Ads.AdManager.v201802.ContentBundle[] updateContentBundles(Google.Api.Ads.AdManager.v201802.ContentBundle[] contentBundles);

		System.Threading.Tasks.Task<Google.Api.Ads.AdManager.v201802.ContentBundle[]> updateContentBundlesAsync(Google.Api.Ads.AdManager.v201802.ContentBundle[] contentBundles);
	}
}
#pragma warning restore 1591
